#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# AUTO-GENERATED CONTENT
d_stem_ye = {"ye'e": {"ye'es": []},
             "ye'r": {"ye're": [], "ye'rs": []},
             "ye's": {"ye'se": []},
             "ye'v": {"ye've": []},
             'yea': ['yeaing'],
             "yea'r": {"yea'rs": []},
             'yeaa': {'yeaas': []},
             'yeaar': {'yeaars': []},
             'yeab': {'yeabs': []},
             'yeabsli': {'yeabsly': []},
             'yeac': {'yeace': [], 'yeacs': []},
             'yeacid': {'yeacides': []},
             'yeaco': {'yeacos': []},
             'yeacu': {'yeacus': []},
             'yead': {'yeading': ['yeadings'], 'yeads': []},
             'yeadi': {'yeady': []},
             'yeading': ['yeadings'],
             'yeae': {'yeaes': []},
             'yeaer': {'yeaers': []},
             'yeaf': {'yeafs': []},
             'yeafr': {'yeafrs': []},
             'yeager': {'yeagers': []},
             'yeagi': {'yeagy': []},
             'yeagl': {'yeagle': []},
             'yeah': {'yeahs': []},
             'yeai': {'yeais': []},
             'yeaij': {'yeaijs': []},
             'yeaili': {'yeaily': []},
             'yeair': {'yeairs': []},
             'yeaj': {'yeajs': []},
             'yeajr': {'yeajrs': []},
             'yeak': {'yeaks': []},
             'yeakel': {'yeakell': []},
             'yeakl': {'yeakle': []},
             'yeal': {'yeale': ['yealed', 'yeales'], 'yeals': []},
             'yealand': {'yealands': []},
             'yeald': {'yealde': ['yealded'], 'yealding': [], 'yealds': []},
             'yealde': ['yealded'],
             'yeale': ['yealed', 'yeales'],
             'yeali': {'yealy': []},
             'yeallow': {'yeallowe': []},
             'yealm': {'yealme': [], 'yealms': []},
             'yealou': {'yealous': []},
             'yeam': {'yeamed': [], 'yeames': [], 'yeaming': ['yeamings'], 'yeams': []},
             'yeaman': {'yeamans': []},
             'yeamen': {'yeamens': []},
             'yeaming': ['yeamings'],
             'yeamon': {'yeamons': []},
             'yean': {'yeaned': [], 'yeaning': [], 'yeans': []},
             'yeandl': {'yeandle': []},
             'yeani': {'yeany': []},
             'yeanl': {'yeanling': ['yeanlings']},
             'yeanling': ['yeanlings'],
             'yeao': {'yeaos': []},
             'yeap': {'yeaps': []},
             'yeapl': {'yeaple': []},
             'year': ['yeare',
                      'yeares',
                      'yeared',
                      'yearely',
                      'yearful',
                      'yearing',
                      'yearings',
                      'yearrings'],
             "year'": {"year'e": [], "year's": []},
             'year-old': {'year-olds': []},
             'yeara': {'yearas': []},
             'yearaft': {'yearafter': []},
             'yearag': {'yearage': []},
             'yearanc': {'yearance': []},
             'yearanniversari': {'yearanniversary': []},
             'yearar': {'yearare': []},
             'yearaverag': {'yearaverage': []},
             'yearbear': {'yearbearer': ['yearbearers']},
             'yearbearer': ['yearbearers'],
             'yearbefor': {'yearbefore': []},
             'yearbi': {'yearby': []},
             'yearbook': {'yearbook': []},
             'yearbri': {'yearbry': []},
             'yearc': {'yearcs': []},
             'yearclass': {'yearclasses': []},
             'yearcolleg': {'yearcollege': []},
             'yearcours': {'yearcourse': []},
             'yearcycl': {'yearcycle': []},
             'yeard': {'yearde': ['yeardes'], 'yeards': []},
             'yeardat': {'yeardate': ['yeardates']},
             'yeardate': ['yeardates'],
             'yearday': {'yeardays': []},
             'yearde': ['yeardes'],
             'yeardlci': {'yeardlcy': []},
             'yeardley': {'yeardleys': []},
             'yeardli': {'yeardly': []},
             'yearearli': {'yearearlier': []},
             'yeareli': {'yearelie': []},
             'yearely': {'yearelye': []},
             'yearend': {'yearended': [],
                         'yearender': [],
                         'yearending': [],
                         'yearends': []},
             'yearer': {'yearers': []},
             'yearf': {'yearfe': [], 'yearfs': []},
             'yearfi': {'yearfy': []},
             'yeargan': {'yeargans': []},
             'yearger': {'yeargers': []},
             'yeargroup': {'yeargroups': []},
             'yearh': {'yearhe': []},
             'yearhistori': {'yearhistory': []},
             'yearhook': {'yearhooks': []},
             'yeari': {'yearis': [], 'yeary': []},
             'yearinterv': {'yearinterval': []},
             'yearj': {'yearjs': []},
             'yearji': {'yearjy': []},
             'yearl': {'yearling': [], 'yearls': []},
             'yearlat': {'yearlater': []},
             'yearli': {'yearlie': [], 'yearly': []},
             'yearlin': {'yearlins': []},
             'yearly': {'yearlye': []},
             'yearlyko': {'yearlykos': []},
             'yearlymeet': {'yearlymeeting': []},
             'yearn': {'yearne': ['yearned'],
                       'yearnful': ['yearnfully'],
                       'yearning': [],
                       'yearns': []},
             'yearnam': {'yearnames': []},
             'yearne': ['yearned'],
             'yearner': {'yearner': []},
             'yearnful': ['yearnfully'],
             'yearningli': {'yearningly': []},
             'yearnumb': {'yearnumber': []},
             'yearo': {'yearos': []},
             'yearold': {'yearolder': [], 'yearoldness': [], 'yearolds': []},
             'yearon': {'yearone': []},
             'yearonli': {'yearonly': []},
             'yearou': {'yearous': []},
             'yearov': {'yearover': []},
             'yearperiod': {'yearperiods': []},
             'yearplan': {'yearplans': []},
             'yearplu': {'yearplus': []},
             'yearr': {'yearrs': []},
             'yearreleas': {'yearreleased': []},
             'yearround': {'yearrounders': []},
             'years': {'yearse': []},
             'yearsa': {'yearsas': []},
             'yearsaft': {'yearsafter': []},
             'yearsafterward': {'yearsafterwards': []},
             'yearsar': {'yearsare': []},
             'yearsbefor': {'yearsbefore': []},
             'yearsdigit': {'yearsdigits': []},
             'yearsearli': {'yearsearlier': []},
             'yearsh': {'yearshe': []},
             'yearsha': {'yearshas': []},
             'yearshav': {'yearshave': []},
             'yearsi': {'yearsis': [], 'yearsy': []},
             'yearslat': {'yearslater': []},
             'yearsley': {'yearsleys': []},
             'yearsli': {'yearsly': []},
             'yearsofag': {'yearsofage': []},
             'yearsold': {'yearsolder': [], 'yearsolds': []},
             'yearspecif': {'yearspecific': []},
             'yearssinc': {'yearssince': []},
             'yearsth': {'yearsthe': []},
             'yearstudi': {'yearstudy': []},
             'yearsurviv': {'yearsurvival': []},
             'yearswa': {'yearswas': []},
             'yearswer': {'yearswere': []},
             'yearsyear': {'yearsyears': []},
             'yearsyearsyearsyearsyear': {'yearsyearsyearsyearsyears': []},
             'yearsyoung': {'yearsyounger': []},
             'yeart': {'yearts': []},
             'yearterm': {'yearterms': []},
             'yearth': {'yearthe': []},
             'yearther': {'yearthere': []},
             'yearthli': {'yearthly': []},
             'yearthquak': {'yearthquakes': []},
             'yearti': {'yearty': []},
             'yeartim': {'yeartime': []},
             'yearwa': {'yearwas': []},
             'yearweek': {'yearweeks': []},
             'yearwis': {'yearwise': []},
             'yearyoung': {'yearyounger': []},
             'yeas': {'yease': []},
             'yeasay': {'yeasayer': ['yeasayers'], 'yeasaying': []},
             'yeasayer': ['yeasayers'],
             'yeasr': {'yeasrs': []},
             'yeast': ['yeaste', 'yeasted', 'yeasting'],
             'yeastbas': {'yeastbased': []},
             'yeastcak': {'yeastcake': ['yeastcakes']},
             'yeastcake': ['yeastcakes'],
             'yeastcel': {'yeastcell': ['yeastcells']},
             'yeastcell': ['yeastcells'],
             'yeastcontain': {'yeastcontaining': []},
             'yeastderiv': {'yeastderived': []},
             'yeastfre': {'yeastfree': []},
             'yeasti': {'yeasties': [], 'yeastiness': [], 'yeasty': []},
             'yeastili': {'yeastily': []},
             'yeastleaven': {'yeastleavened': []},
             'yeastlik': {'yeastlike': []},
             'yeastol': {'yeastolate': []},
             'yeastphas': {'yeastphase': []},
             'yeastrais': {'yeastraised': []},
             'yeastwat': {'yeastwater': []},
             'yeat': {'yeate': ['yeates'], 'yeating': [], 'yeats': []},
             'yeatc': {'yeatcs': []},
             'yeate': ['yeates'],
             'yeatli': {'yeatly': []},
             'yeatman': {'yeatmans': []},
             'yeatmanbigg': {'yeatmanbiggs': []},
             'yeaton': {'yeatons': []},
             'yeatr': {'yeatrs': []},
             'yeats': {'yeats': []},
             'yeatsian': {'yeatsians': []},
             'yeatt': {'yeatts': []},
             'yeau': {'yeaus': []},
             'yeav': {'yeavs': []},
             'yeaver': {'yeavering': []},
             'yeay': {'yeays': []},
             'yeazel': {'yeazell': []},
             'yeazi': {'yeazie': []},
             'yebaw': {'yebaws': []},
             'yebe': {'yebes': []},
             'yeben': {'yebenes': []},
             'yebi': {'yebis': []},
             'yebk': {'yebkes': []},
             'yebrow': {'yebrows': []},
             'yebu': {'yebus': []},
             'yebutiu': {'yebutius': []},
             'yec': {'yecs': []},
             'yecal': {'yecall': []},
             'yech': {'yeche': ['yeches']},
             'yeche': ['yeches'],
             'yechi': {'yechieli': []},
             'yechidu': {'yechidus': []},
             'yechuri': {'yechury': []},
             'yeci': {'yecies': []},
             'yecir': {'yecirs': []},
             'yeck': {'yecke': ['yeckes']},
             'yecke': ['yeckes'],
             'yecol': {'yecole': []},
             'yecr': {'yecre': ['yecres'], 'yecrs': []},
             'yecre': ['yecres'],
             'yect': {'yects': []},
             'yector': {'yectors': []},
             'yed': {'yedded': [], 'yedding': [], 'yeds': []},
             'yeda': {'yedas': []},
             'yedabb': {'yedabber': []},
             'yedant': {'yedantic': []},
             'yedantist': {'yedantists': []},
             'yedash': {'yedashe': []},
             'yedator': {'yedatore': []},
             'yedav': {'yedavalli': []},
             'yeddah': {'yeddahs': []},
             'yeddanap': {'yeddanapalli': []},
             'yeddi': {'yeddie': [], 'yeddy': []},
             'yedding': {'yeddinges': []},
             'yeddyng': {'yeddynges': []},
             'yede': {'yedes': []},
             'yedi': {'yedies': [], 'yedy': []},
             'yedig': {'yediger': []},
             'yedikul': {'yedikule': []},
             'yedil': {'yedile': ['yediles', 'yediler']},
             'yedile': ['yediles', 'yediler'],
             'yeditep': {'yeditepe': []},
             'yedoens': {'yedoense': []},
             'yedoensi': {'yedoensis': []},
             'yedr': {'yedrs': []},
             'yedra': {'yedras': []},
             'yedro': {'yedros': []},
             'yeduan': {'yeduans': []},
             'yee': {'yees': []},
             'yeear': {'yeears': []},
             'yeee': {'yeees': []},
             'yeeee': {'yeeees': []},
             'yeeeee': {'yeeeees': []},
             'yeeeeee': {'yeeeeees': []},
             'yeeeeeee': {'yeeeeeees': []},
             'yeehat': {'yeehats': []},
             'yeeho': {'yeehoing': []},
             'yeek': {'yeeks': []},
             'yeel': {'yeeled': [], 'yeeles': [], 'yeeling': []},
             'yeeld': {'yeelde': ['yeeldes', 'yeelded'], 'yeelding': [], 'yeelds': []},
             'yeelde': ['yeeldes', 'yeelded'],
             'yeelding': {'yeeldinge': []},
             'yeelirri': {'yeelirrie': []},
             'yeen': {'yeens': []},
             'yeep': {'yeeping': [], 'yeeps': []},
             'yeer': {'yeere': ['yeeres', 'yeerely'], 'yeers': []},
             'yeerc': {'yeercs': []},
             'yeere': ['yeeres', 'yeerely'],
             'yeereli': {'yeerelie': []},
             'yeeri': {'yeeris': [], 'yeerys': []},
             'yeerk': {'yeerks': []},
             'yeerli': {'yeerlie': [], 'yeerly': []},
             'yeerongpilli': {'yeerongpilly': []},
             'yeerselv': {'yeerselves': []},
             'yeet': {'yeetes': [], 'yeets': []},
             'yefcr': {'yefcrs': []},
             'yefe': {'yefes': []},
             'yeff': {'yeffe': []},
             'yefim': {'yefime': []},
             'yefir': {'yefirs': []},
             'yefski': {'yefsky': []},
             'yeft': {'yefte': ['yeftes']},
             'yefte': ['yeftes'],
             'yeftr': {'yeftrs': []},
             'yeg': {'yegs': []},
             'yega': {'yegas': []},
             'yegb': {'yegbe': []},
             'yegean': {'yegeans': []},
             'yegerlehn': {'yegerlehner': []},
             'yeget': {'yegetable': ['yegetables'], 'yegetation': []},
             'yegetable': ['yegetables'],
             'yegetiu': {'yegetius': []},
             'yegeu': {'yegeus': []},
             'yegg': {'yegge': [], 'yeggs': []},
             'yegh': {'yeghe': []},
             'yeghiazarian': {'yeghiazarians': []},
             'yeghish': {'yeghishe': []},
             'yegi': {'yegis': []},
             'yegidi': {'yegidis': []},
             'yegidiu': {'yegidius': []},
             'yeginetan': {'yeginetans': []},
             'yegish': {'yegishe': []},
             'yegisthu': {'yegisthus': []},
             'yeglich': {'yeglicher': []},
             'yegn': {'yegnes': []},
             'yego': {'yegos': []},
             'yegor': {'yegors': []},
             'yegori': {'yegory': []},
             'yegorov': {'yegorovs': []},
             'yegr': {'yegrs': []},
             'yegro': {'yegros': []},
             'yegua': {'yeguas': []},
             'yeguaensi': {'yeguaensis': []},
             'yeguar': {'yeguare': []},
             'yegyptu': {'yegyptus': []},
             'yeh': {'yehs': []},
             "yeh'r": {"yeh're": []},
             "yeh'v": {"yeh've": []},
             'yehav': {'yehave': []},
             'yehem': {'yehemence': []},
             'yehezk': {'yehezkeli': []},
             'yehhuh': {'yehhuhs': []},
             'yehi': {'yehieli': []},
             'yehicl': {'yehicle': ['yehicles']},
             'yehicle': ['yehicles'],
             'yehim': {'yehime': []},
             'yehl': {'yehle': [], 'yehling': []},
             'yehp': {'yehping': []},
             'yehud': {'yehude': []},
             'yehuda': {'yehudas': []},
             'yehudi': {'yehudis': []},
             'yehudit': {'yehudite': ['yehudites']},
             'yehudite': ['yehudites'],
             'yehupet': {'yehupets': []},
             'yehw': {'yehwe': []},
             'yei': {'yeis': []},
             'yeiar': {'yeiars': []},
             'yeid': {'yeide': []},
             'yeiir': {'yeiirs': []},
             'yeil': {'yeiled': []},
             'yeild': {'yeilde': ['yeildes', 'yeilded'], 'yeilding': [], 'yeilds': []},
             'yeilde': ['yeildes', 'yeilded'],
             'yein': {'yeins': []},
             'yeir': {'yeire': ['yeires'], 'yeirs': []},
             'yeire': ['yeires'],
             'yeiri': {'yeiris': []},
             'yeirli': {'yeirlie': [], 'yeirly': []},
             'yeiwen': {'yeiwene': []},
             'yejar': {'yejars': []},
             'yejhal': {'yejhall': []},
             'yejiani': {'yejianying': []},
             'yejid': {'yejide': []},
             'yejir': {'yejirs': []},
             'yejr': {'yejrs': []},
             'yek': {'yeks': []},
             'yekaterini': {'yekateriny': []},
             'yekaterininski': {'yekaterininsky': []},
             'yekaterinski': {'yekaterinsky': []},
             'yeke': {'yekes': []},
             'yekel': {'yekele': []},
             'yekk': {'yekke': ['yekkes']},
             'yekke': ['yekkes'],
             'yekr': {'yekrs': []},
             'yekuti': {'yekutieli': []},
             'yel': {'yels': []},
             'yela': {'yelas': []},
             'yelaguin': {'yelaguine': []},
             'yelamo': {'yelamos': []},
             'yelar': {'yelars': []},
             'yeld': {'yelde': ['yelded', 'yeldes'], 'yelding': [], 'yelds': []},
             'yeldal': {'yeldall': []},
             'yelde': ['yelded', 'yeldes'],
             'yeldehal': {'yeldehalle': []},
             'yeldel': {'yeldell': []},
             'yelder': {'yelderes': []},
             'yeldhal': {'yeldhall': []},
             'yeldi': {'yeldis': []},
             'yelding': {'yeldinge': ['yeldinges']},
             'yeldinge': ['yeldinges'],
             'yeldyng': {'yeldynge': []},
             'yele': {'yeled': [], 'yeles': [], 'yeling': []},
             'yelek': {'yeleks': []},
             'yelel': {'yelele': []},
             'yelencs': {'yelencsics': []},
             'yelenoski': {'yelenosky': []},
             'yelenski': {'yelensky': []},
             'yelep': {'yeleped': []},
             'yelet': {'yelets': []},
             'yeletski': {'yeletsky': []},
             'yelfr': {'yelfred': []},
             'yelfwin': {'yelfwine': []},
             'yelgand': {'yelgandal': []},
             'yeli': {'yely': []},
             'yelianu': {'yelianus': []},
             'yelid': {'yelids': []},
             'yeliman': {'yelimane': []},
             'yeliseyevski': {'yeliseyevsky': []},
             'yeliu': {'yelius': []},
             'yelk': {'yelks': []},
             'yelkdivis': {'yelkdivision': []},
             'yelkhovski': {'yelkhovsky': []},
             'yell': ['yelle', 'yelles', 'yelled', 'yelling'],
             'yella': {'yellas': []},
             'yellala': {'yellalas': []},
             'yelland': {'yellands': []},
             'yellareddi': {'yellareddy': []},
             'yelleiu': {'yelleius': []},
             'yeller': {'yeller': []},
             'yelleri': {'yellery': []},
             'yellerston': {'yellerstone': []},
             'yelli': {'yellis': [], 'yelly': []},
             'yellin': {'yellins': []},
             'yello': {'yelloe': [], 'yellos': []},
             'yelloch': {'yelloched': []},
             'yellocut': {'yellocute': [], 'yellocution': []},
             'yelloli': {'yelloly': []},
             'yellor': {'yellore': []},
             'yellow': ['yellowe',
                        'yellowes',
                        'yellowed',
                        'yellower',
                        'yellowing',
                        'yellowism',
                        'yellowings',
                        'yellowness'],
             'yellowback': {'yellowbacked': [], 'yellowbacks': []},
             'yellowband': {'yellowbanded': []},
             'yellowbank': {'yellowbanks': []},
             'yellowbark': {'yellowbarked': []},
             'yellowbeak': {'yellowbeaked': []},
             'yellowbeard': {'yellowbearded': []},
             'yellowbel': {'yellowbells': []},
             'yellowbelli': {'yellowbellied': [], 'yellowbellies': [], 'yellowbelly': []},
             'yellowberri': {'yellowberried': [], 'yellowberries': [], 'yellowberry': []},
             'yellowbi': {'yellowby': []},
             'yellowbil': {'yellowbill': ['yellowbilled']},
             'yellowbill': ['yellowbilled'],
             'yellowbird': {'yellowbird': []},
             'yellowblaz': {'yellowblazed': []},
             'yellowblossom': {'yellowblossomed': []},
             'yellowblu': {'yellowblue': []},
             'yellowbodi': {'yellowbodied': []},
             'yellowbord': {'yellowbordered': []},
             'yellowboy': {'yellowboys': []},
             'yellowbreast': {'yellowbreasted': []},
             'yellowbreech': {'yellowbreeched': []},
             'yellowbrow': {'yellowbrowed': []},
             'yellowbrown': {'yellowbrowns': []},
             'yellowcak': {'yellowcake': []},
             'yellowcent': {'yellowcentered': []},
             'yellowcentr': {'yellowcentred': []},
             'yellowcheck': {'yellowchecked': []},
             'yellowcheek': {'yellowcheeked': []},
             'yellowco': {'yellowcoated': []},
             'yellowcolor': {'yellowcolored': []},
             'yellowcolour': {'yellowcoloured': []},
             'yellowcov': {'yellowcovered': []},
             'yellowcrest': {'yellowcrested': []},
             'yellowcrown': {'yellowcrowned': []},
             'yellowcup': {'yellowcups': []},
             'yellowdi': {'yellowdyed': []},
             'yellowdin': {'yellowdine': []},
             'yellowedg': {'yellowedge': ['yellowedged']},
             'yellowedge': ['yellowedged'],
             'yellowey': {'yelloweye': ['yelloweyes', 'yelloweyed']},
             'yelloweye': ['yelloweyes', 'yelloweyed'],
             'yellowfac': {'yellowface': ['yellowfaced']},
             'yellowface': ['yellowfaced'],
             'yellowfeath': {'yellowfeathered': []},
             'yellowfev': {'yellowfever': []},
             'yellowfin': {'yellowfin': []},
             'yellowfing': {'yellowfingers': []},
             'yellowfleck': {'yellowflecked': []},
             'yellowflesh': {'yellowfleshed': []},
             'yellowfli': {'yellowfly': []},
             'yellowflow': {'yellowflowered': [],
                            'yellowflowering': [],
                            'yellowflowers': []},
             'yellowfoot': {'yellowfooted': []},
             'yellowfring': {'yellowfringed': []},
             'yellowfront': {'yellowfronted': []},
             'yellowfruit': {'yellowfruited': []},
             'yellowglaz': {'yellowglazed': []},
             'yellowglov': {'yellowgloved': []},
             'yellowgrain': {'yellowgrained': []},
             'yellowgreen': {'yellowgreens': []},
             'yellowhair': {'yellowhaired': []},
             'yellowhamm': {'yellowhammer': []},
             'yellowhandl': {'yellowhandled': []},
             'yellowhead': {'yellowheaded': [], 'yellowheads': []},
             'yellowhors': {'yellowhorse': []},
             'yellowhous': {'yellowhouse': []},
             'yellowi': {'yellowis': [], 'yellowy': []},
             'yellowish': {'yellowishness': []},
             'yellowishcolor': {'yellowishcolored': []},
             'yellowishcolour': {'yellowishcoloured': []},
             'yellowishli': {'yellowishly': []},
             'yellowishol': {'yellowisholive': []},
             'yellowishorang': {'yellowishorange': []},
             'yellowishr': {'yellowishred': []},
             'yellowishwhit': {'yellowishwhite': []},
             'yellowjacket': {'yellowjacketed': [], 'yellowjackets': []},
             'yellowjohn': {'yellowjohns': []},
             'yellowjourn': {'yellowjournalism': []},
             'yellowkn': {'yellowknives': []},
             'yellowknif': {'yellowknife': ['yellowknifer', 'yellowknifers']},
             'yellowknife': ['yellowknifer', 'yellowknifers'],
             'yellowle': {'yellowlees': []},
             'yellowleaf': {'yellowleafed': []},
             'yellowleav': {'yellowleaved': []},
             'yellowleg': {'yellowlegged': [], 'yellowlegs': []},
             'yellowley': {'yellowleys': []},
             'yellowli': {'yellowly': []},
             'yellowlight': {'yellowlighted': []},
             'yellowlin': {'yellowlined': []},
             'yellowliv': {'yellowlivered': []},
             'yellowlook': {'yellowlooking': []},
             'yellowman': {'yellowmaned': []},
             'yellowmargin': {'yellowmargined': []},
             'yellowmark': {'yellowmarked': []},
             'yellowmet': {'yellowmetal': []},
             'yellowneck': {'yellownecked': []},
             'yellownos': {'yellownosed': []},
             'yellowochr': {'yellowochre': []},
             'yellowol': {'yellowolive': []},
             'yelloworang': {'yelloworange': ['yelloworanges']},
             'yelloworange': ['yelloworanges'],
             'yellowpag': {'yellowpage': ['yellowpages']},
             'yellowpage': ['yellowpages'],
             'yellowpaint': {'yellowpainted': []},
             'yellowpap': {'yellowpapered': []},
             'yellowpig': {'yellowpigmented': []},
             'yellowpin': {'yellowpine': []},
             'yellowquil': {'yellowquill': []},
             'yellowr': {'yellowred': ['yellowreds']},
             'yellowred': ['yellowreds'],
             'yellowrim': {'yellowrimmed': []},
             'yellowring': {'yellowringed': []},
             'yellowriv': {'yellowriver': []},
             'yellowrob': {'yellowrobe': ['yellowrobed']},
             'yellowrobe': ['yellowrobed'],
             'yellowroof': {'yellowroofed': []},
             'yellowrump': {'yellowrumped': [], 'yellowrumps': []},
             'yellowsand': {'yellowsands': []},
             'yellowseed': {'yellowseeded': []},
             'yellowsensit': {'yellowsensitive': []},
             'yellowshad': {'yellowshaded': []},
             'yellowshaft': {'yellowshafted': []},
             'yellowshank': {'yellowshanks': []},
             'yellowshirt': {'yellowshirted': [], 'yellowshirts': []},
             'yellowshould': {'yellowshouldered': []},
             'yellowskin': {'yellowskinned': [], 'yellowskins': []},
             'yellowspot': {'yellowspots': [], 'yellowspotted': []},
             'yellowspr': {'yellowsprings': []},
             'yellowstain': {'yellowstained': []},
             'yellowstar': {'yellowstarred': []},
             'yellowstarch': {'yellowstarched': []},
             'yellowston': {'yellowstone': []},
             'yellowstonensi': {'yellowstonensis': []},
             'yellowstreak': {'yellowstreaked': []},
             'yellowstrip': {'yellowstripe': ['yellowstriped']},
             'yellowstripe': ['yellowstriped'],
             'yellowtail': ['yellowtailed'],
             'yellowthro': {'yellowthroated': []},
             'yellowthroat': {'yellowthroat': []},
             'yellowthund': {'yellowthunder': []},
             'yellowtil': {'yellowtiled': []},
             'yellowting': {'yellowtinged': []},
             'yellowtint': {'yellowtinted': []},
             'yellowtip': {'yellowtipped': []},
             'yellowton': {'yellowtoned': []},
             'yellowtooth': {'yellowtoothed': []},
             'yellowtop': {'yellowtopped': []},
             'yellowtrim': {'yellowtrimmed': []},
             'yellowvarieg': {'yellowvariegated': []},
             'yellowwal': {'yellowwalled': []},
             'yellowwar': {'yellowware': []},
             'yellowwash': {'yellowwashed': []},
             'yellowwe': {'yellowweed': []},
             'yellowweath': {'yellowweathering': []},
             'yellowwheel': {'yellowwheeled': []},
             'yellowwhit': {'yellowwhite': []},
             'yellowwing': {'yellowwinged': []},
             'yellowwood': {'yellowwood': []},
             'yellowyorang': {'yellowyorange': []},
             'yellowywhit': {'yellowywhite': []},
             'yellvil': {'yellville': []},
             'yelm': {'yelms': []},
             'yelmo': {'yelmos': []},
             'yelnat': {'yelnats': []},
             'yelnoski': {'yelnosky': []},
             'yelo': {'yelos': []},
             'yeloc': {'yelocity': []},
             'yelokhovski': {'yelokhovsky': []},
             'yelop': {'yeloped': [], 'yelopment': []},
             'yelow': {'yelowe': []},
             'yelowness': {'yelownesse': []},
             'yelowston': {'yelowstone': []},
             'yelp': ['yelpe', 'yelped', 'yelping'],
             'yelper': {'yelpers': []},
             'yelpi': {'yelpy': []},
             'yelt': {'yeltes': [], 'yelts': []},
             'yeltatzi': {'yeltatzie': []},
             'yeltoniensi': {'yeltoniensis': []},
             'yeltsin': {'yeltsinism': [], 'yeltsins': []},
             'yeltsinit': {'yeltsinite': ['yeltsinites']},
             'yeltsinite': ['yeltsinites'],
             'yeluru': {'yelurus': []},
             'yelv': {'yelves': []},
             'yelvert': {'yelvertou': []},
             'yelverton': {'yelvertons': []},
             'yelvi': {'yelvis': []},
             'yelw': {'yelwe': []},
             'yem': {'yems': []},
             'yema': {'yemas': []},
             'yeman': {'yemane': [], 'yemans': []},
             'yemanit': {'yemanite': []},
             'yemanj': {'yemanje': []},
             'yemanli': {'yemanly': []},
             'yemann': {'yemannes': []},
             'yemanri': {'yemanry': []},
             'yemase': {'yemasee': ['yemasees']},
             'yemasee': ['yemasees'],
             'yemass': {'yemasse': ['yemasses']},
             'yemasse': {'yemassee': ['yemassees']},
             'yemassee': ['yemassees'],
             'yemb': {'yembe': []},
             'yemen': {'yemen': []},
             'yemenes': {'yemenese': []},
             'yemeni': {'yemeni': [], 'yemeny': []},
             'yemenit': {'yemenite': ['yemenites'], 'yemenitic': []},
             'yemenite': ['yemenites'],
             'yemet': {'yemets': []},
             'yemi': {'yemis': []},
             'yemil': {'yemile': []},
             'yemilianu': {'yemilianus': []},
             'yemiliu': {'yemilius': []},
             'yemini': {'yeminis': []},
             'yeminit': {'yeminite': ['yeminites']},
             'yeminite': ['yeminites'],
             'yemiss': {'yemission': []},
             'yemist': {'yemistes': []},
             'yemit': {'yemitting': []},
             'yemitt': {'yemitters': []},
             'yemm': {'yemme': []},
             'yemo': {'yemos': []},
             'yemp': {'yemps': []},
             'yemr': {'yemrs': []},
             'yemstchik': {'yemstchiks': []},
             'yen': ['yenned', 'yenning'],
             'yena': {'yenas': []},
             'yenabl': {'yenable': ['yenables']},
             'yenable': ['yenables'],
             'yenadi': {'yenadies': [], 'yenadis': []},
             'yenadizz': {'yenadizze': []},
             'yenawin': {'yenawine': []},
             'yenbas': {'yenbased': []},
             'yenbook': {'yenbooks': []},
             'yenc': {'yence': []},
             'yenca': {'yencas': []},
             'yencess': {'yencesse': []},
             'yench': {'yenche': [], 'yenching': []},
             'yend': {'yende': ['yendes']},
             'yendal': {'yendale': [], 'yendall': []},
             'yendat': {'yendats': []},
             'yenddm': {'yenddme': []},
             'yende': {'yendee': []},
             'yendean': {'yendeans': []},
             'yendel': {'yendell': []},
             'yendemiair': {'yendemiaire': []},
             'yendenomin': {'yendenominated': []},
             'yendi': {'yendis': [], 'yendys': []},
             'yendl': {'yendle': []},
             'yendom': {'yendome': []},
             'yendos': {'yendose': []},
             'yendot': {'yendots': []},
             'yene': {'yened': [], 'yenes': [], 'yening': []},
             'yenea': {'yeneas': []},
             'yenega': {'yenegas': []},
             'yenei': {'yeneis': []},
             'yeneid': {'yeneids': []},
             'yener': {'yenerable': [],
                       'yeneral': ['yenerals', 'yenerally'],
                       'yenerated': [],
                       'yeneration': []},
             'yeneral': {'yenerall': []},
             'yenesidemu': {'yenesidemus': []},
             'yenetian': {'yenetians': []},
             'yeng': {'yenge': [], 'yengs': []},
             'yengari': {'yengarie': []},
             'yenge': {'yengee': ['yengees']},
             'yengeanc': {'yengeance': []},
             'yengee': ['yengees'],
             'yengees': {'yengeese': []},
             'yenghi': {'yenghies': []},
             'yengu': {'yengue': [], 'yengus': []},
             'yenh': {'yenhe': []},
             'yeni': {'yenis': [], 'yeny': []},
             'yenic': {'yenice': []},
             'yenical': {'yenicale': []},
             'yenidj': {'yenidje': []},
             'yenidz': {'yenidze': []},
             'yenij': {'yenije': []},
             'yenikal': {'yenikale': []},
             'yenimahal': {'yenimahalle': []},
             'yenis': {'yenise': ['yeniseic']},
             'yenise': {'yenisee': []},
             'yeniseian': {'yeniseian': []},
             'yenit': {'yenite': []},
             'yeniti': {'yenity': []},
             'yeniu': {'yenius': []},
             'yenizelo': {'yenizelos': []},
             'yenj': {'yenjing': []},
             'yenk': {'yenke': [], 'yenking': []},
             'yenke': {'yenkee': ['yenkees']},
             'yenkee': ['yenkees'],
             'yenl': {'yenling': []},
             'yenn': {'yenne': ['yennes'], 'yenns': []},
             'yennadio': {'yennadios': []},
             'yenne': ['yennes'],
             'yenni': {'yennie': [], 'yenny': []},
             'yeno': {'yenos': []},
             'yenofski': {'yenofsky': []},
             'yenosk': {'yenoske': []},
             'yenosuk': {'yenosuke': []},
             'yenou': {'yenous': []},
             'yenough': {'yenoughe': []},
             'yenowin': {'yenowine': []},
             'yenp': {'yenping': []},
             'yenr': {'yenre': [], 'yenrs': []},
             'yenrli': {'yenrly': []},
             'yensavag': {'yensavage': []},
             'yenshe': {'yenshee': []},
             'yent': {'yente': ['yentes', 'yented'], 'yenting': [], 'yents': []},
             'yenta': {'yenta': []},
             'yente': ['yentes', 'yented'],
             'yentekaki': {'yentekakis': []},
             'yenti': {'yentis': [], 'yenty': []},
             'yentidiu': {'yentidius': []},
             'yentil': {'yentilation': []},
             'yentli': {'yently': []},
             'yentral': {'yentrally': [], 'yentrals': []},
             'yentricl': {'yentricle': []},
             'yentur': {'yenture': ['yentured']},
             'yenture': ['yentured'],
             'yenu': {'yenue': [], 'yenus': []},
             'yenukidz': {'yenukidze': []},
             'yenus': {'yenuses': []},
             'yenvil': {'yenville': []},
             'yenworthi': {'yenworthy': []},
             'yeny': {'yenye': []},
             'yenyew': {'yenyewe': []},
             'yeo': {'yeos': []},
             'yeobright': {'yeobrights': []},
             'yeohle': {'yeohlee': []},
             'yeol': {'yeole': []},
             'yeoli': {'yeolis': []},
             'yeolian': {'yeolians': []},
             'yeolist': {'yeolists': []},
             'yeolu': {'yeolus': []},
             'yeoman': {'yeoman': []},
             'yeomandri': {'yeomandrie': [], 'yeomandry': []},
             'yeomanett': {'yeomanette': ['yeomanettes']},
             'yeomanette': ['yeomanettes'],
             'yeomanfarm': {'yeomanfarmer': ['yeomanfarmers']},
             'yeomanfarmer': ['yeomanfarmers'],
             'yeomani': {'yeomany': []},
             'yeomanli': {'yeomanly': []},
             'yeomanlik': {'yeomanlike': []},
             'yeomanri': {'yeomanrie': [], 'yeomanry': []},
             'yeomauri': {'yeomaury': []},
             'yeomen': {'yeoman': []},
             'yeomenprick': {'yeomenprickers': []},
             'yeomenri': {'yeomenry': []},
             'yeon': {'yeons': []},
             'yeopl': {'yeople': []},
             'yeor': {'yeore': [], 'yeors': []},
             'yeorghio': {'yeorghios': []},
             'yeorgio': {'yeorgios': []},
             'yeorgo': {'yeorgos': []},
             'yeorli': {'yeorly': []},
             'yeoryio': {'yeoryios': []},
             'yeothoma': {'yeothomas': []},
             'yeovil': {'yeovill': ['yeoville']},
             'yeovill': ['yeoville'],
             'yeowel': {'yeowell': []},
             'yeowl': {'yeowled': [], 'yeowling': []},
             'yep': {'yeps': []},
             'yepa': {'yepas': []},
             'yepach': {'yepachic': []},
             'yepanchin': {'yepanchins': []},
             'yepavo': {'yepavos': []},
             'yepe': {'yepes': [], 'yeping': []},
             'yepereny': {'yeperenye': []},
             'yepi': {'yepis': []},
             'yepinu': {'yepinus': []},
             'yepistl': {'yepistle': []},
             'yepoqu': {'yepoque': []},
             'yepovr': {'yepovres': []},
             'yepper': {'yeppers': []},
             'yepr': {'yeprs': []},
             'yeqr': {'yeqrs': []},
             'yequian': {'yequians': []},
             'yer': {'yers': []},
             "yer'r": {"yer're": []},
             "yer'v": {"yer've": []},
             'yera': {'yeras': []},
             'yerac': {'yeracity': []},
             'yeracari': {'yeracaris': []},
             'yeraka': {'yerakas': []},
             'yerano': {'yeranos': []},
             'yerar': {'yerars': []},
             'yerasimid': {'yerasimides': []},
             'yerasimo': {'yerasimos': []},
             'yeraslav': {'yeraslave': []},
             'yerastian': {'yerastians': []},
             'yerava': {'yeravas': []},
             'yerazuni': {'yerazunis': []},
             'yerb': {'yerbe': [], 'yerbs': []},
             'yerba': {'yerbas': []},
             'yerbal': {'yerbales': []},
             'yerbam': {'yerbamate': []},
             'yerbani': {'yerbanis': []},
             'yerbatero': {'yerbateros': []},
             'yerberia': {'yerberias': []},
             'yerbero': {'yerberos': []},
             'yerbi': {'yerby': ['yerbys']},
             'yerburi': {'yerbury': []},
             'yerby': ['yerbys'],
             'yerc': {'yerce': [], 'yercs': []},
             'yerd': {'yerde': ['yerdes'], 'yerds': []},
             'yerde': ['yerdes'],
             'yerdi': {'yerdys': []},
             'yerdur': {'yerdure': []},
             'yere': {'yered': [], 'yerely': [], 'yeres': [], 'yering': []},
             'yereanc': {'yereance': []},
             'yerein': {'yereins': []},
             'yerek': {'yereker': []},
             'yereli': {'yerelie': []},
             'yerely': {'yerelye': []},
             'yeremi': {'yeremy': []},
             'yerfass': {'yerfasser': []},
             'yerg': {'yerge': ['yerges']},
             'yergan': {'yergans': []},
             'yerge': ['yerges'],
             'yergenn': {'yergennes': []},
             'yerger': {'yergers': []},
             'yergleichend': {'yergleichende': []},
             'yergn': {'yergne': []},
             'yergu': {'yergue': []},
             'yerh': {'yerhes': []},
             'yerhaltni': {'yerhaltnis': []},
             'yerhaltniss': {'yerhaltnisse': []},
             'yerhun': {'yerhune': []},
             'yeri': {'yeris': [], 'yery': ['yerys']},
             'yerifi': {'yerified': [], 'yerify': []},
             'yerili': {'yerily': []},
             'yerin': {'yerine': []},
             'yerind': {'yerinde': []},
             'yerita': {'yeritas': []},
             'yerk': {'yerke': ['yerkes', 'yerked'], 'yerking': [], 'yerks': []},
             'yerkala': {'yerkalas': []},
             'yerkc': {'yerkcs': []},
             'yerke': ['yerkes', 'yerked'],
             'yerkes': {'yerkes': []},
             'yerkesbridg': {'yerkesbridges': []},
             'yerki': {'yerkie': []},
             'yerl': {'yerle': ['yerles'], 'yerls': []},
             'yerlain': {'yerlaine': []},
             'yerlc': {'yerlces': []},
             'yerle': ['yerles'],
             'yerler': {'yerlere': []},
             'yerlerd': {'yerlerde': []},
             'yerlerin': {'yerlerine': []},
             'yerlerind': {'yerlerinde': []},
             'yerlesm': {'yerlesme': []},
             'yerlesmi': {'yerlesmis': []},
             'yerli': {'yerlie': [], 'yerly': []},
             'yerly': {'yerlye': []},
             'yerma': {'yermas': []},
             'yermak': {'yermaks': []},
             'yermakovskoy': {'yermakovskoye': []},
             'yerman': {'yermans': []},
             'yermandoi': {'yermandois': []},
             'yermani': {'yermany': []},
             'yermano': {'yermanos': []},
             'yermanski': {'yermansky': []},
             'yermo': {'yermos': []},
             'yermolinski': {'yermolinsky': []},
             'yermont': {'yermonter': ['yermonters']},
             'yermonter': ['yermonters'],
             'yermosol': {'yermosols': []},
             'yermouth': {'yermouthe': []},
             'yern': {'yerne': ['yerned', 'yernes'], 'yerning': [], 'yerns': []},
             'yerne': ['yerned', 'yernes'],
             'yerno': {'yernos': []},
             'yero': {'yeros': []},
             'yerolakko': {'yerolakkos': []},
             'yerolympo': {'yerolympos': []},
             'yeroskip': {'yeroskipou': []},
             'yeroskipo': {'yeroskipos': []},
             'yeroulan': {'yeroulanou': []},
             'yerr': {'yerre': ['yerres'], 'yerrs': []},
             'yerra': {'yerras': []},
             'yerral': {'yerrall': []},
             'yerranderi': {'yerranderie': []},
             'yerrap': {'yerrapalli': []},
             'yerre': ['yerres'],
             'yerrel': {'yerrell': []},
             'yerri': {'yerry': []},
             'yerril': {'yerrill': []},
             'yerro': {'yerros': []},
             'yers': {'yerse': ['yersed', 'yerses']},
             'yersail': {'yersailles': []},
             'yersat': {'yersation': []},
             'yerse': ['yersed', 'yerses'],
             'yersek': {'yerseke': []},
             'yersel': {'yersell': [], 'yersels': []},
             'yerselb': {'yerselbs': []},
             'yerself': {'yerselfs': []},
             'yerselv': {'yerselves': []},
             'yersen': {'yersens': []},
             'yersilv': {'yersilves': []},
             'yersini': {'yersinial': []},
             'yersinia': {'yersiniae': [], 'yersinias': []},
             'yersiniapesti': {'yersiniapestis': []},
             'yersiniea': {'yersinieae': []},
             'yersinios': {'yersinioses': []},
             'yersiniosi': {'yersiniosis': []},
             'yersinosi': {'yersinosis': []},
             'yersion': {'yersions': []},
             'yersiti': {'yersity': []},
             'yerst': {'yersts': []},
             'yersu': {'yersus': []},
             'yersuch': {'yersuche': []},
             'yert': {'yerte': ['yertes'], 'yerts': []},
             'yerta': {'yertas': []},
             'yerte': ['yertes'],
             'yertebr': {'yertebrated': []},
             'yerth': {'yerthe': []},
             'yerti': {'yerty': []},
             'yertic': {'yertical': []},
             'yertl': {'yertle': []},
             'yerto': {'yertos': []},
             'yertu': {'yertue': ['yertues']},
             'yertue': ['yertues'],
             'yeru': {'yerus': []},
             'yerua': {'yeruas': []},
             'yerukala': {'yerukalas': []},
             'yerukula': {'yerukulas': []},
             'yerusalimski': {'yerusalimsky': []},
             'yerush': {'yerushe': []},
             'yerushalmi': {'yerushalmy': []},
             'yeruva': {'yeruvas': []},
             'yerva': {'yervas': []},
             'yervier': {'yerviers': []},
             'yervil': {'yerville': []},
             'yery': ['yerys'],
             'yeryth': {'yerything': []},
             'yes': ['yesse', 'yessed', 'yessing'],
             "yes'": {"yes'es": []},
             'yesabl': {'yesable': []},
             'yesacu': {'yesacus': []},
             'yesali': {'yesalis': []},
             'yesaliu': {'yesalius': []},
             'yesavag': {'yesavage': []},
             'yesca': {'yescas': []},
             'yescavag': {'yescavage': []},
             'yescendun': {'yescendune': []},
             'yeschin': {'yeschines': []},
             'yeschk': {'yeschke': []},
             'yeschylo': {'yeschylos': []},
             'yeschylu': {'yeschylus': []},
             'yescomb': {'yescombe': []},
             'yesculapiu': {'yesculapius': []},
             'yesculu': {'yesculus': []},
             'yese': {'yes': ['yesed', 'yesing']},
             'yeselv': {'yeselves': []},
             'yeseria': {'yeserias': []},
             'yesh': {'yeshe': ['yeshes']},
             'yeshak': {'yeshaker': []},
             'yeshal': {'yeshall': []},
             'yeshay': {'yeshaye': []},
             'yeshe': ['yeshes'],
             'yeshibah': {'yeshibahs': []},
             'yeshiv': {'yeshive': ['yeshives']},
             'yeshiva': {'yeshiva': []},
             'yeshivah': {'yeshiva': []},
             'yeshive': ['yeshives'],
             'yeshivo': {'yeshivos': []},
             'yeshkun': {'yeshkuns': []},
             'yesht': {'yeshts': []},
             'yeshu': {'yeshue': []},
             'yeshua': {'yeshuas': []},
             'yeshuo': {'yeshuos': []},
             'yesi': {'yesy': []},
             'yesidi': {'yesidis': []},
             'yesir': {'yesirs': []},
             'yesire': {'yesiree': []},
             'yesirre': {'yesirree': []},
             'yesizw': {'yesizwe': []},
             'yesk': {'yeske': []},
             'yeski': {'yeskis': []},
             'yesnabi': {'yesnaby': []},
             'yeso': {'yesos': []},
             'yesod': {'yesode': [], 'yesodic': []},
             'yesoensi': {'yesoensis': []},
             'yesopu': {'yesopus': []},
             'yesou': {'yesous': []},
             'yesper': {'yespers': []},
             'yespuciu': {'yespucius': []},
             'yesr': {'yesre': [], 'yesrs': []},
             'yess': {'yes': ['yesse', 'yessed', 'yessing']},
             'yessaje': {'yessajee': []},
             'yessay': {'yessaying': []},
             'yessel': {'yessels': []},
             'yesseldyk': {'yesseldyke': []},
             'yessensi': {'yessensis': []},
             'yesser': {'yessers': []},
             'yessi': {'yessis': []},
             'yessio': {'yessios': []},
             'yessir': {'yessirs': []},
             'yessire': {'yessiree': []},
             'yessirre': {'yessirree': []},
             'yessn': {'yessne': []},
             'yessoensi': {'yessoensis': []},
             'yessong': {'yessongs': []},
             'yest': {'yeste': ['yested'], 'yesting': [], 'yests': []},
             'yestat': {'yestate': []},
             'yeste': ['yested'],
             'yester': {'yesters': []},
             'yestercenturi': {'yestercentury': []},
             "yesterd'i": {"yesterd'y": []},
             'yesterdai': {'yesterdaie': [], 'yesterday': []},
             'yesterdaili': {'yesterdailies': []},
             'yesterday': ['yesterdaye', 'yesterdayes'],
             "yesterday'": {"yesterday's": []},
             'yesterdaymorn': {'yesterdaymorning': []},
             'yesterde': {'yesterdee': []},
             'yesterdi': {'yesterdy': []},
             'yesterdni': {'yesterdny': []},
             'yesterev': {'yestereve': []},
             'yestereven': {'yesterevening': []},
             'yestermorn': {'yestermorning': []},
             'yesternight': {'yesternights': []},
             'yestertim': {'yestertime': []},
             'yesterupwin': {'yesterupwine': []},
             'yesteryear': {'yesteryear': []},
             'yesthet': {'yesthetic': ['yesthetically']},
             'yesthetic': ['yesthetically'],
             'yesti': {'yesty': []},
             'yestiddi': {'yestiddy': []},
             'yestidi': {'yestidy': []},
             'yestig': {'yestige': ['yestiges']},
             'yestige': ['yestiges'],
             'yestri': {'yestris': [], 'yestry': []},
             'yesu': {'yesus': []},
             'yesuda': {'yesudas': []},
             'yesuviu': {'yesuvius': []},
             'yesy': {'yesyes': []},
             'yesyesy': {'yesyesyes': []},
             'yet': {'yetfully': [],
                     'yetness': [],
                     'yets': [],
                     'yetted': [],
                     'yetting': []},
             'yeta': {'yetas': []},
             'yetal': {'yetall': []},
             'yetanoth': {'yetanother': []},
             'yetar': {'yetare': []},
             'yetati': {'yetatis': []},
             'yetb': {'yetbe': []},
             'yetbyr': {'yetbyre': []},
             'yetcomplet': {'yetcompleted': []},
             'yete': {'yetes': []},
             'yeteran': {'yeterans': []},
             'yeterinari': {'yeterinary': []},
             'yeterinc': {'yeterince': []},
             'yetern': {'yeternal': []},
             'yetev': {'yeteve': []},
             'yetfam': {'yetfamous': []},
             'yeth': {'yethe': []},
             'yethav': {'yethave': []},
             'yethel': {'yetheling': ['yethelings']},
             'yethelfla': {'yethelflaed': []},
             'yetheling': ['yethelings'],
             'yethelr': {'yethelred': [], 'yethelric': []},
             'yether': {'yethers': []},
             'yetheri': {'yetheris': []},
             'yethi': {'yethis': []},
             'yethiop': {'yethiopic': []},
             'yetholm': {'yetholme': []},
             'yeti': {'yeti': [], 'yety': []},
             'yetincomplet': {'yetincomplete': []},
             'yetir': {'yetirs': []},
             'yetiti': {'yetitis': []},
             'yetiu': {'yetius': []},
             'yetiv': {'yetive': []},
             'yetlich': {'yetlicher': []},
             'yetminst': {'yetminster': []},
             'yetmor': {'yetmore': []},
             'yetnam': {'yetnamed': []},
             'yetolian': {'yetolians': []},
             'yetpublish': {'yetpublished': []},
             'yetr': {'yetrs': []},
             'yetreal': {'yetrealized': []},
             'yetsh': {'yetshe': []},
             'yett': {'yette': ['yettes'], 'yetts': []},
             'yette': ['yettes'],
             'yetter': {'yetters': []},
             'yetth': {'yetthe': []},
             'yetther': {'yetthere': []},
             'yetthes': {'yetthese': []},
             'yetthi': {'yetthis': []},
             'yetti': {'yettie': [], 'yettis': [], 'yetty': []},
             'yetu': {'yetus': []},
             'yetunansw': {'yetunanswered': []},
             'yetund': {'yetunde': []},
             'yetundefin': {'yetundefined': []},
             'yetundetermin': {'yetundetermined': []},
             'yetundevelop': {'yetundeveloped': []},
             'yetundiscov': {'yetundiscovered': []},
             'yetunfinish': {'yetunfinished': []},
             'yetunform': {'yetunformed': []},
             'yetunfulfil': {'yetunfulfilled': []},
             'yetunidentifi': {'yetunidentified': []},
             'yetunnam': {'yetunnamed': []},
             'yetunpublish': {'yetunpublished': []},
             'yetunr': {'yetunrealized': []},
             'yetunresolv': {'yetunresolved': []},
             'yetunspecifi': {'yetunspecified': []},
             'yetuntest': {'yetuntested': []},
             'yetw': {'yetwe': []},
             'yetzer': {'yetzers': []},
             'yetzia': {'yetzias': []},
             'yetzirat': {'yetziratic': []},
             'yeu': {'yeued': [], 'yeus': []},
             'yeudal': {'yeudall': []},
             'yeul': {'yeuls': []},
             'yeur': {'yeure': [], 'yeurs': []},
             'yeus': {'yeuse': []},
             'yeuvil': {'yeuville': []},
             'yev': {'yevs': []},
             'yevamo': {'yevamos': []},
             'yevan': {'yevanic': []},
             'yeve': {'yeved': [], 'yeves': [], 'yeving': []},
             'yevea': {'yeveas': []},
             'yeveai': {'yeveais': []},
             'yevel': {'yevele': [], 'yevell': []},
             'yevem': {'yevems': []},
             'yeven': {'yevenes': []},
             'yeveoi': {'yeveois': []},
             'yever': {'yevering': []},
             'yeveri': {'yevery': []},
             'yevett': {'yevette': []},
             'yevfimi': {'yevfimy': []},
             'yevgeni': {'yevgeny': []},
             'yevgenni': {'yevgenny': []},
             'yevo': {'yevos': []},
             'yevofievo': {'yevofievos': []},
             'yevond': {'yevonde': []},
             'yevonn': {'yevonne': []},
             'yevopevo': {'yevopevos': []},
             'yevov': {'yevovs': []},
             'yevr': {'yevre': ['yevres']},
             'yevre': ['yevres'],
             'yevrop': {'yevrope': []},
             'yevropi': {'yevropy': []},
             'yevtushenko': {'yevtushenko': []},
             'yevtushevski': {'yevtushevsky': []},
             'yew': ['yewe', 'yewes'],
             "yew'r": {"yew're": []},
             "yew'v": {"yew've": []},
             'yewand': {'yewande': []},
             'yewberri': {'yewberries': [], 'yewberry': []},
             'yewdal': {'yewdale': [], 'yewdall': []},
             'yewdel': {'yewdell': []},
             'yewel': {'yewell': []},
             'yewen': {'yewens': []},
             'yewer': {'yewers': []},
             'yewhedg': {'yewhedge': ['yewhedges']},
             'yewhedge': ['yewhedges'],
             'yewlik': {'yewlike': []},
             'yewnit': {'yewnited': []},
             'yewr': {'yewrs': []},
             'yewtre': {'yewtree': ['yewtrees']},
             'yewtree': ['yewtrees'],
             'yewvil': {'yewville': []},
             'yey': {'yeye': ['yeyed', 'yeyes'], 'yeys': []},
             'yeya': {'yeyas': []},
             'yeye': ['yeyed', 'yeyes'],
             'yeyett': {'yeyette': []},
             'yeyot': {'yeyote': []},
             'yeyov': {'yeyove': []},
             'yeyovo': {'yeyovos': []},
             'yezdi': {'yezdis': []},
             'yeze': {'yezed': [], 'yezeed': []},
             'yezede': {'yezedees': []},
             'yezedi': {'yezedis': []},
             'yezeede': {'yezeedees': []},
             'yezeedi': {'yezeedis': []},
             'yezernitski': {'yezernitsky': []},
             'yezerski': {'yezersky': []},
             'yezhov': {'yezhovs': []},
             'yezid': {'yezides': [], 'yezidism': [], 'yezids': []},
             'yezide': {'yezidee': ['yezidees']},
             'yezidee': ['yezidees'],
             'yezidi': {'yezidies': [], 'yezidis': []},
             'yezoens': {'yezoense': []},
             'yezoensi': {'yezoensis': []},
             'yezr': {'yezrs': []},
             'yezz': {'yezzed': []}}
