#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# AUTO-GENERATED CONTENT
d_stem_re = {"re'": {"re's": []},
 "re'a": {"re'as": []},
 "re'd": {"re'de": []},
 "re'i": {"re'is": [], "re'y": []},
 "re'li": {"re'ly": []},
 "re'm": {"re'me": []},
 "re'mi": {"re'my": []},
 "re'n": {"re'ne": []},
 "re'r": {"re're": []},
 "re's": {"re'se": []},
 "re't": {"re'te": []},
 "re'u": {"re'us": []},
 "re'v": {"re've": []},
 'rea': {'reaing': [], 'reas': []},
 "rea'di": {"rea'dy": []},
 "rea'li": {"rea'ly": []},
 'reaa': {'reaaing': [], 'reaas': []},
 'reaaer': {'reaaers': []},
 'reaah': {'reaahed': []},
 'reaaili': {'reaaily': []},
 'reaain': {'reaained': [], 'reaaining': [], 'reaains': []},
 'reaaln': {'reaalned': []},
 'reaaon': {'reaaone': [], 'reaaoning': [], 'reaaons': []},
 'reaaonabl': {'reaaonable': [], 'reaaonably': []},
 'reaard': {'reaarded': [], 'reaards': []},
 'reaark': {'reaarked': [], 'reaarks': []},
 'reaarkabl': {'reaarkable': [], 'reaarkably': []},
 'reaartu': {'reaartus': []},
 'reab': {'reabe': [], 'reabs': []},
 "reab'ti": {"reab'ty": []},
 "reab'z": {"reab'ze": []},
 'reabandon': {'reabandoned': [], 'reabandonment': []},
 'reabduct': {'reabducted': [], 'reabduction': []},
 'reabi': {'reaby': []},
 'reabil': {'reability': []},
 'reabilit': {'reabilitation': []},
 'reabl': {'reable': []},
 'reablat': {'reablation': []},
 'reabolish': {'reabolished': []},
 'reabon': {'reabons': []},
 'reaborpt': {'reaborption': []},
 'reabs': {'reabsed': []},
 'reabsoipt': {'reabsoiption': []},
 'reabsoprt': {'reabsoprtion': []},
 'reabsopt': {'reabsoption': []},
 'reabsorb': {'reabsorbability': [],
              'reabsorbable': [],
              'reabsorbate': [],
              'reabsorbed': [],
              'reabsorber': ['reabsorbers'],
              'reabsorbing': [],
              'reabsorbs': []},
 'reabsorber': ['reabsorbers'],
 'reabsorbt': {'reabsorbtion': [], 'reabsorbtive': []},
 'reabsorpt': {'reabsorption': [], 'reabsorptive': []},
 'reabsorpti': {'reabsorptiou': []},
 'reabsort': {'reabsortion': []},
 'reabstract': {'reabstracted': [], 'reabstracting': [], 'reabstraction': []},
 'reabti': {'reabties': [], 'reabty': []},
 'reabus': {'reabuse': ['reabused'], 'reabusing': []},
 'reabuse': ['reabused'],
 'reabz': {'reabze': ['reabzed']},
 'reabze': ['reabzed'],
 'reac': {'reace': ['reaces', 'reaced'], 'reacing': [], 'reacs': []},
 'reaca': {'reacaed': []},
 'reacair': {'reacaire': []},
 'reacb': {'reacbed': [], 'reacbes': [], 'reacbing': []},
 'reacc': {'reaccs': []},
 'reacceler': {'reaccelerate': ['reaccelerated', 'reaccelerates'],
               'reaccelerating': [],
               'reacceleration': []},
 'reaccelerate': ['reaccelerated', 'reaccelerates'],
 'reaccent': {'reaccented': [], 'reaccenting': [], 'reaccents': []},
 'reaccentu': {'reaccentuate': ['reaccentuates', 'reaccentuated'],
               'reaccentuating': [],
               'reaccentuation': ['reaccentuations']},
 'reaccentuate': ['reaccentuates', 'reaccentuated'],
 'reaccentuation': ['reaccentuations'],
 'reaccept': {'reacceptance': [],
              'reaccepted': [],
              'reaccepting': [],
              'reaccepts': []},
 'reaccess': {'reaccessed': [],
              'reaccesses': [],
              'reaccessing': [],
              'reaccession': []},
 'reacci': {'reaccy': []},
 'reaccion': {'reacciones': []},
 'reaccionaria': {'reaccionarias': []},
 'reaccionario': {'reaccionarios': []},
 'reacclaim': {'reacclaimed': []},
 'reacclim': {'reacclimate': ['reacclimated'],
              'reacclimating': [],
              'reacclimation': []},
 'reacclimat': {'reacclimatization': [],
                'reacclimatize': ['reacclimatized'],
                'reacclimatizing': []},
 'reacclimate': ['reacclimated'],
 'reacclimatis': {'reacclimatise': []},
 'reacclimatize': ['reacclimatized'],
 'reacco': {'reaccoes': []},
 'reaccommod': {'reaccommodate': ['reaccommodated'],
                'reaccommodating': [],
                'reaccommodation': ['reaccommodations']},
 'reaccommodate': ['reaccommodated'],
 'reaccommodation': ['reaccommodations'],
 'reaccomod': {'reaccomodation': []},
 'reaccompani': {'reaccompanied': []},
 'reaccomplish': {'reaccomplished': [], 'reaccomplishment': []},
 'reaccord': {'reaccorded': []},
 'reaccount': {'reaccounting': []},
 'reaccredid': {'reaccredidation': []},
 'reaccredit': {'reaccreditation': [], 'reaccredited': [], 'reaccrediting': []},
 'reaccret': {'reaccrete': ['reaccreted'],
              'reaccreting': [],
              'reaccretion': []},
 'reaccrete': ['reaccreted'],
 'reaccultur': {'reacculturate': ['reacculturated'],
                'reacculturating': [],
                'reacculturation': []},
 'reacculturate': ['reacculturated'],
 'reaccumul': {'reaccumulate': ['reaccumulates', 'reaccumulated'],
               'reaccumulating': [],
               'reaccumulation': ['reaccumulations']},
 'reaccumulate': ['reaccumulates', 'reaccumulated'],
 'reaccumulation': ['reaccumulations'],
 'reaccus': {'reaccused': []},
 'reaccustom': {'reaccustomed': [], 'reaccustoming': []},
 'reacdon': {'reacdons': []},
 'reace': ['reaces', 'reaced'],
 'reaceav': {'reaceaved': []},
 'reacetyl': {'reacetylated': [], 'reacetylation': []},
 'reach': ['reache', 'reached', 'reaching'],
 'reachabl': {'reachabilities': [],
              'reachability': [],
              'reachable': ['reachables']},
 'reachable': ['reachables'],
 'reache': {'reachee': []},
 'reacheabl': {'reacheable': []},
 'reachedit': {'reachedits': []},
 'reachedth': {'reachedthe': []},
 'reacher': {'reacherous': [], 'reachers': []},
 'reacheri': {'reachery': []},
 'reachesth': {'reachesthe': []},
 'reachf': {'reachfed': []},
 'reachi': {'reachy': []},
 'reachiev': {'reachieve': ['reachieves', 'reachieved', 'reachievement'],
              'reachieving': []},
 'reachieve': ['reachieves', 'reachieved', 'reachievement'],
 'reachin': {'reachine': [], 'reachins': []},
 'reaching': {'reachinge': [], 'reachingness': []},
 'reachingli': {'reachingly': []},
 'reachingth': {'reachingthe': []},
 'reachm': {'reachme': []},
 'reacho': {'reachos': []},
 'reachrod': {'reachrods': []},
 'reachth': {'reachthe': []},
 'reachtuir': {'reachtuire': []},
 'reaci': {'reacied': [], 'reacy': []},
 'reacidif': {'reacidification': []},
 'reacidifi': {'reacidified': [], 'reacidify': ['reacidifying']},
 'reacidify': ['reacidifying'],
 'reacii': {'reaciied': []},
 'reaciion': {'reaciions': []},
 'reacio': {'reacios': []},
 'reacion': {'reacions': []},
 'reacit': {'reacitivity': []},
 'reaciton': {'reacitons': []},
 'reack': {'reacked': []},
 'reacknowledg': {'reacknowledge': ['reacknowledges',
                                    'reacknowledged',
                                    'reacknowledgement'],
                  'reacknowledging': [],
                  'reacknowledgment': []},
 'reacknowledge': ['reacknowledges', 'reacknowledged', 'reacknowledgement'],
 'reacl': {'reacle': []},
 'reaclant': {'reaclants': []},
 'reacli': {'reaclied': [], 'reaclies': [], 'reacliing': [], 'reacly': []},
 'reaclion': {'reaclions': []},
 'reacliv': {'reaclive': []},
 'reacn': {'reacne': ['reacnes', 'reacned'], 'reacning': []},
 'reacne': ['reacnes', 'reacned'],
 'reacnon': {'reacnons': []},
 'reaco': {'reacoes': []},
 'reacon': {'reaconed': [], 'reacons': []},
 'reacquaint': {'reacquaintance': ['reacquaintances'],
                'reacquainted': [],
                'reacquainting': [],
                'reacquaints': []},
 'reacquaintance': ['reacquaintances'],
 'reacquir': {'reacquire': ['reacquired',
                            'reacquires',
                            'reacquirer',
                            'reacquirement'],
              'reacquiring': []},
 'reacquire': ['reacquired', 'reacquires', 'reacquirer', 'reacquirement'],
 'reacquisit': {'reacquisition': ['reacquisitions']},
 'reacquisition': ['reacquisitions'],
 'reacquist': {'reacquistion': []},
 'reacr': {'reacred': []},
 'reacreat': {'reacreation': ['reacreational']},
 'reacreation': ['reacreational'],
 'reacrion': {'reacrions': []},
 'reacriv': {'reacrive': []},
 'react': {'reacte': ['reacted'], 'reacting': ['reactings'], 'reacts': []},
 'reactabl': {'reactability': [], 'reactable': []},
 'reactam': {'reactams': []},
 'reactan': {'reactans': []},
 'reactanc': {'reactance': []},
 'reactancetub': {'reactancetube': []},
 'reactand': {'reactands': []},
 'reactanl': {'reactanls': []},
 'reactant': ['reactante'],
 'reacte': ['reacted'],
 'reacted': {'reactedness': []},
 'reacter': {'reacters': []},
 'reacteur': {'reacteurs': []},
 'reacti': {'reactie': ['reacties'], 'reacty': []},
 'reactibl': {'reactibility': []},
 'reactie': ['reacties'],
 'reactif': {'reactifs': []},
 'reactin': {'reactine': [], 'reactins': []},
 'reacting': ['reactings'],
 'reactio': {'reactios': []},
 'reactioa': {'reactioas': []},
 'reaction': ['reactione',
              'reactional',
              'reactionism',
              'reactionable',
              'reactionally'],
 'reactionair': {'reactionaires': []},
 'reactionamplifi': {'reactionamplified': []},
 'reactionar': {'reactionarism': []},
 'reactionari': {'reactionariness': [], 'reactionary': []},
 'reactionarili': {'reactionarily': []},
 'reactionary': {'reactionaryism': []},
 'reactionati': {'reactionaty': []},
 'reactionbas': {'reactionbased': []},
 'reactionbond': {'reactionbonded': []},
 'reactioncent': {'reactioncenter': []},
 'reactioncontrol': {'reactioncontrolled': []},
 'reactiondiffus': {'reactiondiffusion': []},
 'reactioneri': {'reactioneries': [], 'reactionery': []},
 'reactionform': {'reactionformation': ['reactionformations']},
 'reactionformation': ['reactionformations'],
 'reactioni': {'reactionis': []},
 'reactionist': {'reactionists': []},
 'reactionlimit': {'reactionlimited': []},
 'reactionmechan': {'reactionmechanism': []},
 'reactionnair': {'reactionnaire': ['reactionnaires']},
 'reactionnaire': ['reactionnaires'],
 'reactionnari': {'reactionnary': []},
 'reactionnel': {'reactionnelle': ['reactionnelles'], 'reactionnels': []},
 'reactionnelle': ['reactionnelles'],
 'reactionpattern': {'reactionpatterns': []},
 'reactionproduct': {'reactionproducts': []},
 'reactionr': {'reactionrate': ['reactionrates']},
 'reactionrate': ['reactionrates'],
 'reactionspecif': {'reactionspecific': []},
 'reactionsystem': {'reactionsystems': []},
 'reactiontend': {'reactiontendencies': []},
 'reactiontim': {'reactiontime': ['reactiontimes']},
 'reactiontime': ['reactiontimes'],
 'reactiontyp': {'reactiontype': ['reactiontypes']},
 'reactiontype': ['reactiontypes'],
 'reactionveloc': {'reactionvelocity': []},
 'reactionzon': {'reactionzone': []},
 'reactior': {'reactiors': []},
 'reactiou': {'reactious': []},
 'reactiv': {'reactivable': [],
             'reactivate': ['reactivated', 'reactivates'],
             'reactivating': [],
             'reactivation': ['reactivations'],
             'reactivator': ['reactivators'],
             'reactive': ['reactiver',
                          'reactived',
                          'reactives',
                          'reactively',
                          'reactiveness'],
             'reactivism': [],
             'reactivity': [],
             'reactivization': [],
             'reactivized': []},
 'reactivat': {'reactivatability': [], 'reactivatable': []},
 'reactivate': ['reactivated', 'reactivates'],
 'reactivation': ['reactivations'],
 'reactivator': ['reactivators'],
 'reactive': {'reactivee': ['reactivees']},
 'reactivee': ['reactivees'],
 'reactivepow': {'reactivepower': []},
 'reactivi': {'reactivial': [], 'reactiviated': [], 'reactiviation': []},
 'reactivis': {'reactivisation': [],
               'reactivise': ['reactivised'],
               'reactivising': []},
 'reactivise': ['reactivised'],
 'reactivist': {'reactivists': []},
 'reactivit': {'reactivitated': [], 'reactivite': ['reactivites']},
 'reactivite': ['reactivites'],
 'reactivo': {'reactivos': []},
 'reactivti': {'reactivty': []},
 'reactlon': {'reactlons': []},
 'reactlv': {'reactlve': []},
 'reactogen': {'reactogenic': ['reactogenicity']},
 'reactogenic': ['reactogenicity'],
 'reactolit': {'reactolite': []},
 'reactolog': {'reactological': [], 'reactology': []},
 'reactom': {'reactome': []},
 'reacton': {'reactons': []},
 'reactor': ['reactores'],
 'reactorgrad': {'reactorgrade': []},
 'reactori': {'reactory': []},
 'reactorpow': {'reactorpowered': []},
 'reactorproduc': {'reactorproduced': []},
 'reactoryear': {'reactoryears': []},
 'reactual': {'reactualization': ['reactualizations'],
              'reactualize': ['reactualized', 'reactualizes'],
              'reactualizing': []},
 'reactualis': {'reactualisation': [],
                'reactualise': ['reactualised', 'reactualiser', 'reactualises'],
                'reactualising': []},
 'reactualise': ['reactualised', 'reactualiser', 'reactualises'],
 'reactualization': ['reactualizations'],
 'reactualize': ['reactualized', 'reactualizes'],
 'reactuat': {'reactuate': ['reactuated'], 'reactuation': []},
 'reactuate': ['reactuated'],
 'reacu': {'reacued': []},
 'reacuon': {'reacuons': []},
 'reacyl': {'reacylate': ['reacylated'], 'reacylation': []},
 'reacylate': ['reacylated'],
 'read': ['reade',
          'readed',
          'reades',
          'readely',
          'readded',
          'reading',
          'readful',
          'readeing',
          'readness',
          'readding',
          'readfully'],
 "read'i": {"read'y": []},
 "read'li": {"read'ly": []},
 'reada': {'readas': []},
 'readabilti': {'readabilty': []},
 'readabl': {'readability': [],
             'readable': ['readables', 'readableness'],
             'readablity': [],
             'readably': []},
 'readable': ['readables', 'readableness'],
 'readaft': {'readafter': []},
 'readahil': {'readahility': []},
 'readahl': {'readahle': []},
 'readahol': {'readaholic': []},
 'readal': {'readall': []},
 'readallbyt': {'readallbytes': []},
 'readaloud': {'readalouds': []},
 'readanc': {'readance': []},
 'readapt': {'readaptability': [],
             'readaptation': ['readaptations'],
             'readapted': [],
             'readapter': [],
             'readapting': [],
             'readaption': [],
             'readaptive': [],
             'readapts': []},
 'readaptation': ['readaptations'],
 'readar': {'readars': []},
 'readathon': {'readathons': []},
 'readattribut': {'readattributes': []},
 'readback': {'readbacks': []},
 'readbourn': {'readbourne': []},
 'readbyt': {'readbyte': ['readbytes']},
 'readbyte': ['readbytes'],
 'readchar': {'readchars': []},
 'readcommit': {'readcommitted': []},
 'readcr': {'readcrs': []},
 'readd': {'readde': []},
 'readdi': {'readdie': [], 'readdy': []},
 'readdict': {'readdicted': [], 'readdiction': []},
 'readdit': {'readdition': []},
 'readdoubl': {'readdouble': []},
 'readdress': {'readdressed': [], 'readdresses': [], 'readdressing': []},
 'reade': {'readee': ['readees']},
 'readee': ['readees'],
 'readef': {'readefs': []},
 'readei': {'readeis': []},
 'readelementstr': {'readelementstring': []},
 'readenc': {'readence': []},
 'readendel': {'readendelement': []},
 'readept': {'readeption': []},
 'reader': ['readere', 'readered', 'readering'],
 "reader'": {"reader's": []},
 'readera': {'readeras': []},
 'readeraudi': {'readeraudience': []},
 'readerbas': {'readerbased': []},
 'readerboard': {'readerboards': []},
 'readercent': {'readercentered': []},
 'readerfriendli': {'readerfriendly': []},
 'readeri': {'readeris': []},
 'readeridentif': {'readeridentification': []},
 'readerli': {'readerliness': [], 'readerly': []},
 'readerlisten': {'readerlistener': []},
 'readerori': {'readeroriented': []},
 'readerprint': {'readerprinter': ['readerprinters']},
 'readerprinter': ['readerprinters'],
 'readerrespons': {'readerresponse': []},
 'readership': {'readership': []},
 'readersort': {'readersorter': []},
 'readerspect': {'readerspectator': []},
 'readerswrit': {'readerswriters': []},
 'readerview': {'readerviewer': []},
 'readervil': {'readerville': []},
 'readerwil': {'readerwill': []},
 'readerwork': {'readerworks': []},
 'readerwrit': {'readerwriter': []},
 'readet': {'readets': []},
 'readfd': {'readfds': []},
 'readfil': {'readfile': []},
 'readfli': {'readfly': []},
 'readfromfil': {'readfromfile': []},
 'readh': {'readhed': []},
 'readhal': {'readhall': []},
 'readhead': {'readheads': []},
 'readher': {'readhere': ['readhered', 'readherence'], 'readhering': []},
 'readhere': ['readhered', 'readherence'],
 'readhes': {'readhesion': []},
 'readhim': {'readhimer': []},
 'readhowyouw': {'readhowyouwant': []},
 'readi': {'readie': ['readied'],
           'readiing': [],
           'readiness': [],
           'readis': [],
           'ready': ['readying']},
 "readi'i": {"readi'y": []},
 'readiat': {'readiation': []},
 'readibl': {'readibility': [], 'readible': [], 'readibly': []},
 'readic': {'readical': ['readically']},
 'readical': ['readically'],
 'readie': ['readied'],
 'readifi': {'readify': []},
 'readiji': {'readijy': []},
 'readili': {'readilie': [], 'readily': []},
 'readilli': {'readilly': []},
 'readily': {'readilye': []},
 'readilyaccept': {'readilyaccepted': []},
 'readilyaccess': {'readilyaccessible': []},
 'readilyappar': {'readilyapparent': []},
 'readilyavail': {'readilyavailable': []},
 'readilyb': {'readilybe': []},
 'readilygr': {'readilygranted': []},
 'readilyidentifi': {'readilyidentifiable': []},
 'readilysolubl': {'readilysoluble': []},
 'readin': {'readine': ['readines'], 'readins': []},
 'readina': {'readinas': []},
 'readinc': {'readincs': []},
 'readine': {'readinees': []},
 'readinea': {'readineas': []},
 'readinef': {'readinefs': []},
 'readinei': {'readineis': []},
 'readinel': {'readinels': []},
 'readines': {'readinese': []},
 'readiness': {'readinesse': []},
 'reading': {'readingability': [], 'readinge': ['readinger', 'readinges']},
 'readinga': {'readingas': []},
 'readingachiev': {'readingachievement': []},
 'readingbook': {'readingbooks': []},
 'readingcircl': {'readingcircle': []},
 'readingcomprehens': {'readingcomprehension': []},
 'readingcours': {'readingcourse': []},
 'readingdesk': {'readingdesks': []},
 'readingdis': {'readingdisability': [], 'readingdisabled': []},
 'readinge': ['readinger', 'readinges'],
 'readingfram': {'readingframe': []},
 'readingglass': {'readingglasses': []},
 'readingi': {'readingis': []},
 'readingimpair': {'readingimpaired': []},
 'readinginstruct': {'readinginstruction': []},
 'readinglamp': {'readinglamps': []},
 'readinglesson': {'readinglessons': []},
 'readinglik': {'readinglike': []},
 'readinglist': {'readinglists': []},
 'readingmateri': {'readingmaterial': []},
 'readingmatt': {'readingmatter': []},
 'readingparti': {'readingparties': [], 'readingparty': []},
 'readingpubl': {'readingpublic': []},
 'readingreadi': {'readingreadiness': []},
 'readingrel': {'readingrelated': []},
 'readingroom': {'readingrooms': []},
 'readingskil': {'readingskills': []},
 'readingspel': {'readingspelling': []},
 'readingstand': {'readingstands': []},
 'readingstudi': {'readingstudy': []},
 'readingt': {'readingtable': []},
 'readingteach': {'readingteacher': []},
 'readingth': {'readingthe': []},
 'readingthi': {'readingthis': []},
 'readingthink': {'readingthinking': []},
 'readingtim': {'readingtime': []},
 'readingwrit': {'readingwriting': []},
 'readini': {'readiny': []},
 'readino': {'readinos': []},
 'readinq': {'readinqs': []},
 'readioact': {'readioactive': []},
 'readion': {'readions': []},
 'readiri': {'readiry': []},
 'readiti': {'readity': []},
 'readiug': {'readiugs': []},
 'readiust': {'readiustment': []},
 'readjli': {'readjly': []},
 'readjourn': {'readjourned': []},
 'readjud': {'readjudicate': ['readjudicated'],
             'readjudicating': [],
             'readjudication': []},
 'readjudicate': ['readjudicated'],
 'readjus': {'readjusment': []},
 'readjust': {'readjustability': [],
              'readjustable': [],
              'readjusted': [],
              'readjustement': ['readjustements'],
              'readjuster': ['readjusters'],
              'readjusting': [],
              'readjustive': [],
              'readjustment': [],
              'readjusts': []},
 'readjuste': {'readjustee': ['readjustees']},
 'readjustee': ['readjustees'],
 'readjustement': ['readjustements'],
 'readjuster': {'readjusterism': []},
 'readjustm': {'readjustme': []},
 'readjustor': {'readjustors': []},
 'readl': {'readle': [], 'readling': [], 'readlness': []},
 'readli': {'readly': []},
 'readlin': {'readline': ['readlines']},
 'readline': ['readlines'],
 'readlli': {'readlly': []},
 'readlng': {'readlngs': []},
 'readlwrit': {'readlwrite': []},
 'readm': {'readme': ['readmes']},
 'readmani': {'readmany': []},
 'readme': ['readmes'],
 'readmenam': {'readmename': []},
 'readmg': {'readmgs': []},
 'readmi': {'readmis': []},
 'readminist': {'readminister': ['readministers',
                                 'readministered',
                                 'readministering']},
 'readminister': ['readministers', 'readministered', 'readministering'],
 'readministr': {'readministration': ['readministrations']},
 'readministration': ['readministrations'],
 'readmir': {'readmire': ['readmired']},
 'readmire': ['readmired'],
 'readmiss': {'readmission': []},
 'readmit': {'readmits': [], 'readmitted': [], 'readmitting': []},
 'readmitt': {'readmittance': ['readmittances']},
 'readmittance': ['readmittances'],
 'readmodifi': {'readmodify': []},
 'readmor': {'readmore': []},
 'readmostli': {'readmostly': []},
 'readnam': {'readname': []},
 'readnew': {'readnews': []},
 'readng': {'readngs': []},
 'readnois': {'readnoise': []},
 'readonli': {'readonly': []},
 'readonlycheck': {'readonlychecked': []},
 'readonlycollect': {'readonlycollection': []},
 'readonlycollectionbas': {'readonlycollectionbase': []},
 'readonlyrecommend': {'readonlyrecommended': []},
 'readopt': {'readopted': [],
             'readopting': [],
             'readoption': ['readoptions'],
             'readopts': []},
 'readoption': ['readoptions'],
 'reador': {'readors': []},
 'readorn': {'readorned': [], 'readorning': [], 'readornment': []},
 'readout': {'readout': []},
 'readpars': {'readparse': []},
 'readpip': {'readpipe': []},
 'readprocessmemori': {'readprocessmemory': []},
 'readproperti': {'readproperties': [], 'readproperty': []},
 'readr': {'readres': [], 'readrs': []},
 'readress': {'readressed': []},
 'readrli': {'readrly': []},
 'readsdal': {'readsdale': []},
 'readset': {'readsets': []},
 'readsorb': {'readsorbed': [], 'readsorbing': [], 'readsorbs': []},
 'readsorpt': {'readsorption': []},
 'readstartel': {'readstartelement': []},
 'readstat': {'readstate': []},
 'readsth': {'readsthe': []},
 'readstr': {'readstring': []},
 'readsvil': {'readsville': []},
 'readt': {'readted': []},
 'readth': {'readthe': []},
 'readthi': {'readthis': []},
 'readthrough': {'readthroughs': []},
 'readti': {'readty': []},
 'readtli': {'readtly': []},
 'readtng': {'readtngs': []},
 'readtr': {'readtrs': []},
 'readu': {'readus': []},
 'readuncommit': {'readuncommitted': []},
 'readunsignedbyt': {'readunsignedbyte': []},
 'readust': {'readustment': []},
 'readv': {'readving': []},
 'readvanc': {'readvance': ['readvances', 'readvanced', 'readvancement'],
              'readvancing': []},
 'readvance': ['readvances', 'readvanced', 'readvancement'],
 'readvert': {'readverting': []},
 'readvertis': {'readvertise': ['readvertised',
                                'readvertises',
                                'readvertisement'],
                'readvertising': []},
 'readvertise': ['readvertised', 'readvertises', 'readvertisement'],
 'readvil': {'readville': []},
 'readvis': {'readvise': ['readvised']},
 'readvise': ['readvised'],
 'readvmad': {'readvmade': []},
 'readvoc': {'readvocated': []},
 'readwrit': {'readwrite': []},
 'ready': {'readye': [], 'readyness': []},
 'readyarm': {'readyarmed': []},
 'readyassembl': {'readyassembled': []},
 'readybak': {'readybaked': []},
 'readycook': {'readycooked': []},
 'readydescrib': {'readydescribed': []},
 'readydr': {'readydrive': []},
 'readydress': {'readydressed': []},
 'readyform': {'readyformed': []},
 'readyfurnish': {'readyfurnished': []},
 'readyhand': {'readyhanded': []},
 'readyli': {'readyly': []},
 'readyload': {'readyloaded': []},
 'readym': {'readymeals': []},
 'readymad': {'readymade': ['readymades']},
 'readymade': ['readymades'],
 'readymoney': {'readymoneys': []},
 'readymount': {'readymounted': []},
 'readyn': {'readynes': []},
 'readyness': {'readynesse': []},
 'readyng': {'readynge': []},
 'readyorgan': {'readyorganized': []},
 'readypack': {'readypacked': []},
 'readyprepar': {'readyprepared': []},
 'readyprint': {'readyprinted': [], 'readyprints': []},
 'readyreckon': {'readyreckoner': ['readyreckoners']},
 'readyreckoner': ['readyreckoners'],
 'readyrefer': {'readyreference': []},
 'readyroast': {'readyroasted': []},
 'readyroom': {'readyrooms': []},
 'readyst': {'readystate': []},
 'readystatechang': {'readystatechange': []},
 'readytongu': {'readytongued': []},
 'readytrain': {'readytrained': []},
 'readyus': {'readyuse': []},
 'readyvil': {'readyville': []},
 'readywit': {'readywitted': []},
 'readywrit': {'readywriter': []},
 'readz': {'readze': []},
 'reae': {'reaes': []},
 'reaeaber': {'reaeabered': []},
 'reaect': {'reaected': [], 'reaecting': [], 'reaects': []},
 'reaection': {'reaections': []},
 'reaedi': {'reaedy': []},
 'reaedificar': {'reaedificare': []},
 'reaeh': {'reaehed': [], 'reaehes': [], 'reaehing': []},
 'reaeio': {'reaeios': []},
 'reaeiv': {'reaeive': ['reaeived']},
 'reaeive': ['reaeived'],
 'reaember': {'reaembered': []},
 'reaembl': {'reaemble': [], 'reaembling': []},
 'reaemblanc': {'reaemblance': []},
 'reaent': {'reaented': []},
 'reaeon': {'reaeone': [], 'reaeoning': [], 'reaeons': []},
 'reaeonabl': {'reaeonable': [], 'reaeonably': []},
 'reaerat': {'reaerate': ['reaerated'], 'reaerating': [], 'reaeration': []},
 'reaerate': ['reaerated'],
 'reaerosol': {'reaerosolization': [], 'reaerosolized': []},
 'reaerv': {'reaerve': ['reaerved']},
 'reaerve': ['reaerved'],
 'reaet': {'reaeted': []},
 'reaetant': {'reaetants': []},
 'reaetion': {'reaetions': []},
 'reaetionari': {'reaetionary': []},
 'reaetiv': {'reaetive': []},
 'reaew': {'reaewed': []},
 'reaf': {'reafe': ['reafes', 'reafed'], 'reafs': []},
 'reafbn': {'reafbns': []},
 'reafbnabl': {'reafbnable': [], 'reafbnably': []},
 'reafe': ['reafes', 'reafed'],
 'reaferm': {'reafermation': []},
 'reaffect': {'reaffectation': [], 'reaffected': []},
 'reaffer': {'reafference': ['reafferences'], 'reafferent': ['reafferents']},
 'reafference': ['reafferences'],
 'reafferent': {'reafferentation': [], 'reafferente': []},
 'reaffi': {'reaffy': []},
 'reaffili': {'reaffiliate': ['reaffiliated', 'reaffiliates'],
              'reaffiliating': [],
              'reaffiliation': []},
 'reaffiliate': ['reaffiliated', 'reaffiliates'],
 'reaffim': {'reaffimation': [], 'reaffimed': []},
 'reaffin': {'reaffinned': [], 'reaffinning': []},
 'reaffinn': {'reaffinnation': []},
 'reaffir': {'reaffirment': []},
 'reaffirm': {'reaffirmance': [],
              'reaffirmant': [],
              'reaffirmation': [],
              'reaffirmative': [],
              'reaffirme': ['reaffirmed', 'reaffirmer', 'reaffirmers'],
              'reaffirming': [],
              'reaffirms': []},
 'reaffirme': {'reaffirmee': []},
 'reaffirmon': {'reaffirmons': []},
 'reaffirrn': {'reaffirrnation': [], 'reaffirrned': []},
 'reafflict': {'reafflicted': []},
 'reafflrmat': {'reafflrmation': []},
 'reafforest': {'reafforestation': ['reafforestations'],
                'reafforested': [],
                'reafforesting': []},
 'reafforestation': ['reafforestations'],
 'reafftrm': {'reafftrmed': []},
 'reaffum': {'reaffume': ['reaffumed']},
 'reaffume': ['reaffumed'],
 'reafhrmat': {'reafhrmation': []},
 'reafiirm': {'reafiirmation': [],
              'reafiirmed': [],
              'reafiirming': [],
              'reafiirms': []},
 'reafirm': {'reafirmation': [],
             'reafirmed': [],
             'reafirming': [],
             'reafirms': []},
 'reafiti': {'reafity': []},
 'reafiz': {'reafize': ['reafized']},
 'reafize': ['reafized'],
 'reafli': {'reafly': []},
 'reaflirm': {'reaflirmation': [],
              'reaflirmed': [],
              'reaflirming': [],
              'reaflirms': []},
 'reaflum': {'reaflume': ['reaflumed']},
 'reaflume': ['reaflumed'],
 'reafnrmat': {'reafnrmation': []},
 'reafon': {'reafonable': ['reafonableness'],
            'reafonably': [],
            'reafoned': [],
            'reafoner': ['reafoners'],
            'reafoning': ['reafonings'],
            'reafons': []},
 'reafonable': ['reafonableness'],
 'reafonablenef': {'reafonablenefs': []},
 'reafoner': ['reafoners'],
 'reafoning': ['reafonings'],
 'reaforest': {'reaforestation': []},
 'reafrican': {'reafricanization': []},
 'reafsnyd': {'reafsnyder': []},
 'reaft': {'reafte': []},
 'reag': {'reage': ['reaged'], 'reaging': []},
 'reagan': ['reaganism',
            'reaganisms',
            'reaganized',
            'reaganizing',
            'reaganization'],
 'reaganappoint': {'reaganappointed': []},
 'reaganaut': {'reaganauts': []},
 'reagancart': {'reagancarter': []},
 'reaganesqu': {'reaganesque': []},
 'reaganit': {'reaganite': ['reaganites']},
 'reaganite': ['reaganites'],
 'reaganmondal': {'reaganmondale': []},
 'reaganom': {'reaganomic': ['reaganomics']},
 'reaganomic': ['reaganomics'],
 'reaganonom': {'reaganonomics': []},
 'reagant': {'reagants': []},
 'reaganthatch': {'reaganthatcher': []},
 'reaganvil': {'reaganville': []},
 'reagard': {'reagarded': [], 'reagarding': [], 'reagards': []},
 'reage': ['reaged'],
 'reagen': {'reagenic': [], 'reagens': []},
 'reagenc': {'reagencies': [], 'reagency': []},
 'reagent': ['reagente', 'reagentes'],
 'reagentgrad': {'reagentgrade': []},
 'reagenzgla': {'reagenzglas': []},
 'reagenzglas': {'reagenzglaser': []},
 'reager': {'reagere': ['reagerer']},
 'reagerad': {'reagerade': []},
 'reagere': ['reagerer'],
 'reagglomer': {'reagglomerate': ['reagglomerated'], 'reagglomeration': []},
 'reagglomerate': ['reagglomerated'],
 'reagglutin': {'reagglutinate': ['reagglutinated'], 'reagglutination': []},
 'reagglutinate': ['reagglutinated'],
 'reaggrav': {'reaggravated': [], 'reaggravating': [], 'reaggravation': []},
 'reaggreg': {'reaggregate': ['reaggregates', 'reaggregated'],
              'reaggregating': [],
              'reaggregation': ['reaggregations']},
 'reaggregate': ['reaggregates', 'reaggregated'],
 'reaggregation': ['reaggregations'],
 'reagh': {'reaghs': []},
 'reagibl': {'reagibility': []},
 'reagier': {'reagiere': []},
 'reagierend': {'reagierende': ['reagierender']},
 'reagierende': ['reagierender'],
 'reagiert': {'reagierte': []},
 'reagil': {'reagill': []},
 'reagim': {'reagime': []},
 'reagin': ['reaginic'],
 'reagion': {'reagions': []},
 'reagir': {'reagire': ['reagirent']},
 'reagire': ['reagirent'],
 'reagisc': {'reagisce': []},
 'reagiss': {'reagissant': [], 'reagisse': ['reagissent']},
 'reagissai': {'reagissaient': []},
 'reagisse': ['reagissent'],
 'reagit': {'reagitate': ['reagitated'], 'reagitating': [], 'reagitation': []},
 'reagitate': ['reagitated'],
 'reagl': {'reagle': ['reagles']},
 'reagle': ['reagles'],
 'reagnt': {'reagnts': []},
 'reagonom': {'reagonomic': ['reagonomics']},
 'reagonomic': ['reagonomics'],
 'reagrarian': {'reagrarianization': []},
 'reagrd': {'reagrded': [], 'reagrding': [], 'reagrds': []},
 'reagre': {'reagreed': []},
 'reaguj': {'reaguje': []},
 'reah': {'reahed': [], 'reahs': []},
 "reah'ti": {"reah'ty": []},
 'reahchul': {'reahchule': []},
 'reahi': {'reahy': []},
 'reahli': {'reahly': []},
 'reahlli': {'reahlly': []},
 'reahn': {'reahne': ['reahnes'], 'reahns': []},
 'reahne': ['reahnes'],
 'reahs': {'reahse': ['reahsed']},
 'reahsat': {'reahsation': []},
 'reahse': ['reahsed'],
 'reahsorpt': {'reahsorption': []},
 'reahti': {'reahties': [], 'reahty': []},
 'reahu': {'reahus': []},
 'reahz': {'reahze': ['reahzes', 'reahzed'], 'reahzing': []},
 'reahzat': {'reahzation': []},
 'reahze': ['reahzes', 'reahzed'],
 'reai': {'reaied': [], 'reaies': [], 'reaiing': [], 'reais': []},
 'reaiatanc': {'reaiatance': []},
 'reaibn': {'reaibns': []},
 'reaibnabl': {'reaibnable': []},
 'reaid': {'reaide': ['reaided'], 'reaiding': []},
 'reaide': ['reaided'],
 'reaidenc': {'reaidence': []},
 'reaideno': {'reaidenoe': []},
 'reaident': {'reaidents': []},
 'reaidenti': {'reaidential': []},
 'reaidu': {'reaidue': []},
 'reaign': {'reaigned': []},
 'reaignat': {'reaignation': []},
 'reaiili': {'reaiily': []},
 'reaiis': {'reaiise': ['reaiised']},
 'reaiise': ['reaiised'],
 'reaiiti': {'reaiities': [], 'reaiity': []},
 'reaiiz': {'reaiize': ['reaiized']},
 'reaiizat': {'reaiization': []},
 'reaiize': ['reaiized'],
 'reail': {'reailing': []},
 'reailer': {'reailers': []},
 'reaili': {'reaily': []},
 'reailili': {'reailily': []},
 'reailiti': {'reaility': []},
 'reailti': {'reailty': []},
 'reailz': {'reailze': []},
 'reaim': {'reaime': ['reaimed'], 'reaiming': [], 'reaims': []},
 'reaime': ['reaimed'],
 'reain': {'reained': [], 'reaining': [], 'reains': []},
 'reaion': {'reaions': []},
 'reaionabl': {'reaionable': [], 'reaionably': []},
 'reair': {'reaired': [], 'reairing': []},
 'reais': {'reaised': []},
 'reaissanc': {'reaissance': []},
 'reaistanc': {'reaistance': []},
 'reaister': {'reaistered': []},
 'reaiti': {'reaity': []},
 'reaiz': {'reaize': ['reaized']},
 'reaize': ['reaized'],
 'reaji': {'reajy': []},
 'reajiti': {'reajity': []},
 'reajiz': {'reajize': []},
 'reajji': {'reajjy': []},
 'reajli': {'reajly': []},
 'reajon': {'reajonable': [], 'reajons': []},
 'reajust': {'reajuste': ['reajuster',
                          'reajustes',
                          'reajusted',
                          'reajustement',
                          'reajustements'],
             'reajustment': []},
 'reajustavei': {'reajustaveis': []},
 'reajuste': ['reajuster',
              'reajustes',
              'reajusted',
              'reajustement',
              'reajustements'],
 'reak': {'reake': ['reaked', 'reakes'], 'reaking': [], 'reaks': []},
 'reakc': {'reakce': []},
 'reakcij': {'reakcije': []},
 'reakcj': {'reakcje': []},
 'reake': ['reaked', 'reakes'],
 'reaker': {'reakers': []},
 'reakish': {'reakishness': []},
 'reaksi': {'reaksie': []},
 'reaksjon': {'reaksjoner': []},
 'reakt': {'reakts': []},
 'reakti': {'reaktie': ['reakties'], 'reakty': []},
 'reaktie': ['reakties'],
 'reaktion': {'reaktioner': [], 'reaktions': []},
 'reaktionar': {'reaktionare': ['reaktionarer']},
 'reaktionare': ['reaktionarer'],
 'reaktionsdau': {'reaktionsdauer': []},
 'reaktionsfahig': {'reaktionsfahige': []},
 'reaktionsfolg': {'reaktionsfolge': []},
 'reaktionsgemisch': {'reaktionsgemisches': []},
 'reaktionskett': {'reaktionskette': []},
 'reaktionskinetisch': {'reaktionskinetische': []},
 'reaktionslag': {'reaktionslage': []},
 'reaktionsmechanismu': {'reaktionsmechanismus': []},
 'reaktionsmust': {'reaktionsmuster': []},
 'reaktionspartn': {'reaktionspartner': []},
 'reaktionsprodukt': {'reaktionsprodukte': ['reaktionsproduktes']},
 'reaktionsprodukte': ['reaktionsproduktes'],
 'reaktionsschritt': {'reaktionsschritte': []},
 'reaktionssystem': {'reaktionssystems': []},
 'reaktionstechnisch': {'reaktionstechnische': []},
 'reaktionsweis': {'reaktionsweise': []},
 'reaktionszon': {'reaktionszone': []},
 'reaktiv': {'reaktive': ['reaktiver']},
 'reaktive': ['reaktiver'],
 'reaktor': {'reaktors': []},
 'reaktorbauelement': {'reaktorbauelemente': []},
 'reaktorunfal': {'reaktorunfall': []},
 'real': ['reale',
          'realed',
          'realing',
          'realness',
          'realative',
          'realatives',
          'realatively'],
 "real'i": {"real'y": []},
 "real'ti": {"real'ty": []},
 'reala': {'realas': []},
 'realag': {'realage': []},
 'realat': {'realated': [],
            'realating': [],
            'realation': ['realations'],
            'realator': []},
 'realation': ['realations'],
 'realationship': {'realationships': []},
 'realbal': {'realbalance': ['realbalances']},
 'realbalance': ['realbalances'],
 'realbas': {'realbasic': []},
 'realbil': {'realbills': []},
 'realbn': {'realbns': []},
 'realbnabl': {'realbnable': []},
 'realbusi': {'realbusiness': []},
 'realc': {'realce': ['realces'], 'realcs': []},
 'realcapit': {'realcapital': []},
 'realce': ['realces'],
 'realclearpolit': {'realclearpolitics': []},
 'realclim': {'realclimate': []},
 'realcod': {'realcoded': []},
 'reald': {'realde': []},
 'realdenc': {'realdence': []},
 'realdu': {'realdus': []},
 'realeas': {'realease': ['realeases', 'realeased'], 'realeasing': []},
 'realease': ['realeases', 'realeased'],
 'realeinkommen': {'realeinkommens': []},
 'realejo': {'realejos': []},
 'realencyclopadi': {'realencyclopadie': []},
 'realencyclopaedi': {'realencyclopaedie': []},
 'realencyclopddi': {'realencyclopddie': []},
 'realencyclopedi': {'realencyclopedie': []},
 'realencyclopiidi': {'realencyclopiidie': []},
 'realencydopadi': {'realencydopadie': []},
 'realencyklopadi': {'realencyklopadie': []},
 'realencyklopaedi': {'realencyklopaedie': []},
 'realencyklopddi': {'realencyklopddie': []},
 'realencyklopiidi': {'realencyklopiidie': []},
 'realenga': {'realengas': []},
 'realengo': {'realengos': []},
 'realenzyclopadi': {'realenzyclopadie': []},
 'realenzyklopadi': {'realenzyklopadie': []},
 'realenzyklopaedi': {'realenzyklopaedie': []},
 'realenzyklopddi': {'realenzyklopddie': []},
 'realenzyklopedi': {'realenzyklopedie': []},
 'realenzyklopiidi': {'realenzyklopiidie': []},
 'realer': {'realers': []},
 'realert': {'realerted': []},
 'reales': {'realesed': []},
 'realesbian': {'realesbians': []},
 'realest': {'realestate': []},
 'realfi': {'realfy': []},
 'realfti': {'realfty': []},
 'realga': {'realgas': []},
 'realgeschicht': {'realgeschichte': []},
 'realgrund': {'realgrunde': []},
 'realguid': {'realguide': []},
 'realgymnasium': {'realgymnasiums': []},
 'realhi': {'realhy': []},
 'reali': {'realie': ['realies', 'realied'], 'realis': [], 'realy': []},
 "reali'i": {"reali'y": []},
 'realia': {'realiae': ['realiaed']},
 'realiaat': {'realiaation': []},
 'realiabl': {'realiability': [], 'realiable': [], 'realiably': []},
 'realiae': ['realiaed'],
 'realianc': {'realiance': []},
 'realiat': {'realiatic': [], 'realiation': []},
 'realibl': {'realibility': [], 'realible': []},
 'realibu': {'realibus': []},
 'realic': {'realice': []},
 'realici': {'realicy': []},
 'realid': {'realideal': [], 'realides': []},
 'realidad': {'realidade': ['realidades']},
 'realidade': ['realidades'],
 'realidadi': {'realidady': []},
 'realie': {'realiee': ['realieed']},
 'realieat': {'realieation': []},
 'realiee': ['realieed'],
 'realien': {'realienation': []},
 'realienkund': {'realienkunde': []},
 'realif': {'realife': ['realifed']},
 'realife': ['realifed'],
 'realifi': {'realify': []},
 'realig': {'realigment': ['realigments']},
 'realight': {'realighted': [], 'realighting': []},
 'realigment': ['realigments'],
 'realign': {'realigned': [],
             'realignement': [],
             'realigner': ['realigners'],
             'realigning': [],
             'realignment': ['realignments'],
             'realigns': []},
 'realigner': ['realigners'],
 'realignment': ['realignments'],
 'realii': {'realiie': ['realiied', 'realiies']},
 'realiiat': {'realiiation': []},
 'realiie': ['realiied', 'realiies'],
 'realiiti': {'realiity': []},
 'realil': {'realile': []},
 'realili': {'realily': []},
 'realilti': {'realilty': []},
 'realiment': {'realimentation': [], 'realimented': []},
 'realin': {'realine': ['realined', 'realinement', 'realinements'],
            'realining': []},
 'realincom': {'realincome': []},
 'realine': ['realined', 'realinement', 'realinements'],
 'realir': {'realiration': [], 'realire': ['realired']},
 'realire': ['realired'],
 'realiri': {'realiry': []},
 'realis': {'realisability': [],
            'realisable': ['realisables'],
            'realisant': [],
            'realisation': ['realisational'],
            'realise': ['realises',
                        'realised',
                        'realiser',
                        'realisent',
                        'realisers',
                        'realiseable',
                        'realisering',
                        'realisement'],
            'realisic': [],
            'realising': []},
 'realisa': {'realisas': []},
 'realisable': ['realisables'],
 'realisai': {'realisaient': []},
 'realisam': {'realisames': []},
 'realisateur': {'realisateurs': []},
 'realisati': {'realisatie': ['realisaties']},
 'realisatie': ['realisaties'],
 'realisation': ['realisational'],
 'realise': {'realisee': ['realisees']},
 'realisee': ['realisees'],
 'realiser': {'realisere': ['realiseres', 'realiserent']},
 'realisera': {'realiseras': []},
 'realisere': ['realiseres', 'realiserent'],
 'realiseron': {'realiserons': []},
 'realish': {'realished': []},
 'realisierbar': {'realisierbare': []},
 'realisierend': {'realisierende': []},
 'realisiert': {'realisierte': ['realisierter', 'realisiertes']},
 'realisierte': ['realisierter', 'realisiertes'],
 'realisingli': {'realisingly': []},
 'realisit': {'realisitic': ['realisitically']},
 'realisitic': ['realisitically'],
 'realisl': {'realislic': []},
 'realism': ['realisme', 'realismes'],
 'realismid': {'realismidealism': []},
 'realismnomin': {'realismnominalism': []},
 'realismu': {'realismus': []},
 'realismuskonzept': {'realismuskonzeption': []},
 'realismustheori': {'realismustheorie': []},
 'realison': {'realisons': []},
 'realisr': {'realisric': []},
 'realist': ['realiste',
             'realistic',
             'realistes',
             'realister',
             'realistics',
             'realistion',
             'realistical',
             'realistically',
             'realisticness'],
 'realista': {'realistas': []},
 'realisti': {'realistie': ['realisties'], 'realistis': [], 'realisty': []},
 'realisticali': {'realisticaly': []},
 'realisticallymind': {'realisticallyminded': []},
 'realisticament': {'realisticamente': []},
 'realistich': {'realistiche': []},
 'realisticli': {'realisticly': []},
 'realisticlook': {'realisticlooking': []},
 'realisticnaturalist': {'realisticnaturalistic': []},
 'realisticsound': {'realisticsounding': []},
 'realistie': ['realisties'],
 'realistisch': {'realistische': ['realistischer', 'realistisches']},
 'realistische': ['realistischer', 'realistisches'],
 'realistischer': {'realistischere': []},
 'realistischerweis': {'realistischerweise': []},
 'realistisk': {'realistiske': []},
 'realit': {'realitate': ['realitates'],
            'realitation': [],
            'realite': ['realites', 'realited', 'realiter'],
            'realitic': ['realitics'],
            'realition': [],
            'realitities': [],
            'realitive': ['realitively'],
            'realitivity': [],
            'realits': []},
 'realita': {'realitas': []},
 'realitat': {'realitats': []},
 'realitate': ['realitates'],
 'realitati': {'realitatis': []},
 'realitatsgrad': {'realitatsgrades': []},
 'realitatsnah': {'realitatsnahe': []},
 'realite': ['realites', 'realited', 'realiter'],
 'realitet': {'realiteter': []},
 'realiti': {'realitie': [], 'realitis': [], 'reality': []},
 'realitic': ['realitics'],
 'realitit': {'realitites': []},
 'realitive': ['realitively'],
 'realito': {'realitos': []},
 'realitya': {'realityas': []},
 'realitybas': {'realitybased': []},
 'realitycent': {'realitycentered': []},
 'realityconstruct': {'realityconstruction': []},
 'realitycr': {'realitycreating': []},
 'realitydistort': {'realitydistorting': []},
 'realityengin': {'realityengine': []},
 'realityfeel': {'realityfeeling': []},
 'realityi': {'realityis': []},
 'realityori': {'realityoriented': []},
 'realityorient': {'realityorientation': []},
 'realityprincipl': {'realityprinciple': []},
 'realitysens': {'realitysense': []},
 'realitytest': {'realitytested': [], 'realitytesting': []},
 'realityth': {'realitythe': []},
 'realitythink': {'realitythinking': []},
 'realityvalu': {'realityvalue': []},
 'realitywa': {'realitywas': []},
 'realiu': {'realius': []},
 'realiz': {'realizability': [],
            'realizable': ['realizables', 'realizableness'],
            'realizably': [],
            'realizate': ['realizates'],
            'realization': ['realizational', 'realizationally'],
            'realizator': ['realizators'],
            'realize': ['realizer',
                        'realized',
                        'realizes',
                        'realizers',
                        'realizeable'],
            'realizibility': [],
            'realizing': ['realizings'],
            'realizou': [],
            'realizs': []},
 'realiza': {'realizas': []},
 'realizable': ['realizables', 'realizableness'],
 'realizac': {'realizace': []},
 'realizacij': {'realizacije': []},
 'realizacion': {'realizaciones': []},
 'realizacj': {'realizacje': []},
 'realizaco': {'realizacoes': []},
 'realizada': {'realizadas': []},
 'realizado': {'realizados': []},
 'realizador': {'realizadores': []},
 'realizamo': {'realizamos': []},
 'realizandos': {'realizandose': []},
 'realizar': {'realizare': []},
 'realizarla': {'realizarlas': []},
 'realizarlo': {'realizarlos': []},
 'realizars': {'realizarse': []},
 'realizas': {'realizase': []},
 'realizate': ['realizates'],
 'realization': {'realizationism': []},
 'realizationist': {'realizationists': []},
 'realizator': ['realizators'],
 'realizatori': {'realizatory': []},
 'realize': ['realizer', 'realized', 'realizes', 'realizers', 'realizeable'],
 'realized': {'realizedness': []},
 'realizepalett': {'realizepalette': []},
 'realizeth': {'realizethe': []},
 'realizing': ['realizings'],
 'realizingli': {'realizingly': []},
 'realizingth': {'realizingthe': []},
 'realizm': {'realizme': []},
 'realizmu': {'realizmus': []},
 'realizowan': {'realizowane': []},
 'realizowani': {'realizowany': []},
 'realizt': {'realiztion': []},
 'realizuj': {'realizuje': []},
 'realizz': {'realizzate': []},
 'realizzabil': {'realizzabile': []},
 'realizzar': {'realizzare': []},
 'realizzator': {'realizzatore': []},
 'realizzazion': {'realizzazione': []},
 'realji': {'realjy': []},
 'realjti': {'realjty': []},
 'realk': {'realke': ['realked']},
 'realkal': {'realkalization': []},
 'realkalin': {'realkalinization': []},
 'realkalis': {'realkalisation': []},
 'realkapit': {'realkapital': ['realkapitals']},
 'realkapital': ['realkapitals'],
 'realkat': {'realkation': []},
 'realke': ['realked'],
 'realki': {'realky': []},
 'realkurs': {'realkurse': []},
 'realkyl': {'realkylation': []},
 'reall': {'realle': ['realled', 'realles'], 'realls': []},
 'realle': ['realled', 'realles'],
 'realleg': {'reallege': ['realleges', 'realleged'], 'realleging': []},
 'reallege': ['realleges', 'realleged'],
 'realli': {'reallie': ['reallied'], 'really': ['reallys']},
 'reallianc': {'realliance': ['realliances']},
 'realliance': ['realliances'],
 'reallie': ['reallied'],
 'reallif': {'reallife': []},
 'reallign': {'realligned': [], 'reallignment': []},
 'reallis': {'reallised': []},
 'realliti': {'reallity': []},
 'realliv': {'reallive': []},
 'realliz': {'reallize': ['reallized'], 'reallizing': []},
 'reallize': ['reallized'],
 'reallli': {'reallly': []},
 'realllli': {'realllly': []},
 'reallllli': {'reallllly': []},
 'reallm': {'reallme': []},
 'realloc': {'reallocable': [],
             'reallocate': ['reallocates', 'reallocated'],
             'reallocating': [],
             'reallocation': ['reallocational'],
             'reallocative': [],
             'reallocator': []},
 'reallocat': {'reallocatable': []},
 'reallocate': ['reallocates', 'reallocated'],
 'reallocation': ['reallocational'],
 'reallohn': {'reallohne': []},
 'reallook': {'reallooking': []},
 'reallot': {'realloted': [],
             'realloting': [],
             'reallotment': [],
             'reallotted': [],
             'reallotting': []},
 'reallow': {'reallowance': ['reallowances'], 'reallowed': []},
 'reallowance': ['reallowances'],
 'reallti': {'reallty': []},
 'realltl': {'realltles': []},
 'really': ['reallys'],
 "really'v": {"really've": []},
 'reallyar': {'reallyare': []},
 'reallyb': {'reallybe': []},
 'reallygo': {'reallygoing': []},
 'reallyhappen': {'reallyhappened': []},
 'reallyhav': {'reallyhave': []},
 'reallyi': {'reallyis': []},
 'reallyimport': {'reallyimportant': []},
 'reallylik': {'reallylike': []},
 'reallyne': {'reallyneed': []},
 'reallyneed': {'reallyneeded': []},
 'reallyonli': {'reallyonly': []},
 'reallyr': {'reallyreally': []},
 'reallyreallyreallyreallyr': {'reallyreallyreallyreallyreally': []},
 'reallyth': {'reallythe': []},
 'reallyw': {'reallywant': ['reallywanted']},
 'reallywa': {'reallywas': []},
 'reallywant': ['reallywanted'],
 'reallz': {'reallze': ['reallzed']},
 'reallze': ['reallzed'],
 'realm': ['realme', 'realmed', 'realmes'],
 'realment': {'realmente': []},
 'realmi': {'realmis': [], 'realmys': []},
 'realmod': {'realmode': []},
 'realmont': {'realmonte': []},
 'realn': {'realne': []},
 'realnam': {'realname': ['realnames']},
 'realname': ['realnames'],
 'realnetwork': {'realnetworks': []},
 'realni': {'realnie': [], 'realny': []},
 'realnumb': {'realnumber': ['realnumbers']},
 'realnumber': ['realnumbers'],
 'realo': {'realos': []},
 'realog': {'realogy': []},
 'realomet': {'realometer': []},
 'realon': {'realonable': [], 'realonably': [], 'realone': [], 'realons': []},
 'realontologi': {'realontologie': []},
 'realou': {'realous': []},
 'realous': {'realously': []},
 'realousi': {'realousy': []},
 'realp': {'realpe': []},
 'realpeopl': {'realpeople': []},
 'realphabet': {'realphabetize': ['realphabetized'], 'realphabetizing': []},
 'realphabetize': ['realphabetized'],
 'realphilosophi': {'realphilosophie': []},
 'realplay': {'realplayer': ['realplayers']},
 'realplayer': ['realplayers'],
 'realpol': {'realpoliti': []},
 'realpolit': {'realpolitic': ['realpolitics', 'realpolitical']},
 'realpolitic': ['realpolitics', 'realpolitical'],
 'realpolitician': {'realpoliticians': []},
 'realpolitik': ['realpolitiker', 'realpolitikal', 'realpolitikers'],
 'realpolitisch': {'realpolitische': []},
 'realpow': {'realpower': []},
 'realproduc': {'realproducer': []},
 'realproperti': {'realproperty': []},
 'realra': {'realrae': []},
 'realrealrealrealr': {'realrealrealrealreal': []},
 'realri': {'realry': []},
 'realrn': {'realrne': []},
 'realrti': {'realrty': []},
 'realrz': {'realrze': ['realrzed']},
 'realrze': ['realrzed'],
 'reals': {'realse': ['realsed'], 'realsing': []},
 'realschool': {'realschools': []},
 'realschul': {'realschule': ['realschuler']},
 'realschule': ['realschuler'],
 'realschullehr': {'realschullehrer': []},
 'realse': ['realsed'],
 'realsecur': {'realsecure': []},
 'realseem': {'realseeming': []},
 'realserv': {'realserver': ['realservers']},
 'realserver': ['realservers'],
 'realsimpl': {'realsimple': []},
 'realsit': {'realsitic': []},
 'realskol': {'realskole': ['realskoler']},
 'realskole': ['realskoler'],
 'realsong': {'realsongs': []},
 'realsozialismu': {'realsozialismus': []},
 'realspac': {'realspace': []},
 'realt': {'realte': ['realtes', 'realted'], 'realting': [], 'realts': []},
 'realte': {'realtee': ['realteed']},
 'realtee': ['realteed'],
 'realter': {'realteration': ['realterations'],
             'realtered': [],
             'realtering': []},
 'realteration': ['realterations'],
 'realterm': {'realterms': []},
 'realth': {'realthe': []},
 'realtheologi': {'realtheologie': []},
 'realti': {'realtie': [], 'realty': []},
 'realtim': {'realtime': []},
 'realtin': {'realtine': []},
 'realtion': {'realtional': [], 'realtions': []},
 'realtionship': {'realtionships': []},
 'realtist': {'realtistic': [], 'realtists': []},
 'realtiti': {'realtities': [], 'realtity': []},
 'realtiv': {'realtive': ['realtives', 'realtively'], 'realtivity': []},
 'realtive': ['realtives', 'realtively'],
 'realtivist': {'realtivistic': []},
 'realtn': {'realtne': []},
 'realtor': {'realtor': []},
 'realtre': {'realtree': []},
 'realtt': {'realttes': []},
 'realtti': {'realtty': []},
 'realu': {'realued': []},
 'realumin': {'realuminized': []},
 'realunr': {'realunreal': []},
 'realvalu': {'realvalue': ['realvalued', 'realvalues']},
 'realvalue': ['realvalued', 'realvalues'],
 'realvil': {'realville': []},
 'realwag': {'realwage': ['realwages']},
 'realwage': ['realwages'],
 'realz': {'realze': ['realzed'], 'realzing': []},
 'realzat': {'realzation': []},
 'realze': ['realzed'],
 'ream': ['reame', 'reames', 'reamed', 'reaming', 'reamings'],
 'reamain': {'reamained': [], 'reamaining': [], 'reamains': []},
 'reamalgam': {'reamalgamate': ['reamalgamated'],
               'reamalgamating': [],
               'reamalgamation': []},
 'reamalgamate': ['reamalgamated'],
 'reamalgamerg': {'reamalgamerge': []},
 'reambl': {'reamble': []},
 'reambul': {'reambulation': []},
 'reamedi': {'reamedy': []},
 'reamenag': {'reamenage': ['reamenager', 'reamenagement', 'reamenagements']},
 'reamenage': ['reamenager', 'reamenagement', 'reamenagements'],
 'reamend': {'reamended': [],
             'reamending': [],
             'reamendment': ['reamendments']},
 'reamendment': ['reamendments'],
 'reamer': ['reamered', 'reamering'],
 'reami': {'reamie': [], 'reamy': []},
 'reamif': {'reamife': []},
 'reamin': {'reaminated': [],
            'reamination': [],
            'reamined': [],
            'reamining': [],
            'reamins': []},
 'reamind': {'reaminder': []},
 'reammunit': {'reammunitioned': []},
 'reamort': {'reamortization': [], 'reamortize': ['reamortized']},
 'reamortize': ['reamortized'],
 'reamplif': {'reamplification': []},
 'reamplifi': {'reamplified': [],
               'reamplifies': [],
               'reamplify': ['reamplifying']},
 'reamplify': ['reamplifying'],
 'reamput': {'reamputate': ['reamputated'], 'reamputation': ['reamputations']},
 'reamputate': ['reamputated'],
 'reamputation': ['reamputations'],
 'reamread': {'reamreader': []},
 'reamrmat': {'reamrmation': []},
 'reamti': {'reamty': []},
 'rean': {'reane': ['reaned', 'reanes'], 'reaning': [], 'reans': []},
 'reanaesthet': {'reanaesthetized': []},
 'reanal': {'reanalized': []},
 'reanali': {'reanaly': []},
 'reanalvsi': {'reanalvsis': []},
 'reanalys': {'reanalyse': ['reanalyses', 'reanalysed'], 'reanalysing': []},
 'reanalyse': ['reanalyses', 'reanalysed'],
 'reanalysi': {'reanalysis': []},
 'reanalysl': {'reanalysls': []},
 'reanalyz': {'reanalyzable': [],
              'reanalyze': ['reanalyzed', 'reanalyzes'],
              'reanalyzing': []},
 'reanalyze': ['reanalyzed', 'reanalyzes'],
 'reanang': {'reananged': []},
 'reanastamos': {'reanastamosed': []},
 'reanastamosi': {'reanastamosis': []},
 'reanastomos': {'reanastomose': ['reanastomoses', 'reanastomosed'],
                 'reanastomosing': []},
 'reanastomose': ['reanastomoses', 'reanastomosed'],
 'reanastomosi': {'reanastomosis': []},
 'reanc': {'reance': []},
 'reanchor': {'reanchored': [], 'reanchoring': [], 'reanchors': []},
 'reanci': {'reancy': []},
 'reane': ['reaned', 'reanes'],
 'reanesthet': {'reanesthetization': [],
                'reanesthetize': ['reanesthetized'],
                'reanesthetizing': []},
 'reanesthetize': ['reanesthetized'],
 'reang': {'reange': [], 'reangs': []},
 'reangl': {'reangle': ['reangled'], 'reangling': []},
 'reangle': ['reangled'],
 'reangul': {'reangulation': []},
 'reani': {'reanie': ['reanies'], 'reany': []},
 'reanie': ['reanies'],
 'reanim': {'reanimate': ['reanimated', 'reanimates'],
            'reanimating': [],
            'reanimation': ['reanimations'],
            'reanimator': ['reanimators'],
            'reanimer': []},
 'reanimate': ['reanimated', 'reanimates'],
 'reanimation': ['reanimations'],
 'reanimatolog': {'reanimatology': []},
 'reanimator': ['reanimators'],
 'reaniss': {'reanissance': []},
 'reankylosi': {'reankylosis': []},
 'reann': {'reanne': []},
 'reanneal': {'reannealed': [], 'reannealing': [], 'reanneals': []},
 'reanni': {'reanny': []},
 'reannot': {'reannotated': [], 'reannotation': []},
 'reannounc': {'reannounce': ['reannounces', 'reannounced', 'reannouncement'],
               'reannouncing': []},
 'reannounce': ['reannounces', 'reannounced', 'reannouncement'],
 'reanod': {'reanodized': []},
 'reanoint': {'reanointed': [], 'reanointing': [], 'reanointment': []},
 'reanswer': {'reanswered': [], 'reanswering': []},
 'reanticoagul': {'reanticoagulation': []},
 'reanud': {'reanude': []},
 'reanudars': {'reanudarse': []},
 'reanvil': {'reanville': []},
 'reao': {'reaoing': ['reaoings'], 'reaos': []},
 'reaoer': {'reaoers': []},
 'reaoh': {'reaohed': [], 'reaohes': [], 'reaohing': []},
 'reaoing': ['reaoings'],
 'reaolut': {'reaolution': []},
 'reaolv': {'reaolve': ['reaolved']},
 'reaolve': ['reaolved'],
 'reaon': {'reaoning': [], 'reaons': []},
 'reaonabl': {'reaonable': [], 'reaonably': []},
 'reaonanc': {'reaonance': []},
 'reaonsabl': {'reaonsable': []},
 'reaoon': {'reaoons': []},
 'reaor': {'reaored': []},
 'reaort': {'reaorted': []},
 'reaosn': {'reaosns': []},
 'reaot': {'reaote': ['reaoted'], 'reaoting': [], 'reaots': []},
 'reaotant': {'reaotants': []},
 'reaote': ['reaoted'],
 'reaotion': {'reaotione': [], 'reaotions': []},
 'reaotiv': {'reaotive': [], 'reaotivity': []},
 'reaotlon': {'reaotlons': []},
 'reaotor': {'reaotors': []},
 'reaourc': {'reaource': ['reaources']},
 'reaource': ['reaources'],
 'reaov': {'reaove': ['reaoved'], 'reaoving': []},
 'reaove': ['reaoved'],
 'reap': {'reape': ['reapes', 'reaped', 'reapeing'],
          'reaping': ['reapings'],
          'reaps': []},
 'reapabl': {'reapable': []},
 'reaparec': {'reaparece': ['reaparecer']},
 'reaparece': ['reaparecer'],
 'reape': ['reapes', 'reaped', 'reapeing'],
 'reapear': {'reapearance': [], 'reapeared': []},
 'reapeat': {'reapeated': []},
 'reapeatedli': {'reapeatedly': []},
 'reapect': {'reapectable': [],
             'reapected': [],
             'reapecting': [],
             'reapective': ['reapectively'],
             'reapects': []},
 'reapective': ['reapectively'],
 'reapeot': {'reapeotively': []},
 'reaper': {'reaper': []},
 'reaperbind': {'reaperbinder': []},
 'reaph': {'reaphed': []},
 'reaphook': {'reaphooks': []},
 'reapi': {'reapy': []},
 'reapidli': {'reapidly': []},
 'reaping': ['reapings'],
 'reapinghook': {'reapinghooks': []},
 'reapingmachin': {'reapingmachine': ['reapingmachines']},
 'reapingmachine': ['reapingmachines'],
 'reapingtool': {'reapingtools': []},
 'reapir': {'reapiration': [], 'reapirs': []},
 'reapiratori': {'reapiratory': []},
 'reapon': {'reapons': []},
 'reapona': {'reaponae': [], 'reaponaibility': [], 'reaponaible': []},
 'reapond': {'reaponded': [], 'reapondent': ['reapondents']},
 'reapondent': ['reapondents'],
 'reapone': {'reaponee': []},
 'reapons': {'reaponse': ['reaponses'],
             'reaponsibility': [],
             'reaponsible': []},
 'reaponse': ['reaponses'],
 'reaport': {'reaporte': ['reaportes', 'reaported']},
 'reaporte': ['reaportes', 'reaported'],
 'reappar': {'reapparance': [], 'reappared': []},
 'reapparaiss': {'reapparaissent': []},
 'reapparaitr': {'reapparaitre': []},
 'reapparit': {'reapparition': ['reapparitions']},
 'reapparition': ['reapparitions'],
 'reappeal': {'reappealed': [], 'reappeals': []},
 'reappear': {'reappearance': [],
              'reappeared': [],
              'reappearence': [],
              'reappearing': ['reappearings'],
              'reappears': []},
 'reappearing': ['reappearings'],
 'reappel': {'reappeller': []},
 'reapper': {'reapperance': [], 'reappered': [], 'reappers': []},
 'reappli': {'reapplied': [], 'reapplies': [], 'reapply': ['reapplying']},
 'reapplic': {'reapplicability': [],
              'reapplicable': [],
              'reapplicant': ['reapplicants'],
              'reapplication': ['reapplications']},
 'reapplicant': ['reapplicants'],
 'reapplication': ['reapplications'],
 'reapply': ['reapplying'],
 'reappoint': {'reappointed': [],
               'reappointing': [],
               'reappointment': ['reappointments'],
               'reappoints': []},
 'reappointment': ['reappointments'],
 'reappoiut': {'reappoiuted': []},
 'reapport': {'reapportion': ['reapportions',
                              'reapportioned',
                              'reapportioning']},
 'reapportion': {'reapportionment': []},
 'reappos': {'reappose': ['reapposed'], 'reapposing': []},
 'reappose': ['reapposed'],
 'reapposit': {'reapposition': []},
 'reapppear': {'reapppeared': []},
 'reapprais': {'reappraisal': [],
               'reappraise': ['reappraised',
                              'reappraises',
                              'reappraiser',
                              'reappraisers',
                              'reappraisement',
                              'reappraisements'],
               'reappraising': []},
 'reappraise': ['reappraised',
                'reappraises',
                'reappraiser',
                'reappraisers',
                'reappraisement',
                'reappraisements'],
 'reapprasi': {'reapprasial': []},
 'reappreci': {'reappreciate': ['reappreciated'],
               'reappreciating': [],
               'reappreciation': []},
 'reappreciate': ['reappreciated'],
 'reapprehend': {'reapprehended': [], 'reapprehending': [], 'reapprehends': []},
 'reapprehens': {'reapprehension': []},
 'reapprendr': {'reapprendre': []},
 'reapprent': {'reapprenticed': []},
 'reapprias': {'reappriasal': []},
 'reappris': {'reapprisal': [], 'reapprise': ['reapprised']},
 'reapprise': ['reapprised'],
 'reapproach': {'reapproached': [],
                'reapproachement': [],
                'reapproaches': [],
                'reapproaching': [],
                'reapproachment': []},
 'reapproch': {'reapprochement': [], 'reapprochment': []},
 'reappropri': {'reappropriable': [],
                'reappropriate': ['reappropriated', 'reappropriates'],
                'reappropriating': [],
                'reappropriation': ['reappropriations'],
                'reappropriative': [],
                'reapproprier': []},
 'reappropriate': ['reappropriated', 'reappropriates'],
 'reappropriation': ['reappropriations'],
 'reapprov': {'reapproval': ['reapprovals'],
              'reapprove': ['reapproved'],
              'reapproving': []},
 'reapproval': ['reapprovals'],
 'reapprove': ['reapproved'],
 'reaprais': {'reapraisal': []},
 'reaps': {'reapse': []},
 'reapsom': {'reapsome': []},
 'reaqh': {'reaqhed': []},
 'reaquaint': {'reaquaintance': [], 'reaquainted': []},
 'reaquir': {'reaquire': ['reaquired']},
 'reaquire': ['reaquired'],
 'reaquisit': {'reaquisition': []},
 'rear': ['reare', 'reares', 'reared', 'rearing', 'rearely'],
 'rearabl': {'rearability': [], 'rearable': []},
 'rearadmir': {'rearadmiral': ['rearadmirals']},
 'rearadmiral': ['rearadmirals'],
 'rearag': {'rearage': ['rearages']},
 'rearage': ['rearages'],
 'rearang': {'rearanged': [],
             'rearangement': ['rearangements'],
             'rearanging': []},
 'rearangement': ['rearangements'],
 'rearbas': {'rearbase': []},
 'rearbitr': {'rearbitrate': ['rearbitrated'], 'rearbitration': []},
 'rearbitrate': ['rearbitrated'],
 'rearch': {'rearched': [], 'rearches': [], 'rearching': []},
 'rearcher': {'rearchers': []},
 'rearchitect': {'rearchitected': [], 'rearchitecting': []},
 'rearchitectur': {'rearchitecture': []},
 'reard': {'rearde': ['rearded'], 'rearding': [], 'reards': []},
 'rearde': ['rearded'],
 'rearden': {'reardens': []},
 'reardon': {'reardons': []},
 'reardriv': {'reardrive': []},
 'reareat': {'reareation': []},
 'rearend': {'rearended': [], 'rearending': [], 'rearends': []},
 'rearengin': {'rearengine': ['rearengined']},
 'rearengine': ['rearengined'],
 'rearentri': {'rearentry': []},
 'rearer': {'rearers': []},
 'rearess': {'rearession': []},
 'rearfac': {'rearfacing': []},
 'rearfang': {'rearfanged': []},
 'rearfirm': {'rearfirmation': []},
 'reargu': {'reargue': ['reargues', 'reargued'], 'rearguing': []},
 'rearguard': ['rearguarders'],
 'reargue': ['reargues', 'reargued'],
 'reargument': {'rearguments': []},
 'reargunn': {'reargunner': ['reargunners']},
 'reargunner': ['reargunners'],
 'rearh': {'rearhed': [], 'rearhing': []},
 'rearhors': {'rearhorse': []},
 'reari': {'rearis': [], 'reary': []},
 'rearis': {'rearise': ['rearises'], 'rearising': []},
 'rearise': ['rearises'],
 'rearkabl': {'rearkable': []},
 'rearli': {'rearly': []},
 'rearlight': {'rearlights': []},
 'rearlin': {'rearline': []},
 'rearload': {'rearloading': []},
 'rearm': {'rearmed': [], 'rearming': [], 'rearms': []},
 'rearmament': {'rearmament': []},
 'rearman': {'rearmanent': []},
 'rearmer': {'rearmers': []},
 'rearmount': {'rearmounted': []},
 'rearmous': {'rearmouse': []},
 'rearn': {'rearns': []},
 'rearomat': {'rearomatization': [], 'rearomatized': []},
 'rearon': {'rearons': []},
 'rearos': {'rearose': []},
 'rearous': {'rearousal': [],
             'rearouse': ['rearouses', 'rearoused'],
             'rearousing': []},
 'rearouse': ['rearouses', 'rearoused'],
 'rearproject': {'rearprojected': [], 'rearprojection': []},
 'rearquart': {'rearquarter': ['rearquarters']},
 'rearquarter': ['rearquarters'],
 'rearrag': {'rearragement': ['rearragements']},
 'rearragement': ['rearragements'],
 'rearraign': {'rearraigned': [], 'rearraignment': []},
 'rearrang': {'rearrangable': [],
              'rearrange': ['rearranged',
                            'rearranges',
                            'rearranger',
                            'rearrangers',
                            'rearrangement',
                            'rearrangeably',
                            'rearrangeable',
                            'rearrangeability'],
              'rearranging': ['rearrangings'],
              'rearrangment': ['rearrangments']},
 'rearrange': ['rearranged',
               'rearranges',
               'rearranger',
               'rearrangers',
               'rearrangement',
               'rearrangeably',
               'rearrangeable',
               'rearrangeability'],
 'rearranging': ['rearrangings'],
 'rearrangingli': {'rearrangingly': []},
 'rearrangment': ['rearrangments'],
 'rearray': {'rearrayed': [], 'rearraying': []},
 'rearreng': {'rearrengement': []},
 'rearrest': {'rearrested': [], 'rearresting': [], 'rearrests': []},
 'rearriv': {'rearrival': [],
             'rearrive': ['rearrived', 'rearrives'],
             'rearriving': []},
 'rearrive': ['rearrived', 'rearrives'],
 'rearsbi': {'rearsby': []},
 'rearsid': {'rearside': []},
 'rearstag': {'rearstage': []},
 'rearsuspens': {'rearsuspension': []},
 'reart': {'rearte': []},
 'rearteri': {'rearterialization': []},
 'rearticul': {'rearticulate': ['rearticulates', 'rearticulated'],
               'rearticulating': [],
               'rearticulation': ['rearticulations']},
 'rearticulate': ['rearticulates', 'rearticulated'],
 'rearticulation': ['rearticulations'],
 'rearticulatori': {'rearticulatory': []},
 'reartion': {'reartions': []},
 'rearvass': {'rearvassals': []},
 'rearview': {'rearviews': []},
 'rearvis': {'rearvision': []},
 'rearward': {'rearward': []},
 'rearwardfac': {'rearwardfacing': []},
 'rearwardli': {'rearwardly': []},
 'rearway': {'rearways': []},
 'reas': {'rease': ['reases', 'reased'], 'reasing': []},
 'reasan': {'reasanable': [], 'reasans': []},
 'reasbi': {'reasby': []},
 'reasbn': {'reasbns': []},
 'reascend': {'reascendance': [],
              'reascendancy': [],
              'reascendant': [],
              'reascended': [],
              'reascendency': [],
              'reascending': [],
              'reascends': []},
 'reascens': {'reascension': []},
 'reascent': {'reascents': []},
 'reascertain': {'reascertained': [], 'reascertaining': []},
 'reascn': {'reascns': []},
 'reascnabl': {'reascnable': []},
 'reascrib': {'reascribe': ['reascribed', 'reascribes'], 'reascribing': []},
 'reascribe': ['reascribed', 'reascribes'],
 'reascript': {'reascription': []},
 'reasdn': {'reasdns': []},
 'rease': ['reases', 'reased'],
 'reasearch': {'reasearcher': ['reasearchers'],
               'reasearches': [],
               'reasearching': []},
 'reasearcher': ['reasearchers'],
 'reaseguro': {'reaseguros': []},
 'reasel': {'reasels': []},
 'reasembl': {'reasembled': []},
 'reasen': {'reasenable': [], 'reasens': []},
 'reaserch': {'reaserchers': []},
 'reasess': {'reasessment': []},
 'reash': {'reashed': []},
 'reasi': {'reasy': []},
 'reasibl': {'reasible': []},
 'reasid': {'reaside': []},
 'reasili': {'reasily': []},
 'reasin': {'reasins': []},
 'reasing': {'reasinger': []},
 'reasingli': {'reasingly': []},
 'reasion': {'reasions': []},
 'reask': {'reaske': ['reasked'], 'reasking': [], 'reasks': []},
 'reaske': ['reasked'],
 'reaslis': {'reaslised': []},
 'reaslist': {'reaslistic': []},
 'reasnabl': {'reasnable': []},
 'reasnn': {'reasnns': []},
 'reaso': {'reasoing': [], 'reasos': []},
 'reasoa': {'reasoas': []},
 'reasoaabl': {'reasoaable': []},
 'reasoabl': {'reasoable': []},
 'reasoanbl': {'reasoanble': []},
 'reasoh': {'reasohs': []},
 'reasoi': {'reasois': []},
 'reasolut': {'reasolution': []},
 'reasom': {'reasoms': []},
 'reasomng': {'reasomngs': []},
 'reason': ['reasone',
            'reasoner',
            'reasonal',
            'reasones',
            'reasoned',
            'reasoning',
            'reasonant',
            'reasonning',
            'reasonator',
            'reasonibly',
            'reasonance',
            'reasonably',
            'reasonible',
            'reasonment',
            'reasonally',
            'reasonable',
            'reasonances',
            'reasonables',
            'reasonating',
            'reasonablely',
            'reasonability',
            'reasonableness'],
 'reasona': {'reasonaable': [], 'reasonaably': [], 'reasonas': []},
 'reasonab': {'reasonabe': []},
 "reasonab'": {"reasonab'e": []},
 'reasonabi': {'reasonabie': [], 'reasonaby': []},
 'reasonabil': {'reasonabill': []},
 'reasonabl': {'reasonabler': [], 'reasonablness': [], 'reasonabls': []},
 'reasonablelook': {'reasonablelooking': []},
 'reasonablen': {'reasonablenes': []},
 'reasonableness': {'reasonablenesse': []},
 'reasonables': {'reasonablesized': [], 'reasonablesness': []},
 'reasonablesound': {'reasonablesounding': []},
 'reasonabletim': {'reasonabletime': []},
 'reasonabli': {'reasonablie': []},
 'reasonablli': {'reasonablly': []},
 'reasonably': {'reasonablye': []},
 'reasonablyb': {'reasonablybe': []},
 'reasonablymind': {'reasonablyminded': []},
 'reasonablypr': {'reasonablypriced': []},
 'reasonablys': {'reasonablysized': []},
 'reasonabt': {'reasonabte': []},
 'reasonabti': {'reasonabty': []},
 'reasonadl': {'reasonadle': []},
 'reasonahl': {'reasonahle': ['reasonahleness']},
 'reasonahle': ['reasonahleness'],
 'reasonahli': {'reasonahly': []},
 'reasonal': {'reasonale': []},
 'reasonalb': {'reasonalbe': []},
 'reasonalbl': {'reasonalble': []},
 'reasonali': {'reasonaly': []},
 'reasonantli': {'reasonantly': []},
 'reasonaol': {'reasonaole': []},
 'reasonaoli': {'reasonaoly': []},
 'reasonbal': {'reasonbale': []},
 'reasonbas': {'reasonbased': []},
 'reasonbewild': {'reasonbewildering': []},
 'reasonbl': {'reasonble': ['reasonbleness'], 'reasonbly': []},
 'reasonble': ['reasonbleness'],
 'reasoncr': {'reasoncrs': []},
 'reasonebl': {'reasoneble': []},
 'reasonemot': {'reasonemotion': []},
 'reasoner': {'reasonere': []},
 'reasonf': {'reasonfs': []},
 'reasonforth': {'reasonforthe': []},
 'reasongiv': {'reasongiving': []},
 'reasonh': {'reasonhe': []},
 'reasoni': {'reasonis': [], 'reasony': []},
 'reasonin': {'reasonins': []},
 'reasoning': {'reasoninge': ['reasoninges']},
 'reasoninge': ['reasoninges'],
 'reasoningi': {'reasoningis': []},
 'reasoningli': {'reasoningly': []},
 'reasoningpow': {'reasoningpower': ['reasoningpowers']},
 'reasoningpower': ['reasoningpowers'],
 'reasoniug': {'reasoniugs': []},
 'reasonless': {'reasonlesse': [], 'reasonlessness': []},
 'reasonlessli': {'reasonlessly': []},
 'reasonli': {'reasonly': []},
 'reasonmg': {'reasonmgs': []},
 'reasonn': {'reasonnable': [], 'reasonnably': [], 'reasonne': []},
 'reasonnbl': {'reasonnble': []},
 'reasonobl': {'reasonoble': []},
 'reasononlin': {'reasononline': []},
 'reasonov': {'reasonover': []},
 'reasonprincipl': {'reasonprinciple': ['reasonprinciples']},
 'reasonprinciple': ['reasonprinciples'],
 'reasons': {'reasonsable': [], 'reasonse': ['reasonsed'], 'reasonsing': []},
 'reasonsar': {'reasonsare': []},
 'reasonsbl': {'reasonsble': [], 'reasonsbly': []},
 'reasonse': ['reasonsed'],
 'reasonsrespons': {'reasonsresponsive': ['reasonsresponsiveness']},
 'reasonsresponsive': ['reasonsresponsiveness'],
 'reasonswhi': {'reasonswhy': []},
 'reasonth': {'reasonthe': []},
 'reasonwhi': {'reasonwhy': []},
 'reasonyng': {'reasonynge': []},
 'reasoo': {'reasoos': []},
 'reasop': {'reasops': []},
 'reasor': {'reasorable': [], 'reasors': []},
 'reasorb': {'reasorbed': []},
 'reasori': {'reasoris': []},
 'reasorpt': {'reasorption': []},
 'reasoti': {'reasotis': []},
 'reasou': {'reasouing': ['reasouings'], 'reasous': []},
 'reasouabl': {'reasouable': [], 'reasouably': []},
 'reasouer': {'reasouers': []},
 'reasouing': ['reasouings'],
 'reasoun': {'reasounable': [], 'reasoune': ['reasouned'], 'reasouns': []},
 'reasoune': ['reasouned'],
 'reasourc': {'reasource': ['reasources']},
 'reasource': ['reasources'],
 'reaspir': {'reaspirate': ['reaspirated'],
             'reaspirating': [],
             'reaspiration': []},
 'reaspirate': ['reaspirated'],
 'reaspn': {'reaspns': []},
 'reaspnabl': {'reaspnable': []},
 'reaspons': {'reasponse': [], 'reasponsible': []},
 'reasqn': {'reasqns': []},
 'reass': {'reasses': []},
 'reassail': {'reassailed': []},
 'reassambl': {'reassambled': []},
 'reassault': {'reassaulted': []},
 'reassay': {'reassayed': [], 'reassaying': [], 'reassays': []},
 'reassembl': {'reassemblance': [],
               'reassemble': ['reassembles',
                              'reassembler',
                              'reassembled',
                              'reassemblement'],
               'reassembling': ['reassemblings'],
               'reassembly': []},
 'reassemblag': {'reassemblage': ['reassemblages']},
 'reassemblage': ['reassemblages'],
 'reassemble': ['reassembles', 'reassembler', 'reassembled', 'reassemblement'],
 'reassembling': ['reassemblings'],
 'reassemhl': {'reassemhled': []},
 'reasser': {'reasserred': []},
 'reassert': {'reassertation': [],
              'reasserted': [],
              'reasserting': [],
              'reassertion': [],
              'reassertive': ['reassertiveness'],
              'reasserts': []},
 'reassertive': ['reassertiveness'],
 'reasses': {'reassesed': [], 'reassesing': [], 'reassesment': []},
 'reassess': {'reassessable': [],
              'reassessed': [],
              'reassessement': [],
              'reassesses': [],
              'reassessing': [],
              'reassessment': []},
 'reassever': {'reasseverated': []},
 'reassig': {'reassigment': []},
 'reassign': {'reassignable': [],
              'reassignation': [],
              'reassigned': [],
              'reassigning': [],
              'reassignment': [],
              'reassigns': []},
 'reassimil': {'reassimilate': ['reassimilates', 'reassimilated'],
               'reassimilating': [],
               'reassimilation': []},
 'reassimilate': ['reassimilates', 'reassimilated'],
 'reassnm': {'reassnmed': []},
 'reassoci': {'reassociate': ['reassociates', 'reassociated'],
              'reassociating': [],
              'reassociation': ['reassociations']},
 'reassociate': ['reassociates', 'reassociated'],
 'reassociation': ['reassociations'],
 'reasson': {'reassonable': [], 'reassone': [], 'reassons': []},
 'reassoni': {'reassonis': []},
 'reassort': {'reassortant': ['reassortants'],
              'reassorted': [],
              'reassorting': [],
              'reassortment': ['reassortments'],
              'reassorts': []},
 'reassortant': ['reassortants'],
 'reassortment': ['reassortments'],
 'reasssess': {'reasssessment': []},
 'reasssur': {'reasssurance': [],
              'reasssure': ['reasssured'],
              'reasssuring': []},
 'reasssure': ['reasssured'],
 'reassum': {'reassume': ['reassumes', 'reassumed'], 'reassuming': []},
 'reassume': ['reassumes', 'reassumed'],
 'reassumer': {'reassumere': []},
 'reassumpt': {'reassumption': ['reassumptions']},
 'reassumption': ['reassumptions'],
 'reassur': {'reassurable': [],
             'reassurance': [],
             'reassure': ['reassures',
                          'reassurer',
                          'reassured',
                          'reassurers',
                          'reassurement'],
             'reassuring': ['reassurings'],
             'reassurred': [],
             'reassurring': []},
 'reassuranceseek': {'reassuranceseeking': []},
 'reassuranti': {'reassurantie': []},
 'reassure': ['reassures',
              'reassurer',
              'reassured',
              'reassurers',
              'reassurement'],
 'reassuredli': {'reassuredly': []},
 'reassuring': {'reassuringness': []},
 'reassuringli': {'reassuringly': []},
 'reassurr': {'reassurrance': []},
 'reassurringli': {'reassurringly': []},
 'reassut': {'reassuting': []},
 'reast': {'reaste': ['reasted'], 'reasting': [], 'reasts': []},
 'reaste': ['reasted'],
 'reastfeed': {'reastfeeding': []},
 'reasti': {'reasty': []},
 'reastless': {'reastlesse': []},
 'reastr': {'reastre': []},
 'reasult': {'reasults': []},
 'reasum': {'reasume': ['reasumed']},
 'reasume': ['reasumed'],
 'reasun': {'reasuns': []},
 'reasur': {'reasurance': [],
            'reasure': ['reasurer', 'reasures', 'reasured', 'reasurers'],
            'reasuring': [],
            'reasurred': [],
            'reasurring': []},
 'reasuran': {'reasurans': []},
 'reasure': ['reasurer', 'reasures', 'reasured', 'reasurers'],
 'reasuri': {'reasury': []},
 'reasuringli': {'reasuringly': []},
 'reasurr': {'reasurrance': []},
 'reat': {'reate': ['reates', 'reated'],
          'reating': [],
          'reatness': [],
          'reats': []},
 'reata': {'reata': []},
 'reataur': {'reataurant': []},
 'reate': ['reates', 'reated'],
 'reaten': {'reatened': [], 'reatening': []},
 'reath': {'reathe': ['reathes', 'reathed'], 'reathing': [], 'reaths': []},
 'reathe': ['reathes', 'reathed'],
 'reather': {'reathers': []},
 'reathtak': {'reathtaking': []},
 'reati': {'reaties': [], 'reaty': []},
 'reatibu': {'reatibus': []},
 'reatin': {'reatine': ['reatines', 'reatined']},
 'reatine': ['reatines', 'reatined'],
 'reatinin': {'reatinine': []},
 'reatinu': {'reatinus': []},
 'reation': {'reational': ['reationality', 'reationalization'], 'reations': []},
 'reational': {'reationale': []},
 'reationari': {'reationary': []},
 'reationship': {'reationships': []},
 'reatis': {'reatise': ['reatises']},
 'reatise': ['reatises'],
 'reatist': {'reatistic': []},
 'reatiti': {'reatity': []},
 'reativ': {'reative': ['reatively'], 'reativity': []},
 'reative': ['reatively'],
 'reatiz': {'reatization': [], 'reatize': ['reatized']},
 'reatize': ['reatized'],
 'reatli': {'reatly': []},
 'reatlili': {'reatlily': []},
 'reatment': {'reatments': []},
 'reaton': {'reatonable': [], 'reatons': []},
 'reator': {'reatoration': [],
            'reatore': ['reatores', 'reatored'],
            'reators': []},
 'reatore': ['reatores', 'reatored'],
 'reatric': {'reatrice': []},
 'reatrict': {'reatricted': [],
              'reatriction': ['reatrictions'],
              'reatrictive': []},
 'reatriction': ['reatrictions'],
 'reattach': {'reattachable': [],
              'reattached': [],
              'reattachement': [],
              'reattaches': [],
              'reattaching': [],
              'reattachment': ['reattachments']},
 'reattachment': ['reattachments'],
 'reattack': {'reattacked': [], 'reattacking': [], 'reattacks': []},
 'reattain': {'reattained': [],
              'reattaining': [],
              'reattainment': [],
              'reattains': []},
 'reattempt': {'reattempted': [], 'reattempting': [], 'reattempts': []},
 'reattend': {'reattendance': [], 'reattended': [], 'reattending': []},
 'reattent': {'reattention': []},
 'reattest': {'reattestation': [], 'reattested': []},
 'reatti': {'reattie': [], 'reatty': []},
 'reattir': {'reattire': ['reattired']},
 'reattire': ['reattired'],
 'reattiv': {'reattive': []},
 'reattor': {'reattore': []},
 'reattract': {'reattracted': [],
               'reattracting': [],
               'reattraction': [],
               'reattracts': []},
 'reattribut': {'reattribute': ['reattributes', 'reattributed'],
                'reattributing': [],
                'reattribution': ['reattributions', 'reattributional']},
 'reattribute': ['reattributes', 'reattributed'],
 'reattribution': ['reattributions', 'reattributional'],
 'reattun': {'reattune': ['reattuned', 'reattunement'], 'reattuning': []},
 'reattune': ['reattuned', 'reattunement'],
 'reatu': {'reatus': []},
 'reatur': {'reature': ['reatures']},
 'reature': ['reatures'],
 'reau': {'reaued': [], 'reauing': [], 'reaus': []},
 'reauc': {'reauce': ['reauced'], 'reaucing': []},
 'reauce': ['reauced'],
 'reaucraci': {'reaucracies': [], 'reaucracy': []},
 'reaucrat': {'reaucratic': [],
              'reaucratization': [],
              'reaucratized': [],
              'reaucrats': []},
 'reauction': {'reauctioned': []},
 'reaudit': {'reaudited': [],
             'reauditing': [],
             'reaudition': ['reauditioned'],
             'reaudits': []},
 'reaudition': ['reauditioned'],
 'reauditor': {'reauditorization': [],
               'reauditorize': [],
               'reauditorizing': []},
 'reauest': {'reauested': [], 'reauesting': [], 'reauests': []},
 'reaugment': {'reaugmentation': [], 'reaugmented': []},
 'reauili': {'reauily': []},
 'reauir': {'reauire': ['reauired', 'reauires'], 'reauiring': []},
 'reauire': ['reauired', 'reauires'],
 'reauirement': {'reauirements': []},
 'reauisit': {'reauisite': []},
 'reaularli': {'reaularly': []},
 'reaulat': {'reaulations': []},
 'reaulm': {'reaulme': []},
 'reaulr': {'reaulred': []},
 'reault': {'reaulte': ['reaulted'], 'reaulting': [], 'reaults': []},
 'reaulte': ['reaulted'],
 'reaum': {'reaume': ['reaumes', 'reaumed'], 'reaums': []},
 'reaume': ['reaumes', 'reaumed'],
 'reaumur': {'reaumur': []},
 'reaus': {'reaused': []},
 'reaustenit': {'reaustenitization': [],
                'reaustenitized': [],
                'reaustenitizing': []},
 'reauthent': {'reauthenticate': ['reauthenticates', 'reauthenticated'],
               'reauthenticating': [],
               'reauthentication': []},
 'reauthenticate': ['reauthenticates', 'reauthenticated'],
 'reauthor': {'reauthored': [],
              'reauthoring': [],
              'reauthority': [],
              'reauthorization': ['reauthorizations'],
              'reauthorize': ['reauthorizes', 'reauthorized'],
              'reauthorizing': []},
 'reauthoris': {'reauthorisation': [], 'reauthorise': ['reauthorised']},
 'reauthorise': ['reauthorised'],
 'reauthorization': ['reauthorizations'],
 'reauthorize': ['reauthorizes', 'reauthorized'],
 'reauti': {'reauties': [], 'reautiful': [], 'reauty': []},
 'reautoclav': {'reautoclaved': []},
 'reauvai': {'reauvais': []},
 'reauz': {'reauze': ['reauzed']},
 'reauze': ['reauzed'],
 'reav': {'reave': ['reaves', 'reaved', 'reavely'], 'reaving': []},
 'reavail': {'reavailability': [], 'reavailable': [], 'reavailed': []},
 'reave': ['reaves', 'reaved', 'reavely'],
 'reaveal': {'reavealed': [], 'reavealing': [], 'reaveals': []},
 'reavel': {'reaveled': [], 'reavell': []},
 'reavement': {'reavements': []},
 'reaver': {'reavers': []},
 'reaverag': {'reaveraged': []},
 'reavi': {'reavie': [], 'reavis': [], 'reavy': []},
 'reavil': {'reavill': ['reaville']},
 'reavill': ['reaville'],
 'reavl': {'reavls': []},
 'reavow': {'reavowal': [], 'reavowed': [], 'reavowing': []},
 'reawak': {'reawake': ['reawaked', 'reawakes'], 'reawaking': []},
 'reawake': ['reawaked', 'reawakes'],
 'reawaken': {'reawakened': [],
              'reawakener': [],
              'reawakening': ['reawakenings'],
              'reawakens': []},
 'reawakening': ['reawakenings'],
 'reawar': {'reawareness': []},
 'reaward': {'reawarded': [], 'reawarding': []},
 'reawi': {'reawy': []},
 'reawm': {'reawme': []},
 'reawok': {'reawoke': []},
 'reay': {'reays': []},
 'reaya': {'reayas': []},
 'reayrm': {'reayrmed': [], 'reayrming': []},
 'reayrmat': {'reayrmation': []},
 'reazion': {'reazione': []},
 'reazionari': {'reazionarie': []},
 'reb': ['rebbed'],
 'reba': {'rebas': []},
 'rebab': {'rebabs': []},
 'rebabbit': {'rebabbitted': [], 'rebabbitting': []},
 'rebabilit': {'rebabilitation': []},
 'rebabl': {'rebability': [], 'rebable': []},
 'reback': {'rebacked': [], 'rebacking': []},
 'rebadg': {'rebadge': ['rebadged'], 'rebadging': []},
 'rebadge': ['rebadged'],
 'rebag': {'rebagged': [], 'rebagging': []},
 'rebai': {'rebais': []},
 'rebail': {'rebaile': []},
 'rebais': {'rebaise': []},
 'rebait': {'rebaited': [], 'rebaiting': [], 'rebaits': []},
 'rebaj': {'rebaje': ['rebajes']},
 'rebaja': {'rebajas': []},
 'rebajado': {'rebajados': []},
 'rebajars': {'rebajarse': []},
 'rebaje': ['rebajes'],
 'rebak': {'rebake': ['rebaked'], 'rebaking': []},
 'rebake': ['rebaked'],
 'rebal': {'rebalance': ['rebalances'],
           'rebaled': [],
           'rebaling': [],
           'rebals': []},
 'rebalanc': {'rebalanced': [],
              'rebalancer': ['rebalancers'],
              'rebalancing': ['rebalancings']},
 'rebalance': ['rebalances'],
 'rebalancer': ['rebalancers'],
 'rebalancing': ['rebalancings'],
 'reballast': {'reballasted': [], 'reballasting': []},
 'reballot': {'reballoted': [], 'reballoting': []},
 'rebamipid': {'rebamipide': []},
 'reban': {'rebane': [], 'rebanned': []},
 'rebanada': {'rebanadas': []},
 'rebanc': {'rebance': []},
 'reband': {'rebanded': [], 'rebanding': []},
 'rebandag': {'rebandage': ['rebandages', 'rebandaged'], 'rebandaging': []},
 'rebandage': ['rebandages', 'rebandaged'],
 'rebanho': {'rebanhos': []},
 'rebanish': {'rebanished': []},
 'rebank': {'rebanked': [], 'rebanks': []},
 'rebano': {'rebanos': []},
 'rebapt': {'rebaptism': ['rebaptisms'],
            'rebaptization': [],
            'rebaptize': ['rebaptizer',
                          'rebaptized',
                          'rebaptizes',
                          'rebaptizers'],
            'rebaptizing': []},
 'rebaptis': {'rebaptisation': [],
              'rebaptise': ['rebaptises',
                            'rebaptised',
                            'rebaptiser',
                            'rebaptisers'],
              'rebaptising': []},
 'rebaptise': {'rebaptisee': []},
 'rebaptism': {'rebaptismal': [], 'rebaptismate': []},
 'rebaptizando': {'rebaptizandos': []},
 'rebaptizar': {'rebaptizare': []},
 'rebaptize': ['rebaptizer', 'rebaptized', 'rebaptizes', 'rebaptizers'],
 'rebar': {'rebarred': [], 'rebarring': [], 'rebars': []},
 'rebarb': {'rebarbative': ['rebarbatively', 'rebarbativeness'],
            'rebarber': []},
 'rebarbar': {'rebarbarization': [],
              'rebarbarize': ['rebarbarized'],
              'rebarbarizing': []},
 'rebarbaris': {'rebarbarisation': [], 'rebarbarise': []},
 'rebarbarize': ['rebarbarized'],
 'rebarbative': ['rebarbatively', 'rebarbativeness'],
 'rebarbit': {'rebarbitive': []},
 'rebargain': {'rebargained': [], 'rebargaining': []},
 'rebari': {'rebaris': []},
 'rebarrel': {'rebarreled': [], 'rebarreling': [], 'rebarrelled': []},
 'rebas': {'rebase': ['rebased', 'rebases'], 'rebasing': ['rebasings']},
 'rebase': ['rebased', 'rebases'],
 'rebaselin': {'rebaseline': ['rebaselined'], 'rebaselining': []},
 'rebaseline': ['rebaselined'],
 'rebasing': ['rebasings'],
 'rebast': {'rebaste': ['rebasted']},
 'rebaste': ['rebasted'],
 'rebat': {'rebatable': [],
           'rebate': ['rebater',
                      'rebated',
                      'rebaters',
                      'rebateable',
                      'rebatement',
                      'rebatements'],
           'rebating': [],
           'rebator': ['rebators'],
           'rebats': [],
           'rebatted': []},
 'rebatch': {'rebatching': []},
 'rebate': ['rebater',
            'rebated',
            'rebaters',
            'rebateable',
            'rebatement',
            'rebatements'],
 'rebath': {'rebathed': []},
 'rebati': {'rebatie': []},
 'rebato': ['rebatoes'],
 'rebator': ['rebators'],
 'rebatt': {'rebattered': []},
 'rebattr': {'rebattre': []},
 'rebattu': {'rebattue': ['rebattues'], 'rebattus': []},
 'rebattue': ['rebattues'],
 'rebaudiosid': {'rebaudioside': []},
 'rebayl': {'rebayle': []},
 'rebb': {'rebbe': ['rebbes']},
 'rebbachisauru': {'rebbachisaurus': []},
 'rebbe': ['rebbes'],
 'rebbel': {'rebbell': ['rebbells'], 'rebbels': []},
 'rebbell': ['rebbells'],
 'rebbetzin': {'rebbetzins': []},
 'rebbi': {'rebbie': [], 'rebbis': [], 'rebby': []},
 'rebbit': {'rebbites': []},
 'rebbl': {'rebble': ['rebbles']},
 'rebble': ['rebbles'],
 'rebc': {'rebcs': []},
 'rebcll': {'rebclles': []},
 'rebd': {'rebds': []},
 'rebe': {'rebed': [], 'rebee': [], 'rebeing': [], 'rebeli': [], 'rebes': []},
 'rebeautifi': {'rebeautified': [], 'rebeautify': []},
 'rebec': {'rebecs': []},
 'rebecam': {'rebecame': []},
 'rebecca': ['rebeccae', 'rebeccaism'],
 "rebecca'l": {"rebecca'll": []},
 'rebeccait': {'rebeccaites': []},
 'rebeck': {'rebecke': ['rebecker'], 'rebecks': []},
 'rebecke': ['rebecker'],
 'rebecki': {'rebecky': []},
 'rebecom': {'rebecome': ['rebecomes'], 'rebecoming': []},
 'rebecome': ['rebecomes'],
 'rebecqu': {'rebecque': []},
 'rebect': {'rebected': [], 'rebecting': [], 'rebection': ['rebections']},
 'rebection': ['rebections'],
 'rebed': {'rebedded': [], 'rebedding': []},
 'rebef': {'rebefs': []},
 'rebefor': {'rebefore': []},
 'rebeget': {'rebegetting': []},
 'rebegin': {'rebeginning': ['rebeginnings'], 'rebegins': []},
 'rebeginning': ['rebeginnings'],
 'rebehold': {'rebeholding': []},
 'rebei': {'rebeis': []},
 'rebeil': {'rebeille': []},
 'rebein': {'rebeine': []},
 'rebej': {'rebejs': []},
 'rebek': {'rebeks': []},
 'rebekah': {'rebekah': []},
 'rebekk': {'rebekke': []},
 'rebel': ['rebell',
           'rebele',
           'rebeled',
           'rebelle',
           'rebeles',
           'rebells',
           'rebeling',
           'rebelous',
           'rebelles',
           'rebelled',
           'rebelism',
           'rebeller',
           'rebellers',
           'rebellent',
           'rebelling',
           'rebellous',
           'rebellant',
           'rebellings'],
 'rebelado': {'rebelados': []},
 'rebelai': {'rebelais': []},
 'rebelars': {'rebelarse': []},
 'rebelcontrol': {'rebelcontrolled': []},
 'rebeld': {'rebelde': ['rebeldes']},
 'rebelde': ['rebeldes'],
 'rebeldia': {'rebeldias': []},
 'rebelett': {'rebelettes': []},
 'rebelh': {'rebelhous': []},
 'rebeli': {'rebelious': ['rebeliousness']},
 'rebelio': {'rebelioes': []},
 'rebelion': {'rebelione': ['rebeliones'], 'rebelions': []},
 'rebelione': ['rebeliones'],
 'rebelious': ['rebeliousness'],
 'rebella': {'rebellas': []},
 'rebellan': {'rebellans': []},
 'rebellant': {'rebellantes': []},
 'rebellantibu': {'rebellantibus': []},
 'rebellar': {'rebellare': []},
 'rebellass': {'rebellasse': []},
 'rebellead': {'rebelleaders': []},
 'rebelli': {'rebellie': [],
             'rebelliou': ['rebellious', 'rebelliously', 'rebelliousness'],
             'rebellis': [],
             'rebelly': ['rebellys']},
 'rebellibu': {'rebellibus': []},
 'rebellion': ['rebellione', 'rebelliones'],
 'rebellioni': {'rebellionis': []},
 'rebellionibu': {'rebellionibus': []},
 'rebellionist': {'rebellionists': []},
 'rebelliou': ['rebellious', 'rebelliously', 'rebelliousness'],
 'rebellioufli': {'rebellioufly': []},
 'rebellisch': {'rebellische': []},
 'rebellit': {'rebelliter': []},
 'rebellow': {'rebellowed': [], 'rebellowing': [], 'rebellows': []},
 'rebellu': {'rebellus': []},
 'rebelly': {'rebellyous': []},
 'rebelri': {'rebelry': []},
 'rebels': {'rebelse': []},
 'rebelski': {'rebelsky': []},
 'rebelt': {'rebelted': [], 'rebeltion': []},
 'rebend': {'rebending': []},
 'rebenqu': {'rebenque': ['rebenques']},
 'rebenque': ['rebenques'],
 'rebenr': {'rebenring': []},
 'rebequ': {'rebeque': []},
 'reber': {'rebers': []},
 'reberg': {'reberger': []},
 'rebert': {'reberts': []},
 'reberth': {'reberthed': []},
 'rebertu': {'rebertus': []},
 'rebestow': {'rebestowal': [], 'rebestowed': []},
 'rebet': {'rebetes': [], 'rebetic': [], 'rebets': [], 'rebetting': []},
 'rebetzk': {'rebetzke': []},
 'rebeuiou': {'rebeuious': []},
 'rebeuious': {'rebeuiously': []},
 'rebev': {'rebeval': [], 'rebeve': ['rebeved'], 'rebevs': []},
 'rebeve': ['rebeved'],
 'rebevel': {'rebeveled': []},
 'rebeyn': {'rebeyne': []},
 'rebeyrol': {'rebeyrolle': []},
 'rebeyrott': {'rebeyrotte': []},
 'rebgion': {'rebgions': []},
 'rebgiou': {'rebgious': []},
 'rebhun': {'rebhuns': []},
 'rebi': {'rebie': [], 'rebis': [], 'reby': []},
 'rebid': {'rebidding': [], 'rebided': [], 'rebiding': [], 'rebids': []},
 'rebidd': {'rebiddable': []},
 'rebier': {'rebiere': ['rebieres']},
 'rebiere': ['rebieres'],
 'rebiff': {'rebiffe': []},
 'rebil': {'rebility': [],
           'rebill': ['rebills', 'rebilled', 'rebilling'],
           'rebils': []},
 'rebiliu': {'rebilius': []},
 'rebill': ['rebills', 'rebilled', 'rebilling'],
 'rebillet': {'rebilleted': []},
 'rebilu': {'rebilus': []},
 'rebin': {'rebinned': [], 'rebinning': []},
 'rebind': {'rebinder': [], 'rebinding': ['rebindings'], 'rebinds': []},
 'rebinding': ['rebindings'],
 'rebiopsi': {'rebiopsied': [], 'rebiopsies': [], 'rebiopsy': []},
 'rebirth': ['rebirthed',
             'rebirther',
             'rebirthing',
             'rebirthers',
             'rebirthings'],
 'rebirthconsci': {'rebirthconsciousness': []},
 'rebit': {'rebite': [], 'rebiting': ['rebitings']},
 'rebiting': ['rebitings'],
 'rebitt': {'rebitte': []},
 'rebitz': {'rebitzer': []},
 'rebiz': {'rebizant': []},
 'rebl': {'reble': ['rebles', 'rebled'], 'rebling': [], 'rebls': []},
 'reblack': {'reblacked': []},
 'reblacken': {'reblackened': [], 'reblackening': []},
 'reblad': {'rebladed': [], 'reblading': []},
 'reblast': {'reblasted': [], 'reblasting': []},
 'reblau': {'reblaus': []},
 'reblaz': {'reblaze': ['reblazed'], 'reblazing': []},
 'reblaze': ['reblazed'],
 'reblazon': {'reblazoned': []},
 'reble': {'rebleed': ['rebleeds']},
 'rebleach': {'rebleached': [], 'rebleaching': []},
 'rebleed': {'rebleeders': [], 'rebleeding': ['rebleedings']},
 'rebleeding': ['rebleedings'],
 'reblend': {'reblended': [], 'reblending': []},
 'rebless': {'reblessed': []},
 'rebli': {'rebly': []},
 'reblock': {'reblocked': [], 'reblocking': [], 'reblocks': []},
 'reblockag': {'reblockage': []},
 'rebloom': {'rebloomed': [],
             'rebloomer': ['rebloomers'],
             'reblooming': [],
             'reblooms': []},
 'rebloomer': ['rebloomers'],
 'reblossom': {'reblossomed': [], 'reblossoming': [], 'reblossoms': []},
 'reblot': {'reblotted': []},
 'reblow': {'reblowing': []},
 'reblu': {'reblue': ['reblued'], 'rebluing': []},
 'reblue': ['reblued'],
 'rebn': {'rebne': ['rebned'], 'rebns': []},
 'rebne': ['rebned'],
 'rebnk': {'rebnke': ['rebnked']},
 'rebnke': ['rebnked'],
 'rebo': {'rebos': []},
 'reboan': {'reboans': []},
 'reboard': {'reboarded': [], 'reboarding': [], 'reboards': []},
 'rebodi': {'rebodied': [], 'rebody': ['rebodying']},
 'rebody': ['rebodying'],
 'rebohl': {'rebohle': []},
 'reboi': {'rebois': []},
 'reboil': {'reboiled': [],
            'reboiler': ['reboilers', 'reboilered', 'reboilering'],
            'reboiling': ['reboilings'],
            'reboils': []},
 'reboiler': ['reboilers', 'reboilered', 'reboilering'],
 'reboiling': ['reboilings'],
 'reboira': {'reboiras': []},
 'rebois': {'reboise': ['reboisement', 'reboisements']},
 'reboise': ['reboisement', 'reboisements'],
 'rebok': {'reboks': []},
 'rebol': {'reboll': [], 'rebols': []},
 'rebolo': {'rebolos': []},
 'rebolt': {'rebolted': [], 'rebolting': []},
 'rebolu': {'rebolus': []},
 'rebolut': {'rebolution': []},
 'rebolv': {'rebolved': [], 'rebolver': []},
 'rebomb': {'rebombed': [], 'rebombing': []},
 'rebon': {'rebone': []},
 'rebond': {'rebonded': [], 'rebonding': [], 'rebonds': []},
 'rebondi': {'rebondies': []},
 'rebondiss': {'rebondissant': [],
               'rebondissement': ['rebondissements'],
               'rebondissent': []},
 'rebondissant': {'rebondissantes': []},
 'rebondissement': ['rebondissements'],
 'rebook': {'rebooked': [], 'rebooking': ['rebookings'], 'rebooks': []},
 'rebooking': ['rebookings'],
 'reboost': {'reboosted': [], 'reboosting': [], 'reboosts': []},
 'reboot': {'rebooted': [], 'rebooting': [], 'reboots': []},
 'rebopp': {'reboppers': []},
 'reboqu': {'reboque': []},
 'rebor': {'rebore': ['rebored', 'rebores'], 'reboring': ['reborings']},
 'rebord': {'reborde': ['rebordes', 'rebordered', 'rebordering'],
            'rebords': []},
 'reborde': ['rebordes', 'rebordered', 'rebordering'],
 'rebore': ['rebored', 'rebores'],
 'reboring': ['reborings'],
 'reborn': {'reborne': [], 'reborning': [], 'rebornness': [], 'reborns': []},
 'reborrow': {'reborrowed': [],
              'reborrowing': ['reborrowings'],
              'reborrows': []},
 'reborrowing': ['reborrowings'],
 'rebort': {'reborted': []},
 'rebos': {'reboses': []},
 'rebosa': {'rebosas': []},
 'rebosant': {'rebosante': ['rebosantes']},
 'rebosante': ['rebosantes'],
 'reboso': {'rebosos': []},
 'rebot': {'rebote': []},
 'reboti': {'rebotier': []},
 'rebottl': {'rebottle': ['rebottled'], 'rebottling': []},
 'rebottle': ['rebottled'],
 'rebottom': {'rebottomed': [], 'rebottoming': []},
 'rebouca': {'reboucas': []},
 'rebouch': {'rebouche': []},
 'rebouga': {'rebougas': []},
 'rebounc': {'rebounce': ['rebounced'], 'rebouncing': []},
 'rebounce': ['rebounced'],
 'rebound': ['rebounde',
             'rebounded',
             'rebounder',
             'rebounding',
             'rebounders',
             'reboundings'],
 'rebour': {'rebours': []},
 'rebourd': {'rebourde': []},
 'rebout': {'reboute': []},
 'rebov': {'reboval': []},
 'rebow': {'rebows': []},
 'reboza': {'rebozas': []},
 'rebozo': {'rebozo': []},
 'rebpect': {'rebpects': []},
 'rebr': {'rebre': ['rebred'], 'rebring': []},
 'rebra': {'rebras': []},
 'rebrac': {'rebrace': ['rebraced'], 'rebracing': []},
 'rebrace': ['rebraced'],
 'rebracket': {'rebracketed': [], 'rebracketing': []},
 'rebraid': {'rebraided': [], 'rebraiding': [], 'rebraids': []},
 'rebranch': {'rebranched': [], 'rebranches': [], 'rebranching': []},
 'rebrand': {'rebranded': [], 'rebranding': ['rebrandings'], 'rebrands': []},
 'rebranding': ['rebrandings'],
 'rebrassi': {'rebrassier': []},
 'rebraz': {'rebrazed': [], 'rebrazing': []},
 'rebrcath': {'rebrcathing': []},
 'rebre': {'rebreed': []},
 'rebreak': {'rebreaking': [], 'rebreaks': []},
 'rebreath': {'rebreathe': ['rebreathed',
                            'rebreather',
                            'rebreathes',
                            'rebreathers'],
              'rebreathing': []},
 'rebreathe': ['rebreathed', 'rebreather', 'rebreathes', 'rebreathers'],
 'rebreed': {'rebreeding': []},
 'rebreviett': {'rebreviettes': []},
 'rebrew': {'rebrewed': []},
 'rebrib': {'rebribed': []},
 'rebrick': {'rebricked': [], 'rebricking': []},
 'rebridg': {'rebridge': ['rebridged'], 'rebridging': []},
 'rebridge': ['rebridged'],
 'rebridl': {'rebridled': []},
 'rebrief': {'rebriefed': [], 'rebriefing': []},
 'rebrighten': {'rebrightened': [], 'rebrightening': []},
 'rebrin': {'rebrined': []},
 'rebroadcast': ['rebroadcasted',
                 'rebroadcaster',
                 'rebroadcasting',
                 'rebroadcasters'],
 'rebroaden': {'rebroadening': []},
 'rebrok': {'rebroke': []},
 'rebromin': {'rebromination': []},
 'rebronz': {'rebronzed': []},
 'rebrospin': {'rebrospinal': []},
 'rebrot': {'rebrote': []},
 'rebrouss': {'rebrousse': ['rebrousser', 'rebroussement']},
 'rebrousse': ['rebrousser', 'rebroussement'],
 'rebrown': {'rebrowning': []},
 'rebru': {'rebrus': []},
 'rebruari': {'rebruary': []},
 'rebrush': {'rebrushed': [], 'rebrushing': []},
 'rebrut': {'rebrutalized': []},
 'rebt': {'rebted': [], 'rebts': []},
 'rebu': {'rebus': []},
 'rebubl': {'rebublic': []},
 'rebublican': {'rebublicans': []},
 'rebuck': {'rebucked': []},
 'rebuckl': {'rebuckle': ['rebuckled'], 'rebuckling': []},
 'rebuckle': ['rebuckled'],
 'rebud': {'rebudded': [], 'rebudding': []},
 'rebudget': {'rebudgeted': [], 'rebudgeting': []},
 'rebuelto': {'rebueltos': []},
 'rebuelv': {'rebuelve': []},
 'rebuf': {'rebuffed': [], 'rebuffing': []},
 'rebuff': ['rebuffe',
            'rebuffer',
            'rebuffal',
            'rebuffers',
            'rebuffered',
            'rebuffering'],
 'rebuffad': {'rebuffades': []},
 'rebuffu': {'rebuffus': []},
 'rebufl': {'rebufls': []},
 'rebuid': {'rebuiding': []},
 'rebuik': {'rebuiked': []},
 'rebuild': {'rebuildable': [],
             'rebuilded': [],
             'rebuilder': ['rebuilders'],
             'rebuilding': [],
             'rebuilds': []},
 'rebuilder': ['rebuilders'],
 'rebuilt': {'rebuilts': []},
 'rebuk': {'rebukable': [],
           'rebuke': ['rebuked',
                      'rebuker',
                      'rebukeful',
                      'rebukeable',
                      'rebukefully'],
           'rebuking': ['rebukings']},
 'rebuke': ['rebuked', 'rebuker', 'rebukeful', 'rebukeable', 'rebukefully'],
 'rebuking': ['rebukings'],
 'rebukingli': {'rebukingly': []},
 'rebukt': {'rebukte': []},
 'rebul': {'rebulic': [], 'rebull': []},
 'rebuld': {'rebulding': []},
 'rebulk': {'rebulked': []},
 'rebult': {'rebults': []},
 'rebum': {'rebumed': [], 'rebuming': []},
 'rebun': {'rebuned': []},
 'rebunch': {'rebunched': [], 'rebunching': []},
 'rebund': {'rebundant': []},
 'rebundl': {'rebundle': ['rebundled'], 'rebundling': []},
 'rebundle': ['rebundled'],
 'rebunk': {'rebunker': ['rebunkering'], 'rebunking': []},
 'rebunker': ['rebunkering'],
 'rebuoy': {'rebuoyed': []},
 'rebupl': {'rebuplic': []},
 'reburden': {'reburdened': []},
 'rebureaucrat': {'rebureaucratization': []},
 'reburgeon': {'reburgeoning': []},
 'reburi': {'reburial': [],
            'reburied': [],
            'reburies': [],
            'rebury': ['reburying']},
 'reburn': {'reburned': [], 'reburning': [], 'reburns': []},
 'reburnish': {'reburnished': [], 'reburnishing': []},
 'reburrow': {'reburrowing': []},
 'reburru': {'reburrus': []},
 'rebury': ['reburying'],
 'rebus': ['rebused'],
 'rebush': {'rebushed': [], 'rebushing': []},
 'rebuslik': {'rebuslike': []},
 'rebuspublici': {'rebuspublicis': []},
 'rebusqu': {'rebusque': []},
 'rebuss': {'rebus': []},
 'rebut': {'rebutable': [],
           'rebutal': [],
           'rebutant': ['rebutants'],
           'rebute': ['rebuted', 'rebuter', 'rebutes', 'rebutent'],
           'rebuting': [],
           'rebutment': [],
           'rebuts': [],
           'rebutted': [],
           'rebutting': []},
 'rebutant': {'rebutante': ['rebutantes']},
 'rebutante': ['rebutantes'],
 'rebute': ['rebuted', 'rebuter', 'rebutes', 'rebutent'],
 'rebutia': {'rebutias': []},
 'rebutt': {'rebuttability': [],
            'rebuttable': [],
            'rebuttably': [],
            'rebuttal': [],
            'rebuttant': [],
            'rebutter': [],
            'rebutts': []},
 'rebuttalist': {'rebuttalists': []},
 'rebuttl': {'rebuttle': []},
 'rebutton': {'rebuttoned': [], 'rebuttoning': [], 'rebuttons': []},
 'rebuttress': {'rebuttressed': []},
 'rebuv': {'rebuved': []},
 'rebuy': {'rebuying': [], 'rebuys': []},
 'rebv': {'rebvs': []},
 'rec': {'recced': [], 'reccing': [], 'recs': []},
 "rec'": {"rec'ed": []},
 "rec'li": {"rec'ly": []},
 "rec't": {"rec'ts": []},
 'reca': {'recae': [], 'recas': []},
 'recabit': {'recabite': ['recabites']},
 'recabite': ['recabites'],
 'recabl': {'recable': ['recabled'], 'recabling': []},
 'recable': ['recabled'],
 'recach': {'recache': ['recached'], 'recaching': []},
 'recache': ['recached'],
 'recad': {'recade': ['recades']},
 'recade': ['recades'],
 'recado': {'recados': []},
 'recag': {'recage': ['recaged']},
 'recage': ['recaged'],
 'recagn': {'recagnized': []},
 'recah': {'recahed': []},
 'recaicitr': {'recaicitrant': []},
 'recaii': {'recaiied': []},
 'recail': {'recailed': []},
 'recaiv': {'recaive': ['recaived'], 'recaiving': []},
 'recaive': ['recaived'],
 'recaizad': {'recaizade': []},
 'recaka': {'recakas': []},
 'recal': {'recale': ['recaled'],
           'recaling': [],
           'recall': ['recalle',
                      'recalli',
                      'recally',
                      'recalles',
                      'recalled',
                      'recaller',
                      'recallism',
                      'recallers',
                      'recalling',
                      'recallment',
                      'recallable',
                      'recallings',
                      'recallability'],
           'recalment': [],
           'recals': []},
 'recalcif': {'recalcification': []},
 'recalcifi': {'recalcified': [],
               'recalcifies': [],
               'recalcify': ['recalcifying']},
 'recalcify': ['recalcifying'],
 'recalcimin': {'recalcimined': []},
 'recalcin': {'recalcination': [],
              'recalcine': ['recalcined'],
              'recalcining': []},
 'recalcine': ['recalcined'],
 'recalcit': {'recalcitant': []},
 'recalcitr': {'recalcitrance': [],
               'recalcitrancy': [],
               'recalcitrant': ['recalcitrants'],
               'recalcitrate': ['recalcitrated', 'recalcitrates'],
               'recalcitrating': [],
               'recalcitration': ['recalcitrations']},
 'recalcitran': {'recalcitrans': []},
 'recalcitrant': {'recalcitrante': ['recalcitrantes']},
 'recalcitrante': ['recalcitrantes'],
 'recalcitrantli': {'recalcitrantly': []},
 'recalcitrar': {'recalcitrare': []},
 'recalcitrate': ['recalcitrated', 'recalcitrates'],
 'recalcitration': ['recalcitrations'],
 'recalcul': {'recalculate': ['recalculated', 'recalculates'],
              'recalculating': [],
              'recalculation': [],
              'recalculer': []},
 'recalculate': ['recalculated', 'recalculates'],
 'recald': {'recalde': ['recaldes']},
 'recalde': ['recaldes'],
 'recale': ['recaled'],
 'recaleitr': {'recaleitrance': [], 'recaleitrant': []},
 'recalendar': {'recalendared': []},
 'recalesc': {'recalesce': ['recalesces', 'recalescent', 'recalescence']},
 'recalesce': ['recalesces', 'recalescent', 'recalescence'],
 'recaleul': {'recaleulated': []},
 'recali': {'recalied': [], 'recalis': []},
 'recalibr': {'recalibrate': ['recalibrates', 'recalibrated'],
              'recalibrating': [],
              'recalibration': ['recalibrations']},
 'recalibrate': ['recalibrates', 'recalibrated'],
 'recalibration': ['recalibrations'],
 'recalicitr': {'recalicitrant': []},
 'recalitr': {'recalitrant': []},
 'recalk': {'recalked': [], 'recalking': []},
 'recall': ['recalle',
            'recalli',
            'recally',
            'recalles',
            'recalled',
            'recaller',
            'recallism',
            'recallers',
            'recalling',
            'recallment',
            'recallable',
            'recallings',
            'recallability'],
 'recallingth': {'recallingthe': []},
 'recallist': {'recallists': []},
 'recallprecis': {'recallprecision': []},
 'recallsth': {'recallsthe': []},
 'recallth': {'recallthe': []},
 'recaltric': {'recaltricant': []},
 'recam': {'recame': []},
 'recamado': {'recamados': []},
 'recamara': {'recamaras': []},
 'recambio': {'recambios': []},
 'recamedi': {'recamediated': []},
 'recami': {'recamier': ['recamiers']},
 'recamier': ['recamiers'],
 'recaml': {'recamler': []},
 'recammend': {'recammended': []},
 'recamouflag': {'recamouflaged': []},
 'recamp': {'recamped': []},
 'recan': {'recanal': ['recanalize',
                       'recanalized',
                       'recanalizes',
                       'recanalizing',
                       'recanalization',
                       'recanalizations'],
           'recanate': [],
           'recane': ['recaned'],
           'recaning': [],
           'recanize': [],
           'recanned': [],
           'recanning': [],
           'recans': []},
 'recanal': ['recanalize',
             'recanalized',
             'recanalizes',
             'recanalizing',
             'recanalization',
             'recanalizations'],
 'recanalis': {'recanalisation': [],
               'recanalise': ['recanalised'],
               'recanalising': []},
 'recanalise': ['recanalised'],
 'recandesc': {'recandescence': []},
 'recandescer': {'recandescere': []},
 'recane': ['recaned'],
 'recann': {'recannalization': [], 'recannalize': []},
 'recannul': {'recannulate': ['recannulated'],
              'recannulating': [],
              'recannulation': [],
              'recannulization': [],
              'recannulize': []},
 'recannulate': ['recannulated'],
 'recanon': {'recanonization': [],
             'recanonize': ['recanonized'],
             'recanonizing': []},
 'recanonize': ['recanonized'],
 'recant': {'recantation': [],
            'recante': ['recanted', 'recanter', 'recanters'],
            'recanting': ['recantings'],
            'recants': []},
 'recantacyon': {'recantacyons': []},
 'recantatori': {'recantatory': []},
 'recante': ['recanted', 'recanter', 'recanters'],
 'recanting': ['recantings'],
 'recantli': {'recantly': []},
 'recanto': {'recantos': []},
 'recanva': {'recanvas': []},
 'recanvas': {'recanvased': []},
 'recanvass': {'recanvassed': [], 'recanvassing': []},
 'recanzon': {'recanzone': []},
 'recap': ['recapped', 'recapping'],
 'recapacit': {'recapacitated': [], 'recapacitation': []},
 'recapit': {'recapital': ['recapitalize',
                           'recapitalizes',
                           'recapitalized',
                           'recapitalizing',
                           'recapitalization',
                           'recapitalizations'],
             'recapitated': [],
             'recapitation': []},
 'recapital': ['recapitalize',
               'recapitalizes',
               'recapitalized',
               'recapitalizing',
               'recapitalization',
               'recapitalizations'],
 'recapitalis': {'recapitalisation': ['recapitalisations'],
                 'recapitalise': ['recapitalised'],
                 'recapitalising': []},
 'recapitalisation': ['recapitalisations'],
 'recapitalise': ['recapitalised'],
 'recapitu': {'recapituate': [], 'recapituation': []},
 'recapitual': {'recapitualate': [], 'recapitualation': []},
 'recapitualt': {'recapitualte': ['recapitualtes', 'recapitualted'],
                 'recapitualtion': []},
 'recapitualte': ['recapitualtes', 'recapitualted'],
 'recapitul': {'recapitulant': [],
               'recapitulate': ['recapitulates', 'recapitulated'],
               'recapitulating': [],
               'recapitulation': [],
               'recapitulative': ['recapitulatively'],
               'recapitulator': ['recapitulators'],
               'recapitule': ['recapituler']},
 'recapitulan': {'recapitulans': []},
 'recapitular': {'recapitulare': []},
 'recapitulari': {'recapitulary': []},
 'recapitulate': ['recapitulates', 'recapitulated'],
 'recapitulatif': {'recapitulatifs': []},
 'recapitulation': {'recapitulatione': [], 'recapitulationism': []},
 'recapitulationari': {'recapitulationary': []},
 'recapitulationist': {'recapitulationists': []},
 'recapitulative': ['recapitulatively'],
 'recapitulator': ['recapitulators'],
 'recapitulatori': {'recapitulatory': []},
 'recapitule': ['recapituler'],
 'recapitulon': {'recapitulons': []},
 'recapp': {'recappable': [], 'recapper': ['recappers']},
 'recapper': ['recappers'],
 'recapt': {'recaption': ['recaptions', 'recaptioned', 'recaptioning'],
            'recaptive': ['recaptives']},
 'recaption': ['recaptions', 'recaptioned', 'recaptioning'],
 'recaptiv': {'recaptivate': ['recaptivated']},
 'recaptivate': ['recaptivated'],
 'recaptive': ['recaptives'],
 'recaptor': {'recaptors': []},
 'recaptul': {'recaptulate': []},
 'recaptur': {'recapturable': [],
              'recapture': ['recaptured', 'recapturer', 'recapturers'],
              'recapturing': ['recapturings']},
 'recapture': ['recaptured', 'recapturer', 'recapturers'],
 'recapturing': ['recapturings'],
 'recapul': {'recapulation': []},
 'recar': {'recare': ['recared', 'recareering'], 'recarred': []},
 'recara': {'recaras': []},
 'recaranu': {'recaranus': []},
 'recarbon': {'recarbonate': ['recarbonated'],
              'recarbonating': [],
              'recarbonation': [],
              'recarboning': [],
              'recarbonization': [],
              'recarbonize': ['recarbonized', 'recarbonizer'],
              'recarbonizing': []},
 'recarbonate': ['recarbonated'],
 'recarbonize': ['recarbonized', 'recarbonizer'],
 'recarbur': {'recarburization': [],
              'recarburize': ['recarburizer', 'recarburized', 'recarburizers'],
              'recarburizing': []},
 'recarburis': {'recarburisation': [],
                'recarburise': ['recarburised', 'recarburiser'],
                'recarburising': []},
 'recarburise': ['recarburised', 'recarburiser'],
 'recarburize': ['recarburizer', 'recarburized', 'recarburizers'],
 'recard': {'recarded': [], 'recarding': [], 'recards': []},
 'recare': ['recared', 'recareering'],
 'recared': {'recarede': []},
 'recaredu': {'recaredus': []},
 'recargado': {'recargados': []},
 'recargo': {'recargos': []},
 'recari': {'recarious': []},
 'recarpet': {'recarpeted': [], 'recarpeting': []},
 'recarri': {'recarried': [], 'recarry': ['recarrying']},
 'recarriag': {'recarriage': []},
 'recarry': ['recarrying'],
 'recart': {'recarte': ['recarted']},
 'recarte': ['recarted'],
 'recartel': {'recartelization': []},
 'recarv': {'recarve': ['recarves', 'recarved'], 'recarving': []},
 'recarve': ['recarves', 'recarved'],
 'recas': {'recase': ['recased', 'recases'], 'recasing': []},
 'recase': ['recased', 'recases'],
 'recasen': {'recasens': []},
 'recask': {'recasked': []},
 'recasn': {'recasner': []},
 'recass': {'recasse': []},
 'recast': {'recaste': ['recaster', 'recasted', 'recasters'],
            'recasting': [],
            'recasts': []},
 'recaste': ['recaster', 'recasted', 'recasters'],
 'recat': {'recate': ['recated'], 'recating': [], 'recation': ['recations']},
 'recatado': {'recatados': []},
 'recatalog': {'recataloged': [], 'recataloging': []},
 'recatalogu': {'recatalogue': ['recatalogued'], 'recataloguing': []},
 'recatalogue': ['recatalogued'],
 'recatch': {'recatching': []},
 'recate': ['recated'],
 'recategor': {'recategorical': [],
               'recategorization': ['recategorizations'],
               'recategorize': ['recategorized', 'recategorizes'],
               'recategorizing': []},
 'recategoris': {'recategorisation': [],
                 'recategorise': ['recategorised'],
                 'recategorising': []},
 'recategorise': ['recategorised'],
 'recategorization': ['recategorizations'],
 'recategorize': ['recategorized', 'recategorizes'],
 'recathect': {'recathected': [], 'recathecting': [], 'recathects': []},
 'recatheter': {'recatheterization': [], 'recatheterize': ['recatheterized']},
 'recatheterize': ['recatheterized'],
 'recathol': {'recatholization': []},
 'recatholic': {'recatholicization': [],
                'recatholicize': ['recatholicized'],
                'recatholicizing': []},
 'recatholicis': {'recatholicisation': [], 'recatholicised': []},
 'recatholicize': ['recatholicized'],
 'recation': ['recations'],
 'recau': {'recaued': []},
 'recaud': {'recaude': []},
 'recaudacion': {'recaudaciones': []},
 'recaudada': {'recaudadas': []},
 'recaudado': {'recaudados': []},
 'recaudador': {'recaudadores': []},
 'recaudo': {'recaudos': []},
 'recaulk': {'recaulked': [], 'recaulking': [], 'recaulks': []},
 'recaus': {'recause': []},
 'recaustic': {'recausticized': [], 'recausticizing': []},
 'recaut': {'recaution': ['recautions']},
 'recauter': {'recauterized': []},
 'recaution': ['recautions'],
 'recav': {'recave': ['recaved']},
 'recave': ['recaved'],
 'recbercb': {'recbercbes': []},
 'recberch': {'recberches': []},
 'recbrd': {'recbrds': []},
 'recbt': {'recbte': [], 'recbts': []},
 'recc': {'recce': ['recceing']},
 'reccafr': {'reccafred': []},
 'reccar': {'reccared': []},
 'reccaredu': {'reccaredus': []},
 'reccav': {'reccave': ['reccaved']},
 'reccave': ['reccaved'],
 'recce': {'reccee': []},
 'recceiv': {'recceive': ['recceived']},
 'recceive': ['recceived'],
 'reccent': {'reccently': []},
 'reccess': {'reccession': []},
 'reccesvinthu': {'reccesvinthus': []},
 'reccgniz': {'reccgnize': ['reccgnized']},
 'reccgnize': ['reccgnized'],
 'recch': {'recche': ['recched']},
 'recche': ['recched'],
 'recchel': {'reccheles': []},
 'recchele': {'recchelees': []},
 'recchi': {'recchie': []},
 'recchion': {'recchione': []},
 'recchu': {'recchus': []},
 'recci': {'reccy': []},
 'reccipt': {'reccipts': []},
 'recciu': {'recciued': [], 'reccius': []},
 'recciv': {'reccive': ['reccives', 'reccived', 'recciver'], 'recciving': []},
 'reccive': ['reccives', 'reccived', 'recciver'],
 'reccmmend': {'reccmmendation': ['reccmmendations'], 'reccmmended': []},
 'reccmmendation': ['reccmmendations'],
 'reccnstitut': {'reccnstitution': []},
 'reccnt': {'reccntes': []},
 'reccntli': {'reccntly': []},
 'reccogn': {'reccognized': []},
 'reccolect': {'reccolection': []},
 'reccollect': {'reccollected': [], 'reccollection': ['reccollections']},
 'reccollection': ['reccollections'],
 'reccomend': {'reccomendation': ['reccomendations'],
               'reccomended': [],
               'reccomending': [],
               'reccomends': []},
 'reccomendation': ['reccomendations'],
 'reccommend': {'reccommendation': ['reccommendations'],
                'reccommended': [],
                'reccommending': [],
                'reccommends': []},
 'reccommendation': ['reccommendations'],
 'reccon': {'recconed': [], 'recconing': ['recconings']},
 'recconing': ['recconings'],
 'recconnaiss': {'recconnaissance': []},
 'reccopoli': {'reccopolis': []},
 'reccord': {'reccorded': [], 'reccords': []},
 'reccptiv': {'reccptiveness': []},
 'reccptor': {'reccptors': []},
 'reccrd': {'reccrded': [], 'reccrds': []},
 'reccssu': {'reccssus': []},
 'reccur': {'reccurence': ['reccurences'],
            'reccurent': [],
            'reccuring': [],
            'reccurred': [],
            'reccurring': [],
            'reccurs': []},
 'reccurence': ['reccurences'],
 'reccurr': {'reccurrence': ['reccurrences'], 'reccurrent': []},
 'reccurrence': ['reccurrences'],
 'recd': {'recde': []},
 'recdgniz': {'recdgnized': []},
 'recdi': {'recdy': []},
 'recdmmend': {'recdmmended': []},
 'recdrd': {'recdrds': []},
 'recdv': {'recdve': ['recdved']},
 'recdve': ['recdved'],
 'rece': {'reced': ['receds'],
          'recee': ['recees', 'receed', 'receeds'],
          'reces': [],
          'recing': []},
 "rece'v": {"rece've": []},
 'recea': {'receas': []},
 'receal': {'recealed': []},
 'receat': {'receate': [], 'receation': ['receational']},
 'receation': ['receational'],
 'receatli': {'receatly': []},
 'receau': {'receaue': ['receaues', 'receaued'], 'receauing': []},
 'receaue': ['receaues', 'receaued'],
 'receav': {'receave': ['receaved',
                        'receaver',
                        'receaves',
                        'receavers',
                        'receaveing'],
            'receaving': []},
 'receave': ['receaved', 'receaver', 'receaves', 'receavers', 'receaveing'],
 'receaving': {'receavinge': []},
 'receb': {'recebe': ['receber']},
 'recebe': ['receber'],
 'recebed': {'recebedou': []},
 'recebemo': {'recebemos': []},
 'recebida': {'recebidas': []},
 'recebido': {'recebidos': []},
 'reced': {'recedant': [],
           'recede': ['recedes',
                      'receder',
                      'receded',
                      'receders',
                      'recedent',
                      'recedents',
                      'recedeing',
                      'recedence',
                      'recedented'],
           'receding': []},
 'receda': {'recedas': []},
 'recedamu': {'recedamus': []},
 'recedati': {'recedatis': []},
 'recede': ['recedes',
            'receder',
            'receded',
            'receders',
            'recedent',
            'recedents',
            'recedeing',
            'recedence',
            'recedented'],
 'recedeb': {'recedebant': []},
 'receden': {'recedens': []},
 'recedent': {'recedente': ['recedentes']},
 'recedente': ['recedentes'],
 'recedenti': {'recedentis': []},
 'recedentibu': {'recedentibus': []},
 'receder': {'recedere': ['recederent']},
 'recedere': ['recederent'],
 'recedi': {'recedis': []},
 'recedimu': {'recedimus': []},
 'recedingli': {'recedingly': []},
 'recediv': {'recedivism': []},
 'recedur': {'recedure': []},
 'recee': ['recees', 'receed', 'receeds'],
 'receed': {'receede': ['receeded'], 'receeding': []},
 'receede': ['receeded'],
 'receeiv': {'receeived': []},
 'receev': {'receeve': ['receeved']},
 'receeve': ['receeved'],
 'recef': {'recefs': []},
 'receff': {'receffes': []},
 'recefi': {'recefies': []},
 'recefl': {'recefles': []},
 'recefv': {'recefve': ['recefved']},
 'recefve': ['recefved'],
 'recegn': {'recegnized': []},
 'receh': {'recehe': ['recehes', 'recehed'], 'recehing': []},
 'recehe': ['recehes', 'recehed'],
 'recehtli': {'recehtly': []},
 'recei': {'receied': []},
 'receib': {'receibe': []},
 'receic': {'receice': ['receiced']},
 'receice': ['receiced'],
 'receie': {'receieed': []},
 'receiev': {'receieve': ['receieves', 'receieved']},
 'receieve': ['receieves', 'receieved'],
 'receif': {'receife': ['receifed']},
 'receife': ['receifed'],
 'receii': {'receiie': ['receiied']},
 'receiie': ['receiied'],
 'recein': {'receined': []},
 'receint': {'receints': []},
 'receio': {'receioe': ['receioed'], 'receios': []},
 'receioe': ['receioed'],
 'receiot': {'receiots': []},
 'receip': {'receipe': ['receipes', 'receipent', 'receipents'], 'receips': []},
 'receipe': ['receipes', 'receipent', 'receipents'],
 'receipi': {'receipient': ['receipients']},
 'receipient': ['receipients'],
 'receipl': {'receipls': []},
 'receipr': {'receiprs': []},
 'receiproc': {'receiprocal': []},
 'receipt': ['receipte',
             'receipter',
             'receiptes',
             'receipted',
             'receipting',
             'receiption',
             'receiptive'],
 'receiptbook': {'receiptbooks': []},
 'receiptor': {'receiptors': []},
 'receir': {'receire': ['receires', 'receirer', 'receired'], 'receiring': []},
 'receire': ['receires', 'receirer', 'receired'],
 'receis': {'receise': ['receised']},
 'receise': ['receised'],
 'receit': {'receite': ['receites', 'receited'],
            'receiting': [],
            'receits': []},
 'receita': {'receitas': []},
 'receite': ['receites', 'receited'],
 'receitor': {'receitors': []},
 'receiu': {'receiue': ['receiues', 'receiued', 'receiueing'], 'receiuing': []},
 'receiue': ['receiues', 'receiued', 'receiueing'],
 'receiuer': {'receiuers': []},
 'receiuing': {'receiuinge': []},
 'receiv': {'receivability': [],
            'receivable': ['receivables'],
            'receival': ['receivals'],
            'receive': ['received',
                        'receiver',
                        'receives',
                        'receiveing',
                        'receiveable',
                        'receiveables'],
            'receiving': ['receivings'],
            'receivs': []},
 'receivable': ['receivables'],
 'receivahl': {'receivahle': []},
 'receival': ['receivals'],
 'receivd': {'receivde': []},
 'receive': {'receivee': ['receiveed']},
 'receiveani': {'receiveany': []},
 'receivecomplet': {'receivecompleted': []},
 'received': {'receivede': []},
 'receivedbi': {'receivedby': []},
 'receivedhi': {'receivedhis': []},
 'receivedsign': {'receivedsignal': []},
 'receivedth': {'receivedthe': []},
 'receivee': ['receiveed'],
 'receivemessag': {'receivemessage': []},
 'receiveonli': {'receiveonly': []},
 'receiverbas': {'receiverbased': []},
 'receivergener': {'receivergeneral': []},
 'receiveriniti': {'receiverinitiated': []},
 'receivermanag': {'receivermanager': []},
 'receiveroper': {'receiveroperating': []},
 'receiverori': {'receiveroriented': []},
 'receiversgener': {'receiversgeneral': []},
 'receivership': {'receivership': []},
 'receiverstimul': {'receiverstimulator': []},
 'receivertransmitt': {'receivertransmitter': ['receivertransmitters']},
 'receivertransmitter': ['receivertransmitters'],
 'receivesth': {'receivesthe': []},
 'receiveth': {'receivethe': []},
 'receivi': {'receivied': []},
 'receivin': {'receivine': []},
 'receiving': {'receivinge': []},
 'receivinghous': {'receivinghouse': ['receivinghouses']},
 'receivinghouse': ['receivinghouses'],
 'receivingship': {'receivingships': []},
 'receivingst': {'receivingstation': []},
 'receivingth': {'receivingthe': []},
 'receivo': {'receivos': []},
 'receivor': {'receivors': []},
 'receivour': {'receivours': []},
 'receivr': {'receivre': []},
 'receiw': {'receiwed': []},
 'receiy': {'receiye': ['receiyes', 'receiyed', 'receiyer'], 'receiying': []},
 'receiye': ['receiyes', 'receiyed', 'receiyer'],
 'recejv': {'recejve': ['recejved']},
 'recejve': ['recejved'],
 'recel': {'recelant': [],
           'recele': ['receler', 'recelent'],
           'recell': [],
           'recels': []},
 'recele': ['receler', 'recelent'],
 'recelebr': {'recelebrate': ['recelebrated'], 'recelebration': []},
 'recelebrate': ['recelebrated'],
 'receleur': {'receleurs': []},
 'receleus': {'receleuse': []},
 'recelo': {'recelos': []},
 'receloso': {'recelosos': []},
 'recelpt': {'recelpts': []},
 'recelr': {'recelre': ['recelred']},
 'recelre': ['recelred'],
 'recelt': {'recelted': []},
 'recelv': {'recelvable': ['recelvables'],
            'recelve': ['recelves', 'recelver', 'recelved', 'recelvers'],
            'recelving': []},
 'recelvable': ['recelvables'],
 'recelve': ['recelves', 'recelver', 'recelved', 'recelvers'],
 'recem': {'receme': ['recemes'],
           'recemic': [],
           'recemization': [],
           'recemment': []},
 'receme': ['recemes'],
 'recement': {'recementation': [], 'recemented': [], 'recementing': []},
 'recemli': {'recemly': []},
 'recemmend': {'recemmendations': [], 'recemmended': []},
 'recemosu': {'recemosus': []},
 'recemundu': {'recemundus': []},
 'recen': {'recene': ['recened'], 'recens': []},
 "recen'li": {"recen'ly": []},
 'recenc': {'recency': []},
 'recendi': {'recendy': []},
 'recene': ['recened'],
 'recenfli': {'recenfly': []},
 'recenili': {'recenily': []},
 'recenli': {'recenly': []},
 'recenlli': {'recenlly': []},
 'recenlti': {'recenlty': []},
 'recenrli': {'recenrly': []},
 'recens': {'recensant': [],
            'recense': ['recenser',
                        'recenses',
                        'recensed',
                        'recensent',
                        'recensement',
                        'recensements'],
            'recension': ['recensions'],
            'recensiti': ['recensitis']},
 'recense': {'recensee': ['recensees']},
 'recensea': {'recenseas': []},
 'recenseamento': {'recenseamentos': []},
 'recenseamu': {'recenseamus': []},
 'recensebimu': {'recensebimus': []},
 'recensee': ['recensees'],
 'recensemu': {'recensemus': []},
 'recensen': {'recensens': []},
 'recensendi': {'recensendis': []},
 'recensent': {'recensentes': []},
 'recenser': {'recensere': []},
 'recenseur': {'recenseurs': []},
 'recensi': {'recensie': []},
 'recension': {'recensional': ['recensionally'],
               'recensione': ['recensioner', 'recensiones']},
 'recensional': ['recensionally'],
 'recensione': ['recensioner', 'recensiones'],
 'recensioni': {'recensionis': []},
 'recensionibu': {'recensionibus': []},
 'recensionist': {'recensionists': []},
 'recensir': {'recensire': []},
 'recensita': {'recensitae': [], 'recensitas': []},
 'recensiti': ['recensitis'],
 'recensitu': {'recensitus': []},
 'recensor': {'recensore': ['recensored'], 'recensors': []},
 'recensore': ['recensored'],
 'recensqu': {'recensque': []},
 'recensu': {'recensus': []},
 'recensuimu': {'recensuimus': []},
 'recensus': {'recensused': []},
 'recent': ['recente',
            'recentes',
            'recenter',
            'recently',
            'recented',
            'recenters',
            'recentely',
            'recention',
            'recentered',
            'recentment',
            'recentness',
            'recentering',
            'recenterings'],
 "recent'i": {"recent'y": []},
 'recentadv': {'recentadvances': []},
 'recentdecad': {'recentdecades': []},
 'recentdevelop': {'recentdevelopments': []},
 'recentement': {'recentemente': []},
 'recentesqu': {'recentesque': []},
 'recentfi': {'recentfy': []},
 'recentfil': {'recentfiles': []},
 'recenthistori': {'recenthistory': []},
 'recenti': {'recentis': [], 'recenty': []},
 'recentibu': {'recentibus': []},
 'recentior': {'recentiore': ['recentiores']},
 'recentiore': ['recentiores'],
 'recentiori': {'recentioris': []},
 'recentioribu': {'recentioribus': []},
 'recentiorumqu': {'recentiorumque': []},
 'recentisqu': {'recentisque': []},
 'recentissim': {'recentissime': []},
 'recentissima': {'recentissimae': [], 'recentissimas': []},
 'recentissimi': {'recentissimis': []},
 'recentissimu': {'recentissimus': []},
 'recentiu': {'recentius': []},
 'recentlli': {'recentlly': []},
 'recentlyacquir': {'recentlyacquired': []},
 'recentlyadopt': {'recentlyadopted': []},
 'recentlyannounc': {'recentlyannounced': []},
 'recentlyappoint': {'recentlyappointed': []},
 'recentlyarriv': {'recentlyarrived': []},
 'recentlycom': {'recentlycome': []},
 'recentlycomplet': {'recentlycompleted': []},
 'recentlyconclud': {'recentlyconcluded': []},
 'recentlyconqu': {'recentlyconquered': []},
 'recentlyconstruct': {'recentlyconstructed': []},
 'recentlyconvert': {'recentlyconverted': []},
 'recentlycr': {'recentlycreated': []},
 'recentlydeceas': {'recentlydeceased': []},
 'recentlydevelop': {'recentlydeveloped': []},
 'recentlydiscov': {'recentlydiscovered': []},
 'recentlyelect': {'recentlyelected': []},
 'recentlyenact': {'recentlyenacted': []},
 'recentlyerect': {'recentlyerected': []},
 'recentlyestablish': {'recentlyestablished': []},
 'recentlyform': {'recentlyformed': []},
 'recentlyfound': {'recentlyfounded': []},
 'recentlyintroduc': {'recentlyintroduced': []},
 'recentlyinv': {'recentlyinvented': []},
 'recentlyissu': {'recentlyissued': []},
 'recentlyjoin': {'recentlyjoined': []},
 'recentlykil': {'recentlykilled': []},
 'recentlylaunch': {'recentlylaunched': []},
 'recentlymad': {'recentlymade': []},
 'recentlymarri': {'recentlymarried': []},
 'recentlyopen': {'recentlyopened': []},
 'recentlypass': {'recentlypassed': []},
 'recentlypublish': {'recentlypublished': []},
 'recentlypurchas': {'recentlypurchased': []},
 'recentlyreleas': {'recentlyreleased': []},
 'recentlyrestor': {'recentlyrestored': []},
 'recentlyus': {'recentlyused': []},
 'recentlywidow': {'recentlywidowed': []},
 'recentr': {'recentral': ['recentralize',
                           'recentralized',
                           'recentralizes',
                           'recentralizing',
                           'recentralization',
                           'recentralizations'],
             'recentration': [],
             'recentre': ['recentrer', 'recentred', 'recentres'],
             'recentring': []},
 'recentrag': {'recentrage': []},
 'recentral': ['recentralize',
               'recentralized',
               'recentralizes',
               'recentralizing',
               'recentralization',
               'recentralizations'],
 'recentralis': {'recentralisation': [],
                 'recentralise': ['recentralised'],
                 'recentralising': []},
 'recentralise': ['recentralised'],
 'recentre': ['recentrer', 'recentred', 'recentres'],
 'recentri': {'recentry': []},
 'recentrifug': {'recentrifugalized': [],
                 'recentrifugated': [],
                 'recentrifugation': [],
                 'recentrifuge': ['recentrifuged'],
                 'recentrifuging': []},
 'recentrifuge': ['recentrifuged'],
 'recentstudi': {'recentstudies': [], 'recentstudy': []},
 'recentti': {'recentty': []},
 'recenttim': {'recenttimes': []},
 'recentyear': {'recentyears': []},
 'recenu': {'recenue': []},
 'recenz': {'recenzenci': [], 'recenzent': []},
 'recenzj': {'recenzje': []},
 'receommend': {'receommended': []},
 'receot': {'receotion': []},
 'receotli': {'receotly': []},
 'receov': {'receover': ['receovered']},
 'receover': ['receovered'],
 'receoveri': {'receovery': []},
 'recep': {'recepe': [], 'recepiti': []},
 'recepcion': {'recepcione': ['recepciones']},
 'recepcione': ['recepciones'],
 'recepcioni': {'recepcionis': []},
 'receper': {'receperant': [], 'recepere': [], 'receperitis': []},
 'receperi': {'receperis': []},
 'receperimu': {'receperimus': []},
 'recepi': {'recepient': ['recepients'], 'recepies': []},
 'recepient': ['recepients'],
 'recepimu': {'recepimus': []},
 'recepir': {'recepire': []},
 'recepisc': {'recepisce': []},
 'recepiss': {'recepisse': ['recepisses', 'recepissent']},
 'recepisse': ['recepisses', 'recepissent'],
 'recepisti': {'recepistis': []},
 'recepit': {'recepits': []},
 'receplor': {'receplors': []},
 'receplu': {'receplus': []},
 'recepor': {'recepors': []},
 'recepr': {'receprive': []},
 'receproc': {'receprocal': [], 'receprocity': []},
 'recepror': {'receprors': []},
 'recept': {'receptability': [],
            'receptable': ['receptables'],
            'receptal': [],
            'receptance': ['receptances'],
            'receptant': [],
            'receptator': [],
            'recepte': ['receptes', 'recepted', 'recepter', 'recepters'],
            'receptibility': [],
            'receptible': [],
            'receptical': ['recepticals'],
            'recepting': [],
            'reception': ['receptional', 'receptioning'],
            'receptive': ['receptives', 'receptively', 'receptiveness'],
            'receptivity': [],
            'recepts': []},
 'recepta': {'receptae': [], 'receptas': []},
 'receptable': ['receptables'],
 'receptaci': {'receptacie': []},
 'receptacl': {'receptacle': []},
 'receptaculi': {'receptaculis': []},
 'receptaculit': {'receptaculites': []},
 'receptaculitid': {'receptaculitids': []},
 'receptaculo': {'receptaculos': []},
 'receptael': {'receptaele': []},
 'receptance': ['receptances'],
 'receptaol': {'receptaole': []},
 'receptar': {'receptare': []},
 'receptator': {'receptatores': []},
 'receptatoribu': {'receptatoribus': []},
 'recepte': {'receptee': []},
 'recepteur': {'recepteurs': []},
 'recepti': {'receptie': [], 'receptiou': [], 'receptis': []},
 'receptibili': {'receptibilis': []},
 'receptical': ['recepticals'],
 'recepticl': {'recepticle': ['recepticles']},
 'recepticle': ['recepticles'],
 'receptif': {'receptifs': []},
 'reception': {'receptione': ['receptiones'], 'receptionism': []},
 'receptionchamb': {'receptionchamber': []},
 'receptionday': {'receptiondays': []},
 'receptione': ['receptiones'],
 'receptionhal': {'receptionhall': []},
 'receptionhistori': {'receptionhistory': []},
 'receptionhous': {'receptionhouse': []},
 'receptioni': {'receptionis': []},
 'receptionibu': {'receptionibus': []},
 'receptionist': {'receptionist': []},
 'receptionnair': {'receptionnaire': []},
 'receptionroom': {'receptionrooms': []},
 'receptionsorgan': {'receptionsorgane': []},
 'receptive': ['receptives', 'receptively', 'receptiveness'],
 'receptivit': {'receptivite': []},
 'receptivo': {'receptivos': []},
 'receptlv': {'receptlveness': []},
 'recepto': {'receptos': []},
 'receptocl': {'receptocle': []},
 'receptor': ['receptore', 'receptoric', 'receptoral', 'receptores'],
 'receptora': {'receptoras': []},
 'receptoract': {'receptoractive': []},
 'receptoractiv': {'receptoractivated': []},
 'receptoradenyl': {'receptoradenylate': []},
 'receptorassoci': {'receptorassociated': []},
 'receptorbas': {'receptorbased': []},
 'receptorbear': {'receptorbearing': []},
 'receptorbind': {'receptorbinding': []},
 'receptorblock': {'receptorblocking': []},
 'receptorchannel': {'receptorchannels': []},
 'receptorcontain': {'receptorcontaining': []},
 'receptorcoupl': {'receptorcoupled': []},
 'receptordefici': {'receptordeficient': []},
 'receptordepend': {'receptordependent': []},
 'receptordestroy': {'receptordestroying': []},
 'receptorf': {'receptorfs': []},
 'receptorg': {'receptorgated': []},
 'receptorgener': {'receptorgenerated': []},
 'receptorhormon': {'receptorhormone': []},
 'receptori': {'receptorial': [], 'receptoris': [], 'receptory': []},
 'receptoribu': {'receptoribus': []},
 'receptorimmunoreact': {'receptorimmunoreactive': []},
 'receptorindepend': {'receptorindependent': []},
 'receptorinduc': {'receptorinduced': []},
 'receptorinteract': {'receptorinteracting': []},
 'receptorionophor': {'receptorionophore': []},
 'receptorlik': {'receptorlike': []},
 'receptorlink': {'receptorlinked': []},
 'receptormedi': {'receptormediated': []},
 'receptorneg': {'receptornegative': []},
 'receptorolog': {'receptorology': []},
 'receptoroper': {'receptoroperated': []},
 'receptorposit': {'receptorpositive': []},
 'receptorregul': {'receptorregulated': []},
 'receptorrel': {'receptorrelated': []},
 'receptorselect': {'receptorselective': []},
 'receptorspecif': {'receptorspecific': []},
 'receptorstimul': {'receptorstimulated': [], 'receptorstimulating': []},
 'receptort': {'receptorts': []},
 'receptortarget': {'receptortargeted': []},
 'receptortyrosin': {'receptortyrosine': []},
 'receptosecretori': {'receptosecretory': []},
 'receptosom': {'receptosome': ['receptosomes']},
 'receptosome': ['receptosomes'],
 'receptot': {'receptots': []},
 'receptotop': {'receptotopic': []},
 'receptric': {'receptrice': ['receptrices']},
 'receptrice': ['receptrices'],
 'receptro': {'receptros': []},
 'recepts': {'receptse': []},
 'receptu': {'receptual': ['receptually'], 'receptus': []},
 'receptual': ['receptually'],
 'receptur': {'recepture': []},
 'recepturo': {'recepturos': []},
 'recepturu': {'recepturus': []},
 'recer': {'recerred': []},
 'recercar': {'recercare': []},
 'recercel': {'recercele': []},
 'recerch': {'recerche': ['recerches', 'recercher']},
 'recerche': ['recerches', 'recercher'],
 'recerd': {'recerded': [], 'recerds': []},
 'receritli': {'receritly': []},
 'recerpt': {'recerpts': []},
 'recerqu': {'recerques': []},
 'recerr': {'recerre': []},
 'recertif': {'recertificated': [], 'recertification': ['recertifications']},
 'recertifi': {'recertified': [],
               'recertifies': [],
               'recertify': ['recertifying']},
 'recertification': ['recertifications'],
 'recertiflc': {'recertiflcation': []},
 'recertify': ['recertifying'],
 'recertli': {'recertly': []},
 'recerv': {'recervable': [],
            'recerve': ['recerves', 'recerver', 'recerved'],
            'recerving': []},
 'recerve': ['recerves', 'recerver', 'recerved'],
 'reces': {'recese': [], 'recesion': [], 'recesive': []},
 'recesi': {'recesies': []},
 'recesivo': {'recesivos': []},
 'recess': ['recesssive', 'recesssion'],
 'recessari': {'recessary': []},
 'recessarili': {'recessarily': []},
 'recesser': {'recesserant': []},
 'recesseri': {'recesseris': []},
 'recessi': {'recessie': []},
 'recessibu': {'recessibus': []},
 'recessimu': {'recessimus': []},
 'recession': {'recessional': ['recessionally'], 'recessione': []},
 'recessional': ['recessionally'],
 'recessionari': {'recessionary': []},
 'recessioni': {'recessionis': []},
 'recessioninduc': {'recessioninduced': []},
 'recessionplagu': {'recessionplagued': []},
 'recessionrel': {'recessionrelated': []},
 'recessionresect': {'recessionresection': []},
 'recessionresist': {'recessionresistant': []},
 'recessiss': {'recessisse': ['recessissent']},
 'recessisse': ['recessissent'],
 'recesss': {'recess': ['recesssive', 'recesssion']},
 'recesstim': {'recesstime': []},
 'recessu': {'recessus': []},
 'recessuru': {'recessurus': []},
 'recesv': {'recesved': []},
 'recet': {'recete': [], 'recets': []},
 'receta': {'recetas': []},
 'recetli': {'recetly': []},
 'recett': {'recette': ['recettes']},
 'recette': ['recettes'],
 'recettor': {'recettore': []},
 'recetv': {'recetve': ['recetves', 'recetved'], 'recetving': []},
 'recetve': ['recetves', 'recetved'],
 'receu': {'receue': ['receued', 'receues'], 'receus': []},
 'receue': ['receued', 'receues'],
 'receuil': {'receuille': ['receuillement'], 'receuils': []},
 'receuild': {'receuildes': []},
 'receuille': ['receuillement'],
 'receuilli': {'receuillies': [], 'receuillis': []},
 'receuon': {'receuons': []},
 'receur': {'receurent': []},
 'receutli': {'receutly': []},
 'recev': {'recevable': ['recevables'],
           'recevant': [],
           'receve': ['recever', 'receves', 'receved', 'recevered'],
           'receving': []},
 'recevabilit': {'recevabilite': []},
 'recevable': ['recevables'],
 'recevai': {'recevaient': [], 'recevais': []},
 'receve': ['recever', 'receves', 'receved', 'recevered'],
 'recever': {'recevere': []},
 'receveri': {'recevery': []},
 'receveur': {'receveurs': []},
 'receveus': {'receveuse': []},
 'recevi': {'recevie': ['recevied', 'recevies']},
 'recevido': {'recevidos': []},
 'recevie': ['recevied', 'recevies'],
 'receving': {'recevinge': []},
 'recevion': {'recevions': []},
 'recevoi': {'recevoient': [], 'recevois': []},
 'recevon': {'recevons': []},
 'recevour': {'recevours': []},
 'recevra': {'recevras': []},
 'recevrai': {'recevraient': [], 'recevrais': []},
 'recevrion': {'recevrions': []},
 'recevroi': {'recevroient': [], 'recevrois': []},
 'recevron': {'recevrons': []},
 'recew': {'recewe': ['recewed']},
 'recewe': ['recewed'],
 'recey': {'receyed': []},
 'receyt': {'receyte': ['receytes'], 'receyts': []},
 'receyte': ['receytes'],
 'receyu': {'receyue': ['receyued', 'receyuers'], 'receyuing': []},
 'receyue': ['receyued', 'receyuers'],
 'receyuyng': {'receyuynge': []},
 'receyv': {'receyve': ['receyved', 'receyver', 'receyves', 'receyvers'],
            'receyving': []},
 'receyve': ['receyved', 'receyver', 'receyves', 'receyvers'],
 'receyving': {'receyvinge': []},
 'receyvour': {'receyvours': []},
 'receyvyng': {'receyvynge': []},
 'recezion': {'recezione': []},
 'recfuir': {'recfuired': []},
 'recgnit': {'recgnition': []},
 'recgniz': {'recgnize': ['recgnized']},
 'recgnize': ['recgnized'],
 'recgon': {'recgonize': ['recgonized']},
 'recgonis': {'recgonised': []},
 'recgonit': {'recgonition': []},
 'recgonize': ['recgonized'],
 'rech': {'reche': ['reches', 'reched'], 'reching': [], 'rechs': []},
 'rechabit': {'rechabite': ['rechabites'], 'rechabitism': []},
 'rechabitc': {'rechabitcs': []},
 'rechabite': ['rechabites'],
 'rechac': {'rechace': []},
 'rechahecrian': {'rechahecrians': []},
 'rechain': {'rechained': [], 'rechaining': []},
 'rechaka': {'rechakas': []},
 'rechalk': {'rechalked': []},
 'rechalleng': {'rechallenge': ['rechallenged', 'rechallenges'],
                'rechallenging': []},
 'rechallenge': ['rechallenged', 'rechallenges'],
 'rechamb': {'rechamber': ['rechambered', 'rechambering']},
 'rechamber': ['rechambered', 'rechambering'],
 'rechamu': {'rechamus': []},
 'rechan': {'rechanical': []},
 'rechanel': {'rechanelled': []},
 'rechang': {'rechange': ['rechanges', 'rechanged'], 'rechanging': []},
 'rechange': ['rechanges', 'rechanged'],
 'rechannel': {'rechanneled': [],
               'rechanneling': ['rechannelings'],
               'rechannelization': [],
               'rechannelize': ['rechannelized'],
               'rechannelizing': [],
               'rechannelled': [],
               'rechannelling': [],
               'rechannels': []},
 'rechanneling': ['rechannelings'],
 'rechannelize': ['rechannelized'],
 'rechant': {'rechanted': [], 'rechants': []},
 'recharact': {'recharacter': ['recharactered']},
 'recharacter': {'recharacterization': ['recharacterizations'],
                 'recharacterize': ['recharacterized', 'recharacterizes'],
                 'recharacterizing': []},
 'recharacteris': {'recharacterisation': [],
                   'recharacterise': ['recharacterised'],
                   'recharacterising': []},
 'recharacterise': ['recharacterised'],
 'recharacterization': ['recharacterizations'],
 'recharacterize': ['recharacterized', 'recharacterizes'],
 'recharch': {'recharches': []},
 'rechard': {'rechards': []},
 'recharg': {'rechargable': [],
             'recharge': ['recharger',
                          'recharged',
                          'recharges',
                          'rechargers',
                          'rechargeable',
                          'rechargement',
                          'rechargeables',
                          'rechargeability'],
             'recharging': ['rechargings']},
 'recharge': ['recharger',
              'recharged',
              'recharges',
              'rechargers',
              'rechargeable',
              'rechargement',
              'rechargeables',
              'rechargeability'],
 'recharging': ['rechargings'],
 'rechart': {'recharte': ['recharted',
                          'recharter',
                          'recharters',
                          'rechartered',
                          'rechartering'],
             'recharting': [],
             'recharts': []},
 'recharte': ['recharted',
              'recharter',
              'recharters',
              'rechartered',
              'rechartering'],
 'rechas': {'rechase': ['rechased']},
 'rechase': ['rechased'],
 'rechat': {'rechate': []},
 'rechaud': {'rechauds': []},
 'rechauff': {'rechauffant': [],
              'rechauffe': ['rechauffer', 'rechauffent', 'rechauffement']},
 'rechauffag': {'rechauffage': []},
 'rechauffe': {'rechauffee': ['rechauffees']},
 'rechauffee': ['rechauffees'],
 'rechauffi': {'rechauffie': []},
 'rechazada': {'rechazadas': []},
 'rechazado': {'rechazados': []},
 'rechazamo': {'rechazamos': []},
 'rechazo': {'rechazos': []},
 'rechbauerstrass': {'rechbauerstrasse': []},
 'rechberg': {'rechberger': []},
 'rechcrch': {'rechcrches': []},
 'rechcrchc': {'rechcrchcs': []},
 'reche': ['reches', 'reched'],
 'recheat': {'recheate': []},
 'rechech': {'recheches': []},
 'recheck': {'rechecked': [], 'rechecking': ['recheckings'], 'rechecks': []},
 'rechecking': ['recheckings'],
 'rechei': {'recheis': []},
 'recheich': {'recheiches': []},
 'rechel': {'rechele': ['recheles'], 'rechelle': []},
 'rechelbach': {'rechelbacher': []},
 'rechele': ['recheles'],
 'rechelesness': {'rechelesnesse': []},
 'rechenanlag': {'rechenanlage': []},
 'rechenau': {'rechenauer': []},
 'rechenberg': {'rechenberger': []},
 'rechendorf': {'rechendorfer': []},
 'rechenergebniss': {'rechenergebnisse': []},
 'rechenfehl': {'rechenfehler': []},
 'rechenger': {'rechengerate': []},
 'rechenh': {'rechenhes': []},
 'rechenmach': {'rechenmacher': []},
 'rechenmaschin': {'rechenmaschine': []},
 'rechenmeist': {'rechenmeister': ['rechenmeisters']},
 'rechenmeister': ['rechenmeisters'],
 'rechenmethod': {'rechenmethode': []},
 'rechenmodel': {'rechenmodell': []},
 'rechenoper': {'rechenoperation': []},
 'rechenpfennig': {'rechenpfennige': []},
 'rechenprogramm': {'rechenprogramme': []},
 'rechenschaft': {'rechenschafts': []},
 'rechenschaftsbericht': {'rechenschaftsberichte': []},
 'rechenschieb': {'rechenschieber': []},
 'rechensystem': {'rechensysteme': []},
 'rechenunterricht': {'rechenunterrichts': []},
 'rechenverfahren': {'rechenverfahrens': []},
 'rechenzentrum': {'rechenzentrums': []},
 'recherc': {'recherce': ['recherces']},
 'rechercb': {'rechercbes': []},
 'recherce': ['recherces'],
 'recherch': {'recherchant': [],
              'recherche': ['rechercher',
                            'recherches',
                            'recherchers',
                            'recherchent'],
              'recherchs': []},
 'recherchai': {'recherchaient': [], 'recherchais': []},
 'recherchc': {'recherchcs': []},
 'recherche': {'recherchee': ['recherchees']},
 'recherchee': ['recherchees'],
 'rechercheron': {'rechercherons': []},
 'recherchesd': {'recherchesde': []},
 'rechercheur': {'rechercheurs': []},
 'recherchi': {'recherchie': [], 'recherchy': []},
 'recherchiert': {'recherchierte': []},
 'rechercho': {'recherchos': []},
 'recherchon': {'recherchons': []},
 'rechercht': {'recherchts': []},
 'recherck': {'recherckes': []},
 'rechercli': {'recherclies': []},
 'rechercn': {'rechercnes': []},
 'recherech': {'rechereche': ['rechereches']},
 'rechereche': ['rechereches'],
 'rechereh': {'recherehe': ['recherehes']},
 'recherehe': ['recherehes'],
 'recherla': {'recherlas': []},
 'recheroh': {'recherohes': []},
 'recherrh': {'recherrhes': []},
 'recherth': {'recherthes': []},
 'rechest': {'rechester': []},
 'rechew': {'rechewed': [], 'rechewing': [], 'rechews': []},
 'rechi': {'rechie': [], 'rechis': [], 'rechy': []},
 'rechiariu': {'rechiarius': []},
 'rechied': {'rechiede': []},
 'rechign': {'rechigne': []},
 'rechil': {'rechill': ['rechilled', 'rechilling']},
 'rechill': ['rechilled', 'rechilling'],
 'reching': {'rechinger': []},
 'rechink': {'rechinked': [], 'rechinking': []},
 'rechip': {'rechipped': [], 'rechipping': []},
 'rechipp': {'rechipper': []},
 'rechisel': {'rechiseled': [], 'rechiselled': []},
 'rechitski': {'rechitsky': []},
 'rechkemm': {'rechkemmer': []},
 'rechl': {'rechle': [], 'rechls': []},
 'rechlorin': {'rechlorinated': [], 'rechlorination': []},
 'rechlsgeschicht': {'rechlsgeschichte': []},
 'rechmh': {'rechmhes': []},
 'rechmir': {'rechmire': []},
 'rechn': {'rechne': [], 'rechning': []},
 'rechnen': {'rechnens': []},
 'rechnend': {'rechnende': ['rechnendes']},
 'rechnende': ['rechnendes'],
 'rechner': {'rechners': []},
 'rechnergestiitzt': {'rechnergestiitzte': ['rechnergestiitzter']},
 'rechnergestiitzte': ['rechnergestiitzter'],
 'rechnergestutzt': {'rechnergestutzte': []},
 'rechnerisch': {'rechnerische': ['rechnerischer']},
 'rechnerische': ['rechnerischer'],
 'rechnernetz': {'rechnernetze': []},
 'rechnerorganis': {'rechnerorganisation': []},
 'rechnersystem': {'rechnersysteme': []},
 'rechnerunterstiitzt': {'rechnerunterstiitzte': []},
 'rechnerunterstutzt': {'rechnerunterstutzte': []},
 'rechnet': {'rechnete': []},
 'rechnic': {'rechnical': ['rechnically']},
 'rechnical': ['rechnically'],
 'rechnician': {'rechnicians': []},
 'rechniqu': {'rechnique': ['rechniques']},
 'rechnique': ['rechniques'],
 'rechnitz': {'rechnitzer': []},
 'rechnolog': {'rechnological': ['rechnologically'],
               'rechnologies': [],
               'rechnology': []},
 'rechnological': ['rechnologically'],
 'rechnung': {'rechnungs': []},
 'rechnungsbuch': {'rechnungsbucher': []},
 'rechnungsergebniss': {'rechnungsergebnisse': []},
 'rechnungsfuhr': {'rechnungsfuhrer': []},
 'rechnungshof': {'rechnungshofes': []},
 'rechnungsjahr': {'rechnungsjahres': []},
 'rechnungslegung': {'rechnungslegungs': []},
 'rechnungsmethod': {'rechnungsmethode': []},
 'rechnungswesen': {'rechnungswesens': []},
 'recho': {'rechoed': []},
 'rechoic': {'rechoice': []},
 'rechon': {'rechoned': []},
 'rechoos': {'rechoose': [], 'rechoosing': []},
 'rechop': {'rechopped': [], 'rechopping': []},
 'rechorch': {'rechorches': []},
 'rechoreograph': {'rechoreographed': [], 'rechoreographing': []},
 'rechorg': {'rechorged': [], 'rechorges': []},
 'rechos': {'rechose': []},
 'rechquaaki': {'rechquaakie': []},
 'rechri': {'rechris': []},
 'rechristcn': {'rechristcned': []},
 'rechristen': {'rechristened': [],
                'rechristening': ['rechristenings'],
                'rechristens': []},
 'rechristening': ['rechristenings'],
 'rechristian': {'rechristianed': [],
                 'rechristianization': [],
                 'rechristianize': ['rechristianized'],
                 'rechristianizing': []},
 'rechristianis': {'rechristianisation': [], 'rechristianise': []},
 'rechristianize': ['rechristianized'],
 'rechrom': {'rechrome': ['rechromed'], 'rechroming': []},
 'rechromatograph': {'rechromatographed': [], 'rechromatographing': []},
 'rechromatographi': {'rechromatography': []},
 'rechrome': ['rechromed'],
 'rechstein': {'rechsteiner': []},
 'recht': {'rechte': ['rechtes'], 'rechts': []},
 'rechtair': {'rechtaire': []},
 'rechte': ['rechtes'],
 'rechteck': {'rechtecke': [], 'rechtecks': []},
 'rechteckig': {'rechteckige': ['rechteckiges', 'rechteckiger']},
 'rechteckige': ['rechteckiges', 'rechteckiger'],
 'rechtelijk': {'rechtelijke': []},
 'rechten': {'rechtens': []},
 'rechter': {'rechters': []},
 'rechterlijk': {'rechterlijke': []},
 'rechtfertig': {'rechtfertige': []},
 'rechtfertigend': {'rechtfertigende': []},
 'rechtfertigt': {'rechtfertigte': []},
 'rechtfertigung': {'rechtfertigungs': []},
 'rechtfertigungsbegriff': {'rechtfertigungsbegriffs': []},
 'rechtfertigungsdekret': {'rechtfertigungsdekretes': []},
 'rechtfertigungsgrund': {'rechtfertigungsgrunde': []},
 'rechtfertigungslehr': {'rechtfertigungslehre': []},
 'rechtgeschicht': {'rechtgeschichte': []},
 'rechtgeschiedeni': {'rechtgeschiedenis': []},
 'rechtglaubig': {'rechtglaubige': []},
 'rechthebbend': {'rechthebbende': []},
 'rechthoekig': {'rechthoekige': []},
 'rechtin': {'rechtine': []},
 'rechtlehr': {'rechtlehre': []},
 'rechtlich': {'rechtliche': ['rechtliches', 'rechtlicher']},
 'rechtliche': ['rechtliches', 'rechtlicher'],
 'rechtlo': {'rechtlos': []},
 'rechtlos': {'rechtlose': ['rechtloser']},
 'rechtlose': ['rechtloser'],
 'rechtmassig': {'rechtmassige': []},
 'rechtori': {'rechtoris': []},
 'rechtrch': {'rechtrches': []},
 'rechts': {'rechtse': []},
 'rechtsakademi': {'rechtsakademie': []},
 'rechtsakt': {'rechtsakte': []},
 'rechtsalterthiim': {'rechtsalterthiimer': []},
 'rechtsalterthum': {'rechtsalterthumer': []},
 'rechtsaltertiim': {'rechtsaltertiimer': []},
 'rechtsaltertum': {'rechtsaltertumer': []},
 'rechtsanspruch': {'rechtsanspruche': []},
 'rechtsanthropologi': {'rechtsanthropologie': []},
 'rechtsanwalt': {'rechtsanwalte': [], 'rechtsanwalts': []},
 'rechtsanwaltskamm': {'rechtsanwaltskammer': []},
 'rechtsanwdlt': {'rechtsanwdlte': []},
 'rechtsanwend': {'rechtsanwender': []},
 'rechtsausschuss': {'rechtsausschusses': []},
 'rechtsbedel': {'rechtsbedeling': []},
 'rechtsbegriff': {'rechtsbegriffe': [], 'rechtsbegriffs': []},
 'rechtsbehelf': {'rechtsbehelfe': []},
 'rechtsberat': {'rechtsberater': []},
 'rechtsbescherm': {'rechtsbescherming': []},
 'rechtsbeschwerd': {'rechtsbeschwerde': []},
 'rechtsbiich': {'rechtsbiicher': []},
 'rechtsbrech': {'rechtsbrecher': []},
 'rechtsbuch': {'rechtsbucher': [], 'rechtsbuches': []},
 'rechtschaffen': {'rechtschaffene': ['rechtschaffener']},
 'rechtschaffene': ['rechtschaffener'],
 'rechtschaffn': {'rechtschaffner': []},
 'rechtscharakt': {'rechtscharakter': []},
 'rechtschul': {'rechtschule': []},
 'rechtsdenk': {'rechtsdenker': []},
 'rechtsdenken': {'rechtsdenkens': []},
 'rechtsdenkmal': {'rechtsdenkmaler': []},
 'rechtsdogmatisch': {'rechtsdogmatische': []},
 'rechtsfal': {'rechtsfall': ['rechtsfalle']},
 'rechtsfall': ['rechtsfalle'],
 'rechtsfilosofi': {'rechtsfilosofie': []},
 'rechtsfolg': {'rechtsfolge': []},
 'rechtsfrag': {'rechtsfrage': []},
 'rechtsg': {'rechtsge': ['rechtsges']},
 'rechtsgcschicht': {'rechtsgcschichte': []},
 'rechtsge': ['rechtsges'],
 'rechtsgebi': {'rechtsgebied': []},
 'rechtsgebiet': {'rechtsgebiete': []},
 'rechtsgedank': {'rechtsgedanke': []},
 'rechtsgeleerd': {'rechtsgeleerde': []},
 'rechtsgelehrt': {'rechtsgelehrte': ['rechtsgelehrter']},
 'rechtsgelehrte': ['rechtsgelehrter'],
 'rechtsgemeind': {'rechtsgemeinde': []},
 'rechtsgeschaft': {'rechtsgeschafte': [], 'rechtsgeschafts': []},
 'rechtsgeschichl': {'rechtsgeschichle': []},
 'rechtsgeschicht': {'rechtsgeschichte': []},
 'rechtsgeschichtlich': {'rechtsgeschichtliche': ['rechtsgeschichtlicher',
                                                  'rechtsgeschichtliches']},
 'rechtsgeschichtliche': ['rechtsgeschichtlicher', 'rechtsgeschichtliches'],
 'rechtsgeschiedeni': {'rechtsgeschiedenis': []},
 'rechtsgiit': {'rechtsgiiter': []},
 'rechtsgrundlag': {'rechtsgrundlage': []},
 'rechtsgrundsatz': {'rechtsgrundsatze': []},
 'rechtsgut': {'rechtsguter': []},
 'rechtshandel': {'rechtshandeling': []},
 'rechtshandhav': {'rechtshandhaving': []},
 'rechtshilf': {'rechtshilfe': []},
 'rechtshistorik': {'rechtshistoriker': []},
 'rechtshistorisch': {'rechtshistorische': ['rechtshistorischer',
                                            'rechtshistorisches']},
 'rechtshistorische': ['rechtshistorischer', 'rechtshistorisches'],
 'rechtside': {'rechtsidee': []},
 'rechtsinstitut': {'rechtsinstitute': []},
 'rechtskommunik': {'rechtskommunikation': []},
 'rechtskontrol': {'rechtskontrolle': []},
 'rechtskraftig': {'rechtskraftige': ['rechtskraftiges']},
 'rechtskraftige': ['rechtskraftiges'],
 'rechtskrei': {'rechtskreis': []},
 'rechtskreis': {'rechtskreise': []},
 'rechtskund': {'rechtskunde': []},
 'rechtskundig': {'rechtskundige': []},
 'rechtslag': {'rechtslage': []},
 'rechtsleben': {'rechtslebens': []},
 'rechtslehr': {'rechtslehre': ['rechtslehrer']},
 'rechtslehre': ['rechtslehrer'],
 'rechtsm': {'rechtsmed': []},
 'rechtsnachfolg': {'rechtsnachfolge': ['rechtsnachfolger']},
 'rechtsnachfolge': ['rechtsnachfolger'],
 'rechtsontwikkel': {'rechtsontwikkeling': []},
 'rechtsord': {'rechtsorde': []},
 'rechtspfleg': {'rechtspflege': ['rechtspfleger']},
 'rechtspflege': ['rechtspfleger'],
 'rechtsphilo': {'rechtsphilos': []},
 'rechtsphilosophi': {'rechtsphilosophie': []},
 'rechtsphilosophisch': {'rechtsphilosophische': []},
 'rechtspleg': {'rechtspleging': []},
 'rechtspluralismu': {'rechtspluralismus': []},
 'rechtspolitisch': {'rechtspolitische': ['rechtspolitischer']},
 'rechtspolitische': ['rechtspolitischer'],
 'rechtspopulismu': {'rechtspopulismus': []},
 'rechtsposit': {'rechtsposition': []},
 'rechtspositi': {'rechtspositie': []},
 'rechtspositivismu': {'rechtspositivismus': []},
 'rechtsprechend': {'rechtsprechende': []},
 'rechtsprechung': {'rechtsprechungs': []},
 'rechtsprinzip': {'rechtsprinzips': []},
 'rechtsproblem': {'rechtsprobleme': []},
 'rechtsquel': {'rechtsquelle': []},
 'rechtsquellenlehr': {'rechtsquellenlehre': []},
 'rechtsradikal': {'rechtsradikale': []},
 'rechtsradikalismu': {'rechtsradikalismus': []},
 'rechtsregel': {'rechtsregels': []},
 'rechtssach': {'rechtssache': []},
 'rechtssatz': {'rechtssatze': ['rechtssatzes']},
 'rechtssatze': ['rechtssatzes'],
 'rechtsschopferisch': {'rechtsschopferische': []},
 'rechtsschul': {'rechtsschule': []},
 'rechtsschutz': {'rechtsschutzes': []},
 'rechtssdtz': {'rechtssdtze': []},
 'rechtsseitig': {'rechtsseitige': ['rechtsseitiger']},
 'rechtsseitige': ['rechtsseitiger'],
 'rechtssociologi': {'rechtssociologie': []},
 'rechtssoziologi': {'rechtssoziologie': []},
 'rechtssphar': {'rechtssphare': []},
 'rechtssprach': {'rechtssprache': []},
 'rechtssprichwort': {'rechtssprichworter': []},
 'rechtsstaat': {'rechtsstaates': [], 'rechtsstaats': []},
 'rechtsstaatlich': {'rechtsstaatliche': ['rechtsstaatlicher']},
 'rechtsstaatliche': ['rechtsstaatlicher'],
 'rechtsstatu': {'rechtsstatus': []},
 'rechtsstreit': {'rechtsstreites': [], 'rechtsstreits': []},
 'rechtssubjekt': {'rechtssubjekte': []},
 'rechtssystem': {'rechtssysteme': [], 'rechtssystems': []},
 'rechtstaat': {'rechtstaats': []},
 'rechtstein': {'rechtsteiner': []},
 'rechtsterminologi': {'rechtsterminologie': []},
 'rechtstheoretisch': {'rechtstheoretische': []},
 'rechtstheori': {'rechtstheorie': []},
 'rechtstradit': {'rechtstradition': []},
 'rechtstrag': {'rechtstrager': []},
 'rechtstreek': {'rechtstreeks': []},
 'rechtstreeks': {'rechtstreekse': []},
 'rechtsverbindlich': {'rechtsverbindliche': []},
 'rechtsvergelijk': {'rechtsvergelijking': []},
 'rechtsvergelijkend': {'rechtsvergelijkende': []},
 'rechtsvergleichend': {'rechtsvergleichende': ['rechtsvergleichender',
                                                'rechtsvergleichendes']},
 'rechtsvergleichende': ['rechtsvergleichender', 'rechtsvergleichendes'],
 'rechtsverhaeltniss': {'rechtsverhaeltnisse': []},
 'rechtsverhaltni': {'rechtsverhaltnis': []},
 'rechtsverhaltniss': {'rechtsverhaltnisse': ['rechtsverhaltnisses']},
 'rechtsverhaltnisse': ['rechtsverhaltnisses'],
 'rechtsverhdltniss': {'rechtsverhdltnisse': []},
 'rechtsverk': {'rechtsverkeer': []},
 'rechtsverkehr': {'rechtsverkehrs': []},
 'rechtsvind': {'rechtsvinding': []},
 'rechtsvord': {'rechtsvordering': []},
 'rechtsvorm': {'rechtsvorming': []},
 'rechtswahr': {'rechtswahrer': []},
 'rechtsweg': {'rechtswege': ['rechtsweges']},
 'rechtswege': ['rechtsweges'],
 'rechtswesen': {'rechtswesens': []},
 'rechtswidrig': {'rechtswidrige': ['rechtswidriges', 'rechtswidriger']},
 'rechtswidrige': ['rechtswidriges', 'rechtswidriger'],
 'rechtswissenschaftl': {'rechtswissenschaftler': []},
 'rechtswissenschaftlich': {'rechtswissenschaftliche': ['rechtswissenschaftlicher']},
 'rechtswissenschaftliche': ['rechtswissenschaftlicher'],
 'rechtszustand': {'rechtszustande': ['rechtszustandes']},
 'rechtszustande': ['rechtszustandes'],
 'rechtvaardig': {'rechtvaardige': [], 'rechtvaardiging': []},
 'rechtwinklig': {'rechtwinklige': ['rechtwinkliges', 'rechtwinkliger']},
 'rechtwinklige': ['rechtwinkliges', 'rechtwinkliger'],
 'rechtzeitig': {'rechtzeitige': ['rechtzeitiger']},
 'rechtzeitige': ['rechtzeitiger'],
 'rechuck': {'rechucked': [], 'rechucking': []},
 'rechurn': {'rechurned': [], 'rechurning': []},
 'rechut': {'rechute': ['rechutes']},
 'rechute': ['rechutes'],
 'reci': {'recie': [], 'recis': [], 'recy': []},
 'recia': {'recias': []},
 'reciabl': {'reciable': []},
 'recial': {'recialism': [], 'recially': []},
 'reciament': {'reciamente': []},
 'reciat': {'reciate': ['reciated'], 'reciation': []},
 'reciate': ['reciated'],
 'recib': {'recibe': ['recibes']},
 'reciba': {'recibas': []},
 'recibamo': {'recibamos': []},
 'recibe': ['recibes'],
 'recibida': {'recibidas': []},
 'recibido': {'recibidos': []},
 'recibier': {'recibiere': []},
 'recibies': {'recibiese': []},
 'recibimiento': {'recibimientos': []},
 'recibimo': {'recibimos': []},
 'recibir': {'recibire': []},
 'recibiremo': {'recibiremos': []},
 'recibirl': {'recibirle': []},
 'recibirla': {'recibirlas': []},
 'recibirlo': {'recibirlos': []},
 'recibirm': {'recibirme': []},
 'recibirno': {'recibirnos': []},
 'recibirs': {'recibirse': []},
 'recibist': {'recibiste': []},
 'recibo': {'recibos': []},
 'recic': {'recice': []},
 'recicatr': {'recicatrization': []},
 'reciclado': {'reciclados': []},
 'reciclaj': {'reciclaje': []},
 'recicv': {'recicved': []},
 'recid': {'recidant': [],
           'recide': ['recided', 'recides', 'recident', 'recidence'],
           'reciding': [],
           'recidive': ['recidives'],
           'recidivity': []},
 'recide': ['recided', 'recides', 'recident', 'recidence'],
 'recider': {'recidere': []},
 'recidiss': {'recidisse': []},
 'recidiv': {'recidival': [],
             'recidivant': ['recidivants'],
             'recidivate': ['recidivated', 'recidivates'],
             'recidivating': [],
             'recidivation': ['recidivations'],
             'recidiver': [],
             'recidivism': [],
             'recidivous': []},
 'recidivan': {'recidivans': []},
 'recidivant': {'recidivante': ['recidivantes']},
 'recidivante': ['recidivantes'],
 'recidivate': ['recidivated', 'recidivates'],
 'recidivation': ['recidivations'],
 'recidive': ['recidives'],
 'recidivist': ['recidiviste',
                'recidivistic',
                'recidivistes',
                'recidivistically'],
 'recidivu': {'recidivus': []},
 'recidu': {'recidual': []},
 'recieat': {'recieation': []},
 'reciedumbr': {'reciedumbre': []},
 'recient': {'reciente': ['recientes']},
 'reciente': ['recientes'],
 'recientement': {'recientemente': []},
 'reciepi': {'reciepient': []},
 'reciept': {'reciepts': []},
 'recieu': {'recieue': ['recieued']},
 'recieue': ['recieued'],
 'reciev': {'recievable': [],
            'recieve': ['recieved',
                        'reciever',
                        'recieves',
                        'recievers',
                        'recieveing'],
            'recieving': []},
 'recieve': ['recieved', 'reciever', 'recieves', 'recievers', 'recieveing'],
 'recif': {'recifal': [], 'recife': [], 'recification': [], 'recifs': []},
 'recifal': {'recifale': ['recifales']},
 'recifale': ['recifales'],
 'reciff': {'reciffe': []},
 'recifi': {'recify': []},
 'recign': {'recignized': []},
 'reciiv': {'reciived': []},
 'recil': {'recile': ['reciled']},
 'recile': ['reciled'],
 'recili': {'reciliation': []},
 'recilla': {'recillas': []},
 'recim': {'recimer': []},
 'recin': {'recine': ['recines']},
 'recinch': {'recinched': []},
 'recinct': {'recincts': []},
 'recind': {'recinded': [], 'recinding': []},
 'recine': ['recines'],
 'recing': {'recinge': []},
 'recino': {'recinos': []},
 'recinol': {'recinoleic': []},
 'recinto': {'recintos': []},
 'recinu': {'recinus': []},
 'recinzion': {'recinzione': []},
 'recio': {'recios': []},
 'recion': {'recional': [], 'recions': []},
 'recioroc': {'reciorocal': []},
 'reciou': {'recious': []},
 'recip': {'recipe': ['recipent', 'recipents'], 'recipitis': [], 'recips': []},
 'recipathi': {'recipathy': []},
 'recipcr': {'recipcre': []},
 'recipe': {'recipee': ['recipees']},
 'recipee': ['recipees'],
 'recipeint': {'recipeints': []},
 'recipelik': {'recipelike': []},
 'reciper': {'recipere': ['reciperes', 'reciperent']},
 'reciperanda': {'reciperandae': []},
 'reciperator': {'reciperatores': []},
 'recipere': ['reciperes', 'reciperent'],
 'reciperemu': {'reciperemus': []},
 'reciph': {'reciphered': [], 'reciphering': []},
 'recipi': {'recipiant': ['recipiants'],
            'recipie': ['recipies', 'recipient', 'recipiency', 'recipience'],
            'recipis': [],
            'recipy': []},
 'recipia': {'recipias': []},
 'recipiamu': {'recipiamus': []},
 'recipiant': ['recipiants'],
 'recipiati': {'recipiatis': []},
 'recipic': {'recipice': []},
 'recipie': ['recipies', 'recipient', 'recipiency', 'recipience'],
 'recipieb': {'recipiebant': []},
 'recipiemu': {'recipiemus': []},
 'recipien': {'recipiens': []},
 'recipienda': {'recipiendae': [], 'recipiendas': []},
 'recipiendair': {'recipiendaire': ['recipiendaires']},
 'recipiendaire': ['recipiendaires'],
 'recipiendari': {'recipiendary': []},
 'recipiendi': {'recipiendis': []},
 'recipiendo': {'recipiendos': []},
 'recipiendu': {'recipiendus': []},
 'recipienr': {'recipienrs': []},
 'recipient': {'recipiente': ['recipientes']},
 'recipientcountri': {'recipientcountry': []},
 'recipiente': ['recipientes'],
 'recipienti': {'recipientis': []},
 'recipientibu': {'recipientibus': []},
 'recipienttyp': {'recipienttype': []},
 'recipieti': {'recipietis': []},
 'recipimu': {'recipimus': []},
 'recipioc': {'recipiocal': [], 'recipiocity': []},
 'recipiss': {'recipisse': []},
 'recipit': {'recipitate': ['recipitated'],
             'recipitating': [],
             'recipitation': [],
             'recipite': []},
 'recipitate': ['recipitated'],
 'recipitqu': {'recipitque': []},
 'recipl': {'reciplent': []},
 'reciploc': {'reciplocal': []},
 'recipoc': {'recipocal': [], 'recipocity': []},
 'reciporc': {'reciporcal': []},
 'recipr': {'reciprical': []},
 'recipricoc': {'recipricocity': []},
 'recipro': {'reciproal': [], 'reciproeal': []},
 'reciproc': {'reciprocable': [],
              'reciprocably': [],
              'reciprocal': ['reciprocally',
                             'reciprocality',
                             'reciprocalness',
                             'reciprocalization'],
              'reciprocant': ['reciprocants'],
              'reciprocate': ['reciprocated', 'reciprocates'],
              'reciprocating': [],
              'reciprocation': [],
              'reciprocative': [],
              'reciprocator': ['reciprocators'],
              'reciproce': [],
              'reciprocical': [],
              'reciprocity': []},
 'reciproca': {'reciprocae': [], 'reciprocas': []},
 'reciprocal': {'reciprocall': []},
 'reciprocallattic': {'reciprocallattice': []},
 'reciprocalspac': {'reciprocalspace': []},
 'reciprocaltrad': {'reciprocaltrade': []},
 'reciprocament': {'reciprocamente': []},
 'reciprocan': {'reciprocans': []},
 'reciprocant': ['reciprocants'],
 'reciprocar': {'reciprocare': []},
 'reciprocate': ['reciprocated', 'reciprocates'],
 'reciprocatingengin': {'reciprocatingengine': []},
 'reciprocatingli': {'reciprocatingly': []},
 'reciprocation': {'reciprocatione': []},
 'reciprocationi': {'reciprocationis': []},
 'reciprocator': ['reciprocators'],
 'reciprocatori': {'reciprocatory': []},
 'reciproch': {'reciproche': []},
 'reciproci': {'reciprocial': [], 'reciprocis': [], 'reciprocy': []},
 'reciprocidad': {'reciprocidade': []},
 'reciprocit': {'reciprocite': []},
 'reciprocitarian': {'reciprocitarians': []},
 'reciprocitybas': {'reciprocitybased': []},
 'reciproco': {'reciprocos': []},
 'reciprocr': {'reciprocrate': ['reciprocrated'], 'reciprocrating': []},
 'reciprocrate': ['reciprocrated'],
 'reciprocu': {'reciprocus': []},
 'reciprok': {'reciproke': []},
 'reciproo': {'reciprooal': []},
 'reciproqu': {'reciproque': ['reciproques', 'reciproquement']},
 'reciproque': ['reciproques', 'reciproquement'],
 'recipros': {'reciprosity': []},
 'recipt': {'reciptivity': [], 'recipts': []},
 'reciptoc': {'reciptocal': [], 'reciptocity': []},
 'recir': {'recire': ['recired']},
 'recircl': {'recircle': ['recircles', 'recircled'], 'recircling': []},
 'recircle': ['recircles', 'recircled'],
 'recircuit': {'recircuited': [], 'recircuiting': [], 'recircuits': []},
 'recircul': {'recirculate': ['recirculates', 'recirculated'],
              'recirculating': [],
              'recirculation': [],
              'recirculative': [],
              'recirculator': ['recirculators']},
 'recircular': {'recircularization': [],
                'recircularize': ['recircularized'],
                'recircularizing': []},
 'recircularis': {'recircularisation': []},
 'recircularize': ['recircularized'],
 'recirculate': ['recirculates', 'recirculated'],
 'recirculator': ['recirculators'],
 'recirculatori': {'recirculatory': []},
 'recircumcis': {'recircumcise': ['recircumcised'], 'recircumcision': []},
 'recircumcise': ['recircumcised'],
 'recire': ['recired'],
 'recirul': {'recirulation': []},
 'recis': {'recise': ['recised', 'recisely'], 'recision': ['recisions']},
 'recisa': {'recisas': []},
 'recisament': {'recisamente': []},
 'recise': ['recised', 'recisely'],
 'recisi': {'recisis': []},
 'recision': ['recisions'],
 'reciso': {'recisos': []},
 'reciss': {'recission': []},
 'recissori': {'recissory': []},
 'recist': {'recister': []},
 'recit': {'recitability': [],
           'recitable': [],
           'recital': [],
           'recitant': ['recitants'],
           'recitate': ['recitated'],
           'recitating': [],
           'recitation': ['recitational'],
           'recitative': ['recitatively'],
           'recitator': ['recitators'],
           'recite': ['reciter',
                      'recites',
                      'recited',
                      'recitent',
                      'reciteing',
                      'recitement',
                      'recitements'],
           'reciting': ['recitings'],
           'recition': [],
           'recits': []},
 'recita': {'recitas': []},
 'recitab': {'recitabant': []},
 'recitacion': {'recitaciones': []},
 'recitado': {'recitados': []},
 'recitai': {'recitaient': []},
 'recital': {'recitales': [], 'recitall': []},
 'recitalist': {'recitalist': []},
 'recitamu': {'recitamus': []},
 'recitan': {'recitans': []},
 'recitanda': {'recitandae': [], 'recitandas': []},
 'recitandi': {'recitandis': []},
 'recitant': {'recitante': ['recitantes']},
 'recitante': ['recitantes'],
 'recitanti': {'recitantis': []},
 'recitantibu': {'recitantibus': []},
 'recitar': {'recitare': ['recitares']},
 'recitare': ['recitares'],
 'recitass': {'recitasse': []},
 'recitat': {'recitatation': []},
 'recitata': {'recitatae': [], 'recitatas': []},
 'recitate': ['recitated'],
 'recitati': {'recitatis': []},
 'recitatif': {'recitatifs': []},
 'recitation': {'recitatione': ['recitationes']},
 'recitatione': ['recitationes'],
 'recitationibu': {'recitationibus': []},
 'recitationist': {'recitationists': []},
 'recitationroom': {'recitationrooms': []},
 'recitativ': {'recitatival': [],
               'recitatived': [],
               'recitativic': ['recitativical']},
 'recitative': ['recitatively'],
 'recitativelik': {'recitativelike': []},
 'recitativic': ['recitativical'],
 'recitativo': {'recitativos': []},
 'recitator': {'recitatores': []},
 'recitatu': {'recitatus': []},
 'recitavimu': {'recitavimus': []},
 'recitazion': {'recitazione': []},
 'recite': {'recitee': ['recitees']},
 'recitee': ['recitees'],
 'recitemu': {'recitemus': []},
 'recitfi': {'recitfy': []},
 'reciti': {'recitiation': [], 'recity': []},
 'recitif': {'recitification': []},
 'recitifi': {'recitified': []},
 'reciting': ['recitings'],
 'recititud': {'recititude': []},
 'recitor': {'recitors': []},
 'recitud': {'recitude': []},
 'reciu': {'recius': []},
 'reciuir': {'reciuire': ['reciuired']},
 'reciuire': ['reciuired'],
 'reciuit': {'reciuited': [], 'reciuitment': [], 'reciuits': []},
 'reciv': {'recive': ['recives', 'reciver', 'recived', 'recivers'],
           'reciving': []},
 'recive': ['recives', 'reciver', 'recived', 'recivers'],
 'recivid': {'recividism': []},
 'recividist': {'recividists': []},
 'recivies': {'reciviese': []},
 'recivil': {'recivilization': [],
             'recivilize': ['recivilized'],
             'recivilizing': []},
 'recivilian': {'recivilianization': []},
 'recivilis': {'recivilisation': [], 'recivilise': ['recivilised']},
 'recivilise': ['recivilised'],
 'recivilize': ['recivilized'],
 'reciystal': {'reciystallization': []},
 'recjuest': {'recjuested': []},
 'recjuir': {'recjuire': ['recjuired', 'recjuires', 'recjuirements']},
 'recjuire': ['recjuired', 'recjuires', 'recjuirements'],
 'reck': {'recke': ['reckes', 'recked'], 'recking': [], 'recks': []},
 "reck'n": {"reck'ns": []},
 'reckag': {'reckage': []},
 'reckan': {'reckanize': ['reckanized']},
 'reckanize': ['reckanized'],
 'reckard': {'reckards': []},
 'reckas': {'reckase': []},
 'recke': ['reckes', 'recked'],
 'reckel': {'reckell': []},
 'reckeles': {'reckelesness': []},
 'recken': {'reckened': [], 'reckening': ['reckenings'], 'reckens': []},
 'reckendorf': {'reckendorfer': []},
 'reckenholzstrass': {'reckenholzstrasse': []},
 'reckening': ['reckenings'],
 'reckenyng': {'reckenynge': []},
 'recker': {'reckers': []},
 'reckerch': {'reckerches': []},
 'reckern': {'reckernize': ['reckernized']},
 'reckernis': {'reckernise': ['reckernised']},
 'reckernise': ['reckernised'],
 'reckernize': ['reckernized'],
 'reckett': {'recketts': []},
 'reckhau': {'reckhaus': []},
 'recki': {'recky': []},
 'reckin': {'reckined': [], 'reckins': []},
 'recking': {'reckinger': []},
 'reckitt': {'reckitts': []},
 'reckl': {'reckle': ['reckles'], 'reckling': ['recklings']},
 'reckle': ['reckles'],
 'reckles': {'recklesness': []},
 'recklesli': {'recklesly': []},
 'reckless': {'recklesse': [], 'recklessness': []},
 'recklessli': {'recklessly': []},
 'recklessn': {'recklessne': ['recklessnes']},
 'recklessne': ['recklessnes'],
 'reckli': {'recklies': [], 'reckly': []},
 'reckling': ['recklings'],
 'recklinghaus': {'recklinghauser': []},
 'recklinghausen': {'recklinghausens': []},
 'recklinghausensch': {'recklinghausenscher': []},
 'reckliti': {'recklitis': []},
 'reckmey': {'reckmeyer': []},
 'reckn': {'reckned': [], 'reckning': ['recknings']},
 'recknagl': {'recknagle': []},
 'recknel': {'recknell': []},
 'reckning': {'reckninge': []},
 'reckno': {'recknoed': []},
 'recknon': {'recknoned': [], 'recknoning': []},
 'recknyng': {'recknynge': []},
 'reckogn': {'reckognized': []},
 'reckon': {'reckonability': [],
            'reckonable': [],
            'reckone': ['reckoner', 'reckoned'],
            'reckoning': [],
            'reckonize': ['reckonized'],
            'reckonned': [],
            'reckons': []},
 "reckon'l": {"reckon'll": []},
 'reckone': ['reckoner', 'reckoned'],
 'reckoning': {'reckoninge': ['reckoninges']},
 'reckoninge': ['reckoninges'],
 'reckonis': {'reckonise': ['reckonises', 'reckonised']},
 'reckonise': ['reckonises', 'reckonised'],
 'reckonize': ['reckonized'],
 'reckou': {'reckoued': [], 'reckouing': []},
 'recks': {'reckse': []},
 'reckt': {'reckte': [], 'reckts': []},
 'recktal': {'recktall': []},
 'recl': {'recle': ['recled', 'recles'], 'recling': []},
 'recla': {'reclas': []},
 'reclad': {'recladding': []},
 'reclaim': {'reclaimability': [],
             'reclaimable': ['reclaimables'],
             'reclaimant': ['reclaimants'],
             'reclaimation': [],
             'reclaime': ['reclaimed', 'reclaimer', 'reclaimers'],
             'reclaiming': ['reclaimings'],
             'reclaims': []},
 'reclaimable': ['reclaimables'],
 'reclaimant': ['reclaimants'],
 'reclaime': ['reclaimed', 'reclaimer', 'reclaimers'],
 'reclaiming': ['reclaimings'],
 'reclain': {'reclained': []},
 'reclair': {'reclaire': []},
 'reclam': {'reclamable': [],
            'reclamant': ['reclamants'],
            'reclamated': [],
            'reclamation': [],
            'reclamative': [],
            'reclame': ['reclamed', 'reclames', 'reclamer'],
            'reclaming': [],
            'reclams': []},
 'reclama': {'reclamas': []},
 'reclamacion': {'reclamacione': ['reclamaciones']},
 'reclamacione': ['reclamaciones'],
 'reclamaco': {'reclamacoes': []},
 'reclamada': {'reclamadas': []},
 'reclamado': {'reclamados': []},
 'reclamai': {'reclamaient': [], 'reclamais': []},
 'reclamamo': {'reclamamos': []},
 'reclamant': {'reclamante': ['reclamantes']},
 'reclamante': ['reclamantes'],
 'reclamantibu': {'reclamantibus': []},
 'reclamar': {'reclamare': []},
 'reclamars': {'reclamarse': []},
 'reclamation': {'reclamatione': []},
 'reclamationist': {'reclamationists': []},
 'reclamatori': {'reclamatory': []},
 'reclame': {'reclamee': ['reclamees']},
 'reclamee': ['reclamees'],
 'reclamer': {'reclamerent': []},
 'reclamerai': {'reclameraient': []},
 'reclamizzar': {'reclamizzare': []},
 'reclamm': {'reclammation': []},
 'reclamo': {'reclamoent': [], 'reclamos': []},
 'reclamon': {'reclamons': []},
 'reclamp': {'reclamped': [], 'reclamping': [], 'reclamps': []},
 'reclarif': {'reclarification': []},
 'reclarifi': {'reclarified': [],
               'reclarifies': [],
               'reclarify': ['reclarifying']},
 'reclarify': ['reclarifying'],
 'reclasp': {'reclasped': [], 'reclasping': [], 'reclasps': []},
 'reclass': {'reclassed': [],
             'reclassement': [],
             'reclasser': ['reclassering'],
             'reclassing': []},
 'reclasser': ['reclassering'],
 'reclassif': {'reclassifed': [], 'reclassification': []},
 'reclassifi': {'reclassifiable': [],
                'reclassified': [],
                'reclassifier': ['reclassifiers'],
                'reclassifies': [],
                'reclassify': ['reclassifying']},
 'reclassifier': ['reclassifiers'],
 'reclassifk': {'reclassifkation': []},
 'reclassifl': {'reclassifled': []},
 'reclassiflc': {'reclassiflcation': []},
 'reclassify': ['reclassifying'],
 'reclaym': {'reclayme': ['reclaymed']},
 'reclayme': ['reclaymed'],
 'recle': ['recled', 'recles'],
 'reclean': {'recleaned': [],
             'recleaner': ['recleaners'],
             'recleaning': [],
             'recleans': []},
 'recleaner': ['recleaners'],
 'recleans': {'recleanse': ['recleansed'], 'recleansing': []},
 'recleanse': ['recleansed'],
 'reclear': {'reclearance': [], 'recleared': [], 'reclearing': []},
 'recleav': {'recleaved': []},
 'reclect': {'reclected': []},
 'reclench': {'reclenched': [], 'reclenching': []},
 'reclev': {'recleve': ['recleved']},
 'recleve': ['recleved'],
 'recli': {'recly': []},
 'reclick': {'reclicked': [], 'reclicking': []},
 'reclierch': {'reclierches': []},
 'recliercli': {'reclierclies': []},
 'recliff': {'recliffe': []},
 'reclifi': {'reclify': []},
 'reclimb': {'reclimbed': [], 'reclimbing': [], 'reclimbs': []},
 'reclin': {'reclinable': [],
            'reclinate': [],
            'reclination': ['reclinations'],
            'recline': ['reclined', 'recliner', 'reclines'],
            'reclining': []},
 'reclinan': {'reclinans': []},
 'reclinar': {'reclinare': []},
 'reclination': ['reclinations'],
 'reclinatu': {'reclinatus': []},
 'recline': ['reclined', 'recliner', 'reclines'],
 'reclini': {'reclinis': []},
 'reclinomona': {'reclinomonas': []},
 'reclip': {'reclipped': [], 'reclipping': []},
 'reclit': {'reclits': []},
 'reclitud': {'reclitude': []},
 'recliu': {'reclius': []},
 'reclli': {'reclly': []},
 'recln': {'reclns': []},
 'reclo': {'reclos': []},
 'recloak': {'recloaked': []},
 'reclock': {'reclocked': [], 'reclocking': [], 'reclocks': []},
 'reclog': {'reclogging': []},
 'reclomid': {'reclomide': []},
 'reclon': {'reclone': ['recloned'], 'recloning': []},
 'reclone': ['recloned'],
 'reclos': {'reclosable': [],
            'reclose': ['recloser',
                        'recloses',
                        'reclosed',
                        'reclosers',
                        'recloseable'],
            'reclosing': ['reclosings']},
 'reclose': ['recloser', 'recloses', 'reclosed', 'reclosers', 'recloseable'],
 'reclosing': ['reclosings'],
 'reclosur': {'reclosure': ['reclosures']},
 'reclosure': ['reclosures'],
 'reclot': {'reclotting': []},
 'recloth': {'reclothe': ['reclothes', 'reclothed'], 'reclothing': []},
 'reclothe': ['reclothes', 'reclothed'],
 'reclp': {'reclpe': ['reclpes']},
 'reclpe': ['reclpes'],
 'reclplent': {'reclplents': []},
 'reclproc': {'reclprocal': []},
 'reclterch': {'reclterches': []},
 'reclu': {'reclus': []},
 'recluc': {'recluce': []},
 'reclud': {'reclude': ['recluded', 'recludes'], 'recluding': []},
 'reclude': ['recluded', 'recludes'],
 'recluden': {'recludens': []},
 'recluder': {'recludere': []},
 'recludi': {'recludis': []},
 'recluf': {'reclufe': []},
 'recluido': {'recluidos': []},
 'recluir': {'recluire': ['recluired', 'recluires']},
 'recluire': ['recluired', 'recluires'],
 'reclus': {'recluse': ['reclused', 'reclusely', 'recluseness'],
            'reclusing': [],
            'reclusion': ['reclusions'],
            'reclusive': ['reclusives', 'reclusively', 'reclusiveness'],
            'reclusivity': []},
 'reclusa': {'reclusae': [], 'reclusas': []},
 'recluse': ['reclused', 'reclusely', 'recluseness'],
 'reclusi': {'reclusis': []},
 'reclusion': {'reclusione': []},
 'reclusisqu': {'reclusisque': []},
 'reclusive': ['reclusives', 'reclusively', 'reclusiveness'],
 'recluso': {'reclusos': []},
 'reclusori': {'reclusory': []},
 'reclust': {'recluster': ['reclustered', 'reclustering']},
 'recluster': ['reclustered', 'reclustering'],
 'reclusu': {'reclusus': []},
 'reclut': {'reclute': []},
 'recluta': {'reclutas': []},
 'reclutado': {'reclutados': []},
 'reclutar': {'reclutare': []},
 'reclysterizar': {'reclysterizare': []},
 'recmbark': {'recmbarked': []},
 'recmerg': {'recmerged': [], 'recmergence': []},
 'recmest': {'recmested': []},
 'recmir': {'recmire': ['recmired', 'recmires', 'recmirements']},
 'recmire': ['recmired', 'recmires', 'recmirements'],
 'recmit': {'recmited': [], 'recmiting': [], 'recmitment': [], 'recmits': []},
 'recmmend': {'recmmendations': [], 'recmmended': []},
 'recmphas': {'recmphasized': []},
 'recnact': {'recnacted': [], 'recnactment': []},
 'recnerch': {'recnerches': []},
 'recnforc': {'recnforce': ['recnforced', 'recnforcement', 'recnforcements']},
 'recnforce': ['recnforced', 'recnforcement', 'recnforcements'],
 'recni': {'recny': []},
 'recniit': {'recniited': [],
             'recniiting': [],
             'recniitment': [],
             'recniits': []},
 'recntli': {'recntly': []},
 'reco': {'recoe': ['recoed', 'recoes', 'recoeds'], 'recoing': [], 'recos': []},
 'recoaaend': {'recoaaendations': [], 'recoaaended': []},
 'recoagul': {'recoagulate': ['recoagulated'], 'recoagulation': []},
 'recoagulate': ['recoagulated'],
 'recoal': {'recoaled': [], 'recoaling': []},
 'recoalesc': {'recoalesce': ['recoalesced', 'recoalescence'],
               'recoalescing': []},
 'recoalesce': ['recoalesced', 'recoalescence'],
 'recoamend': {'recoamended': []},
 'recoan': {'recoanize': ['recoanized']},
 'recoanend': {'recoanended': []},
 'recoanit': {'recoanition': []},
 'recoanize': ['recoanized'],
 'recoarct': {'recoarctation': []},
 'recoars': {'recoarse': []},
 'recoastruct': {'recoastruction': []},
 'recoat': {'recoatability': [],
            'recoatable': [],
            'recoated': [],
            'recoater': [],
            'recoating': ['recoatings'],
            'recoats': []},
 'recoating': ['recoatings'],
 'recobbl': {'recobbled': []},
 'recobd': {'recobds': []},
 'recobr': {'recobre': []},
 'recobrado': {'recobrados': []},
 'recobrars': {'recobrarse': []},
 'recocili': {'recociliation': []},
 'recock': {'recocked': [], 'recocking': [], 'recocks': []},
 'recocn': {'recocnized': []},
 'recocnit': {'recocnition': []},
 'recoct': {'recocted': []},
 'recod': {'recodable': [],
           'recode': ['recodes', 'recoded', 'recoder', 'recoders'],
           'recoding': [],
           'recods': []},
 'recode': ['recodes', 'recoded', 'recoder', 'recoders'],
 'recodif': {'recodification': ['recodifications']},
 'recodifi': {'recodified': [], 'recodifies': [], 'recodify': ['recodifying']},
 'recodification': ['recodifications'],
 'recodify': ['recodifying'],
 'recodo': {'recodos': []},
 'recoe': ['recoed', 'recoes', 'recoeds'],
 'recoen': {'recoenize': ['recoenized']},
 'recoenis': {'recoenised': []},
 'recoenit': {'recoenition': []},
 'recoenize': ['recoenized'],
 'recofd': {'recofded': [], 'recofds': []},
 'recoffin': {'recoffined': []},
 'recog': {'recoge': ['recoged', 'recoger', 'recoges'],
           'recogize': ['recogized', 'recogizes'],
           'recogizing': [],
           'recogs': []},
 'recoga': {'recogaize': ['recogaized']},
 'recogais': {'recogaised': []},
 'recogait': {'recogaition': []},
 'recogaize': ['recogaized'],
 'recogan': {'recoganized': []},
 'recoganis': {'recoganised': []},
 'recoge': ['recoged', 'recoger', 'recoges'],
 'recogemo': {'recogemos': []},
 'recogerla': {'recogerlas': []},
 'recogerlo': {'recogerlos': []},
 'recogerm': {'recogerme': []},
 'recogers': {'recogerse': []},
 'recogi': {'recogiized': []},
 'recogida': {'recogidas': []},
 'recogido': {'recogidos': []},
 'recogiendos': {'recogiendose': []},
 'recogies': {'recogiese': []},
 'recogiit': {'recogiition': []},
 'recogimiento': {'recogimientos': []},
 'recogimo': {'recogimos': []},
 'recogin': {'recoginize': ['recoginized']},
 'recoginit': {'recoginition': []},
 'recoginize': ['recoginized'],
 'recogins': {'recoginse': ['recoginsed']},
 'recoginse': ['recoginsed'],
 'recogint': {'recogintion': []},
 'recoginz': {'recoginze': ['recoginzed']},
 'recoginze': ['recoginzed'],
 'recogis': {'recogise': ['recogised']},
 'recogise': ['recogised'],
 'recogit': {'recogitate': [], 'recogition': []},
 'recogitan': {'recogitans': []},
 'recogiuz': {'recogiuze': ['recogiuzed']},
 'recogiuze': ['recogiuzed'],
 'recogiz': {'recogizable': []},
 'recogize': ['recogized', 'recogizes'],
 'recogl': {'recoglize': ['recoglized']},
 'recoglit': {'recoglition': []},
 'recoglize': ['recoglized'],
 'recogms': {'recogmse': ['recogmses', 'recogmsed']},
 'recogmse': ['recogmses', 'recogmsed'],
 'recogmt': {'recogmtion': []},
 'recogmz': {'recogmzable': [],
             'recogmze': ['recogmzed', 'recogmzes'],
             'recogmzing': []},
 'recogmze': ['recogmzed', 'recogmzes'],
 'recogn': {'recognation': [],
            'recogne': [],
            'recogniced': [],
            'recogniti': ['recognitis'],
            'recognization': [],
            'recognize': ['recognizer',
                          'recognized',
                          'recognizes',
                          'recognizers'],
            'recognizing': ['recognizings']},
 'recogni': {'recogniation': [],
             'recognied': [],
             'recognies': [],
             'recognis': []},
 'recognia': {'recogniae': ['recogniaed']},
 'recogniae': ['recogniaed'],
 'recognic': {'recognice': []},
 'recognicion': {'recognicione': ['recogniciones']},
 'recognicione': ['recogniciones'],
 'recognie': {'recogniee': ['recognieed']},
 'recogniee': ['recognieed'],
 'recognif': {'recognife': ['recognifed']},
 'recognife': ['recognifed'],
 'recognig': {'recogniged': []},
 'recognii': {'recogniie': ['recogniied', 'recogniies'], 'recogniiing': []},
 'recogniie': ['recogniied', 'recogniies'],
 'recogninit': {'recogninition': []},
 'recognir': {'recognire': ['recognired']},
 'recognire': ['recognired'],
 'recognis': {'recognisability': [],
              'recognisable': [],
              'recognisably': [],
              'recognisance': [],
              'recognisant': [],
              'recognisation': [],
              'recognise': ['recognises',
                            'recogniser',
                            'recognised',
                            'recognisers',
                            'recogniseably',
                            'recogniseable'],
              'recognisible': [],
              'recognising': [],
              'recognision': []},
 'recognisahl': {'recognisahle': []},
 'recognisaunc': {'recognisaunce': []},
 'recognise': ['recognises',
               'recogniser',
               'recognised',
               'recognisers',
               'recogniseably',
               'recogniseable'],
 'recognisedli': {'recognisedly': []},
 'recognish': {'recognished': []},
 'recognisingli': {'recognisingly': []},
 'recognisit': {'recognisition': []},
 'recognist': {'recognistion': []},
 'recognit': {'recognite': ['recognited'],
              'recognitic': [],
              'recognition': ['recognitional',
                              'recognitionals',
                              'recognitionally'],
              'recognitive': ['recognitively']},
 'recognita': {'recognitae': [], 'recognitas': []},
 'recognite': ['recognited'],
 'recogniti': {'recognitie': [], 'recognitiou': []},
 'recognition': {'recognitione': ['recognitiones']},
 'recognitionbas': {'recognitionbased': []},
 'recognitione': ['recognitiones'],
 'recognitioni': {'recognitionis': []},
 'recognitionibu': {'recognitionibus': []},
 'recognitionist': {'recognitionists': []},
 'recognitionmark': {'recognitionmarks': []},
 'recognitionmemori': {'recognitionmemory': []},
 'recognitionprim': {'recognitionprimed': []},
 'recognitionscen': {'recognitionscene': []},
 'recognitiontranscend': {'recognitiontranscendent': []},
 'recognitit': {'recognitition': []},
 'recognitive': ['recognitively'],
 'recognito': {'recognitos': []},
 'recognitor': {'recognitores': [], 'recognitors': []},
 'recognitori': {'recognitory': []},
 'recognitu': {'recognitus': []},
 'recogniz': {'recognizability': [],
              'recognizable': ['recognizables', 'recognizableness'],
              'recognizably': [],
              'recognizance': [],
              'recognizant': [],
              'recognizeable': [],
              'recognizeably': [],
              'recognizibility': [],
              'recognizible': [],
              'recognizs': []},
 'recognizable': ['recognizables', 'recognizableness'],
 'recognizahl': {'recognizahle': []},
 'recognizaunc': {'recognizaunce': ['recognizaunces']},
 'recognizaunce': ['recognizaunces'],
 'recognize': {'recognizee': ['recognizees', 'recognizeed']},
 'recognizeda': {'recognizedas': []},
 'recognizedbi': {'recognizedby': []},
 'recognizedli': {'recognizedly': []},
 'recognizedth': {'recognizedthe': []},
 'recognizee': ['recognizees', 'recognizeed'],
 'recognizesth': {'recognizesthe': []},
 'recognizeth': {'recognizethe': []},
 'recognizi': {'recognizied': []},
 'recognizing': ['recognizings'],
 'recognizingli': {'recognizingly': []},
 'recognizingth': {'recognizingthe': []},
 'recognizit': {'recognizition': []},
 'recognizor': {'recognizors': []},
 'recognjz': {'recognjzed': []},
 'recognk': {'recognke': ['recognked']},
 'recognke': ['recognked'],
 'recognlt': {'recognltion': []},
 'recognlz': {'recognlze': ['recognlzed']},
 'recognlze': ['recognlzed'],
 'recognoi': {'recognois': []},
 'recognoiftr': {'recognoiftre': []},
 'recognoiss': {'recognoissance': [], 'recognoissant': [], 'recognoissent': []},
 'recognoissoi': {'recognoissoient': []},
 'recognoisson': {'recognoissons': []},
 'recognoistr': {'recognoistre': []},
 'recognosc': {'recognoscant': [],
               'recognosce': ['recognosced', 'recognosces'],
               'recognoscing': []},
 'recognosca': {'recognoscas': []},
 'recognosce': ['recognosced', 'recognosces'],
 'recognoscen': {'recognoscens': []},
 'recognoscendi': {'recognoscendis': []},
 'recognoscent': {'recognoscente': ['recognoscentes']},
 'recognoscente': ['recognoscentes'],
 'recognoscentibu': {'recognoscentibus': []},
 'recognoscer': {'recognoscere': ['recognoscerent']},
 'recognoscere': ['recognoscerent'],
 'recognosci': {'recognoscis': []},
 'recognoscimu': {'recognoscimus': []},
 'recognot': {'recognotion': []},
 'recognoviss': {'recognovisse': []},
 'recognrz': {'recognrze': ['recognrzed']},
 'recognrze': ['recognrzed'],
 'recogns': {'recognsed': []},
 'recognsi': {'recognsied': []},
 'recognt': {'recogntion': []},
 'recognte': {'recogntee': ['recognteed']},
 'recogntee': ['recognteed'],
 'recogntt': {'recognttion': []},
 'recogntz': {'recogntze': ['recogntzed']},
 'recogntze': ['recogntzed'],
 'recognu': {'recognue': ['recognued', 'recognues']},
 'recognue': ['recognued', 'recognues'],
 'recognz': {'recognze': ['recognzed'], 'recognzing': []},
 'recognze': ['recognzed'],
 'recognzi': {'recognzie': ['recognzied']},
 'recognzie': ['recognzied'],
 'recogo': {'recogoized': []},
 'recogon': {'recogonize': ['recogonized']},
 'recogonize': ['recogonized'],
 'recogr': {'recogrize': ['recogrized']},
 'recogrit': {'recogrition': []},
 'recogrize': ['recogrized'],
 'recogruz': {'recogruze': ['recogruzed']},
 'recogruze': ['recogruzed'],
 'recogt': {'recogtion': []},
 'recogth': {'recogthe': []},
 'recogu': {'recoguize': ['recoguizes', 'recoguized'], 'recoguizing': []},
 'recoguis': {'recoguise': ['recoguises', 'recoguised'], 'recoguising': []},
 'recoguise': ['recoguises', 'recoguised'],
 'recoguit': {'recoguition': []},
 'recoguize': ['recoguizes', 'recoguized'],
 'recogz': {'recogzed': []},
 'recohabit': {'recohabitation': []},
 'recoher': {'recohere': ['recoherence']},
 'recohere': ['recoherence'],
 'recoi': {'recois': []},
 'recoid': {'recoided': [], 'recoider': [], 'recoiding': [], 'recoids': []},
 'recoil': ['recoile',
            'recoiles',
            'recoiled',
            'recoiler',
            'recoilers',
            'recoiller',
            'recoiling',
            'recoilings'],
 'recoilfre': {'recoilfree': []},
 'recoillessli': {'recoillessly': []},
 'recoiloper': {'recoiloperated': []},
 'recoin': {'recoined': [], 'recoining': ['recoinings'], 'recoins': []},
 'recoinag': {'recoinage': ['recoinages']},
 'recoinage': ['recoinages'],
 'recoining': ['recoinings'],
 'recoinmend': {'recoinmended': []},
 'recoinp': {'recoinpence': []},
 'recoipt': {'recoipts': []},
 'recoiv': {'recoive': ['recoived', 'recoiver', 'recoives', 'recoivent'],
            'recoiving': []},
 'recoive': ['recoived', 'recoiver', 'recoives', 'recoivent'],
 'recoj': {'recoje': ['recojer']},
 'recoje': ['recojer'],
 'recojida': {'recojidas': []},
 'recokd': {'recokds': []},
 'recokn': {'recokned': []},
 'recokon': {'recokoned': [], 'recokoning': []},
 'recol': {'recolant': [],
           'recole': ['recolement'],
           'recoll': ['recolle',
                      'recolled',
                      'recoller',
                      'recollate',
                      'recollated',
                      'recollating',
                      'recollement',
                      'recollation']},
 'recola': {'recolas': []},
 'recolamu': {'recolamus': []},
 'recole': ['recolement'],
 'recoleccion': {'recolecciones': []},
 'recolect': {'recolected': [],
              'recolecting': [],
              'recolection': ['recolections'],
              'recolects': []},
 'recolectada': {'recolectadas': []},
 'recolectado': {'recolectados': []},
 'recolection': ['recolections'],
 'recolecto': {'recolectos': []},
 'recolector': {'recolectores': []},
 'recolen': {'recolens': []},
 'recolend': {'recolende': []},
 'recolenda': {'recolendae': [], 'recolendas': []},
 'recolendu': {'recolendus': []},
 'recolent': {'recolentes': []},
 'recoler': {'recolere': []},
 'recolet': {'recolete': [], 'recolets': []},
 'recoleta': {'recoletas': []},
 'recoleto': {'recoletos': []},
 'recolh': {'recolhe': ['recolher']},
 'recolhe': ['recolher'],
 'recolhida': {'recolhidas': []},
 'recolhido': {'recolhidos': []},
 'recolhimento': {'recolhimentos': []},
 'recoli': {'recolis': []},
 'recolimu': {'recolimus': []},
 'recoll': ['recolle',
            'recolled',
            'recoller',
            'recollate',
            'recollated',
            'recollating',
            'recollement',
            'recollation'],
 'recollaps': {'recollapse': ['recollapses', 'recollapsed'],
               'recollapsing': []},
 'recollapse': ['recollapses', 'recollapsed'],
 'recollct': {'recollcts': []},
 'recollect': {'recollectable': [],
               'recollecte': ['recollected'],
               'recollectible': [],
               'recollecting': [],
               'recollection': [],
               'recollective': ['recollectively', 'recollectiveness'],
               'recollects': []},
 'recollecte': ['recollected'],
 'recollected': {'recollectedness': []},
 'recollectedli': {'recollectedly': []},
 'recollecti': {'recollectiou': ['recollectious'], 'recollectis': []},
 'recollectiou': ['recollectious'],
 'recollectiv': {'recollectivization': [],
                 'recollectivize': ['recollectivized'],
                 'recollectivizing': []},
 'recollective': ['recollectively', 'recollectiveness'],
 'recollectivis': {'recollectivisation': []},
 'recollectivize': ['recollectivized'],
 'recollectlon': {'recollectlons': []},
 'recollecto': {'recollectos': []},
 'recollecton': {'recollectons': []},
 'recollector': {'recollectors': []},
 'recolledt': {'recolledtion': []},
 'recolleet': {'recolleeted': [], 'recolleetion': ['recolleetions']},
 'recolleetion': ['recolleetions'],
 'recolleft': {'recollefted': [], 'recolleftion': []},
 'recolleot': {'recolleoted': [], 'recolleotion': ['recolleotions']},
 'recolleotion': ['recolleotions'],
 'recollet': {'recolletion': [], 'recollets': []},
 'recolleto': {'recolletos': []},
 'recollett': {'recollettes': []},
 'recollid': {'recollide': []},
 'recolliger': {'recolligere': []},
 'recollim': {'recollimate': ['recollimated', 'recollimates'],
              'recollimating': [],
              'recollimation': []},
 'recollimate': ['recollimated', 'recollimates'],
 'recollis': {'recollision': ['recollisions']},
 'recollision': ['recollisions'],
 'recolloct': {'recolloction': []},
 'recolon': {'recolonization': ['recolonizations'],
             'recolonize': ['recolonizer',
                            'recolonizes',
                            'recolonized',
                            'recolonizers'],
             'recolonizing': [],
             'recolons': []},
 'recoloni': {'recolonial': ['recolonialization']},
 'recolonial': ['recolonialization'],
 'recolonis': {'recolonisation': ['recolonisations'],
               'recolonise': ['recolonised', 'recolonises', 'recolonisers'],
               'recolonising': []},
 'recolonisation': ['recolonisations'],
 'recolonise': ['recolonised', 'recolonises', 'recolonisers'],
 'recolonization': ['recolonizations'],
 'recolonize': ['recolonizer', 'recolonizes', 'recolonized', 'recolonizers'],
 'recolor': {'recoloration': [],
             'recolored': [],
             'recoloring': ['recolorings'],
             'recolorization': [],
             'recolorize': ['recolorized'],
             'recolors': []},
 'recoloring': ['recolorings'],
 'recolorize': ['recolorized'],
 'recolour': {'recoloured': [], 'recolouring': [], 'recolours': []},
 'recolt': {'recoltant': [], 'recolte': ['recolter', 'recoltes', 'recoltent']},
 'recolte': {'recoltee': ['recoltees']},
 'recoltee': ['recoltees'],
 'recolut': {'recolution': []},
 'recolutionari': {'recolutionary': []},
 'recolv': {'recolved': []},
 'recom': {'recome': ['recomes', 'recomed'],
           'recoming': [],
           'recommed': ['recommeds'],
           'recomment': ['recomments', 'recommented'],
           'recoms': []},
 'recomaend': {'recomaendations': [], 'recomaended': []},
 'recomand': {'recomandations': [], 'recomande': ['recomanded']},
 'recomande': ['recomanded'],
 'recomaund': {'recomaunde': []},
 'recomb': {'recombed': [], 'recombes': [], 'recombing': [], 'recombs': []},
 'recombi': {'recombiant': []},
 'recombin': {'recombinability': [],
              'recombinable': [],
              'recombinance': [],
              'recombinancy': [],
              'recombinant': [],
              'recombinate': ['recombinated', 'recombinates'],
              'recombinating': [],
              'recombination': ['recombinational', 'recombinationally'],
              'recombinative': [],
              'recombinator': ['recombinators'],
              'recombine': ['recombined',
                            'recombines',
                            'recombiner',
                            'recombiners',
                            'recombinent',
                            'recombineering'],
              'recombining': ['recombinings']},
 'recombinagen': {'recombinagenic': []},
 'recombinaison': {'recombinaisons': []},
 'recombinant': {'recombinante': []},
 'recombinantli': {'recombinantly': []},
 'recombinas': {'recombinase': ['recombinases']},
 'recombinase': ['recombinases'],
 'recombinate': ['recombinated', 'recombinates'],
 'recombination': ['recombinational', 'recombinationally'],
 'recombinationactiv': {'recombinationactivating': []},
 'recombinationdefici': {'recombinationdeficient': []},
 'recombinationdepend': {'recombinationdependent': []},
 'recombinationenhanc': {'recombinationenhanced': []},
 'recombinationgener': {'recombinationgeneration': []},
 'recombinator': ['recombinators'],
 'recombinatori': {'recombinatorial': [], 'recombinatory': []},
 'recombine': ['recombined',
               'recombines',
               'recombiner',
               'recombiners',
               'recombinent',
               'recombineering'],
 'recombining': ['recombinings'],
 'recombinogen': {'recombinogenic': ['recombinogenicity']},
 'recombinogenic': ['recombinogenicity'],
 'recombit': {'recombitant': []},
 'recombln': {'recomblnant': [], 'recomblne': ['recomblned']},
 'recomblne': ['recomblned'],
 'recombm': {'recombmant': [], 'recombme': []},
 'recombust': {'recombustion': []},
 'recomd': {'recomdations': []},
 'recome': ['recomes', 'recomed'],
 'recomemb': {'recomember': []},
 'recomemnd': {'recomemndations': [], 'recomemnded': []},
 'recomend': {'recomendable': ['recomendables'],
              'recomendation': ['recomendations'],
              'recomende': ['recomended'],
              'recomending': [],
              'recomends': []},
 'recomendable': ['recomendables'],
 'recomendacion': {'recomendaciones': []},
 'recomendaco': {'recomendacoes': []},
 'recomendada': {'recomendadas': []},
 'recomendado': {'recomendados': []},
 'recomendamo': {'recomendamos': []},
 'recomendation': ['recomendations'],
 'recomendatori': {'recomendatory': []},
 'recomende': ['recomended'],
 'recomfort': {'recomforte': ['recomforted'],
               'recomforting': [],
               'recomforts': []},
 'recomforte': ['recomforted'],
 'recomfortur': {'recomforture': []},
 'recomhin': {'recomhinant': [],
              'recomhination': [],
              'recomhine': ['recomhined']},
 'recomhine': ['recomhined'],
 'recomiend': {'recomiende': []},
 'recomienda': {'recomiendas': []},
 'recomin': {'recominant': [], 'recomination': []},
 'recominend': {'recominended': []},
 'recomiss': {'recomissioned': []},
 'recomit': {'recomitted': []},
 'recomlend': {'recomlendations': [], 'recomlended': []},
 'recomm': {'recomme': ['recommer', 'recommence', 'recommences']},
 'recommand': {'recommandable': ['recommandables'],
               'recommandant': [],
               'recommandation': ['recommandations'],
               'recommande': ['recommandes',
                              'recommander',
                              'recommanded',
                              'recommandent'],
               'recommanding': [],
               'recommands': []},
 'recommandable': ['recommandables'],
 'recommandai': {'recommandaient': []},
 'recommandation': ['recommandations'],
 'recommande': {'recommandee': ['recommandees']},
 'recommandee': ['recommandees'],
 'recommandon': {'recommandons': []},
 'recommaund': {'recommaunde': []},
 'recommcnd': {'recommcndable': []},
 'recomme': ['recommer', 'recommence', 'recommences'],
 'recommead': {'recommeaded': []},
 'recommed': {'recommedation': ['recommedations'],
              'recommeded': [],
              'recommeding': []},
 'recommedation': ['recommedations'],
 'recommedn': {'recommednations': [], 'recommedned': []},
 'recommemb': {'recommember': []},
 'recommemd': {'recommemded': []},
 'recommemor': {'recommemorate': []},
 'recommen': {'recommenation': ['recommenations'], 'recommened': []},
 'recommena': {'recommenaations': [], 'recommenaed': []},
 'recommenation': ['recommenations'],
 'recommenc': {'recommencant': [],
               'recommencates': [],
               'recommenced': [],
               'recommencement': [],
               'recommencent': [],
               'recommencer': [],
               'recommencing': []},
 'recommence': {'recommencee': []},
 'recommencer': {'recommencerent': []},
 'recommenceroi': {'recommenceroient': []},
 'recommenceron': {'recommencerons': []},
 'recommencon': {'recommencons': []},
 'recommend': {'recommendability': [],
               'recommendable': ['recommendables'],
               'recommendably': [],
               'recommendant': [],
               'recommendated': [],
               'recommendation': ['recommendational'],
               'recommendative': [],
               'recommende': ['recommender',
                              'recommendes',
                              'recommended',
                              'recommenders'],
               'recommending': [],
               'recommends': []},
 'recommendable': ['recommendables'],
 'recommendacion': {'recommendaciones': [], 'recommendacions': []},
 'recommendadon': {'recommendadons': []},
 'recommendaiion': {'recommendaiions': []},
 'recommendaion': {'recommendaions': []},
 'recommendaiton': {'recommendaitons': []},
 'recommendalion': {'recommendalions': []},
 'recommendanon': {'recommendanons': []},
 'recommendaon': {'recommendaons': []},
 'recommendari': {'recommendary': []},
 'recommendarion': {'recommendarions': []},
 'recommendat': {'recommendatic': []},
 'recommendati': {'recommendatiou': ['recommendatious']},
 'recommendaticn': {'recommendaticns': []},
 'recommendatin': {'recommendatins': []},
 'recommendatio': {'recommendatios': []},
 'recommendatioa': {'recommendatioas': []},
 'recommendation': {'recommendatione': ['recommendationes']},
 'recommendatione': ['recommendationes'],
 'recommendatiou': ['recommendatious'],
 'recommendatlon': {'recommendatlons': []},
 'recommendatoin': {'recommendatoins': []},
 'recommendaton': {'recommendatons': []},
 'recommendatori': {'recommendatory': []},
 'recommendauon': {'recommendauons': []},
 'recommendd': {'recommenddations': []},
 'recommende': {'recommendee': ['recommendees']},
 'recommendedbi': {'recommendedby': []},
 'recommendee': ['recommendees'],
 'recommendet': {'recommendetion': ['recommendetions']},
 'recommendetion': ['recommendetions'],
 'recommending': {'recommendinge': []},
 'recommendit': {'recommenditions': []},
 'recommendon': {'recommendons': []},
 'recommendot': {'recommendotions': []},
 'recommendst': {'recommendstions': []},
 'recommendt': {'recommendtion': ['recommendtions']},
 'recommendth': {'recommendthe': []},
 'recommendtion': ['recommendtions'],
 'recommened': {'recommeneded': []},
 'recommeno': {'recommenoations': [], 'recommenoed': []},
 'recomment': {'recommentation': ['recommentations'], 'recommentions': []},
 'recommentation': ['recommentations'],
 'recommerci': {'recommercialization': []},
 'recommerd': {'recommerdations': [], 'recommerded': []},
 'recommerid': {'recommerided': []},
 'recommeud': {'recommeudation': [],
               'recommeuded': [],
               'recommeuding': [],
               'recommeuds': []},
 'recommiss': {'recommission': ['recommissions',
                                'recommissioned',
                                'recommissioning']},
 'recommission': ['recommissions', 'recommissioned', 'recommissioning'],
 'recommit': {'recommital': [],
              'recommited': [],
              'recommiting': [],
              'recommitment': ['recommitments'],
              'recommits': [],
              'recommitted': [],
              'recommitting': []},
 'recommitment': ['recommitments'],
 'recommitt': {'recommittal': ['recommittals'], 'recommittment': []},
 'recommittal': ['recommittals'],
 'recommmend': {'recommmendation': ['recommmendations'],
                'recommmended': [],
                'recommmending': [],
                'recommmends': []},
 'recommmendation': ['recommmendations'],
 'recommn': {'recommned': []},
 'recommnd': {'recommndations': [], 'recommnded': []},
 'recommned': {'recommnedations': [], 'recommneded': []},
 'recommod': {'recommodations': []},
 'recommodif': {'recommodification': []},
 'recommodifi': {'recommodified': [], 'recommodify': ['recommodifying']},
 'recommodify': ['recommodifying'],
 'recommond': {'recommondation': ['recommondations'],
               'recommonded': [],
               'recommonds': []},
 'recommondation': ['recommondations'],
 'recommsnd': {'recommsndations': [], 'recommsnded': []},
 'recommun': {'recommunalization': [],
              'recommunicate': ['recommunicated', 'recommunicates'],
              'recommunicating': [],
              'recommunication': [],
              'recommunization': []},
 'recommunicate': ['recommunicated', 'recommunicates'],
 'recomnd': {'recomnded': []},
 'recomnend': {'recomnendation': ['recomnendations'],
               'recomnended': [],
               'recomnending': [],
               'recomnends': []},
 'recomnendation': ['recomnendations'],
 'recomniend': {'recomniended': []},
 'recomp': {'recompance': [], 'recompence': ['recompences']},
 'recompa': {'recompas': []},
 'recompact': {'recompacted': [],
               'recompacting': [],
               'recompaction': [],
               'recompacts': []},
 'recompar': {'recompare': ['recompared'], 'recomparing': []},
 'recompare': ['recompared'],
 'recompartment': {'recompartmentalization': []},
 'recompcnc': {'recompcnce': []},
 'recompen': {'recompens': []},
 'recompenc': {'recompenced': [], 'recompencing': []},
 'recompence': ['recompences'],
 'recompene': {'recompenee': []},
 'recompenf': {'recompenfe': ['recompenfed', 'recompenfer']},
 'recompenfe': ['recompenfed', 'recompenfer'],
 'recompeno': {'recompenoe': []},
 'recompens': {'recompensable': [],
               'recompensant': [],
               'recompensate': ['recompensated', 'recompensates'],
               'recompensating': [],
               'recompensation': ['recompensations'],
               'recompense': ['recompensed', 'recompenser', 'recompensent'],
               'recompensing': [],
               'recompensive': []},
 'recompensa': {'recompensas': []},
 'recompensado': {'recompensados': []},
 'recompensar': {'recompensare': []},
 'recompensate': ['recompensated', 'recompensates'],
 'recompensation': {'recompensatione': []},
 'recompensatori': {'recompensatory': []},
 'recompense': {'recompensee': ['recompensees']},
 'recompensee': ['recompensees'],
 'recompet': {'recompete': ['recompeted'], 'recompeting': []},
 'recompete': ['recompeted'],
 'recompetit': {'recompetition': []},
 'recompeuc': {'recompeuce': []},
 'recompil': {'recompilation': ['recompilations'],
              'recompile': ['recompiles', 'recompiled', 'recompilement'],
              'recompiling': []},
 'recompilation': ['recompilations'],
 'recompile': ['recompiles', 'recompiled', 'recompilement'],
 'recompl': {'recomplement': ['recomplemented', 'recomplementing'],
             'recomplicate': ['recomplicates', 'recomplicated'],
             'recomplicating': [],
             'recomplication': ['recomplications']},
 'recomplement': {'recomplementation': []},
 'recomplet': {'recomplete': ['recompletes', 'recompleted'],
               'recompleting': [],
               'recompletion': ['recompletions']},
 'recomplete': ['recompletes', 'recompleted'],
 'recompletion': ['recompletions'],
 'recompli': {'recompliance': []},
 'recomplicate': ['recomplicates', 'recomplicated'],
 'recomplication': ['recomplications'],
 'recompon': {'recompone': ['recomponer']},
 'recompone': ['recomponer'],
 'recompos': {'recomposable': [],
              'recomposant': [],
              'recompose': ['recomposed',
                            'recomposer',
                            'recomposes',
                            'recomposent'],
              'recomposing': []},
 'recompose': {'recomposee': []},
 'recomposit': {'recomposite': ['recomposited'],
                'recomposition': ['recompositions', 'recompositional']},
 'recomposite': ['recomposited'],
 'recomposition': ['recompositions', 'recompositional'],
 'recomposur': {'recomposure': []},
 'recompound': {'recompounded': [],
                'recompounding': ['recompoundings'],
                'recompounds': []},
 'recompounding': ['recompoundings'],
 'recomprador': {'recompradorization': []},
 'recomprehend': {'recomprehended': []},
 'recomprehens': {'recomprehension': []},
 'recompress': {'recompressed': [],
                'recompresses': [],
                'recompressing': [],
                'recompression': ['recompressions']},
 'recompression': ['recompressions'],
 'recompressor': {'recompressors': []},
 'recompt': {'recompted': []},
 'recomput': {'recomputable': [],
              'recomputation': ['recomputations'],
              'recompute': ['recomputed', 'recomputes'],
              'recomputing': []},
 'recomputation': ['recomputations'],
 'recompute': ['recomputed', 'recomputes'],
 'recomrend': {'recomrended': []},
 'recomrnend': {'recomrnendation': ['recomrnendations'], 'recomrnended': []},
 'recomrnendation': ['recomrnendations'],
 'recomth': {'recomthe': []},
 'recomtruct': {'recomtruction': []},
 'recon': {'reconance': [],
           'reconation': [],
           'recone': ['reconed'],
           'reconing': ['reconings'],
           'reconize': ['reconized', 'reconizes'],
           'reconizing': [],
           'reconned': [],
           'reconning': [],
           'recons': []},
 'reconaend': {'reconaended': []},
 'reconaiss': {'reconaissance': ['reconaissances']},
 'reconaissance': ['reconaissances'],
 'reconaitr': {'reconaitre': []},
 'reconatitut': {'reconatitution': []},
 'reconatruct': {'reconatruction': []},
 'reconbin': {'reconbination': []},
 'reconc': {'reconceal': ['reconcealed'],
            'reconceive': ['reconceives'],
            'reconcent': []},
 'reconcav': {'reconcave': []},
 'reconccptu': {'reconccptualization': []},
 'reconcd': {'reconcde': ['reconcded']},
 'reconcde': ['reconcded'],
 'reconceal': ['reconcealed'],
 'reconced': {'reconceded': []},
 'reconceiv': {'reconceived': [], 'reconceiving': []},
 'reconceive': ['reconceives'],
 'reconcentr': {'reconcentrate': ['reconcentrates', 'reconcentrated'],
                'reconcentrating': [],
                'reconcentration': ['reconcentrations'],
                'reconcentrator': []},
 'reconcentrado': {'reconcentradoes': [], 'reconcentrados': []},
 'reconcentrate': ['reconcentrates', 'reconcentrated'],
 'reconcentration': ['reconcentrations'],
 'reconcepru': {'reconceprualization': [],
                'reconceprualize': ['reconceprualized'],
                'reconceprualizing': []},
 'reconceprualize': ['reconceprualized'],
 'reconcept': {'reconception': ['reconceptions']},
 'reconception': {'reconceptionalization': []},
 'reconceptu': {'reconceptual': ['reconceptualism',
                                 'reconceptualize',
                                 'reconceptualizes',
                                 'reconceptualized',
                                 'reconceptualizing',
                                 'reconceptualization',
                                 'reconceptualizations']},
 'reconceptual': ['reconceptualism',
                  'reconceptualize',
                  'reconceptualizes',
                  'reconceptualized',
                  'reconceptualizing',
                  'reconceptualization',
                  'reconceptualizations'],
 'reconceptualis': {'reconceptualisation': ['reconceptualisations'],
                    'reconceptualise': ['reconceptualises', 'reconceptualised'],
                    'reconceptualising': []},
 'reconceptualisation': ['reconceptualisations'],
 'reconceptualise': ['reconceptualises', 'reconceptualised'],
 'reconceptualist': {'reconceptualists': []},
 'reconceptul': {'reconceptulization': []},
 'reconcess': {'reconcession': []},
 'reconciali': {'reconcialiation': []},
 'reconcih': {'reconcihation': []},
 'reconcii': {'reconciie': []},
 'reconciii': {'reconciiiation': []},
 'reconcil': {'reconcilability': [],
              'reconcilable': ['reconcilables', 'reconcilableness'],
              'reconcilably': [],
              'reconcilation': ['reconcilations'],
              'reconcile': ['reconciles',
                            'reconciler',
                            'reconciled',
                            'reconcileing',
                            'reconcileable',
                            'reconcilement',
                            'reconcileably',
                            'reconcilements',
                            'reconcileableness'],
              'reconciling': ['reconcilings'],
              'reconcillation': [],
              'reconcilled': [],
              'reconcilling': [],
              'reconcilment': []},
 'reconcilable': ['reconcilables', 'reconcilableness'],
 'reconcilation': ['reconcilations'],
 'reconcilatori': {'reconcilatory': []},
 'reconcilc': {'reconcilcable': []},
 'reconcile': ['reconciles',
               'reconciler',
               'reconciled',
               'reconcileing',
               'reconcileable',
               'reconcilement',
               'reconcileably',
               'reconcilements',
               'reconcileableness'],
 'reconciled': {'reconciledness': []},
 'reconcili': {'reconciliability': [],
               'reconciliable': [],
               'reconciliant': [],
               'reconciliate': ['reconciliates', 'reconciliated'],
               'reconciliating': [],
               'reconciliation': ['reconciliational'],
               'reconciliative': [],
               'reconciliator': ['reconciliators'],
               'reconcilie': ['reconcilied',
                              'reconcilies',
                              'reconcilier',
                              'reconcilient']},
 'reconciliado': {'reconciliados': []},
 'reconcilian': {'reconcilians': []},
 'reconciliandi': {'reconciliandis': []},
 'reconciliando': {'reconciliandos': []},
 'reconciliar': {'reconciliare': []},
 'reconciliars': {'reconciliarse': []},
 'reconciliata': {'reconciliatae': []},
 'reconciliate': ['reconciliates', 'reconciliated'],
 'reconciliati': {'reconciliatis': []},
 'reconciliation': {'reconciliatione': [], 'reconciliationism': []},
 'reconciliationi': {'reconciliationis': []},
 'reconciliationist': {'reconciliationists': []},
 'reconciliato': {'reconciliatos': []},
 'reconciliator': ['reconciliators'],
 'reconciliatori': {'reconciliatory': []},
 'reconciliatu': {'reconciliatus': []},
 'reconciliazion': {'reconciliazione': []},
 'reconcilie': {'reconciliee': ['reconciliees']},
 'reconciliee': ['reconciliees'],
 'reconciling': ['reconcilings'],
 'reconcilingli': {'reconcilingly': []},
 'reconcilit': {'reconcilitation': [], 'reconcilition': []},
 'reconcilli': {'reconcilliation': []},
 'reconcilliatori': {'reconcilliatory': []},
 'reconciti': {'reconcitiation': []},
 'reconcoct': {'reconcocted': []},
 'reconconstruct': {'reconconstruction': []},
 'reconcrescer': {'reconcrescerent': []},
 'reconcret': {'reconcretization': [], 'reconcretized': []},
 'reconcyl': {'reconcyle': ['reconcyled']},
 'reconcyle': ['reconcyled'],
 'recond': {'reconde': ['reconded'],
            'reconditi': ['reconditis'],
            'reconds': []},
 'recondari': {'recondary': []},
 'reconde': ['reconded'],
 'recondemn': {'recondemnation': [], 'recondemned': []},
 'reconden': {'recondens': []},
 'recondens': {'recondensation': [],
               'recondense': ['recondenses', 'recondensed'],
               'recondensing': []},
 'recondense': ['recondenses', 'recondensed'],
 'reconder': {'recondere': []},
 'recondi': {'recondis': []},
 'recondit': {'recondite': ['reconditely', 'reconditeness'],
              'recondition': ['reconditions',
                              'reconditioned',
                              'reconditioning',
                              'reconditionings']},
 'recondita': {'reconditae': [], 'reconditas': []},
 'recondite': ['reconditely', 'reconditeness'],
 'reconditi': ['reconditis'],
 'recondition': {'reconditionable': [], 'reconditioner': ['reconditioners']},
 'reconditioner': ['reconditioners'],
 'recondito': {'reconditos': []},
 'reconditu': {'reconditus': []},
 'recondo': {'recondos': []},
 'reconduct': {'reconducted': [],
               'reconducting': [],
               'reconduction': [],
               'reconducts': []},
 'reconductor': {'reconductoring': []},
 'reconduir': {'reconduire': []},
 'reconduis': {'reconduisant': []},
 'reconduit': {'reconduite': [], 'reconduits': []},
 'recone': ['reconed'],
 'reconeil': {'reconeile': ['reconeiled', 'reconeileable']},
 'reconeile': ['reconeiled', 'reconeileable'],
 'reconeili': {'reconeiliation': []},
 'reconf': {'reconfer': ['reconfers', 'reconferred', 'reconferring']},
 'reconfeder': {'reconfederation': []},
 'reconfer': ['reconfers', 'reconferred', 'reconferring'],
 'reconfess': {'reconfessed': [], 'reconfession': []},
 'reconfession': {'reconfessionalization': []},
 'reconfigur': {'reconfigurability': [],
                'reconfigurable': [],
                'reconfigurate': ['reconfigurated'],
                'reconfigurating': [],
                'reconfiguration': ['reconfigurations', 'reconfigurational'],
                'reconfigurative': [],
                'reconfigure': ['reconfigures',
                                'reconfigurer',
                                'reconfigured',
                                'reconfigurement'],
                'reconfiguring': ['reconfigurings']},
 'reconfigurate': ['reconfigurated'],
 'reconfiguration': ['reconfigurations', 'reconfigurational'],
 'reconfigure': ['reconfigures',
                 'reconfigurer',
                 'reconfigured',
                 'reconfigurement'],
 'reconfiguring': ['reconfigurings'],
 'reconfin': {'reconfine': ['reconfined', 'reconfines', 'reconfinement'],
              'reconfining': []},
 'reconfine': ['reconfined', 'reconfines', 'reconfinement'],
 'reconfirm': {'reconfirmation': ['reconfirmations'],
               'reconfirmed': [],
               'reconfirming': [],
               'reconfirms': []},
 'reconfirmation': ['reconfirmations'],
 'reconfisc': {'reconfiscated': [], 'reconfiscation': []},
 'reconflgur': {'reconflgurable': []},
 'reconform': {'reconformation': [], 'reconformed': [], 'reconforming': []},
 'reconfort': {'reconfortant': [], 'reconforte': ['reconforter']},
 'reconfortant': {'reconfortante': []},
 'reconforte': ['reconforter'],
 'reconfront': {'reconfrontation': [],
                'reconfronted': [],
                'reconfronting': [],
                'reconfronts': []},
 'recong': {'recongeal': ['recongealed', 'recongealing'],
            'recongize': ['recongizes', 'recongized'],
            'recongizing': []},
 'recongeal': ['recongealed', 'recongealing'],
 'recongel': {'recongelation': []},
 'recongis': {'recongise': ['recongised']},
 'recongise': ['recongised'],
 'recongit': {'recongition': []},
 'recongiz': {'recongizable': []},
 'recongize': ['recongizes', 'recongized'],
 'recongn': {'recongnize': ['recongnized', 'recongnizes'], 'recongnizing': []},
 'recongnis': {'recongnisable': [],
               'recongnise': ['recongnised', 'recongnises'],
               'recongnising': []},
 'recongnise': ['recongnised', 'recongnises'],
 'recongnit': {'recongnition': []},
 'recongniz': {'recongnizable': []},
 'recongnize': ['recongnized', 'recongnizes'],
 'recongnoiss': {'recongnoissent': []},
 'recongnoistr': {'recongnoistre': []},
 'recongreg': {'recongregate': ['recongregated'], 'recongregation': []},
 'recongregate': ['recongregated'],
 'reconhec': {'reconhece': ['reconhecer']},
 'reconhece': ['reconhecer'],
 'reconhecida': {'reconhecidas': []},
 'reconhecidament': {'reconhecidamente': []},
 'reconhecido': {'reconhecidos': []},
 'reconili': {'reconiliation': []},
 'reconimend': {'reconimended': []},
 'reconing': {'reconinge': []},
 'reconip': {'reconipence': []},
 'reconis': {'reconise': ['reconised']},
 'reconise': ['reconised'],
 'reconit': {'reconition': []},
 'reconitr': {'reconitre': []},
 'reconiz': {'reconizable': []},
 'reconize': ['reconized', 'reconizes'],
 'reconjoin': {'reconjoined': []},
 'reconjug': {'reconjugate': ['reconjugated'],
              'reconjugating': [],
              'reconjugation': []},
 'reconjugate': ['reconjugated'],
 'reconjunct': {'reconjunction': []},
 'reconjur': {'reconjure': ['reconjured'], 'reconjuring': []},
 'reconjure': ['reconjured'],
 'reconl': {'reconled': [], 'reconls': []},
 'reconmend': {'reconmendation': ['reconmendations'],
               'reconmended': [],
               'reconmending': [],
               'reconmends': []},
 'reconmendation': ['reconmendations'],
 'reconn': {'reconnize': ['reconnized', 'reconnizes']},
 'reconnaftr': {'reconnaftre': []},
 'reconnai': {'reconnais': []},
 'reconnais': {'reconnaisance': ['reconnaisances'], 'reconnaisant': []},
 'reconnaisance': ['reconnaisances'],
 'reconnaiss': {'reconnaissable': ['reconnaissables'],
                'reconnaissance': [],
                'reconnaissant': ['reconnaissants'],
                'reconnaisse': ['reconnaissent', 'reconnaissence'],
                'reconnaissions': []},
 'reconnaissable': ['reconnaissables'],
 'reconnaissai': {'reconnaissaient': [], 'reconnaissais': []},
 'reconnaissancebomb': {'reconnaissancebomber': []},
 'reconnaissant': {'reconnaissante': ['reconnaissantes']},
 'reconnaissante': ['reconnaissantes'],
 'reconnaisse': ['reconnaissent', 'reconnaissence'],
 'reconnaisson': {'reconnaissons': []},
 'reconnaisss': {'reconnaisssance': []},
 'reconnaitr': {'reconnaitre': ['reconnaitred']},
 'reconnaitrai': {'reconnaitraient': []},
 'reconnaitre': ['reconnaitred'],
 'reconnaitron': {'reconnaitrons': []},
 'reconnaltr': {'reconnaltre': []},
 'reconnassi': {'reconnassiance': []},
 'reconnattr': {'reconnattre': []},
 'reconncct': {'reconncction': []},
 'reconnect': {'reconnectable': [],
               'reconnected': [],
               'reconnecting': [],
               'reconnection': ['reconnections'],
               'reconnective': [],
               'reconnects': []},
 'reconnected': {'reconnectedness': []},
 'reconnection': ['reconnections'],
 'reconnend': {'reconnendation': ['reconnendations'], 'reconnended': []},
 'reconnendation': ['reconnendations'],
 'reconneu': {'reconneues': []},
 'reconniass': {'reconniassance': []},
 'reconniss': {'reconnissance': []},
 'reconnize': ['reconnized', 'reconnizes'],
 'reconnnaiss': {'reconnnaissance': []},
 'reconnnend': {'reconnnended': []},
 'reconnoi': {'reconnois': []},
 'reconnoias': {'reconnoiasance': []},
 'reconnoiff': {'reconnoiffance': [], 'reconnoiffant': []},
 'reconnoiftr': {'reconnoiftre': []},
 'reconnois': {'reconnoisance': ['reconnoisances']},
 'reconnoisance': ['reconnoisances'],
 'reconnoiss': {'reconnoissable': [],
                'reconnoissance': ['reconnoissances'],
                'reconnoissant': [],
                'reconnoisse': ['reconnoissent'],
                'reconnoissions': []},
 'reconnoissancc': {'reconnoissanccs': []},
 'reconnoissance': ['reconnoissances'],
 'reconnoissane': {'reconnoissanee': ['reconnoissanees']},
 'reconnoissanee': ['reconnoissanees'],
 'reconnoissano': {'reconnoissanoe': []},
 'reconnoissant': {'reconnoissante': []},
 'reconnoissauc': {'reconnoissauce': []},
 'reconnoisse': ['reconnoissent'],
 'reconnoissoi': {'reconnoissoient': []},
 'reconnoisson': {'reconnoissons': []},
 'reconnoistr': {'reconnoistre': []},
 'reconnoit': {'reconnoiter': ['reconnoiters',
                               'reconnoitered',
                               'reconnoitering']},
 'reconnoitcr': {'reconnoitcred': [], 'reconnoitcring': []},
 'reconnoiter': {'reconnoiterer': ['reconnoiterers']},
 'reconnoiterer': ['reconnoiterers'],
 'reconnoitr': {'reconnoitre': ['reconnoitres',
                                'reconnoitrer',
                                'reconnoitred',
                                'reconnoitrers',
                                'reconnoitreing'],
                'reconnoitring': []},
 'reconnoitre': ['reconnoitres',
                 'reconnoitrer',
                 'reconnoitred',
                 'reconnoitrers',
                 'reconnoitreing'],
 'reconnolss': {'reconnolssance': []},
 'reconnolt': {'reconnoltered': [], 'reconnoltering': []},
 'reconnu': {'reconnue': ['reconnues'], 'reconnus': []},
 'reconnue': ['reconnues'],
 'reconnum': {'reconnumes': []},
 'reconnur': {'reconnurent': []},
 'reconoc': {'reconoce': ['reconoces', 'reconoced', 'reconocer'],
             'reconocible': ['reconocibles']},
 'reconoce': ['reconoces', 'reconoced', 'reconocer'],
 'reconocemo': {'reconocemos': []},
 'reconoceremo': {'reconoceremos': []},
 'reconocerl': {'reconocerle': []},
 'reconocerla': {'reconocerlas': []},
 'reconocerlo': {'reconocerlos': []},
 'reconocerm': {'reconocerme': []},
 'reconocerno': {'reconocernos': []},
 'reconocers': {'reconocerse': []},
 'reconocible': ['reconocibles'],
 'reconocida': {'reconocidas': []},
 'reconocido': {'reconocidos': []},
 'reconociendos': {'reconociendose': []},
 'reconocies': {'reconociese': []},
 'reconocimiento': {'reconocimientos': []},
 'reconocimo': {'reconocimos': []},
 'reconoil': {'reconoile': ['reconoiled']},
 'reconoile': ['reconoiled'],
 'reconoiss': {'reconoissance': []},
 'reconoit': {'reconoiter': ['reconoitered', 'reconoitering']},
 'reconoiter': ['reconoitered', 'reconoitering'],
 'reconoitr': {'reconoitre': ['reconoitred'], 'reconoitring': []},
 'reconoitre': ['reconoitred'],
 'reconom': {'reconomic': []},
 'reconomi': {'reconomie': [], 'reconomy': []},
 'reconozcamo': {'reconozcamos': []},
 'reconqu': {'reconquer': ['reconquers', 'reconquered', 'reconquering']},
 'reconquer': {'reconquerer': []},
 'reconqueror': {'reconquerors': []},
 'reconquest': {'reconquests': []},
 'reconquet': {'reconquete': []},
 'reconqui': {'reconquis': []},
 'reconquis': {'reconquise': []},
 'reconquistador': {'reconquistadores': []},
 'reconrs': {'reconrse': []},
 'recons': {'reconsent': []},
 'reconsat': {'reconsats': []},
 'reconsci': {'reconscious': []},
 'reconscript': {'reconscripted': []},
 'reconsecr': {'reconsecrate': ['reconsecrated', 'reconsecrates'],
               'reconsecrating': [],
               'reconsecration': ['reconsecrations']},
 'reconsecrate': ['reconsecrated', 'reconsecrates'],
 'reconsecration': ['reconsecrations'],
 'reconserv': {'reconservation': []},
 'reconsid': {'reconsider': ['reconsiders',
                             'reconsidered',
                             'reconsidering',
                             'reconsiderings']},
 'reconsider': {'reconsiderable': [],
                'reconsideration': [],
                'reconsidere': ['reconsiderer']},
 'reconsidere': {'reconsideree': []},
 'reconsign': {'reconsigned': [],
               'reconsigning': [],
               'reconsignment': ['reconsignments'],
               'reconsigns': []},
 'reconsignment': ['reconsignments'],
 'reconsil': {'reconsile': ['reconsiles', 'reconsiled', 'reconsileing'],
              'reconsiling': []},
 'reconsile': ['reconsiles', 'reconsiled', 'reconsileing'],
 'reconsili': {'reconsiliation': []},
 'reconsititut': {'reconsitituted': [], 'reconsititution': []},
 'reconsitut': {'reconsitute': ['reconsituted'], 'reconsitution': []},
 'reconsitute': ['reconsituted'],
 'reconslitut': {'reconslitution': []},
 'reconsol': {'reconsole': ['reconsoled']},
 'reconsole': ['reconsoled'],
 'reconsolid': {'reconsolidate': ['reconsolidates', 'reconsolidated'],
                'reconsolidating': [],
                'reconsolidation': ['reconsolidations']},
 'reconsolidate': ['reconsolidates', 'reconsolidated'],
 'reconsolidation': ['reconsolidations'],
 'reconsritut': {'reconsritution': []},
 'reconsrruct': {'reconsrruction': []},
 'reconsruct': {'reconsruction': []},
 'reconstaict': {'reconstaiction': []},
 'reconstel': {'reconstellate': ['reconstellates', 'reconstellated'],
               'reconstellating': [],
               'reconstellation': ['reconstellations']},
 'reconstellate': ['reconstellates', 'reconstellated'],
 'reconstellation': ['reconstellations'],
 'reconstilut': {'reconstilution': []},
 'reconstirut': {'reconstirution': []},
 'reconstit': {'reconstition': []},
 'reconstitnt': {'reconstitntion': []},
 'reconstitu': {'reconstituant': [],
                'reconstitue': ['reconstitues',
                                'reconstituer',
                                'reconstitued',
                                'reconstituent',
                                'reconstituents']},
 'reconstitue': {'reconstituee': ['reconstituees']},
 'reconstituee': ['reconstituees'],
 'reconstitur': {'reconstiture': ['reconstitured']},
 'reconstiture': ['reconstitured'],
 'reconstitut': {'reconstitutability': [],
                 'reconstitutable': [],
                 'reconstitute': ['reconstituter',
                                  'reconstituted',
                                  'reconstitutes'],
                 'reconstituting': [],
                 'reconstitution': ['reconstitutions', 'reconstitutional'],
                 'reconstitutive': ['reconstitutively']},
 'reconstitute': ['reconstituter', 'reconstituted', 'reconstitutes'],
 'reconstituti': {'reconstitutiou': []},
 'reconstitution': {'reconstitutionalization': []},
 'reconstitutive': ['reconstitutively'],
 'reconstituy': {'reconstituye': []},
 'reconstiuct': {'reconstiuction': []},
 'reconstltut': {'reconstltution': []},
 'reconstmct': {'reconstmcted': [], 'reconstmction': []},
 'reconstnict': {'reconstnicted': [], 'reconstniction': []},
 'reconstnrct': {'reconstnrction': []},
 'reconstract': {'reconstracted': [], 'reconstraction': []},
 'reconstrain': {'reconstrained': []},
 'reconstrct': {'reconstrction': []},
 'reconstrcut': {'reconstrcution': []},
 'reconstrict': {'reconstriction': []},
 'reconstrnct': {'reconstrnction': []},
 'reconstru': {'reconstruable': [],
               'reconstrual': ['reconstruals'],
               'reconstrue': ['reconstrued', 'reconstrues'],
               'reconstruing': []},
 'reconstrual': ['reconstruals'],
 'reconstruc': {'reconstruced': [], 'reconstrucing': []},
 'reconstruccion': {'reconstrucciones': []},
 'reconstrucr': {'reconstrucred': []},
 'reconstruct': {'reconstructability': [],
                 'reconstructable': [],
                 'reconstructed': [],
                 'reconstructer': ['reconstructers'],
                 'reconstructibility': [],
                 'reconstructible': [],
                 'reconstructing': ['reconstructings'],
                 'reconstruction': ['reconstructional'],
                 'reconstructive': ['reconstructives', 'reconstructively'],
                 'reconstructs': []},
 'reconstructer': ['reconstructers'],
 'reconstructi': {'reconstructie': []},
 'reconstructing': ['reconstructings'],
 'reconstruction': {'reconstructionism': []},
 'reconstructionari': {'reconstructionary': []},
 'reconstructionist': {'reconstructionists': []},
 'reconstructiv': {'reconstructivism': []},
 'reconstructive': ['reconstructives', 'reconstructively'],
 'reconstructivist': {'reconstructivists': []},
 'reconstructor': {'reconstructors': []},
 'reconstructth': {'reconstructthe': []},
 'reconstructur': {'reconstructure': ['reconstructured'],
                   'reconstructuring': []},
 'reconstructure': ['reconstructured'],
 'reconstrue': ['reconstrued', 'reconstrues'],
 'reconstruet': {'reconstruetion': []},
 'reconstruida': {'reconstruidas': []},
 'reconstruido': {'reconstruidos': []},
 'reconstruir': {'reconstruire': []},
 'reconstruis': {'reconstruisant': [], 'reconstruisent': []},
 'reconstruit': {'reconstruite': ['reconstruites'], 'reconstruits': []},
 'reconstruite': ['reconstruites'],
 'reconstrukt': {'reconstruktion': []},
 'reconstrut': {'reconstruted': [], 'reconstrution': []},
 'reconstruy': {'reconstruye': []},
 'reconstruzion': {'reconstruzione': []},
 'reconsttucr': {'reconsttucred': []},
 'reconsttuct': {'reconsttucted': [],
                 'reconsttucting': [],
                 'reconsttuction': []},
 'reconstuct': {'reconstucted': [],
                'reconstucting': [],
                'reconstuction': ['reconstuctions'],
                'reconstuctive': []},
 'reconstuction': ['reconstuctions'],
 'reconsturct': {'reconsturction': []},
 'reconsult': {'reconsultation': [], 'reconsulted': [], 'reconsulting': []},
 'reconsum': {'reconsume': ['reconsumed'], 'reconsuming': []},
 'reconsume': ['reconsumed'],
 'reconsumm': {'reconsummate': ['reconsummated'], 'reconsummation': []},
 'reconsummate': ['reconsummated'],
 'reconsumpt': {'reconsumption': []},
 'reconsutut': {'reconsutution': []},
 'reconsyl': {'reconsyled': []},
 'recont': {'reconte': ['reconter']},
 'recontact': {'recontacted': [], 'recontacting': [], 'recontacts': []},
 'recontain': {'recontained': [],
               'recontaining': [],
               'recontainment': [],
               'recontains': []},
 'recontamin': {'recontaminate': ['recontaminated', 'recontaminates'],
                'recontaminating': [],
                'recontamination': []},
 'recontaminate': ['recontaminated', 'recontaminates'],
 'reconte': ['reconter'],
 'recontempl': {'recontemplate': [], 'recontemplation': []},
 'recontest': {'recontested': [], 'recontesting': []},
 'reconteur': {'reconteurs': []},
 'reconth': {'reconthe': []},
 'recontinu': {'recontinuance': [],
               'recontinuation': [],
               'recontinue': ['recontinued'],
               'recontinuing': []},
 'recontinue': ['recontinued'],
 'recontli': {'recontly': []},
 'recontour': {'recontoured': [], 'recontouring': [], 'recontours': []},
 'recontr': {'recontrant': [],
             'recontre': ['recontres', 'recontrer', 'recontrent']},
 'recontra': {'recontras': []},
 'recontract': {'recontracted': [],
                'recontracting': [],
                'recontraction': [],
                'recontracts': []},
 'recontractur': {'recontracture': []},
 'recontre': {'recontree': []},
 'recontribut': {'recontribute': ['recontributes', 'recontributed'],
                 'recontributing': [],
                 'recontribution': ['recontributions']},
 'recontribute': ['recontributes', 'recontributed'],
 'recontribution': ['recontributions'],
 'recontriv': {'recontrived': []},
 'recontrol': {'recontrolled': [], 'recontrolling': []},
 'recontruct': {'recontructed': [],
                'recontructing': [],
                'recontruction': ['recontructions'],
                'recontructive': []},
 'recontruction': ['recontructions'],
 'reconttruct': {'reconttruction': []},
 'reconunend': {'reconunendation': ['reconunendations'], 'reconunended': []},
 'reconunendation': ['reconunendations'],
 'reconuoiss': {'reconuoissance': []},
 'reconuoit': {'reconuoiter': ['reconuoitering']},
 'reconuoiter': ['reconuoitering'],
 'reconv': {'reconver': []},
 'reconvalesc': {'reconvalescence': [], 'reconvalescent': ['reconvalescents']},
 'reconvalescent': ['reconvalescents'],
 'reconvci': {'reconvcy': []},
 'reconven': {'reconvene': ['reconvenes', 'reconvened'], 'reconvening': []},
 'reconvencion': {'reconvenciones': []},
 'reconvene': ['reconvenes', 'reconvened'],
 'reconvent': {'reconvention': ['reconventions', 'reconventional']},
 'reconvention': {'reconventionalized': []},
 'reconventionnel': {'reconventionnelle': ['reconventionnelles']},
 'reconventionnelle': ['reconventionnelles'],
 'reconverg': {'reconverge': ['reconverges',
                              'reconverged',
                              'reconvergent',
                              'reconvergence'],
               'reconverging': []},
 'reconverge': ['reconverges', 'reconverged', 'reconvergent', 'reconvergence'],
 'reconvers': {'reconversion': ['reconversions']},
 'reconversion': ['reconversions'],
 'reconvert': {'reconverted': [],
               'reconverter': [],
               'reconvertibility': [],
               'reconvertible': [],
               'reconverting': [],
               'reconverts': []},
 'reconverti': {'reconvertis': []},
 'reconvey': {'reconveyance': ['reconveyances'],
              'reconveyed': [],
              'reconveying': [],
              'reconveys': []},
 'reconveyance': ['reconveyances'],
 'reconvict': {'reconvicted': [],
               'reconvicting': [],
               'reconviction': ['reconvictions']},
 'reconviction': ['reconvictions'],
 'reconvili': {'reconvilier': []},
 'reconvinc': {'reconvince': ['reconvinced', 'reconvinces'],
               'reconvincing': []},
 'reconvince': ['reconvinced', 'reconvinces'],
 'reconvoc': {'reconvocation': []},
 'reconvok': {'reconvoke': ['reconvoked'], 'reconvoking': []},
 'reconvoke': ['reconvoked'],
 'reconvolut': {'reconvolution': []},
 'reconwgur': {'reconwguration': [], 'reconwgure': ['reconwgured']},
 'reconwgure': ['reconwgured'],
 'reconyng': {'reconynge': ['reconynges']},
 'reconynge': ['reconynges'],
 'recook': {'recooked': [], 'recooking': []},
 'recool': {'recooled': [], 'recooler': [], 'recooling': []},
 'recoon': {'recoonized': []},
 'recoop': {'recooper': ['recoopered', 'recoopering']},
 'recooper': {'recooperate': []},
 'recoordin': {'recoordinate': ['recoordinated'],
               'recoordinating': [],
               'recoordination': []},
 'recoordinate': ['recoordinated'],
 'recop': {'recope': []},
 'recopi': {'recopie': ['recopier', 'recopies', 'recopied'],
            'recopy': ['recopying', 'recopyings']},
 'recopie': ['recopier', 'recopies', 'recopied'],
 'recopil': {'recopilation': []},
 'recopilacion': {'recopilaciones': []},
 'recopilada': {'recopiladas': []},
 'recopilado': {'recopilados': []},
 'recopn': {'recopnize': ['recopnized']},
 'recopnize': ['recopnized'],
 'recopoli': {'recopolis': []},
 'recopp': {'recopper': ['recoppered', 'recoppering']},
 'recopper': ['recoppered', 'recoppering'],
 'recopt': {'recoption': []},
 'recopy': ['recopying', 'recopyings'],
 'recopyright': {'recopyrighted': []},
 'recoqn': {'recoqnize': ['recoqnized']},
 'recoqnit': {'recoqnition': []},
 'recoqnize': ['recoqnized'],
 'recor': {'recore': ['recores', 'recorer', 'recored', 'recoreds', 'recorered'],
           'recoring': [],
           'recors': []},
 'recora': {'recoraed': [], 'recoras': []},
 'recoramend': {'recoramended': []},
 'recoranend': {'recoranended': []},
 'recorap': {'recorapence': []},
 'recorc': {'recorced': [], 'recorcs': []},
 'record': ['recorde',
            'recordes',
            'recorder',
            'recorded',
            'recordal',
            'recordals',
            'recording',
            'recordant',
            'recordness',
            'recordance',
            'recordable',
            'recordator',
            'recordered',
            'recordering',
            'recordation',
            'recordables',
            'recordative',
            'recordations',
            'recordability'],
 'record-c': {'record-cou': []},
 'recordaberi': {'recordaberis': []},
 'recordacion': {'recordacione': ['recordaciones']},
 'recordacione': ['recordaciones'],
 'recordacioni': {'recordacionis': []},
 'recordaco': {'recordacoes': []},
 'recordada': {'recordadas': []},
 'recordado': {'recordados': []},
 'recordal': {'recordall': []},
 'recordamo': {'recordamos': []},
 'recordan': {'recordans': []},
 'recordandol': {'recordandole': []},
 'recordant': {'recordantes': []},
 'recordanti': {'recordantis': []},
 'recordar': {'recordare': ['recordarer']},
 'recordare': ['recordarer'],
 'recordaremo': {'recordaremos': []},
 'recordari': {'recordaris': []},
 'recordarl': {'recordarle': ['recordarles']},
 'recordarla': {'recordarlas': []},
 'recordarle': ['recordarles'],
 'recordarlo': {'recordarlos': []},
 'recordarm': {'recordarme': []},
 'recordarno': {'recordarnos': []},
 'recordars': {'recordarse': []},
 'recordart': {'recordarte': []},
 'recordat': {'recordats': []},
 'recordation': {'recordatione': ['recordationes']},
 'recordatione': ['recordationes'],
 'recordationi': {'recordationis': []},
 'recordatorio': {'recordatorios': []},
 'recordatu': {'recordatus': []},
 'recordbas': {'recordbased': []},
 'recordbi': {'recordby': []},
 'recordbook': {'recordbooks': []},
 'recordbreak': {'recordbreaker': ['recordbreakers'], 'recordbreaking': []},
 'recordbreaker': ['recordbreakers'],
 'recordbuy': {'recordbuyers': [], 'recordbuying': []},
 'recordchang': {'recordchanger': []},
 'recordchangecomplet': {'recordchangecomplete': []},
 'recordcompani': {'recordcompany': []},
 'recordcompar': {'recordcomparator': []},
 'recordedbi': {'recordedby': []},
 'recordedli': {'recordedly': []},
 'recordedmus': {'recordedmusic': []},
 'recordemo': {'recordemos': []},
 'recordenumer': {'recordenumeration': []},
 'recordercontrol': {'recordercontroller': []},
 'recorderi': {'recorderis': []},
 'recorderlik': {'recorderlike': []},
 'recorderplay': {'recorderplayer': []},
 'recordership': {'recorderships': []},
 'recordfactori': {'recordfactory': []},
 'recordfilt': {'recordfilter': []},
 'recordhold': {'recordholder': ['recordholders'], 'recordholding': []},
 'recordholder': ['recordholders'],
 'recordhous': {'recordhouse': []},
 'recordi': {'recordier': [], 'recordis': []},
 'recordimet': {'recordimeter': []},
 'recordin': {'recordins': []},
 'recordindustri': {'recordindustry': []},
 'recording': {'recordinge': []},
 'recordingmodul': {'recordingmodule': []},
 'recordingth': {'recordingthe': []},
 'recordist': {'recordists': []},
 'recordit': {'recordite': ['recordites']},
 'recordite': ['recordites'],
 'recordkeep': {'recordkeeper': ['recordkeepers'], 'recordkeeping': []},
 'recordkeeper': ['recordkeepers'],
 'recordlik': {'recordlike': []},
 'recordlinkag': {'recordlinkage': []},
 'recordlng': {'recordlngs': []},
 'recordlock': {'recordlocking': [], 'recordlocks': []},
 'recordmak': {'recordmaker': ['recordmakers'], 'recordmaking': []},
 'recordmaker': ['recordmakers'],
 'recordmg': {'recordmgs': []},
 'recordnam': {'recordname': []},
 'recordnumb': {'recordnumber': []},
 'recordoffic': {'recordoffice': []},
 'recordomat': {'recordomatic': []},
 'recordori': {'recordoriented': []},
 'recordplay': {'recordplayer': ['recordplayers'], 'recordplaying': []},
 'recordplayer': ['recordplayers'],
 'recordretent': {'recordretention': []},
 'records': {'recordsize': ['recordsized']},
 'recordsaffect': {'recordsaffected': []},
 'recordsar': {'recordsare': []},
 'recordselector': {'recordselectors': []},
 'recordsen': {'recordsenate': []},
 'recordset': {'recordsets': [], 'recordsetting': []},
 'recordsetclon': {'recordsetclone': []},
 'recordsett': {'recordsetter': []},
 'recordsettyp': {'recordsettype': []},
 'recordshatt': {'recordshattering': []},
 'recordsize': ['recordsized'],
 'recordskeep': {'recordskeeping': []},
 'recordsmanag': {'recordsmanagement': []},
 'recordsmash': {'recordsmashing': []},
 'recordsofth': {'recordsofthe': []},
 'recordsourc': {'recordsource': []},
 'recordsth': {'recordsthe': []},
 'recordstor': {'recordstore': []},
 'recordtak': {'recordtaking': []},
 'recordth': {'recordthe': []},
 'recordti': {'recordtying': []},
 'recordtyp': {'recordtype': []},
 'recordvoc': {'recordvocational': []},
 'recordwis': {'recordwise': []},
 'recordyng': {'recordynge': []},
 'recore': ['recores', 'recorer', 'recored', 'recoreds', 'recorered'],
 'recored': {'recoreded': []},
 'recoreri': {'recorery': []},
 'recorgan': {'recorganized': []},
 'recorgn': {'recorgnized': []},
 'recork': {'recorked': [], 'recorking': [], 'recorks': []},
 'recormaiss': {'recormaissance': []},
 'recormend': {'recormended': []},
 'recormnend': {'recormnendation': ['recormnendations'],
                'recormnended': [],
                'recormnends': []},
 'recormnendation': ['recormnendations'],
 'recorn': {'recornered': [], 'recornized': []},
 'recornit': {'recornition': []},
 'recornmend': {'recornmendation': ['recornmendations'], 'recornmended': []},
 'recornmendation': ['recornmendations'],
 'recornp': {'recornpence': []},
 'recoro': {'recoroed': [], 'recoroer': [], 'recoroing': [], 'recoros': []},
 'recoron': {'recoronation': []},
 'recorop': {'recoropence': []},
 'recorp': {'recorps': []},
 'recorpor': {'recorporation': []},
 'recorr': {'recorre': ['recorrer']},
 'recorre': ['recorrer'],
 'recorrect': {'recorrected': [],
               'recorrecting': [],
               'recorrection': ['recorrections'],
               'recorrects': []},
 'recorrection': ['recorrections'],
 'recorrel': {'recorrelate': ['recorrelated'], 'recorrelation': []},
 'recorrelate': ['recorrelated'],
 'recorremo': {'recorremos': []},
 'recorrent': {'recorrente': ['recorrentes']},
 'recorrente': ['recorrentes'],
 'recorrida': {'recorridas': []},
 'recorrido': {'recorridos': []},
 'recorrimend': {'recorrimended': []},
 'recorrimo': {'recorrimos': []},
 'recorrmend': {'recorrmended': []},
 'recorrobor': {'recorroborated': []},
 'recorrunend': {'recorrunendations': [], 'recorrunended': []},
 'recorrupt': {'recorrupted': []},
 'recors': {'recorse': []},
 'recort': {'recorte': ['recorted', 'recortes'], 'recorts': []},
 'recortada': {'recortadas': []},
 'recortado': {'recortados': []},
 'recorte': ['recorted', 'recortes'],
 'recoru': {'recorued': [], 'recorus': []},
 'recorv': {'recorvered': []},
 'recorveri': {'recorvery': []},
 'recorvit': {'recorvits': []},
 'recosn': {'recosnized': []},
 'recosnit': {'recosnition': []},
 'recost': {'recosted': [], 'recosting': []},
 'recostada': {'recostadas': []},
 'recostado': {'recostados': []},
 'recostruct': {'recostruction': []},
 'recostruzion': {'recostruzione': []},
 'recostum': {'recostume': ['recostumed'], 'recostuming': []},
 'recostume': ['recostumed'],
 'recot': {'recoter': ['recotered']},
 'recotd': {'recotded': [], 'recotds': []},
 'recoter': ['recotered'],
 'recoteri': {'recotery': []},
 'recotnp': {'recotnpence': []},
 'recou': {'recous': []},
 'recouch': {'recouched': []},
 'recoucil': {'recoucile': ['recouciled']},
 'recoucile': ['recouciled'],
 'recoudr': {'recoudre': []},
 'recouect': {'recouection': ['recouections']},
 'recouection': ['recouections'],
 'recouer': {'recouered': [], 'recouering': [], 'recouers': []},
 'recoueri': {'recouerie': [], 'recouery': []},
 'recouery': {'recouerye': []},
 'recouet': {'recouets': []},
 'recouis': {'recouise': []},
 'recoul': {'recoules': []},
 'recouli': {'recouly': []},
 'recounoiss': {'recounoissance': []},
 'recounoit': {'recounoiter': ['recounoitering']},
 'recounoiter': ['recounoitering'],
 'recounr': {'recounred': []},
 'recount': ['recounte',
             'recounter',
             'recountal',
             'recounted',
             'recounting',
             'recounters',
             'recountals',
             'recountered',
             'recountable',
             'recountments',
             'recountability'],
 'recountri': {'recountry': []},
 'recoup': {'recoupability': [],
            'recoupable': [],
            'recoupant': [],
            'recoupe': ['recouper',
                        'recouped',
                        'recoupes',
                        'recoupent',
                        'recoupement',
                        'recoupements',
                        'recouperative'],
            'recouping': [],
            'recoupment': ['recoupments'],
            'recoups': []},
 'recoupe': {'recoupee': ['recoupees']},
 'recoupee': ['recoupees'],
 'recouper': {'recouperate': ['recouperated'],
              'recouperating': [],
              'recouperation': []},
 'recouperate': ['recouperated'],
 'recoupl': {'recouple': ['recoupled', 'recouples'],
             'recoupling': ['recouplings']},
 'recouple': ['recoupled', 'recouples'],
 'recoupling': ['recouplings'],
 'recoupment': ['recoupments'],
 'recour': {'recourant': [],
            'recoure': ['recoured', 'recourent'],
            'recours': []},
 'recourai': {'recouraient': []},
 'recourb': {'recourbant': [], 'recourbe': ['recourbes', 'recourbent']},
 'recourbe': {'recourbee': ['recourbees']},
 'recourbee': ['recourbees'],
 'recourc': {'recource': ['recources']},
 'recource': ['recources'],
 'recoure': ['recoured', 'recourent'],
 'recourf': {'recourfe': []},
 'recouri': {'recourie': []},
 'recourl': {'recourle': []},
 'recouron': {'recourons': []},
 'recours': {'recourse': ['recoursed', 'recoursers'], 'recoursing': []},
 'recourse': ['recoursed', 'recoursers'],
 'recourso': {'recoursos': []},
 'recous': {'recouse': []},
 'recouss': {'recousse': []},
 'recoustitut': {'recoustitution': []},
 'recouts': {'recoutse': []},
 'recouur': {'recouurer': []},
 'recouv': {'recouvered': []},
 'recouvert': {'recouverte': ['recouvertes'], 'recouverts': []},
 'recouverte': ['recouvertes'],
 'recouvr': {'recouvrable': ['recouvrables'],
             'recouvrance': [],
             'recouvrant': [],
             'recouvre': ['recouvrer',
                          'recouvres',
                          'recouvrent',
                          'recouvrement',
                          'recouvrements']},
 'recouvrable': ['recouvrables'],
 'recouvrai': {'recouvraient': []},
 'recouvre': {'recouvree': ['recouvrees']},
 'recouvree': ['recouvrees'],
 'recouvremen': {'recouvremens': []},
 'recov': {'recovable': [],
           'recovation': [],
           'recove': ['recover',
                      'recoved',
                      'recovers',
                      'recovered',
                      'recovering',
                      'recoverings'],
           'recoving': []},
 "recov'ri": {"recov'ry": []},
 'recovari': {'recovary': []},
 'recovcri': {'recovcry': []},
 'recove': ['recover',
            'recoved',
            'recovers',
            'recovered',
            'recovering',
            'recoverings'],
 'recoveco': {'recovecos': []},
 'recovei': {'recoveied': [], 'recoveiing': []},
 'recoven': {'recovenanting': []},
 'recover': {'recoverability': [],
             'recoverable': ['recoverables', 'recoverableness'],
             'recoverably': [],
             'recoverance': [],
             'recovere': ['recoveres', 'recoverer']},
 'recoverabiliri': {'recoverabiliry': []},
 'recoverable': ['recoverables', 'recoverableness'],
 'recoverag': {'recoverage': []},
 'recoverahl': {'recoverahle': []},
 'recovere': {'recoveree': ['recoverees']},
 'recoveredmemori': {'recoveredmemory': []},
 'recoveree': ['recoverees'],
 'recoveri': {'recoverie': [], 'recovery': ['recoverying']},
 'recovering': {'recoveringe': []},
 'recoveror': {'recoverors': []},
 'recovers': {'recoversion': []},
 'recoverth': {'recoverthe': []},
 'recovery': {'recoverye': []},
 'recoveryi': {'recoveryis': []},
 'recoveryori': {'recoveryoriented': []},
 'recoveryr': {'recoveryrate': []},
 'recoveryrel': {'recoveryrelated': []},
 'recoverywa': {'recoverywas': []},
 'recovet': {'recoveting': []},
 'recoveti': {'recovety': []},
 'recovor': {'recovored': []},
 'recovori': {'recovory': []},
 'recovr': {'recovred': [], 'recovrer': [], 'recovring': []},
 'recovri': {'recovry': []},
 'recoy': {'recoyer': ['recoyered']},
 'recoyer': ['recoyered'],
 'recoyeri': {'recoyery': []},
 'recoyl': {'recoyle': ['recoyles', 'recoyled'], 'recoyling': []},
 'recoyle': ['recoyles', 'recoyled'],
 'recp': {'recps': []},
 'recpair': {'recpaired': [], 'recpaires': []},
 'recpect': {'recpective': ['recpectively']},
 'recpective': ['recpectively'],
 'recpen': {'recpened': []},
 'recpent': {'recpents': []},
 'recpetor': {'recpetors': []},
 'recpgniz': {'recpgnize': ['recpgnized']},
 'recpgnize': ['recpgnized'],
 'recpient': {'recpients': []},
 'recpiest': {'recpiested': []},
 'recpiir': {'recpiire': ['recpiired', 'recpiires', 'recpiirements'],
             'recpiiring': []},
 'recpiire': ['recpiired', 'recpiires', 'recpiirements'],
 'recpiisit': {'recpiisite': []},
 'recpiv': {'recpived': []},
 'recpjir': {'recpjired': []},
 'recpmmend': {'recpmmended': []},
 'recprd': {'recprded': [], 'recprds': []},
 'recpt': {'recpts': []},
 'recptacl': {'recptacle': []},
 'recptor': {'recptors': []},
 'recpuir': {'recpuire': ['recpuired', 'recpuires']},
 'recpuire': ['recpuired', 'recpuires'],
 'recpver': {'recpvered': []},
 'recpveri': {'recpvery': []},
 'recqgniz': {'recqgnized': []},
 'recqrd': {'recqrds': []},
 'recqu': {'recques': []},
 'recquigni': {'recquignies': []},
 'recquir': {'recquire': ['recquires', 'recquired']},
 'recquire': ['recquires', 'recquired'],
 'recr': {'recre': ['recreative',
                    'recreatives',
                    'recreativity',
                    'recreatively',
                    'recreativeness']},
 'recrack': {'recracked': [], 'recracking': []},
 'recradl': {'recradled': []},
 'recraft': {'recrafted': [], 'recrafting': [], 'recrafts': []},
 'recrank': {'recranked': []},
 'recrat': {'recrate': ['recrated'],
            'recrating': [],
            'recration': ['recrational']},
 'recrate': ['recrated'],
 'recration': ['recrational'],
 'recrd': {'recrds': []},
 'recre': {'recree': []},
 'recrea': {'recreas': []},
 'recreacion': {'recreaciones': [], 'recreacions': []},
 'recreacioni': {'recreacionis': []},
 'recreact': {'recreaction': ['recreactional']},
 'recreaction': ['recreactional'],
 'recrean': {'recreans': []},
 'recreanc': {'recreance': [], 'recreancy': []},
 'recreando': {'recreandos': []},
 'recreant': {'recreant': []},
 'recreantis': {'recreantise': []},
 'recreantli': {'recreantly': []},
 'recrear': {'recreare': []},
 'recrearion': {'recrearional': []},
 'recrears': {'recrearse': []},
 'recreas': {'recrease': ['recreased'], 'recreasing': []},
 'recrease': ['recreased'],
 'recreat': {'recreatable': [],
             'recreate': ['recreated', 'recreates'],
             'recreatic': [],
             'recreating': [],
             'recreation': ['recreational', 'recreationals', 'recreationally'],
             'recreator': ['recreators']},
 'recreate': ['recreated', 'recreates'],
 'recreati': {'recreatie': [], 'recreatiou': [], 'recreatis': []},
 'recreatiev': {'recreatieve': []},
 'recreatif': {'recreatifs': []},
 'recreation': {'recreatione': ['recreationes', 'recreationers']},
 'recreationalist': {'recreationalists': []},
 'recreationari': {'recreationary': []},
 'recreatione': ['recreationes', 'recreationers'],
 'recreationground': {'recreationgrounds': []},
 'recreationi': {'recreationis': []},
 'recreationist': {'recreationists': []},
 'recreationori': {'recreationoriented': []},
 'recreationrel': {'recreationrelated': []},
 'recreationroom': {'recreationrooms': []},
 'recreatiu': {'recreatiue': []},
 'recreativa': {'recreativas': []},
 'recreativo': {'recreativos': []},
 'recreatlon': {'recreatlonal': []},
 'recreaton': {'recreatonal': []},
 'recreator': ['recreators'],
 'recreatori': {'recreatory': []},
 'recreatu': {'recreatus': []},
 'recreazion': {'recreazione': []},
 'recrec': {'recrecer': []},
 'recred': {'recredence': []},
 'recredenti': {'recredential': ['recredentials',
                                 'recredentialed',
                                 'recredentialing']},
 'recredential': ['recredentials', 'recredentialed', 'recredentialing'],
 'recreder': {'recredere': []},
 'recredit': {'recredited': [], 'recrediting': [], 'recredits': []},
 'recree': {'recreee': []},
 'recreet': {'recreetion': []},
 'recreio': {'recreios': []},
 'recrem': {'recremated': []},
 'recrement': {'recremental': [], 'recrements': []},
 'recrementiti': {'recrementitial': [], 'recrementitious': []},
 'recreo': {'recreos': []},
 'recreol': {'recreolization': []},
 'recreolog': {'recreology': []},
 'recreot': {'recreotion': []},
 'recresc': {'recrescence': []},
 'recret': {'recretion': ['recretional']},
 'recretari': {'recretary': []},
 'recretion': ['recretional'],
 'recreu': {'recreus': []},
 'recrgan': {'recrganization': [], 'recrganize': ['recrganized']},
 'recrganis': {'recrganisation': []},
 'recrganize': ['recrganized'],
 'recri': {'recrie': [], 'recry': ['recrys']},
 'recrimin': {'recriminalization': [],
              'recriminalize': ['recriminalized'],
              'recriminalizing': [],
              'recriminate': ['recriminates', 'recriminated'],
              'recriminating': ['recriminatings'],
              'recrimination': [],
              'recriminative': [],
              'recriminator': ['recriminators']},
 'recriminacion': {'recriminaciones': []},
 'recriminalis': {'recriminalisation': [], 'recriminalised': []},
 'recriminalize': ['recriminalized'],
 'recriminate': ['recriminates', 'recriminated'],
 'recriminating': ['recriminatings'],
 'recriminatingli': {'recriminatingly': []},
 'recriminator': ['recriminators'],
 'recriminatori': {'recriminatory': []},
 'recrimp': {'recrimped': []},
 'recripoc': {'recripocal': []},
 'recriproc': {'recriprocal': [], 'recriprocating': [], 'recriprocity': []},
 'recrir': {'recrire': []},
 'recrirnin': {'recrirninations': []},
 'recrisp': {'recrisped': []},
 'recristal': {'recristallization': [], 'recristallized': []},
 'recristallis': {'recristallisation': ['recristallisations'],
                  'recristallise': []},
 'recristallisation': ['recristallisations'],
 'recristallise': {'recristallisee': []},
 'recrit': {'recriticality': []},
 'recritic': {'recriticism': []},
 'recritur': {'recriture': []},
 'recriut': {'recriutment': []},
 'recriv': {'recrived': []},
 'recrnit': {'recrnited': [], 'recrnits': []},
 'recrod': {'recroded': [], 'recrods': []},
 'recroir': {'recroire': []},
 'recrop': {'recropped': [], 'recropping': []},
 'recroquevil': {'recroqueville': ['recroqueviller']},
 'recroqueville': ['recroqueviller'],
 'recross': {'recrossed': [], 'recrosses': [], 'recrossing': ['recrossings']},
 'recrossc': {'recrosscs': []},
 'recrossing': ['recrossings'],
 'recrown': {'recrowned': [], 'recrowning': [], 'recrowns': []},
 'recru': {'recrue': ['recrues'], 'recrus': []},
 'recrucifi': {'recrucified': [], 'recrucify': ['recrucifying']},
 'recrucify': ['recrucifying'],
 'recrud': {'recrudence': [], 'recrudes': []},
 'recrudes': {'recrudesence': []},
 'recrudesc': {'recrudesce': ['recrudesced',
                              'recrudesces',
                              'recrudescent',
                              'recrudescency',
                              'recrudescence'],
               'recrudescing': []},
 'recrudesce': ['recrudesced',
                'recrudesces',
                'recrudescent',
                'recrudescency',
                'recrudescence'],
 'recrudescen': {'recrudescene': []},
 'recrudescens': {'recrudescense': []},
 'recrudescent': {'recrudescente': []},
 'recrue': ['recrues'],
 'recruinn': {'recruinnent': []},
 'recruir': {'recruire': ['recruired']},
 'recruire': ['recruired'],
 'recruit': ['recruite',
             'recruited',
             'recruital',
             'recruites',
             'recruiter',
             'recruitted',
             'recruiting',
             'recruitings',
             'recruitment',
             'recruitable',
             'recruitement',
             'recruitability'],
 'recruita': {'recruitaent': []},
 'recruite': {'recruitee': ['recruitees']},
 'recruitee': ['recruitees'],
 'recruiti': {'recruities': [], 'recruity': []},
 'recruitingground': {'recruitinggrounds': []},
 'recruitingoffic': {'recruitingoffice': ['recruitingofficer',
                                          'recruitingofficers']},
 'recruitingoffice': ['recruitingofficer', 'recruitingofficers'],
 'recruitingserg': {'recruitingsergeant': ['recruitingsergeants']},
 'recruitingsergeant': ['recruitingsergeants'],
 'recruitingst': {'recruitingstations': []},
 'recruitn': {'recruitnent': []},
 'recruitor': {'recruitors': []},
 'recruiun': {'recruiunent': []},
 'recrult': {'recrultment': []},
 'recrumpl': {'recrumpled': []},
 'recrush': {'recrushed': [], 'recrushing': []},
 'recrut': {'recrutant': [],
            'recrute': ['recrutes',
                        'recruted',
                        'recruter',
                        'recrutent',
                        'recrutement',
                        'recrutering',
                        'recrutements'],
            'recruting': [],
            'recrutment': [],
            'recruts': []},
 'recrutai': {'recrutaient': []},
 'recrute': {'recrutee': ['recrutees']},
 'recrutee': ['recrutees'],
 'recruteur': {'recruteurs': []},
 'recruti': {'recrutiment': []},
 'recrvstal': {'recrvstallization': [], 'recrvstallized': []},
 'recry': ['recrys'],
 'recryatal': {'recryatallization': [], 'recryatallized': []},
 'recryetal': {'recryetallization': [], 'recryetallized': []},
 'recryslal': {'recryslallization': [], 'recryslallized': []},
 'recryst': {'recrystal': ['recrystalli',
                           'recrystalize',
                           'recrystalizes',
                           'recrystalized',
                           'recrystalizing',
                           'recrystalization',
                           'recrystalizations']},
 'recrystail': {'recrystailization': [], 'recrystailized': []},
 'recrystal': {'recrystall': ['recrystallize',
                              'recrystallizes',
                              'recrystallized',
                              'recrystallation',
                              'recrystallizing',
                              'recrystallization',
                              'recrystallizations']},
 'recrystalhz': {'recrystalhzation': [], 'recrystalhzed': []},
 'recrystali': {'recrystaliization': []},
 'recrystalis': {'recrystalisation': [], 'recrystalised': []},
 'recrystall': ['recrystallize',
                'recrystallizes',
                'recrystallized',
                'recrystallation',
                'recrystallizing',
                'recrystallization',
                'recrystallizations'],
 'recrystallia': {'recrystalliaation': [], 'recrystalliaed': []},
 'recrystallin': {'recrystalline': []},
 'recrystallis': {'recrystallisation': ['recrystallisations'],
                  'recrystallise': ['recrystallised', 'recrystallises'],
                  'recrystallising': []},
 'recrystallisation': ['recrystallisations'],
 'recrystallise': ['recrystallised', 'recrystallises'],
 'recrystalliz': {'recrystallizable': []},
 'recrystallizt': {'recrystalliztion': []},
 'recrystalllz': {'recrystalllzation': [], 'recrystalllzed': []},
 'recrystau': {'recrystauization': [], 'recrystauized': []},
 'recrytal': {'recrytallization': []},
 'recsiv': {'recsive': ['recsived', 'recsives'], 'recsiving': []},
 'recsive': ['recsived', 'recsives'],
 'recsiz': {'recsize': []},
 'recsntli': {'recsntly': []},
 'recstablish': {'recstablishment': []},
 'rect': {'recte': ['rected', 'rectes'],
          'recting': [],
          'rectness': [],
          'rects': []},
 "rect'ri": {"rect'ry": []},
 'recta': {'rectae': [], 'rectas': []},
 'rectabl': {'rectable': []},
 'rectagon': {'rectagonal': []},
 'rectal': {'rectale': ['rectales'], 'rectally': [], 'rectals': []},
 'rectale': ['rectales'],
 'rectali': {'rectalis': []},
 'rectament': {'rectamente': []},
 'rectamqu': {'rectamque': []},
 'rectanc': {'rectance': []},
 'rectang': {'rectange': ['rectanges']},
 'rectange': ['rectanges'],
 'rectangel': {'rectangels': []},
 'rectangi': {'rectangie': []},
 'rectangl': {'rectangle': ['rectangled']},
 'rectangle': ['rectangled'],
 'rectangleshap': {'rectangleshaped': []},
 'rectangt': {'rectangte': []},
 'rectangul': {'rectangulate': ['rectangulated'],
               'rectangulation': [],
               'rectangule': ['rectanguler', 'rectangules']},
 'rectangulair': {'rectangulaire': ['rectangulaires']},
 'rectangulaire': ['rectangulaires'],
 'rectangular': {'rectangulare': ['rectangulares'],
                 'rectangularity': [],
                 'rectangularization': [],
                 'rectangularize': ['rectangularized'],
                 'rectangularizing': [],
                 'rectangulars': []},
 'rectangularcoordin': {'rectangularcoordinate': []},
 'rectangulare': ['rectangulares'],
 'rectangulari': {'rectangularis': []},
 'rectangularibu': {'rectangularibus': []},
 'rectangularis': {'rectangularisation': []},
 'rectangularize': ['rectangularized'],
 'rectangularli': {'rectangularly': []},
 'rectangularlik': {'rectangularlike': []},
 'rectangularsect': {'rectangularsection': ['rectangularsectioned']},
 'rectangularsection': ['rectangularsectioned'],
 'rectangularshap': {'rectangularshaped': []},
 'rectangulate': ['rectangulated'],
 'rectangulatu': {'rectangulatus': []},
 'rectangule': ['rectanguler', 'rectangules'],
 'rectanguli': {'rectangulis': []},
 'rectangulo': {'rectangulos': []},
 'rectangulu': {'rectangulus': []},
 'rectanu': {'rectanus': []},
 'rectaqu': {'rectaque': []},
 'rectascens': {'rectascension': []},
 'rectatu': {'rectatus': []},
 'rectc': {'rectce': []},
 'recte': ['rected', 'rectes'],
 'recteat': {'recteation': ['recteational']},
 'recteation': ['recteational'],
 'rectectomi': {'rectectomy': []},
 'rected': {'rectedness': []},
 'recten': {'rectene': []},
 'rectenna': {'rectennas': []},
 'rectequ': {'recteque': []},
 'recteur': {'recteurs': []},
 'rectf': {'rectfe': []},
 'recth': {'recthe': []},
 'recti': {'rectis': []},
 'rectic': {'rectices': []},
 'recticl': {'recticle': []},
 'recticorni': {'recticornis': []},
 'recticul': {'recticulate': ['recticulated'], 'recticule': []},
 'recticulari': {'recticularis': []},
 'recticulate': ['recticulated'],
 'recticuloendotheli': {'recticuloendothelial': []},
 'rectif': {'rectifed': [],
            'rectifer': ['rectifers'],
            'rectific': ['rectification', 'rectificative', 'rectificatives'],
            'rectifing': []},
 'rectifer': ['rectifers'],
 'rectifi': {'rectifiability': [],
             'rectifiable': [],
             'rectifiant': [],
             'rectifie': ['rectified', 'rectifies', 'rectifier', 'rectifient'],
             'rectify': ['rectifyed', 'rectifying']},
 'rectific': ['rectification', 'rectificative', 'rectificatives'],
 'rectificacion': {'rectificaciones': []},
 'rectificar': {'rectificare': []},
 'rectificatori': {'rectificatory': []},
 'rectificatu': {'rectificatus': []},
 'rectifie': {'rectifiee': ['rectifiees']},
 'rectifiee': ['rectifiees'],
 'rectifierfilt': {'rectifierfilter': []},
 'rectifiertyp': {'rectifiertype': []},
 'rectifiy': {'rectifiying': []},
 'rectifron': {'rectifrons': []},
 'rectift': {'rectifted': []},
 'rectifv': {'rectifving': []},
 'rectify': {'rectifye': ['rectifyer']},
 'rectifye': ['rectifyer'],
 'rectigrad': {'rectigradation': ['rectigradations']},
 'rectigradation': ['rectigradations'],
 'rectil': {'rectile': []},
 'rectilaterali': {'rectilateralis': []},
 'rectili': {'rectilied': []},
 'rectilign': {'rectiligne': ['rectilignes']},
 'rectiligne': ['rectilignes'],
 'rectilin': {'rectiline': ['rectilineal', 'rectilineally']},
 'rectiline': ['rectilineal', 'rectilineally'],
 'rectilinear': {'rectilinearity': [], 'rectilinears': []},
 'rectilinearili': {'rectilinearily': []},
 'rectilinearli': {'rectilinearly': []},
 'rectilinei': {'rectilineis': []},
 'rectilineu': {'rectilineus': []},
 'rectimargin': {'rectimarginate': []},
 'rectimuscl': {'rectimuscles': []},
 'rectinervi': {'rectinervis': []},
 'rection': {'rectional': ['rectionally'], 'rectione': [], 'rections': []},
 'rectional': ['rectionally'],
 'rectionari': {'rectionary': []},
 'rectionist': {'rectionists': []},
 'rectipet': {'rectipetality': []},
 'rectiqu': {'rectique': []},
 'rectiradi': {'rectiradiate': []},
 'rectirostri': {'rectirostris': []},
 'rectis': {'rectisication': []},
 'rectiseri': {'rectiserial': []},
 'rectisi': {'rectisie': ['rectisies', 'rectisied'], 'rectisy': ['rectisying']},
 'rectisie': ['rectisies', 'rectisied'],
 'rectispinu': {'rectispinus': []},
 'rectissim': {'rectissime': []},
 'rectissimi': {'rectissimis': []},
 'rectisy': ['rectisying'],
 'rectiti': {'rectitis': []},
 'rectitnd': {'rectitnde': []},
 'rectitud': {'rectitude': []},
 'rectitudin': {'rectitudinal': [],
                'rectitudine': ['rectitudines'],
                'rectitudinous': []},
 'rectitudine': ['rectitudines'],
 'rectitudini': {'rectitudinis': []},
 'rectitudinibu': {'rectitudinibus': []},
 'rectitut': {'rectitute': []},
 'rectiu': {'rectius': []},
 'rectiusculi': {'rectiusculis': []},
 'rectiv': {'rective': ['rectived', 'rectives'], 'rectivity': []},
 'rective': ['rectived', 'rectives'],
 'rectiw': {'rectiwed': []},
 'rectli': {'rectly': []},
 'rectlon': {'rectlons': []},
 'rectn': {'rectns': []},
 'recto': {'recto': []},
 'rectoabdomin': {'rectoabdominal': []},
 'rectoan': {'rectoanal': []},
 'rectobi': {'rectoby': []},
 'rectoccl': {'rectoccle': []},
 'rectocel': {'rectocele': []},
 'rectocloac': {'rectocloacal': []},
 'rectococcyg': {'rectococcygeal': []},
 'rectococcygeu': {'rectococcygeus': []},
 'rectocoel': {'rectocoele': []},
 'rectocol': {'rectocolic': [], 'rectocolitis': []},
 'rectocolit': {'rectocolite': []},
 'rectocolon': {'rectocolonic': []},
 'rectocutan': {'rectocutaneous': []},
 'rectoeel': {'rectoeele': []},
 'rectogenit': {'rectogenital': []},
 'rectolabi': {'rectolabial': []},
 'rectomi': {'rectomy': []},
 'rectoperin': {'rectoperineal': []},
 'rectoperiton': {'rectoperitoneal': []},
 'rectoplasti': {'rectoplasty': []},
 'rectoprostat': {'rectoprostatic': []},
 'rectoqu': {'rectoque': []},
 'rector': ['rectore', 'rectoral', 'rectores', 'rectorate'],
 'rectora': {'rectoras': []},
 'rectorado': {'rectorados': []},
 'rectorat': {'rectorats': []},
 'rectoratsred': {'rectoratsrede': []},
 'rectorect': {'rectorectal': []},
 'rectoremqu': {'rectoremque': []},
 'rectoresqu': {'rectoresque': []},
 'rectori': {'rectorial': [], 'rectorie': [], 'rectoris': [], 'rectory': []},
 'rectoria': {'rectoriae': [], 'rectorias': []},
 'rectoribu': {'rectoribus': []},
 'rectorii': {'rectoriis': []},
 'rectoriqu': {'rectorique': []},
 'rectorit': {'rectorite': []},
 'rectorqu': {'rectorque': []},
 'rectorship': {'rectorship': []},
 'rectory': {'rectorye': []},
 'rectoryhous': {'rectoryhouse': []},
 'rectorynam': {'rectoryname': []},
 'rectosacr': {'rectosacral': []},
 'rectoscop': {'rectoscope': ['rectoscopes'], 'rectoscopic': []},
 'rectoscope': ['rectoscopes'],
 'rectoscopi': {'rectoscopy': []},
 'rectosigmoid': {'rectosigmoidal': [], 'rectosigmoiditis': []},
 'rectosigmoidectomi': {'rectosigmoidectomy': []},
 'rectosigmoidoscopi': {'rectosigmoidoscopy': []},
 'rectosphincter': {'rectosphincteric': []},
 'rectostomi': {'rectostomy': []},
 'rectotomi': {'rectotomy': []},
 'rectourethr': {'rectourethral': []},
 'rectourethrali': {'rectourethralis': []},
 'rectourinari': {'rectourinary': []},
 'rectouterin': {'rectouterine': []},
 'rectovagin': {'rectovaginal': []},
 'rectoves': {'rectovesical': []},
 'rectovesicali': {'rectovesicalis': []},
 'rectovesicl': {'rectovesicle': []},
 'rectract': {'rectractable': []},
 'rectractil': {'rectractile': []},
 'rectric': {'rectrice': ['rectrices']},
 'rectrice': ['rectrices'],
 'rectricibu': {'rectricibus': []},
 'rectricibusqu': {'rectricibusque': []},
 'rectrict': {'rectricted': [], 'rectrictions': []},
 'rects': {'rectse': []},
 'rectti': {'rectty': []},
 'rectu': {'rectus': []},
 'rectuir': {'rectuired': [], 'rectuirment': []},
 'rectuit': {'rectuited': [],
             'rectuiting': [],
             'rectuitment': [],
             'rectuits': []},
 'rectul': {'rectules': []},
 'rectum': {'rectum': []},
 'rectumn': {'rectumne': []},
 'rectumqu': {'rectumque': []},
 'recturu': {'recturus': []},
 'rectvis': {'rectvisible': []},
 'rectyp': {'rectype': []},
 'recu': {'recue': ['recued', 'recues'], 'recuing': [], 'recus': []},
 'recua': {'recuas': []},
 'recub': {'recubant': [], 'recubation': []},
 'recubamu': {'recubamus': []},
 'recuban': {'recubans': []},
 'recubanti': {'recubantis': []},
 'recubantibu': {'recubantibus': []},
 'recubar': {'recubare': []},
 'recubierta': {'recubiertas': []},
 'recubierto': {'recubiertos': []},
 'recubr': {'recubre': []},
 'recuc': {'recuce': ['recuced']},
 'recuce': ['recuced'],
 'recucrdo': {'recucrdos': []},
 'recuct': {'recuction': []},
 'recud': {'recuded': []},
 'recue': ['recued', 'recues'],
 'recueil': {'recueillant': [],
             'recueille': ['recueilles',
                           'recueiller',
                           'recueillent',
                           'recueillement',
                           'recueillements'],
             'recueils': []},
 'recueild': {'recueilde': ['recueildes']},
 'recueilde': ['recueildes'],
 'recueillai': {'recueillaient': []},
 'recueille': ['recueilles',
               'recueiller',
               'recueillent',
               'recueillement',
               'recueillements'],
 'recueilli': {'recueillie': ['recueillies'],
               'recueillis': [],
               'recueilly': []},
 'recueillie': ['recueillies'],
 'recueillir': {'recueillirent': []},
 'recueillit': {'recueillites': []},
 'recueillon': {'recueillons': []},
 'recuel': {'recuell': []},
 'recuelli': {'recuellies': [], 'recuellis': []},
 'recuento': {'recuentos': []},
 'recuentro': {'recuentros': []},
 'recuerd': {'recuerde': ['recuerdes']},
 'recuerda': {'recuerdas': []},
 'recuerde': ['recuerdes'],
 'recuerdes': {'recuerdese': []},
 'recuerdo': {'recuerdos': []},
 'recuest': {'recuested': []},
 'recuf': {'recufants': [], 'recuffed': []},
 'recuilli': {'recuillies': [], 'recuillis': [], 'recuilly': []},
 'recuir': {'recuire': ['recuired', 'recuires', 'recuirement', 'recuirements'],
            'recuiring': []},
 'recuire': ['recuired', 'recuires', 'recuirement', 'recuirements'],
 'recuit': {'recuite': ['recuited', 'recuiter', 'recuiters'],
            'recuiting': [],
            'recuitment': [],
            'recuits': []},
 'recuite': ['recuited', 'recuiter', 'recuiters'],
 'recul': {'reculant': [],
           'recule': ['reculed',
                      'reculer',
                      'recules',
                      'reculent',
                      'reculement'],
           'recull': ['reculled'],
           'reculs': []},
 'recula': {'reculas': []},
 'reculad': {'reculade': []},
 'reculai': {'reculaient': []},
 'recule': {'reculee': ['reculees']},
 'reculee': ['reculees'],
 'reculfu': {'reculfus': []},
 'reculi': {'reculis': []},
 'recull': ['reculled'],
 'reculon': {'reculons': []},
 'recult': {'recults': []},
 'recultiv': {'recultivate': ['recultivated'],
              'recultivating': [],
              'recultivation': ['recultivations']},
 'recultivate': ['recultivated'],
 'recultivation': ['recultivations'],
 'recultur': {'reculturalization': [],
              'reculturation': [],
              'reculture': ['recultures', 'recultured'],
              'reculturing': [],
              'reculturization': []},
 'reculture': ['recultures', 'recultured'],
 'reculv': {'reculver': ['reculvers']},
 'reculver': ['reculvers'],
 'recum': {'recumes': []},
 'recumb': {'recumbancy': [],
            'recumbant': [],
            'recumbence': [],
            'recumbencies': [],
            'recumbency': [],
            'recumbent': ['recumbents', 'recumbently']},
 'recumben': {'recumbens': []},
 'recumbent': {'recumbentes': []},
 'recumbentibu': {'recumbentibus': []},
 'recumber': {'recumbere': []},
 'recumbi': {'recumbis': []},
 'recumh': {'recumhent': []},
 'recun': {'recunence': [], 'recunent': [], 'recuning': []},
 'recup': {'recupe': ['recuper',
                      'recuperative',
                      'recuperatives',
                      'recuperatively',
                      'recuperativeness'],
           'recupping': []},
 'recupe': ['recuper',
            'recuperative',
            'recuperatives',
            'recuperatively',
            'recuperativeness'],
 'recupel': {'recupellation': [], 'recupelled': []},
 'recuper': {'recuperability': [],
             'recuperable': ['recuperables'],
             'recuperant': [],
             'recuperate': ['recuperates', 'recuperated'],
             'recuperating': [],
             'recuperation': [],
             'recuperator': ['recuperators'],
             'recupere': ['recuperer', 'recuperes', 'recuperent']},
 'recuperable': ['recuperables'],
 'recuperacion': {'recuperacione': ['recuperaciones']},
 'recuperacione': ['recuperaciones'],
 'recuperada': {'recuperadas': []},
 'recuperado': {'recuperados': []},
 'recuperamo': {'recuperamos': []},
 'recuperand': {'recuperande': []},
 'recuperanda': {'recuperandae': [], 'recuperandas': []},
 'recuperandi': {'recuperandis': []},
 'recuperar': {'recuperare': ['recuperarent']},
 'recuperare': ['recuperarent'],
 'recuperars': {'recuperarse': []},
 'recuperass': {'recuperasse': []},
 'recuperata': {'recuperatae': [], 'recuperatas': []},
 'recuperate': ['recuperates', 'recuperated'],
 'recuperati': {'recuperatis': []},
 'recuperation': {'recuperatione': ['recuperationes']},
 'recuperatione': ['recuperationes'],
 'recuperationi': {'recuperationis': []},
 'recuperator': {'recuperatores': []},
 'recuperatori': {'recuperatory': []},
 'recuperatoribu': {'recuperatoribus': []},
 'recuperavimu': {'recuperavimus': []},
 'recupere': {'recuperee': ['recuperees']},
 'recuperee': ['recuperees'],
 'recur': {'recure': ['recured',
                      'recures',
                      'recurent',
                      'recurence',
                      'recurences'],
           'recuring': [],
           'recurity': [],
           'recurred': [],
           'recurring': [],
           'recurs': []},
 'recurar': {'recurarization': []},
 'recurb': {'recurbed': [], 'recurbing': []},
 'recurd': {'recurded': [], 'recurds': []},
 'recure': ['recured', 'recures', 'recurent', 'recurence', 'recurences'],
 'recurettag': {'recurettage': []},
 'recurit': {'recurited': [],
             'recuriting': [],
             'recuritment': [],
             'recurits': []},
 'recurl': {'recurled': [], 'recurling': []},
 'recurn': {'recurned': []},
 'recuro': {'recuros': []},
 'recurr': {'recurrable': [],
            'recurrance': ['recurrances'],
            'recurrant': [],
            'recurre': ['recurrent',
                        'recurrence',
                        'recurrents',
                        'recurrency',
                        'recurrently',
                        'recurrencies'],
            'recurrring': [],
            'recurrs': []},
 'recurra': {'recurras': []},
 'recurramu': {'recurramus': []},
 'recurrance': ['recurrances'],
 'recurre': ['recurrent',
             'recurrence',
             'recurrents',
             'recurrency',
             'recurrently',
             'recurrencies'],
 'recurren': {'recurrens': []},
 'recurrencefre': {'recurrencefree': []},
 'recurrendi': {'recurrendy': []},
 'recurrene': {'recurrenee': []},
 'recurrenli': {'recurrenlis': []},
 'recurrent': {'recurrente': ['recurrentes']},
 'recurrente': ['recurrentes'],
 'recurrenti': {'recurrential': [], 'recurrentis': []},
 'recurrentibu': {'recurrentibus': []},
 'recurrer': {'recurrere': []},
 'recurrimo': {'recurrimos': []},
 'recurrimu': {'recurrimus': []},
 'recurringli': {'recurringly': []},
 'recurrirs': {'recurrirse': []},
 'recurrr': {'recurrrence': [], 'recurrrent': []},
 'recurs': {'recurse': ['recursed', 'recurses'],
            'recursing': [],
            'recursion': [],
            'recursive': ['recursives', 'recursively', 'recursiveness'],
            'recursivities': [],
            'recursivity': []},
 'recurse': ['recursed', 'recurses'],
 'recursive': ['recursives', 'recursively', 'recursiveness'],
 'recursivedesc': {'recursivedescent': []},
 'recursivit': {'recursivite': []},
 'recurso': {'recursos': []},
 'recursor': {'recursors': []},
 'recursu': {'recursus': []},
 'recurt': {'recurting': []},
 'recurv': {'recurvate': ['recurvated'],
            'recurvation': [],
            'recurve': ['recurves', 'recurved'],
            'recurving': []},
 'recurva': {'recurvae': []},
 'recurvali': {'recurvalis': []},
 'recurvan': {'recurvans': []},
 'recurvate': ['recurvated'],
 'recurvati': {'recurvatis': []},
 'recurvatu': {'recurvatus': []},
 'recurvatur': {'recurvature': ['recurvatures']},
 'recurvature': ['recurvatures'],
 'recurve': ['recurves', 'recurved'],
 'recurvi': {'recurvis': []},
 'recurvirostri': {'recurvirostris': []},
 'recurvirostrida': {'recurvirostridae': []},
 'recurvoid': {'recurvoides': []},
 'recurvu': {'recurvus': []},
 'recus': {'recusable': [],
           'recusal': [],
           'recusance': [],
           'recusancy': [],
           'recusant': [],
           'recusation': [],
           'recuse': ['recused', 'recuses', 'recuser', 'recusent'],
           'recusing': [],
           'recusion': [],
           'recusive': ['recusively']},
 'recusa': {'recusas': []},
 'recusab': {'recusabant': []},
 'recusabimu': {'recusabimus': []},
 'recusamu': {'recusamus': []},
 'recusan': {'recusans': []},
 'recusanci': {'recusancie': []},
 'recusant': {'recusante': ['recusantes']},
 'recusante': ['recusantes'],
 'recusanti': {'recusantis': []},
 'recusantibu': {'recusantibus': []},
 'recusar': {'recusare': ['recusarent']},
 'recusare': ['recusarent'],
 'recusass': {'recusasse': []},
 'recusati': {'recusatis': []},
 'recusation': {'recusatione': ['recusationes']},
 'recusatione': ['recusationes'],
 'recusationi': {'recusationis': []},
 'recuscit': {'recuscitate': [], 'recuscitation': []},
 'recuse': {'recusee': []},
 'recushion': {'recushioned': []},
 'recusive': ['recusively'],
 'recuss': {'recussent': []},
 'recustom': {'recustomize': []},
 'recusu': {'recusus': []},
 'recut': {'recutes': [],
           'recution': [],
           'recuts': [],
           'recutting': ['recuttings']},
 'recutitaqu': {'recutitaque': []},
 'recutr': {'recutrence': [], 'recutrent': []},
 'recutt': {'recutter': []},
 'recutting': ['recuttings'],
 'recuu': {'recuus': []},
 'recuvv': {'recuvver': []},
 'recuyel': {'recuyell': []},
 'recuyl': {'recuyles': []},
 'recv': {'recved': [], 'recves': []},
 'recvalu': {'recvaluation': []},
 'recvcl': {'recvcle': ['recvcled'], 'recvcling': []},
 'recvclabl': {'recvclable': []},
 'recvcle': ['recvcled'],
 'recvonli': {'recvonly': []},
 'recyc': {'recycable': []},
 'recycl': {'recyclability': [],
            'recyclable': ['recyclables'],
            'recyclate': ['recyclates'],
            'recycle': ['recycles',
                        'recycler',
                        'recycled',
                        'recyclers',
                        'recycleable',
                        'recyclement',
                        'recycleability'],
            'recyclic': ['recyclical'],
            'recycling': [],
            'recyclization': [],
            'recyclize': ['recyclized']},
 'recyclable': ['recyclables'],
 'recyclag': {'recyclage': ['recyclages']},
 'recyclage': ['recyclages'],
 'recyclate': ['recyclates'],
 'recycle': ['recycles',
             'recycler',
             'recycled',
             'recyclers',
             'recycleable',
             'recyclement',
             'recycleability'],
 'recycledcont': {'recycledcontent': []},
 'recycli': {'recyclying': []},
 'recyclic': ['recyclical'],
 'recyclin': {'recycline': []},
 'recyclis': {'recyclisation': []},
 'recyclize': ['recyclized'],
 'recyct': {'recycte': []},
 'recyd': {'recydables': [], 'recyde': ['recyder', 'recyded'], 'recyding': []},
 'recyde': ['recyder', 'recyded'],
 'recyl': {'recyle': ['recyled', 'recyles'], 'recyling': []},
 'recylc': {'recylced': [], 'recylcing': []},
 'recyle': ['recyled', 'recyles'],
 'recyrstal': {'recyrstallization': []},
 'recystal': {'recystallization': [], 'recystallized': []},
 'recyt': {'recyte': ['recyted'], 'recyting': []},
 'recyte': ['recyted'],
 'recyv': {'recyve': ['recyved']},
 'recyve': ['recyved'],
 'red': ['redded', 'redness', 'redding'],
 'reda': {'redas': []},
 'redabsorb': {'redabsorbing': []},
 'redac': {'redace': ['redaced'], 'redacing': []},
 'redaccion': {'redacciones': []},
 'redace': ['redaced'],
 'redacr': {'redacre': []},
 'redact': ['redacte',
            'redacted',
            'redacter',
            'redacting',
            'redaction',
            'redactive',
            'redactional',
            'redactionally'],
 'redacta': {'redactae': [], 'redactas': []},
 'redactada': {'redactadas': []},
 'redactado': {'redactados': []},
 'redacteur': {'redacteurs': []},
 'redacti': {'redactie': [], 'redactis': []},
 'redactionari': {'redactionary': []},
 'redactioncrit': {'redactioncritical': []},
 'redactioncritic': {'redactioncriticism': []},
 'redactionnel': {'redactionnelle': ['redactionnelles'], 'redactionnels': []},
 'redactionnelle': ['redactionnelles'],
 'redacto': {'redactos': []},
 'redactor': ['redactoral', 'redactores'],
 'redactori': {'redactorial': [], 'redactory': []},
 'redactric': {'redactrice': []},
 'redactu': {'redactus': []},
 'redada': {'redadas': []},
 'redae': {'redaeed': []},
 'redaim': {'redaiming': []},
 'redakc': {'redakce': []},
 'redakcij': {'redakcije': []},
 'redakcyjn': {'redakcyjne': []},
 'redakcyjni': {'redakcyjny': []},
 'redakt': {'redaktion': ['redaktions']},
 'redakteur': {'redakteure': [], 'redakteurs': []},
 'redaktion': ['redaktions'],
 'redaktionel': {'redaktionell': ['redaktionelle', 'redaktioneller']},
 'redaktionell': ['redaktionelle', 'redaktioneller'],
 'redaktionsgeschicht': {'redaktionsgeschichte': []},
 'redaktionsgeschichtlich': {'redaktionsgeschichtliche': []},
 'redaktionskommiss': {'redaktionskommission': []},
 'redaktionskritisch': {'redaktionskritische': []},
 'redaktionsprozess': {'redaktionsprozesse': []},
 'redaktor': {'redaktors': []},
 'redaktori': {'redaktory': []},
 'redaktorki': {'redaktorky': []},
 'redaktorzi': {'redaktorzy': []},
 'redal': {'redall': []},
 'redali': {'redalie': []},
 'redalj': {'redalje': []},
 'redam': {'redame': []},
 'redamag': {'redamaged': []},
 'redamar': {'redamare': []},
 'redamp': {'redamped': [], 'redamping': []},
 'redampen': {'redampened': [], 'redampening': []},
 'redan': {'redans': []},
 'redang': {'redange': []},
 'redanti': {'redanty': []},
 'redar': {'redarator': [], 'redare': [], 'redars': []},
 'redareforen': {'redareforening': []},
 'redargu': {'redarguant': [],
             'redargue': ['redargues', 'redargued', 'redarguer']},
 'redargue': ['redargues', 'redargued', 'redarguer'],
 'redarguen': {'redarguens': []},
 'redarguer': {'redarguere': []},
 'redargut': {'redargution': ['redargutions']},
 'redargution': {'redargutione': ['redargutiones']},
 'redargutione': ['redargutiones'],
 'redargutionibu': {'redargutionibus': []},
 'redargutu': {'redargutus': []},
 'redari': {'redaris': []},
 'redarian': {'redarians': []},
 'redarm': {'redarmed': []},
 'redarmi': {'redarmy': []},
 'redarn': {'redarned': []},
 'redass': {'redasse': []},
 'redassif': {'redassification': []},
 'redassifi': {'redassified': []},
 'redat': {'redate': ['redates', 'redated'],
           'redating': ['redatings'],
           'redation': ['redations'],
           'redator': ['redators']},
 'redate': ['redates', 'redated'],
 'redating': ['redatings'],
 'redation': ['redations'],
 'redator': ['redators'],
 'redatori': {'redatory': []},
 'redatt': {'redatte': []},
 'redattor': {'redattore': []},
 'redaub': {'redaubed': []},
 'redawn': {'redawned': [], 'redawning': []},
 'reday': {'redays': []},
 'redazion': {'redazione': []},
 'redazional': {'redazionale': []},
 'redb': {'redbed': ['redbeds']},
 'redback': {'redbacked': [], 'redbacks': []},
 'redbait': {'redbaited': [], 'redbaiter': ['redbaiters'], 'redbaiting': []},
 'redbaiter': ['redbaiters'],
 'redbak': {'redbaked': []},
 'redbal': {'redball': []},
 'redband': {'redbanded': [], 'redbands': []},
 'redbank': {'redbanks': []},
 'redbar': {'redbarred': []},
 'redbark': {'redbarked': []},
 'redbeak': {'redbeaked': []},
 'redbean': {'redbeans': []},
 'redbeard': {'redbearded': [], 'redbeards': []},
 'redbed': ['redbeds'],
 'redbelli': {'redbellied': [], 'redbelly': []},
 'redberri': {'redberried': [], 'redberry': []},
 'redbi': {'redby': []},
 'redbil': {'redbill': ['redbills', 'redbilled']},
 'redbill': ['redbills', 'redbilled'],
 'redbird': {'redbird': []},
 'redblaz': {'redblazed': []},
 'redblind': {'redblindness': []},
 'redblond': {'redblonde': []},
 'redblood': {'redblooded': []},
 'redblooded': {'redbloodedness': []},
 'redblossom': {'redblossomed': []},
 'redblotch': {'redblotched': []},
 'redblu': {'redblue': []},
 'redbodi': {'redbodied': []},
 'redbon': {'redbone': []},
 'redbook': {'redbooks': []},
 'redbord': {'redbordered': []},
 'redborn': {'redborne': []},
 'redbornestok': {'redbornestoke': []},
 'redboum': {'redboume': []},
 'redbourn': {'redbourne': []},
 'redbra': {'redbrae': ['redbraes']},
 'redbrae': ['redbraes'],
 'redbreast': ['redbreasted'],
 'redbrick': {'redbricked': [], 'redbricks': []},
 'redbricklearn': {'redbricklearning': []},
 'redbridg': {'redbridge': []},
 'redbristl': {'redbristled': []},
 'redbronz': {'redbronze': []},
 'redbrook': {'redbrooke': []},
 'redbrow': {'redbrowed': []},
 'redbrown': {'redbrowns': []},
 'redbu': {'redbus': []},
 'redbud': {'redbud': []},
 'redbug': {'redbug': []},
 'redbul': {'redbull': []},
 'redburi': {'redbury': []},
 'redburn': {'redburne': [], 'redburning': [], 'redburns': []},
 'redburnish': {'redburnished': []},
 'redcap': ['redcapped', 'redcapping'],
 'redcarpet': {'redcarpeted': []},
 'redcastl': {'redcastle': []},
 'redcat': {'redcats': []},
 'redcatch': {'redcatchers': []},
 'redcedar': {'redcedars': []},
 'redcel': {'redcell': ['redcells']},
 'redcell': ['redcells'],
 'redcem': {'redcemer': []},
 'redcheck': {'redchecked': [], 'redcheckered': []},
 'redcheek': {'redcheeked': []},
 'redchest': {'redchested': []},
 'redchff': {'redchffe': []},
 'redcircl': {'redcircled': []},
 'redcli': {'redcly': []},
 'redclif': {'redclife': []},
 'redcliff': {'redcliffe': ['redcliffes'], 'redcliffs': []},
 'redcliffe': ['redcliffes'],
 'redclifi': {'redclifie': []},
 'redclifl': {'redclifle': []},
 'redcliflf': {'redcliflfe': []},
 'redclift': {'redclifte': []},
 'redcliif': {'redcliife': []},
 'redclijf': {'redclijfe': []},
 'redclitf': {'redclitfe': []},
 'redcliv': {'redclive': []},
 'redcllff': {'redcllffe': []},
 'redcloak': {'redcloaked': []},
 'redcloth': {'redclothed': []},
 'redclov': {'redclover': []},
 'redclyff': {'redclyffe': []},
 'redclyfi': {'redclyfie': []},
 'redclyfl': {'redclyfle': []},
 'redclyft': {'redclyfte': []},
 'redclyjf': {'redclyjfe': []},
 'redclyn': {'redclyne': []},
 'redcmptorist': {'redcmptorists': []},
 'redcoat': ['redcoated'],
 'redcockad': {'redcockaded': []},
 'redcollar': {'redcollared': []},
 'redcolor': {'redcolored': []},
 'redcolour': {'redcoloured': []},
 'redcot': {'redcote': []},
 'redcov': {'redcovered': []},
 'redcrest': {'redcrested': []},
 'redcross': {'redcrosse': []},
 'redcrown': {'redcrowned': []},
 'redcsdal': {'redcsdale': []},
 'redcurr': {'redcurrant': ['redcurrants']},
 'redcurrant': ['redcurrants'],
 'redcurtain': {'redcurtained': []},
 'redcushion': {'redcushioned': []},
 'redcut': {'redcution': []},
 'redd': {'redde': ['reddes', 'reddely'], 'reddness': [], 'redds': []},
 'redda': {'reddas': []},
 'reddal': {'reddale': [], 'reddall': ['reddalls']},
 'reddall': ['reddalls'],
 'reddamu': {'reddamus': []},
 'reddanc': {'reddance': []},
 'reddarqu': {'reddarque': []},
 'reddati': {'reddatis': []},
 'reddaub': {'reddaubed': []},
 'reddaway': {'reddaways': []},
 'reddcr': {'reddcre': []},
 'redde': ['reddes', 'reddely'],
 'reddeb': {'reddebant': []},
 'reddehas': {'reddehase': []},
 'reddel': {'reddell': []},
 'reddemu': {'reddemus': []},
 'redden': {'reddened': [],
            'reddener': ['reddeners'],
            'reddening': ['reddenings'],
            'reddens': []},
 'reddenbach': {'reddenbacher': []},
 'reddend': {'reddende': []},
 'reddenda': {'reddendae': [], 'reddendas': []},
 'reddendi': {'reddendis': []},
 'reddendo': {'reddendos': []},
 'reddendu': {'reddendus': []},
 'reddener': ['reddeners'],
 'reddening': ['reddenings'],
 'reddent': {'reddente': ['reddentes']},
 'reddente': ['reddentes'],
 'reddenti': {'reddentis': []},
 'reddentibu': {'reddentibus': []},
 'redder': {'reddere': ['redderes', 'redderent'], 'redders': []},
 'reddere': ['redderes', 'redderent'],
 'redderemu': {'redderemus': []},
 'redderequ': {'reddereque': []},
 'reddesdal': {'reddesdale': []},
 'reddeti': {'reddetis': []},
 'reddi': {'reddie': ['reddies'],
           'reddiness': [],
           'reddis': [],
           'reddy': ['reddys', 'reddyed']},
 'reddiap': {'reddiaper': []},
 'reddiar': {'reddiars': []},
 'reddicion': {'reddicione': []},
 'reddick': {'reddicks': []},
 'reddicliff': {'reddicliffe': []},
 'reddider': {'reddiderant': [], 'reddidere': []},
 'reddideri': {'reddideris': []},
 'reddidimu': {'reddidimus': []},
 'reddidiss': {'reddidisse': ['reddidissent']},
 'reddidisse': ['reddidissent'],
 'reddidisti': {'reddidistis': []},
 'reddie': ['reddies'],
 'reddiff': {'reddiffe': []},
 'reddili': {'reddily': []},
 'reddimu': {'reddimus': []},
 'reddin': {'reddines': [], 'reddins': []},
 'redding': {'reddinge': ['reddinger', 'reddinges']},
 'reddinge': ['reddinger', 'reddinges'],
 'reddingiu': {'reddingius': []},
 'reddington': {'reddingtons': []},
 'reddip': {'reddipalli': []},
 'reddiqu': {'reddique': []},
 'reddir': {'reddire': []},
 'reddish': {'reddishes': [], 'reddishness': []},
 'reddishblond': {'reddishblonde': []},
 'reddishblu': {'reddishblue': []},
 'reddishbronz': {'reddishbronze': []},
 'reddishbrown': {'reddishbrowns': []},
 'reddishchocol': {'reddishchocolate': []},
 'reddishcolor': {'reddishcolored': []},
 'reddishcolour': {'reddishcoloured': []},
 'reddishhair': {'reddishhaired': []},
 'reddishli': {'reddishly': []},
 'reddishlook': {'reddishlooking': []},
 'reddishorang': {'reddishorange': []},
 'reddishpurpl': {'reddishpurple': []},
 'reddishting': {'reddishtinged': []},
 'reddishwhit': {'reddishwhite': []},
 'reddit': {'reddite': [], 'reddition': ['redditions'], 'redditive': []},
 'reddita': {'redditae': [], 'redditas': []},
 'redditaqu': {'redditaque': []},
 'redditi': {'redditis': []},
 'redditibu': {'redditibus': []},
 'reddition': {'redditione': []},
 'redditioni': {'redditionis': []},
 'reddito': {'redditos': []},
 'redditqu': {'redditque': []},
 'reddits': {'redditse': []},
 'redditu': {'redditus': []},
 'reddituro': {'reddituros': []},
 'reddituru': {'redditurus': []},
 'reddl': {'reddle': ['reddled'], 'reddling': []},
 'reddle': ['reddled'],
 'reddlebag': {'reddlebags': []},
 'reddot': {'reddotted': []},
 'reddrap': {'reddraped': []},
 'reddress': {'reddressed': []},
 'redduntqu': {'redduntque': []},
 'reddy': {'reddye': [], 'reddyness': []},
 'reddyet': {'reddyetal': []},
 'reddyff': {'reddyffe': []},
 'reddyn': {'reddynes': []},
 'rede': {'reded': [],
          'redee': ['redeed'],
          'redely': [],
          'redes': [],
          'reding': ['redings']},
 'redea': {'redeas': []},
 'redeadal': {'redeadale': []},
 'redeal': {'redealing': [], 'redeals': []},
 'redeam': {'redeamed': [], 'redeamer': []},
 'redeamu': {'redeamus': []},
 'redear': {'redeared': [], 'redears': []},
 'redeat': {'redeated': []},
 'redeath': {'redeaths': []},
 'redeati': {'redeatis': []},
 'redeb': {'redebate': ['redebated'], 'redebating': []},
 'redebate': ['redebated'],
 'redebit': {'redebited': []},
 'redebrid': {'redebrided': [], 'redebridement': []},
 'redec': {'redeced': []},
 'redecessor': {'redecessors': []},
 'redecid': {'redecide': ['redecided', 'redecides'], 'redeciding': []},
 'redecide': ['redecided', 'redecides'],
 'redecilla': {'redecillas': []},
 'redeciph': {'redeciphered': []},
 'redecis': {'redecision': ['redecisions']},
 'redecision': ['redecisions'],
 'redeck': {'redecke': ['redecked', 'redecker'], 'redecking': []},
 'redecke': ['redecked', 'redecker'],
 'redeclar': {'redeclaration': ['redeclarations'],
              'redeclare': ['redeclares', 'redeclared'],
              'redeclaring': []},
 'redeclaration': ['redeclarations'],
 'redeclare': ['redeclares', 'redeclared'],
 'redecompos': {'redecomposed': []},
 'redecomposit': {'redecomposition': []},
 'redecor': {'redecorate': ['redecorates', 'redecorated'],
             'redecorating': [],
             'redecoration': ['redecorations'],
             'redecorator': ['redecorators']},
 'redecorate': ['redecorates', 'redecorated'],
 'redecoration': ['redecorations'],
 'redecorator': ['redecorators'],
 'redecouvert': {'redecouverte': ['redecouvertes'], 'redecouverts': []},
 'redecouverte': ['redecouvertes'],
 'redecouvr': {'redecouvre': []},
 'redect': {'redection': []},
 'reded': {'rededicate': ['rededicates', 'rededicated'],
           'rededicating': [],
           'rededication': []},
 'rededg': {'rededged': []},
 'rededicate': ['rededicates', 'rededicated'],
 'rededicatori': {'rededicatory': []},
 'redee': ['redeed'],
 'redeed': {'redeeded': []},
 'redeeem': {'redeeemed': [], 'redeeemer': [], 'redeeeming': []},
 'redeem': {'redeemability': [],
            'redeemable': ['redeemables', 'redeemableness'],
            'redeemably': [],
            'redeeme': ['redeemer', 'redeemed', 'redeemes'],
            'redeeming': [],
            'redeems': []},
 'redeemable': ['redeemables', 'redeemableness'],
 'redeeme': ['redeemer', 'redeemed', 'redeemes'],
 'redeemed': {'redeemedness': []},
 'redeeming': {'redeeminge': []},
 'redeemingli': {'redeemingly': []},
 'redeempt': {'redeemption': []},
 'redeepen': {'redeepening': []},
 'redef': {'redefer': []},
 'redefect': {'redefected': [],
              'redefecting': [],
              'redefection': ['redefections']},
 'redefection': ['redefections'],
 'redefector': {'redefectors': []},
 'redefend': {'redefended': []},
 'redefin': {'redefinable': [],
             'redefination': [],
             'redefine': ['redefined',
                          'redefines',
                          'redefiner',
                          'redefiners',
                          'redefinement'],
             'redefining': ['redefinings']},
 'redefine': ['redefined',
              'redefines',
              'redefiner',
              'redefiners',
              'redefinement'],
 'redefini': {'redefinie': [], 'redefinis': []},
 'redefining': ['redefinings'],
 'redefinit': {'redefinition': ['redefinitional']},
 'redefinition': ['redefinitional'],
 'redefint': {'redefintion': []},
 'redefm': {'redefme': ['redefmes', 'redefmed'], 'redefming': []},
 'redefme': ['redefmes', 'redefmed'],
 'redefmit': {'redefmition': []},
 'redeform': {'redeformation': [], 'redeformed': []},
 'redeftn': {'redeftne': ['redeftned']},
 'redeftne': ['redeftned'],
 'redeftnit': {'redeftnition': []},
 'redegimu': {'redegimus': []},
 'redegiss': {'redegisse': []},
 'redegjord': {'redegjorde': []},
 'redegjorels': {'redegjorelse': []},
 'redegond': {'redegonde': []},
 'redegor': {'redegores': []},
 'redegorels': {'redegorelse': []},
 'redehal': {'redehalle': []},
 'redeifi': {'redeified': []},
 'redeiv': {'redeive': ['redeived']},
 'redeive': ['redeived'],
 'redek': {'redeke': ['redeker']},
 'redeke': ['redeker'],
 'redekiinst': {'redekiinste': []},
 'redekunst': {'redekunste': []},
 'redel': {'redele': ['redeler', 'redeles'],
           'redelings': [],
           'redell': [],
           'redels': []},
 'redele': ['redeler', 'redeles'],
 'redeleg': {'redelegate': ['redelegates', 'redelegated'],
             'redelegating': [],
             'redelegation': ['redelegations']},
 'redelegate': ['redelegates', 'redelegated'],
 'redelegation': ['redelegations'],
 'redelf': {'redelfs': []},
 'redeliber': {'redeliberate': ['redeliberated'],
               'redeliberating': [],
               'redeliberation': ['redeliberations']},
 'redeliberate': ['redeliberated'],
 'redeliberation': ['redeliberations'],
 'redeliff': {'redeliffe': []},
 'redelijk': {'redelijke': []},
 'redelik': {'redelike': []},
 'redelimit': {'redelimitation': [], 'redelimited': []},
 'redelin': {'redelineate': ['redelineated'], 'redelineation': []},
 'redelineate': ['redelineated'],
 'redelinghui': {'redelinghuis': []},
 'redelinghuy': {'redelinghuys': []},
 'redeliu': {'redeliuer': ['redeliuered'], 'redelius': []},
 'redeliuer': ['redeliuered'],
 'redeliv': {'redeliver': ['redelivers', 'redelivered', 'redelivering']},
 'redeliver': {'redeliverance': []},
 'redeliveri': {'redeliveries': [], 'redelivery': []},
 'redelmei': {'redelmeier': []},
 'redelsheim': {'redelsheimer': []},
 'redelsperg': {'redelsperger': []},
 'redelyff': {'redelyffe': []},
 'redelyv': {'redelyver': ['redelyvered']},
 'redelyver': ['redelyvered'],
 'redem': {'redeme': ['redemed', 'redemer', 'redemeer'],
           'redeming': [],
           'redemmed': []},
 'redemand': {'redemande': ['redemanded', 'redemander'],
              'redemanding': [],
              'redemands': []},
 'redemande': ['redemanded', 'redemander'],
 'redemarc': {'redemarcate': ['redemarcated'],
              'redemarcating': [],
              'redemarcation': []},
 'redemarcate': ['redemarcated'],
 'redemarrag': {'redemarrage': []},
 'redemat': {'redematous': []},
 'redembroid': {'redembroidered': []},
 'redeme': {'redemeed': []},
 'redemey': {'redemeyer': []},
 'redemft': {'redemftion': []},
 'redemirla': {'redemirlas': []},
 'redemis': {'redemise': ['redemised']},
 'redemise': ['redemised'],
 'redemiss': {'redemisse': []},
 'redemisti': {'redemistis': []},
 'redemit': {'redemitting': []},
 'redemocrat': {'redemocratization': ['redemocratizations'],
                'redemocratize': ['redemocratized'],
                'redemocratizing': []},
 'redemocratis': {'redemocratisation': []},
 'redemocratization': ['redemocratizations'],
 'redemocratize': ['redemocratized'],
 'redemonstr': {'redemonstrable': [],
                'redemonstrate': ['redemonstrates', 'redemonstrated'],
                'redemonstrating': [],
                'redemonstration': []},
 'redemonstrate': ['redemonstrates', 'redemonstrated'],
 'redemor': {'redemore': []},
 'redemot': {'redemotion': []},
 'redempcion': {'redempcione': []},
 'redempcioni': {'redempcionis': []},
 'redempt': {'redemption': ['redemptional'],
             'redemptive': ['redemptively', 'redemptiveness']},
 'redempta': {'redemptae': [], 'redemptas': []},
 'redempti': {'redemptiou': [], 'redemptis': []},
 'redemption': {'redemptione': ['redemptiones',
                                'redemptioner',
                                'redemptioners'],
                'redemptionism': []},
 'redemptionari': {'redemptionary': []},
 'redemptioncr': {'redemptioncrs': []},
 'redemptione': ['redemptiones', 'redemptioner', 'redemptioners'],
 'redemptioni': {'redemptionis': []},
 'redemptionibu': {'redemptionibus': []},
 'redemptionist': {'redemptionists': []},
 'redemptionpric': {'redemptionprice': []},
 'redemptive': ['redemptively', 'redemptiveness'],
 'redemptivehistor': {'redemptivehistorical': []},
 'redempto': {'redemptos': []},
 'redemptor': {'redemptore': ['redemptores'], 'redemptors': []},
 'redemptore': ['redemptores'],
 'redemptori': {'redemptorial': [], 'redemptoris': [], 'redemptory': []},
 'redemptoribu': {'redemptoribus': []},
 'redemptorist': {'redemptoristes': [], 'redemptorists': []},
 'redemptoristin': {'redemptoristine': ['redemptoristines']},
 'redemptoristine': ['redemptoristines'],
 'redemptric': {'redemptrice': []},
 'redemptu': {'redemptus': []},
 'redempturu': {'redempturus': []},
 'redemsk': {'redemske': []},
 'redemt': {'redemtion': []},
 'redemtion': {'redemtione': []},
 'redemtioni': {'redemtionis': []},
 'reden': {'redene': ['redened', 'redenering'], 'redening': [], 'redens': []},
 'redenamel': {'redenameled': []},
 'redenbach': {'redenbacher': []},
 'redenback': {'redenbacker': []},
 'redenc': {'redence': []},
 'redend': {'redende': ['redender']},
 'redende': ['redender'],
 'redene': ['redened', 'redenering'],
 'redenhal': {'redenhall': []},
 'redeni': {'redenied': [], 'redeny': []},
 'redeniu': {'redenius': []},
 'redenomin': {'redenominate': ['redenominated'],
               'redenominating': [],
               'redenomination': []},
 'redenominate': ['redenominated'],
 'redenpt': {'redenption': []},
 'redenquel': {'redenquelle': []},
 'redensif': {'redensification': []},
 'redent': {'redente': ['redented'], 'redents': []},
 'redente': ['redented'],
 'redenti': {'redentials': []},
 'redentin': {'redentiner': []},
 'redentor': {'redentore': ['redentores']},
 'redentore': ['redentores'],
 'redentorista': {'redentoristas': []},
 'redentric': {'redentrice': []},
 'redenvelop': {'redenvelope': []},
 'redenvo': {'redenvoering': []},
 'redenzion': {'redenzione': []},
 'redeoat': {'redeoats': []},
 'redepartur': {'redeparture': []},
 'redepen': {'redepenning': []},
 'redepict': {'redepicted': [], 'redepiction': []},
 'redeploi': {'redeploiement': []},
 'redeploy': {'redeployability': [],
              'redeployable': [],
              'redeployed': [],
              'redeploying': [],
              'redeployment': [],
              'redeploys': []},
 'redeploye': {'redeployees': []},
 'redeport': {'redeported': []},
 'redepos': {'redepose': ['redeposed'], 'redeposing': []},
 'redepose': ['redeposed'],
 'redeposit': {'redeposited': [],
               'redepositing': [],
               'redeposition': ['redepositional'],
               'redeposits': []},
 'redeposition': ['redepositional'],
 'redeposlt': {'redeposlted': []},
 'redepreci': {'redepreciate': []},
 'redept': {'redeption': []},
 'redequel': {'redequelle': []},
 'reder': {'rederal': [],
           'rederation': [],
           'redere': ['redered', 'rederer'],
           'rederic': [],
           'redering': [],
           'rederive': ['rederives'],
           'rederring': [],
           'reders': []},
 'rederchiu': {'rederchius': []},
 'redere': ['redered', 'rederer'],
 'rederi': {'rederie': []},
 'rederick': {'redericks': []},
 'rederiforen': {'rederiforening': []},
 'rederijk': {'rederijker': ['rederijkers']},
 'rederijker': ['rederijkers'],
 'rederijkerskam': {'rederijkerskamer': ['rederijkerskamers']},
 'rederijkerskamer': ['rederijkerskamers'],
 'rederiv': {'rederivation': ['rederivations'],
             'rederived': [],
             'rederiving': []},
 'rederivation': ['rederivations'],
 'rederive': ['rederives'],
 'redersverenig': {'redersvereniging': []},
 'rederu': {'rederus': []},
 'rederyk': {'rederyker': ['rederykers']},
 'rederyker': ['rederykers'],
 'redesc': {'redescent': []},
 'redescend': {'redescendant': [],
               'redescended': [],
               'redescendent': [],
               'redescending': [],
               'redescends': []},
 'redescendr': {'redescendre': []},
 'redescrib': {'redescribable': [],
               'redescribe': ['redescribed', 'redescribes', 'redescriber'],
               'redescribing': []},
 'redescribe': ['redescribed', 'redescribes', 'redescriber'],
 'redescript': {'redescription': ['redescriptions'], 'redescriptive': []},
 'redescription': ['redescriptions'],
 'redescubr': {'redescubre': []},
 'redesdal': {'redesdale': ['redesdales']},
 'redesdale': ['redesdales'],
 'redesert': {'redeserted': []},
 'redesign': {'redesignate': ['redesignates', 'redesignated'],
              'redesignating': [],
              'redesignation': ['redesignations'],
              'redesigned': [],
              'redesigner': ['redesigners'],
              'redesigning': ['redesignings'],
              'redesigns': []},
 'redesignate': ['redesignates', 'redesignated'],
 'redesignation': ['redesignations'],
 'redesigner': ['redesigners'],
 'redesigning': ['redesignings'],
 'redesitu': {'redesituation': []},
 'redespatch': {'redespatched': []},
 'redessin': {'redessine': ['redessiner']},
 'redessine': ['redessiner'],
 'redestin': {'redestination': [], 'redestined': []},
 'redestribut': {'redestribution': []},
 'redestroy': {'redestroyed': []},
 'redestruct': {'redestruction': []},
 'redeswir': {'redeswire': []},
 'redet': {'redete': ['redeter']},
 'redetach': {'redetached': [], 'redetachment': ['redetachments']},
 'redetachment': ['redetachments'],
 'redetail': {'redetailed': []},
 'redetain': {'redetained': []},
 'redete': ['redeter'],
 'redetect': {'redetected': [],
              'redetecting': [],
              'redetection': [],
              'redetects': []},
 'redeteil': {'redeteile': []},
 'redetennin': {'redetennination': []},
 'redetent': {'redetention': []},
 'redetermin': {'redeterminable': [],
                'redetermination': [],
                'redetermine': ['redetermined', 'redetermines'],
                'redetermining': []},
 'redetermine': ['redetermined', 'redetermines'],
 'redetzk': {'redetzke': []},
 'redeuabl': {'redeuable': []},
 'redeunt': {'redeunte': ['redeuntes']},
 'redeunte': ['redeuntes'],
 'redeunti': {'redeuntis': []},
 'redeuntibu': {'redeuntibus': []},
 'redeuntqu': {'redeuntque': []},
 'redev': {'redevable': ['redevables'], 'redevance': ['redevances']},
 'redevable': ['redevables'],
 'redevance': ['redevances'],
 'redevelop': {'redevelopable': [],
               'redeveloped': [],
               'redeveloper': ['redevelopers'],
               'redevelopes': [],
               'redeveloping': [],
               'redevelopment': [],
               'redevelops': []},
 'redeveloper': ['redevelopers'],
 'redevelopment': {'redevelopmental': []},
 'redeven': {'redevenant': []},
 'redevenai': {'redevenais': []},
 'redevenu': {'redevenue': ['redevenues'], 'redevenus': []},
 'redevenue': ['redevenues'],
 'redevi': {'redevient': []},
 'redevien': {'redeviens': []},
 'redevienn': {'redevienne': ['redeviennent']},
 'redevienne': ['redeviennent'],
 'redevis': {'redevise': ['redevised'], 'redevising': []},
 'redevise': ['redevised'],
 'redevivu': {'redevivus': []},
 'redevo': {'redevoering': []},
 'redevot': {'redevote': ['redevoted']},
 'redevote': ['redevoted'],
 'redewat': {'redewater': []},
 'redeweis': {'redeweise': []},
 'redewiedergab': {'redewiedergabe': []},
 'redewil': {'redewill': []},
 'redewn': {'redewne': ['redewned'], 'redewning': []},
 'redewne': ['redewned'],
 'redewnit': {'redewnition': []},
 'redey': {'redeye': ['redeyed']},
 'redeye': ['redeyed'],
 'redezv': {'redezvous': []},
 'redfac': {'redface': ['redfaced']},
 'redface': ['redfaced'],
 'redfacedli': {'redfacedly': []},
 'redfearn': {'redfearne': [], 'redfearns': []},
 'redfeath': {'redfeather': ['redfeathered']},
 'redfeather': ['redfeathered'],
 'redfem': {'redfems': []},
 'redfer': {'redfering': []},
 'redfern': {'redferne': [], 'redferns': []},
 'redfezz': {'redfezzed': []},
 'redfield': {'redfields': []},
 'redfigur': {'redfigure': ['redfigured']},
 'redfigure': ['redfigured'],
 'redfilt': {'redfilter': ['redfiltered']},
 'redfilter': ['redfiltered'],
 'redfin': {'redfinned': [], 'redfins': []},
 'redfir': {'redfire': [], 'redfiring': []},
 'redfish': {'redfish': []},
 'redflag': {'redflagged': [], 'redflags': []},
 'redfleck': {'redflecked': []},
 'redflesh': {'redfleshed': []},
 'redflow': {'redflower': ['redflowered', 'redflowering']},
 'redflower': ['redflowered', 'redflowering'],
 'redflush': {'redflushed': []},
 'redfoot': {'redfooted': []},
 'redfor': {'redfors': []},
 'redford': {'redford': []},
 'redfram': {'redframed': []},
 'redfre': {'redfree': []},
 'redfring': {'redfringed': []},
 'redfront': {'redfronted': []},
 'redfruit': {'redfruited': []},
 'redfur': {'redfurred': []},
 'redg': {'redge': ['redges'], 'redging': []},
 'redgat': {'redgate': []},
 'redgauntlet': {'redgauntlets': []},
 'redge': ['redges'],
 'redger': {'redgers': []},
 'redgewel': {'redgewell': []},
 'redgi': {'redgie': []},
 'redgil': {'redgill': []},
 'redglar': {'redglare': []},
 'redglaz': {'redglazed': []},
 'redglob': {'redglobe': []},
 'redglow': {'redglowing': []},
 'redgown': {'redgowned': []},
 'redgrain': {'redgrained': []},
 'redgranit': {'redgranite': []},
 'redgrav': {'redgrave': ['redgraves']},
 'redgrave': ['redgraves'],
 'redgrous': {'redgrouse': []},
 'redgrov': {'redgrove': []},
 'redgum': {'redgums': []},
 'redgwel': {'redgwell': []},
 'redh': {'redhed': []},
 'redhair': {'redhaired': []},
 'redhairi': {'redhairy': []},
 'redhal': {'redhall': []},
 'redhamm': {'redhammer': []},
 'redhand': {'redhanded': []},
 'redhandl': {'redhandled': []},
 'redhard': {'redhardness': []},
 'redhat': {'redhatted': []},
 'redhaw': {'redhaws': []},
 'redhawk': {'redhawks': []},
 'redhead': ['redheaded'],
 'redheaded': {'redheadedness': []},
 'redheel': {'redheeled': []},
 'redheff': {'redheffer': []},
 'redheif': {'redheifer': []},
 'redher': {'redherring': ['redherrings']},
 'redherring': ['redherrings'],
 'redheugh': {'redheughs': []},
 'redhiber': {'redhibere': []},
 'redhibit': {'redhibition': []},
 'redhibitoir': {'redhibitoire': ['redhibitoires']},
 'redhibitoire': ['redhibitoires'],
 'redhibitori': {'redhibitory': []},
 'redhil': {'redhill': ['redhills']},
 'redhill': ['redhills'],
 'redhood': {'redhooded': []},
 'redhors': {'redhorse': []},
 'redhot': {'redhots': []},
 'redhous': {'redhouse': []},
 'redhu': {'redhued': []},
 'redhump': {'redhumped': []},
 'redhunt': {'redhunter': ['redhunters'], 'redhunting': []},
 'redhunter': ['redhunters'],
 'redi': {'rediative': [],
          'redie': ['redies', 'redied'],
          'rediness': [],
          'redis': [],
          'redy': ['redys', 'redyed', 'redying']},
 'redia': {'rediae': [], 'redias': []},
 'rediadi': {'rediadis': []},
 'rediagnos': {'rediagnose': ['rediagnosed', 'rediagnoses'],
               'rediagnosing': []},
 'rediagnose': ['rediagnosed', 'rediagnoses'],
 'rediagnosi': {'rediagnosis': []},
 'rediagram': {'rediagrammed': []},
 'redial': {'redialed': [],
            'redialing': [],
            'redialled': [],
            'redialling': [],
            'redials': []},
 'redialyz': {'redialyzed': []},
 'redianc': {'rediance': []},
 'rediand': {'rediands': []},
 'rediap': {'rediaper': ['rediapered', 'rediapering']},
 'rediaper': ['rediapered', 'rediapering'],
 'rediasolv': {'rediasolved': []},
 'rediat': {'rediate': ['rediated'],
            'rediating': [],
            'rediation': ['rediations']},
 'rediate': ['rediated'],
 'rediation': ['rediations'],
 'redib': {'redibant': []},
 'redibi': {'redibis': []},
 'redibl': {'redibility': [], 'redible': [], 'redibly': []},
 'redibu': {'redibus': []},
 'redic': {'redical': ['redicals', 'redically', 'redicalism'],
           'redicate': ['redicates', 'redicated'],
           'redication': [],
           'redice': ['redices', 'rediced'],
           'redics': []},
 'redica': {'redicament': []},
 'redical': ['redicals', 'redically', 'redicalism'],
 'redicate': ['redicates', 'redicated'],
 'redice': ['redices', 'rediced'],
 'redick': {'redicker': []},
 'redicot': {'redicote': []},
 'redict': {'redictable': [],
            'redictably': [],
            'redictate': ['redictated'],
            'redictating': [],
            'redictation': [],
            'redicted': [],
            'redicting': [],
            'rediction': ['redictions'],
            'redictive': []},
 'redictate': ['redictated'],
 'rediction': ['redictions'],
 'redictor': {'redictors': []},
 'redicul': {'redicule': ['rediculed', 'redicules'],
             'rediculing': [],
             'rediculous': ['rediculously']},
 'redicule': ['rediculed', 'redicules'],
 'rediculous': ['rediculously'],
 'rediculu': {'rediculus': []},
 'redidu': {'redidual': []},
 'redie': ['redies', 'redied'],
 'redieh': {'rediehs': []},
 'redien': {'rediens': []},
 'rediensqu': {'rediensque': []},
 'redient': {'redients': []},
 'redier': {'redierant': [], 'rediere': []},
 'redieri': {'redieris': []},
 'redierimu': {'redierimus': []},
 'redif': {'redifer': [], 'redifs': []},
 'rediff': {'rediffs': []},
 'redifferenti': {'redifferentiate': ['redifferentiated', 'redifferentiates'],
                  'redifferentiating': [],
                  'redifferentiation': ['redifferentiations']},
 'redifferentiate': ['redifferentiated', 'redifferentiates'],
 'redifferentiation': ['redifferentiations'],
 'rediffract': {'rediffracted': [], 'rediffraction': []},
 'rediffus': {'rediffuse': ['rediffused'],
              'rediffusing': [],
              'rediffusion': []},
 'rediffuse': ['rediffused'],
 'redifin': {'redifine': ['redifined'], 'redifining': []},
 'redifine': ['redifined'],
 'redifinit': {'redifinition': []},
 'rediflus': {'rediflusion': []},
 'rediftus': {'rediftusion': []},
 'redifus': {'redifusion': []},
 'redifuss': {'redifussion': []},
 'redig': {'redigant': [],
           'redige': ['rediges',
                      'rediger',
                      'redigent',
                      'redigeant',
                      'redigering'],
           'redigging': []},
 'rediga': {'redigas': []},
 'redigamu': {'redigamus': []},
 'redige': {'redigee': ['redigees']},
 'redigeb': {'redigebant': []},
 'redigee': ['redigees'],
 'redigen': {'redigens': []},
 'redigendi': {'redigendis': []},
 'redigendo': {'redigendos': []},
 'redigent': {'redigentes': []},
 'rediger': {'redigere': ['redigerent']},
 'redigere': ['redigerent'],
 'redigest': {'redigested': [],
              'redigesting': [],
              'redigestion': [],
              'redigests': []},
 'redigi': {'redigis': []},
 'redigiert': {'redigierte': []},
 'redigit': {'redigitalization': [],
             'redigitalize': ['redigitalized'],
             'redigitization': [],
             'redigitize': ['redigitized'],
             'redigitizing': []},
 'redigitalize': ['redigitalized'],
 'redigitize': ['redigitized'],
 'redignifi': {'redignified': [], 'redignify': []},
 'rediguid': {'rediguide': ['rediguides']},
 'rediguide': ['rediguides'],
 'rediic': {'rediice': ['rediiced']},
 'rediice': ['rediiced'],
 'rediict': {'rediiction': []},
 'rediiss': {'rediisse': ['rediissent']},
 'rediisse': ['rediissent'],
 'redik': {'rediker': []},
 'redil': {'redilate': ['redilates', 'redilated'],
           'redilating': [],
           'redilation': [],
           'redile': ['rediles']},
 'redilat': {'redilatation': []},
 'redilate': ['redilates', 'redilated'],
 'redile': ['rediles'],
 'redili': {'redily': []},
 'redilut': {'redilute': ['rediluted'], 'rediluting': [], 'redilution': []},
 'redilute': ['rediluted'],
 'redim': {'redimant': [],
           'redime': ['redimer', 'redimes'],
           'redimible': ['redimibles'],
           'redimiti': []},
 'redima': {'redimas': []},
 'redime': ['redimer', 'redimes'],
 'redimeb': {'redimebant': []},
 'redimen': {'redimens': []},
 'redimendi': {'redimendis': []},
 'redimendo': {'redimendos': []},
 'redimendu': {'redimendus': []},
 'redimens': {'redimension': ['redimensions',
                              'redimensioned',
                              'redimensioning']},
 'redimension': ['redimensions', 'redimensioned', 'redimensioning'],
 'rediment': {'redimentes': [], 'rediments': []},
 'redimentari': {'redimentary': []},
 'redimentibu': {'redimentibus': []},
 'redimer': {'redimere': ['redimeres', 'redimerent']},
 'redimere': ['redimeres', 'redimerent'],
 'redimible': ['redimibles'],
 'redimida': {'redimidas': []},
 'redimido': {'redimidos': []},
 'redimir': {'redimire': []},
 'redimirlo': {'redimirlos': []},
 'redimirno': {'redimirnos': []},
 'redimirs': {'redimirse': []},
 'redimit': {'redimite': []},
 'redimito': {'redimitos': []},
 'redimitu': {'redimitus': []},
 'redimu': {'redimus': []},
 'redin': {'redine': ['redines', 'rediner'], 'redining': []},
 'redine': ['redines', 'rediner'],
 'rediness': {'redinesse': []},
 'reding': {'redinge': ['redinges', 'redinger']},
 'redinge': ['redinges', 'redinger'],
 'redingot': {'redingote': ['redingotes']},
 'redingote': ['redingotes'],
 'redingott': {'redingotte': []},
 'redington': {'redingtons': []},
 'redink': {'redinked': []},
 'redintegr': {'redintegrant': [],
               'redintegrate': ['redintegrates', 'redintegrated'],
               'redintegrating': [],
               'redintegration': ['redintegrations'],
               'redintegrative': ['redintegratively']},
 'redintegrar': {'redintegrare': []},
 'redintegrate': ['redintegrates', 'redintegrated'],
 'redintegrati': {'redintegratis': []},
 'redintegration': ['redintegrations'],
 'redintegrative': ['redintegratively'],
 'redioact': {'redioactive': [], 'redioactivity': []},
 'rediou': {'redious': []},
 'redip': {'redipped': [], 'redipping': [], 'redips': []},
 'rediprim': {'rediprime': []},
 'redir': {'redire': ['redires', 'redirent']},
 'redire': ['redires', 'redirent'],
 'redirect': {'redirectable': [],
              'redirected': [],
              'redirecting': [],
              'redirection': ['redirections',
                              'redirectional',
                              'redirectioning'],
              'redirective': [],
              'redirects': []},
 'redirectfromloginpag': {'redirectfromloginpage': []},
 'redirection': ['redirections', 'redirectional', 'redirectioning'],
 'redirector': {'redirectors': []},
 'rediremu': {'rediremus': []},
 'redis': {'redisant': [], 'redise': ['redisent']},
 'redisburs': {'redisbursed': []},
 'redischarg': {'redischarge': ['redischarged']},
 'redischarge': ['redischarged'],
 'redisciplin': {'rediscipline': ['redisciplined'], 'redisciplining': []},
 'rediscipline': ['redisciplined'],
 'redisclos': {'redisclose': ['rediscloses', 'redisclosed'],
               'redisclosing': []},
 'redisclose': ['rediscloses', 'redisclosed'],
 'redisclosur': {'redisclosure': []},
 'rediscount': {'rediscountability': [],
                'rediscountable': [],
                'rediscounted': [],
                'rediscounter': [],
                'rediscounting': [],
                'rediscounts': []},
 'rediscov': {'rediscover': ['rediscovers', 'rediscovered', 'rediscovering'],
              'rediscoving': []},
 'rediscover': {'rediscoverable': [], 'rediscoverer': ['rediscoverers']},
 'rediscoverer': ['rediscoverers'],
 'rediscoveri': {'rediscovery': []},
 'rediscret': {'rediscretization': []},
 'rediscript': {'rediscription': []},
 'rediscuss': {'rediscussed': [],
               'rediscusses': [],
               'rediscussing': [],
               'rediscussion': ['rediscussions']},
 'rediscussion': ['rediscussions'],
 'redise': ['redisent'],
 'redisguis': {'redisguised': []},
 'redish': {'redishes': []},
 'redisinfect': {'redisinfected': []},
 'redisintegr': {'redisintegration': []},
 'redisk': {'rediske': []},
 'redisloc': {'redislocate': ['redislocates', 'redislocated'],
              'redislocating': [],
              'redislocation': ['redislocations']},
 'redislocate': ['redislocates', 'redislocated'],
 'redislocation': ['redislocations'],
 'redisolv': {'redisolved': []},
 'redison': {'redisons': []},
 'redispatch': {'redispatched': [], 'redispatches': [], 'redispatching': []},
 'redispens': {'redispensed': [], 'redispensing': []},
 'redispers': {'redispersable': [],
               'redispersal': [],
               'redisperse': ['redispersed', 'redisperses'],
               'redispersibility': [],
               'redispersible': [],
               'redispersing': [],
               'redispersion': []},
 'redisperse': ['redispersed', 'redisperses'],
 'redisplac': {'redisplace': ['redisplaced', 'redisplacement'],
               'redisplacing': []},
 'redisplace': ['redisplaced', 'redisplacement'],
 'redisplay': {'redisplayed': [], 'redisplaying': [], 'redisplays': []},
 'redispos': {'redisposal': [],
              'redispose': ['redisposes', 'redisposed'],
              'redisposing': []},
 'redispose': ['redisposes', 'redisposed'],
 'redisposit': {'redisposition': []},
 'redisrict': {'redisricting': []},
 'rediss': {'redisse': ['redissent']},
 'redisse': ['redissent'],
 'redissect': {'redissected': [], 'redissection': []},
 'redissemin': {'redisseminate': ['redisseminated'], 'redissemination': []},
 'redisseminate': ['redisseminated'],
 'redissoci': {'redissociate': ['redissociated', 'redissociates'],
               'redissociating': [],
               'redissociation': []},
 'redissociate': ['redissociated', 'redissociates'],
 'redissolut': {'redissolution': []},
 'redissolv': {'redissolvable': [],
               'redissolve': ['redissolved', 'redissolves'],
               'redissolving': []},
 'redissolvc': {'redissolvcs': []},
 'redissolve': ['redissolved', 'redissolves'],
 'redist': {'redistance': []},
 'redistend': {'redistended': []},
 'redistens': {'redistension': []},
 'redistent': {'redistention': []},
 'redistibut': {'redistibution': [], 'redistibutive': []},
 'redistil': {'redistill': ['redistills',
                            'redistilled',
                            'redistilling',
                            'redistillation',
                            'redistillations']},
 'redistill': ['redistills',
               'redistilled',
               'redistilling',
               'redistillation',
               'redistillations'],
 'redistnbut': {'redistnbutes': [], 'redistnbution': [], 'redistnbutive': []},
 'redistribu': {'redistribue': ['redistribuer']},
 'redistribue': ['redistribuer'],
 'redistribur': {'redistriburive': []},
 'redistribut': {'redistributable': ['redistributables'],
                 'redistribute': ['redistributes',
                                  'redistributed',
                                  'redistributer'],
                 'redistributing': [],
                 'redistribution': ['redistributional'],
                 'redistributive': ['redistributively', 'redistributiveness']},
 'redistributable': ['redistributables'],
 'redistribute': ['redistributes', 'redistributed', 'redistributer'],
 'redistribution': {'redistributionism': []},
 'redistributionari': {'redistributionary': []},
 'redistributionist': {'redistributionists': []},
 'redistributiv': {'redistributivism': []},
 'redistributive': ['redistributively', 'redistributiveness'],
 'redistributivo': {'redistributivos': []},
 'redistributlv': {'redistributlve': []},
 'redistributor': {'redistributors': []},
 'redistributori': {'redistributory': []},
 'redistribuzion': {'redistribuzione': []},
 'redistrict': {'redistricted': [],
                'redistricters': [],
                'redistricting': ['redistrictings'],
                'redistricts': []},
 'redistricting': ['redistrictings'],
 'redistrihut': {'redistrihute': ['redistrihuted'],
                 'redistrihuting': [],
                 'redistrihution': [],
                 'redistrihutive': []},
 'redistrihute': ['redistrihuted'],
 'redistrlbut': {'redistrlbutive': []},
 'redistrubut': {'redistrubution': []},
 'redisttibut': {'redisttibution': []},
 'redisturb': {'redisturbed': []},
 'redit': {'redite': ['redited', 'redites'], 'redition': [], 'redits': []},
 'redita': {'reditaments': [], 'reditas': []},
 'reditab': {'reditabs': []},
 'reditari': {'reditary': []},
 'redite': ['redited', 'redites'],
 'rediti': {'redity': []},
 'reditibu': {'reditibus': []},
 'redition': {'reditione': []},
 'reditioni': {'reditionis': []},
 'redito': {'reditos': []},
 'reditor': {'reditors': []},
 'reditqu': {'reditque': []},
 'reditu': {'reditus': []},
 'reditura': {'rediturae': [], 'redituras': []},
 'redituraqu': {'redituraque': []},
 'redituro': {'redituros': []},
 'redituru': {'rediturus': []},
 'reditusqu': {'reditusque': []},
 'redituumqu': {'redituumque': []},
 'rediu': {'redius': []},
 'rediv': {'redival': [], 'redivive': []},
 'rediverg': {'redivergence': ['redivergences'], 'redivergent': []},
 'redivergence': ['redivergences'],
 'redivers': {'rediversion': []},
 'rediversif': {'rediversification': []},
 'rediversifi': {'rediversified': [], 'rediversify': ['rediversifying']},
 'rediversify': ['rediversifying'],
 'redivert': {'rediverted': [], 'rediverting': []},
 'redivid': {'redivide': ['redivides', 'redivided', 'redivider'],
             'redividing': []},
 'redivide': ['redivides', 'redivided', 'redivider'],
 'redividu': {'redividus': []},
 'redivin': {'redivinization': []},
 'redivis': {'redivisible': [], 'redivision': ['redivisions', 'redivisioning']},
 'redivision': ['redivisions', 'redivisioning'],
 'rediviu': {'redivius': []},
 'rediviva': {'redivivae': [], 'redivivas': []},
 'redivivi': {'redivivis': []},
 'rediviviu': {'redivivius': []},
 'redivivn': {'redivivns': []},
 'redivivo': {'redivivos': []},
 'redivivu': {'redivivus': []},
 'redivorc': {'redivorce': ['redivorces', 'redivorced']},
 'redivorce': ['redivorces', 'redivorced'],
 'redivu': {'redivue': [], 'redivus': []},
 'redjacket': {'redjacketed': [], 'redjackets': []},
 'redjang': {'redjangs': []},
 'redjersey': {'redjerseyed': []},
 'redk': {'redke': []},
 'redki': {'redkie': []},
 'redknif': {'redknife': []},
 'redknob': {'redknobbed': []},
 'redknuckl': {'redknuckled': []},
 'redkot': {'redkote': []},
 'redl': {'redle': ['redles'], 'redling': []},
 'redlabel': {'redlabelled': []},
 'redlacqu': {'redlacquer': ['redlacquered']},
 'redlacquer': ['redlacquered'],
 'redlak': {'redlake': ['redlakes']},
 'redlake': ['redlakes'],
 'redland': {'redlander': ['redlanders'], 'redlands': []},
 'redlander': ['redlanders'],
 'redle': ['redles'],
 'redlead': {'redleaded': []},
 'redleaf': {'redleafed': []},
 'redleath': {'redleather': []},
 'redleav': {'redleaved': []},
 'redleg': {'redlegged': [], 'redlegs': []},
 'redlen': {'redlener': []},
 'redler': {'redlers': []},
 'redlett': {'redletter': ['redlettered']},
 'redletter': ['redlettered'],
 'redlhamm': {'redlhammer': []},
 'redli': {'redly': []},
 'redlich': {'redliche': ['redlicher', 'redliches'], 'redlichs': []},
 'redliche': ['redlicher', 'redliches'],
 'redlichiid': {'redlichiids': []},
 'redlid': {'redlidded': []},
 'redlight': {'redlighted': [], 'redlights': []},
 'redlik': {'redlike': []},
 'redlin': {'redline': ['redlined', 'redliner', 'redlines', 'redliners'],
            'redlining': []},
 'redline': ['redlined', 'redliner', 'redlines', 'redliners'],
 'redling': {'redlinger': []},
 'redlinghui': {'redlinghuis': []},
 'redlip': {'redlipped': []},
 'redlist': {'redlisted': []},
 'redliveri': {'redliveried': []},
 'redlli': {'redlly': []},
 'redlook': {'redlooking': []},
 'redlscount': {'redlscounted': []},
 'redlssolv': {'redlssolved': []},
 'redlstribut': {'redlstributive': []},
 'redmaid': {'redmaids': []},
 'redmain': {'redmaine': []},
 'redmak': {'redmaking': []},
 'redman': {'redmaned': [], 'redmans': []},
 'redmantl': {'redmantle': []},
 'redmapl': {'redmaple': []},
 'redmark': {'redmarked': []},
 'redmarn': {'redmarne': []},
 'redmarshal': {'redmarshall': []},
 'redmavn': {'redmavne': []},
 'redmayn': {'redmayne': ['redmaynes']},
 'redmayne': ['redmaynes'],
 'redmer': {'redmere': []},
 'redmil': {'redmile': ['redmiles'], 'redmill': []},
 'redmile': ['redmiles'],
 'redminst': {'redminster': []},
 'redmir': {'redmire': ['redmires']},
 'redmire': ['redmires'],
 'redmon': {'redmons': []},
 'redmond': {'redmondism': [], 'redmonds': []},
 'redmondit': {'redmondite': ['redmondites']},
 'redmondite': ['redmondites'],
 'redmonit': {'redmonite': ['redmonites']},
 'redmonite': ['redmonites'],
 'redmor': {'redmore': []},
 'redmoustach': {'redmoustached': []},
 'redmouth': {'redmouthed': []},
 'redmyr': {'redmyre': []},
 'redn': {'redne': ['rednes'], 'redning': []},
 'rednail': {'rednailed': []},
 'rednal': {'rednall': []},
 'rednc': {'rednce': ['rednces', 'rednced'], 'redncing': []},
 'rednce': ['rednces', 'rednced'],
 'redne': {'redneed': []},
 'redneck': ['rednecked', 'redneckism'],
 'redneckeri': {'redneckery': []},
 'rednecki': {'rednecky': []},
 'rednef': {'rednefs': []},
 'redner': {'redners': []},
 'rednerisch': {'rednerische': []},
 'rednersvil': {'rednersville': []},
 'redness': {'rednesse': []},
 'redno': {'rednoed': []},
 'rednos': {'rednose': ['rednosed']},
 'rednose': ['rednosed'],
 'redo': {'redoes': [], 'redoing': ['redoings'], 'redos': []},
 'redoabl': {'redoable': []},
 'redobl': {'redoble': ['redobles']},
 'redoble': ['redobles'],
 'redoc': {'redoce': ['redoced']},
 'redoce': ['redoced'],
 'redochr': {'redochre': ['redochred']},
 'redochre': ['redochred'],
 'redock': {'redocked': [], 'redocking': []},
 'redocket': {'redocketed': [], 'redocketing': []},
 'redoct': {'redoction': []},
 'redocu': {'redocument': ['redocumented', 'redocumenting']},
 'redocument': {'redocumentation': []},
 'redogjord': {'redogjorde': []},
 'redogjort': {'redogjorts': []},
 'redogor': {'redogores': [], 'redogors': []},
 'redogorels': {'redogorelse': ['redogorelser']},
 'redogorelse': ['redogorelser'],
 'redoi': {'redois': []},
 'redoing': ['redoings'],
 'redol': {'redolant': [],
           'redole': ['redolent',
                      'redolency',
                      'redolence',
                      'redoleant',
                      'redolently']},
 'redole': ['redolent', 'redolency', 'redolence', 'redoleant', 'redolently'],
 'redolen': {'redolens': []},
 'redolent': {'redolente': ['redolentes']},
 'redolente': ['redolentes'],
 'redolentibu': {'redolentibus': []},
 'redolentqu': {'redolentque': []},
 'redoler': {'redolere': []},
 'redoliff': {'redoliffe': []},
 'redolog': {'redology': []},
 'redomest': {'redomesticate': ['redomesticated'],
              'redomesticating': [],
              'redomestication': []},
 'redomesticate': ['redomesticated'],
 'redomicil': {'redomicile': ['redomiciled']},
 'redomicile': ['redomiciled'],
 'redomicili': {'redomiciliation': []},
 'redomin': {'redominance': [],
             'redominant': [],
             'redominate': ['redominated', 'redominates'],
             'redomination': []},
 'redominantli': {'redominantly': []},
 'redominate': ['redominated', 'redominates'],
 'redon': {'redonated': [],
           'redonation': [],
           'redone': ['redones'],
           'redonned': [],
           'redonning': [],
           'redons': []},
 'redond': {'redondance': ['redondances'],
            'redondant': ['redondants'],
            'redonde': ['redondes', 'redonder']},
 'redonda': {'redonda': []},
 'redondament': {'redondamente': []},
 'redondance': ['redondances'],
 'redondant': {'redondante': ['redondantes']},
 'redondante': ['redondantes'],
 'redonde': ['redondes', 'redonder'],
 'redondeada': {'redondeadas': []},
 'redondeado': {'redondeados': []},
 'redondilha': {'redondilhas': []},
 'redondilla': {'redondillas': []},
 'redondo': {'redondos': []},
 'redone': ['redones'],
 'redonensi': {'redonensis': []},
 'redonn': {'redonnant': [], 'redonne': ['redonner', 'redonnent']},
 'redonne': ['redonner', 'redonnent'],
 'redont': {'redonte': []},
 'redooc': {'redooce': ['redooced']},
 'redooce': ['redooced'],
 'redop': {'redoped': [], 'redoping': []},
 'redor': {'redore': ['redorer']},
 'redorang': {'redorange': ['redoranges']},
 'redorange': ['redoranges'],
 'redord': {'redorded': [], 'redords': []},
 'redore': ['redorer'],
 'redort': {'redorte': ['redorted'], 'redorts': []},
 'redorte': ['redorted'],
 'redos': {'redose': ['redosed'], 'redosing': []},
 'redose': ['redosed'],
 'redosi': {'redosier': []},
 'redouan': {'redouane': []},
 'redoubl': {'redoublant': [],
             'redouble': ['redoubler',
                          'redoubled',
                          'redoubles',
                          'redoublent',
                          'redoublement',
                          'redoublements'],
             'redoubling': ['redoublings']},
 'redouble': {'redoublee': ['redoublees']},
 'redoublee': ['redoublees'],
 'redoublemen': {'redoublemens': []},
 'redoubling': ['redoublings'],
 'redoublon': {'redoublons': []},
 'redoubt': ['redoubte',
             'redoubter',
             'redoubted',
             'redoubting',
             'redoubtable',
             'redoubtably',
             'redoubtables',
             'redoubtability'],
 'redouhl': {'redouhle': ['redouhled']},
 'redouhle': ['redouhled'],
 'redouht': {'redouhts': []},
 'redoul': {'redoules': []},
 'redound': {'redounde': ['redounded'], 'redounding': [], 'redounds': []},
 'redounde': ['redounded'],
 'redout': {'redoutable': ['redoutables'],
            'redoutant': [],
            'redoute': ['redoutes', 'redouted', 'redouter', 'redoutent'],
            'redoutions': [],
            'redouts': []},
 'redoutable': ['redoutables'],
 'redoutai': {'redoutaient': [], 'redoutais': []},
 'redoute': {'redoutee': ['redoutees']},
 'redoutee': ['redoutees'],
 'redoutensa': {'redoutensaal': []},
 'redoutensaal': {'redoutensaale': []},
 'redoutensal': {'redoutensale': []},
 'redouton': {'redoutons': []},
 'redova': {'redovas': []},
 'redovisa': {'redovisas': []},
 'redovisad': {'redovisade': ['redovisades']},
 'redovisade': ['redovisades'],
 'redovisat': {'redovisats': []},
 'redovisn': {'redovisning': []},
 'redovr': {'redovre': []},
 'redowa': {'redowas': []},
 'redown': {'redowne': ['redowned']},
 'redownd': {'redownde': []},
 'redowne': ['redowned'],
 'redownload': {'redownloading': []},
 'redp': {'redpe': ['redpes']},
 'redpaint': {'redpainted': []},
 'redpant': {'redpanting': [], 'redpants': []},
 'redpath': {'redpaths': []},
 'redpattern': {'redpatterned': []},
 'redpe': ['redpes'],
 'redpencil': {'redpenciled': []},
 'redpenni': {'redpenny': []},
 'redpepp': {'redpepper': []},
 'redpig': {'redpigmented': []},
 'redpin': {'redpine': []},
 'redplast': {'redplastic': []},
 'redplum': {'redplumed': []},
 'redpoint': {'redpointed': [], 'redpointing': []},
 'redpol': {'redpole': ['redpoles'], 'redpoll': []},
 'redpole': ['redpoles'],
 'redpolish': {'redpolished': []},
 'redposit': {'redpositive': []},
 'redproc': {'redprocal': []},
 'redpurpl': {'redpurple': []},
 'redr': {'redre': ['redred', 'redres'], 'redring': []},
 'redraft': ['redrafted', 'redrafting', 'redraftings'],
 'redrain': {'redrained': [], 'redraining': []},
 'redrainag': {'redrainage': []},
 'redramat': {'redramatization': [],
              'redramatize': ['redramatizes', 'redramatized'],
              'redramatizing': []},
 'redramatize': ['redramatizes', 'redramatized'],
 'redrap': {'redrape': ['redrapes', 'redraped'], 'redraping': []},
 'redrape': ['redrapes', 'redraped'],
 'redraught': {'redraughted': [], 'redraughting': []},
 'redraw': {'redrawal': [],
            'redrawers': [],
            'redrawing': ['redrawings'],
            'redraws': []},
 'redrawal': {'redrawall': []},
 'redrawing': ['redrawings'],
 'redre': ['redred', 'redres'],
 'redream': {'redreamed': [], 'redreaming': [], 'redreams': []},
 'redredg': {'redredge': ['redredged'], 'redredging': []},
 'redredge': ['redredged'],
 'redref': {'redreffed': [], 'redreffing': [], 'redrefs': []},
 'redrefl': {'redrefled': [], 'redrefling': []},
 'redrei': {'redreis': []},
 'redrel': {'redrels': []},
 'redres': {'redrese': ['redresent', 'redresents', 'redresented']},
 'redrese': ['redresent', 'redresents', 'redresented'],
 'redresent': {'redresentation': []},
 'redress': ['redresse',
             'redresser',
             'redressed',
             'redressal',
             'redressant',
             'redressing',
             'redressals',
             'redressive',
             'redression',
             'redressent',
             'redressers',
             'redressible',
             'redressable',
             'redressings',
             'redressment',
             'redressement',
             'redressments',
             'redressements',
             'redressibility',
             'redressability'],
 'redresse': {'redressee': ['redressees']},
 'redressee': ['redressees'],
 'redresseur': {'redresseurs': []},
 'redressor': {'redressors': []},
 'redri': {'redried': [], 'redries': [], 'redry': ['redrying']},
 'redribbon': {'redribboned': []},
 'redric': {'redrice': []},
 'redrid': {'redriding': []},
 'redridg': {'redridge': []},
 'redrier': {'redriers': []},
 'redriff': {'redriffe': []},
 'redril': {'redrill': ['redrilled', 'redrilling']},
 'redrill': ['redrilled', 'redrilling'],
 'redrim': {'redrimmed': []},
 'redring': {'redringed': []},
 'redrint': {'redrinted': []},
 'redrip': {'redripe': []},
 'redriv': {'redrive': ['redriver'], 'redriving': []},
 'redrive': ['redriver'],
 'redrob': {'redrobe': ['redrobed']},
 'redrobe': ['redrobed'],
 'redrock': {'redrocks': []},
 'redroof': {'redroofed': [], 'redroofs': []},
 'redroot': {'redroot': []},
 'redrop': {'redropped': []},
 'redror': {'redrored': []},
 'redros': {'redrose': []},
 'redrov': {'redrove': []},
 'redrump': {'redrumped': []},
 'redruthit': {'redruthite': []},
 'redry': ['redrying'],
 'redsail': {'redsailed': []},
 'redsandston': {'redsandstone': []},
 'redsash': {'redsashed': []},
 'redscal': {'redscale': []},
 'redsdal': {'redsdale': []},
 'redseck': {'redsecker': []},
 'redsel': {'redsell': []},
 'redsensit': {'redsensitive': []},
 'redsequin': {'redsequined': []},
 'redsett': {'redsetter': []},
 'redshad': {'redshaded': []},
 'redshaft': {'redshafted': []},
 'redshank': ['redshanked', 'redshankes'],
 'redshift': ['redshifted', 'redshifting'],
 'redshiftdist': {'redshiftdistance': []},
 'redshingl': {'redshingled': []},
 'redshirt': {'redshirted': [], 'redshirting': [], 'redshirts': []},
 'redshlft': {'redshlfts': []},
 'redshort': {'redshortness': []},
 'redshould': {'redshoulder': ['redshouldered']},
 'redshoulder': ['redshouldered'],
 'redsick': {'redsicker': []},
 'redsid': {'redside': ['redsided', 'redsides']},
 'redside': ['redsided', 'redsides'],
 'redskab': {'redskaber': []},
 'redskap': {'redskaper': []},
 'redski': {'redsky': []},
 'redskin': ['redskinned'],
 'redskinett': {'redskinettes': []},
 'redsleev': {'redsleeved': []},
 'redslip': {'redslipped': []},
 'redsmear': {'redsmeared': []},
 'redsnapp': {'redsnapper': ['redsnappers']},
 'redsnapper': ['redsnappers'],
 'redspeckl': {'redspeckled': []},
 'redspid': {'redspider': []},
 'redspinn': {'redspinner': []},
 'redspir': {'redspire': []},
 'redspot': {'redspotted': []},
 'redstain': {'redstained': [], 'redstaining': []},
 'redstal': {'redstall': []},
 'redstar': {'redstarred': []},
 'redstart': {'redstart': []},
 'redstat': {'redstate': []},
 'redstem': {'redstemmed': []},
 'redstick': {'redsticks': []},
 'redstock': {'redstocking': ['redstockings']},
 'redstocking': {'redstockinged': []},
 'redston': {'redstone': ['redstones']},
 'redstone': ['redstones'],
 'redstrak': {'redstrake': []},
 'redstreak': {'redstreake': ['redstreaked'], 'redstreaks': []},
 'redstreake': ['redstreaked'],
 'redstrip': {'redstripe': ['redstriped']},
 'redstripe': ['redstriped'],
 'redsuit': {'redsuited': []},
 'redswir': {'redswire': []},
 'redt': {'redte': []},
 'redtab': {'redtabbed': []},
 'redtag': {'redtagged': []},
 'redtail': ['redtailed'],
 'redtap': {'redtape': ['redtaped', 'redtapeism'], 'redtapism': []},
 'redtape': ['redtaped', 'redtapeism'],
 'redtapist': {'redtapists': []},
 'redtassel': {'redtasseled': [], 'redtasselled': []},
 'redtenbach': {'redtenbacher': []},
 'redthroat': {'redthroated': [], 'redthroats': []},
 'redthund': {'redthunder': []},
 'redtic': {'redtice': ['redticed']},
 'redtice': ['redticed'],
 'redtid': {'redtide': []},
 'redtil': {'redtile': ['redtiled']},
 'redtile': ['redtiled'],
 'redting': {'redtinged': []},
 'redtint': {'redtinted': []},
 'redtip': {'redtipped': []},
 'redtl': {'redtled': []},
 'redton': {'redtoned': []},
 'redtongu': {'redtongued': []},
 'redtooth': {'redtoothed': []},
 'redtop': {'redtopped': [], 'redtops': []},
 'redtre': {'redtree': []},
 'redtrim': {'redtrimmed': []},
 'redtrous': {'redtrousered': []},
 'redtrunk': {'redtrunked': []},
 'redturban': {'redturbaned': []},
 'redu': {'redue': ['redued', 'redues', 'redueing'],
          'reduing': [],
          'redus': []},
 'redua': {'reduaed': []},
 'redub': {'redubbed': [], 'redubbing': [], 'redubs': []},
 'redubb': {'redubbe': []},
 'redubl': {'redublic': []},
 'reduc': {'reducability': [],
           'reducable': [],
           'reducant': [],
           'reducation': ['reducations'],
           'reducators': [],
           'reducced': [],
           'reduce': ['reduces',
                      'reduced',
                      'reducer',
                      'reducent',
                      'reduceing',
                      'reducents',
                      'reducement',
                      'reduceable',
                      'reducering',
                      'reducements',
                      'reduceability'],
           'reducibilities': [],
           'reducibility': [],
           'reducible': ['reducibles', 'reducibleness'],
           'reducibly': [],
           'reducing': [],
           'reducive': [],
           'reducs': []},
 'reduca': {'reducas': []},
 'reducamu': {'reducamus': []},
 'reducas': {'reducase': []},
 'reducatas': {'reducatase': []},
 'reducati': {'reducatis': []},
 'reducation': ['reducations'],
 'reducats': {'reducatse': []},
 'reduccion': {'reducciones': []},
 'reduce': {'reducee': ['reduceed']},
 'reduced': {'reducedness': []},
 'reducedbi': {'reducedby': []},
 'reducedcalori': {'reducedcalorie': []},
 'reducedgrav': {'reducedgravity': []},
 'reducedinstruct': {'reducedinstruction': []},
 'reducedintens': {'reducedintensity': []},
 'reducedord': {'reducedorder': []},
 'reducedpressur': {'reducedpressure': []},
 'reducedpric': {'reducedprice': []},
 'reducedr': {'reducedrate': []},
 'reducedresolut': {'reducedresolution': []},
 'reduceds': {'reducedsize': []},
 'reducedscal': {'reducedscale': []},
 'reducedth': {'reducedthe': []},
 'reducedtillag': {'reducedtillage': []},
 'reducedvoltag': {'reducedvoltage': []},
 'reducee': ['reduceed'],
 'reducemqu': {'reducemque': []},
 'reducen': {'reducens': []},
 'reducenda': {'reducendae': []},
 'reducendi': {'reducendis': []},
 'reducendo': {'reducendos': []},
 'reducendu': {'reducendus': []},
 'reducent': {'reducente': ['reducentes']},
 'reducente': ['reducentes'],
 'reducer': {'reducere': ['reduceres', 'reducerent']},
 'reducera': {'reduceras': []},
 'reducerad': {'reducerade': ['reducerades']},
 'reducerade': ['reducerades'],
 'reducerat': {'reducerats': []},
 'reducere': ['reduceres', 'reducerent'],
 'reducereti': {'reduceretis': []},
 'reducesth': {'reducesthe': []},
 'reduceth': {'reducethe': []},
 'reduci': {'reducis': []},
 'reducias': {'reduciase': []},
 'reducibili': {'reducibilis': []},
 'reducible': ['reducibles', 'reducibleness'],
 'reducida': {'reducidas': []},
 'reducido': {'reducidos': []},
 'reduciendos': {'reduciendose': []},
 'reducihl': {'reducihle': []},
 'reducillo': {'reducillos': []},
 'reducimu': {'reducimus': []},
 'reducin': {'reducine': [], 'reducins': []},
 'reducing': {'reducinge': []},
 'reducingag': {'reducingagent': []},
 'reducingbal': {'reducingbalance': []},
 'reducingli': {'reducingly': []},
 'reducingth': {'reducingthe': []},
 'reducingvalv': {'reducingvalve': []},
 'reducion': {'reduciones': [], 'reducions': []},
 'reducirend': {'reducirende': []},
 'reducirl': {'reducirle': []},
 'reducirla': {'reducirlas': []},
 'reducirlo': {'reducirlos': []},
 'reducirs': {'reducirse': []},
 'reducirt': {'reducirte': []},
 'reducit': {'reducite': []},
 'reduclas': {'reduclase': []},
 'reduclion': {'reduclionism': []},
 'reduco': {'reducoes': []},
 'reducrion': {'reducrionism': []},
 'reduct': {'reductance': [],
            'reductant': [],
            'reducte': ['reducted'],
            'reductibility': [],
            'reductible': ['reductibles'],
            'reductic': [],
            'reducting': [],
            'reduction': ['reductional', 'reductionally'],
            'reductive': ['reductives', 'reductively', 'reductiveness'],
            'reductivity': [],
            'reducts': []},
 'reducta': {'reductae': [], 'reductas': []},
 'reductan': {'reductans': []},
 'reductas': {'reductase': []},
 'reductasedefici': {'reductasedeficient': []},
 'reducte': ['reducted'],
 'reducteur': {'reducteurs': []},
 'reducth': {'reducthe': []},
 'reducti': {'reductie': [], 'reductiou': [], 'reductis': []},
 'reductible': ['reductibles'],
 'reductimetr': {'reductimetric': []},
 'reductio': {'reductio': []},
 'reduction': {'reductionalism': [],
               'reductione': ['reductiones'],
               'reductionism': []},
 'reductionalist': {'reductionalistic': ['reductionalistically']},
 'reductionalistic': ['reductionalistically'],
 'reductionari': {'reductionary': []},
 'reductiondivis': {'reductiondivision': []},
 'reductione': ['reductiones'],
 'reductioni': {'reductionis': []},
 'reductioninth': {'reductioninthe': []},
 'reductionist': {'reductionistic': ['reductionistically'],
                  'reductionists': []},
 'reductionistic': ['reductionistically'],
 'reductionnism': {'reductionnisme': []},
 'reductionnist': {'reductionniste': []},
 'reductiontub': {'reductiontube': []},
 'reductionwork': {'reductionworks': []},
 'reductiv': {'reductivism': []},
 'reductive': ['reductives', 'reductively', 'reductiveness'],
 'reductivist': {'reductivistic': [], 'reductivists': []},
 'reductlon': {'reductlons': []},
 'reducto': {'reductos': []},
 'reductoisomeras': {'reductoisomerase': []},
 'reductometr': {'reductometric': []},
 'reducton': {'reductone': ['reductones']},
 'reductone': ['reductones'],
 'reductor': {'reductores': [], 'reductors': []},
 'reductora': {'reductoras': []},
 'reductos': {'reductose': []},
 'reductric': {'reductrice': ['reductrices']},
 'reductrice': ['reductrices'],
 'reductu': {'reductus': []},
 'redud': {'redudancy': [], 'redudant': [], 'reduded': []},
 'redudt': {'redudtion': []},
 'redue': {'reduee': ['redueed', 'reduees']},
 'reduee': ['redueed', 'reduees'],
 'reduet': {'reduetion': ['reduetions']},
 'reduetas': {'reduetase': []},
 'reduetion': {'reduetionism': []},
 'reduft': {'reduftion': []},
 'redui': {'reduis': []},
 'reduict': {'reduicte': ['reduictes'], 'reduicts': []},
 'reduicte': ['reduictes'],
 'reduir': {'reduire': ['reduired']},
 'reduirai': {'reduiraient': []},
 'reduire': ['reduired'],
 'reduis': {'reduisant': [], 'reduise': ['reduisent']},
 'reduisai': {'reduisaient': []},
 'reduise': ['reduisent'],
 'reduisir': {'reduisirent': []},
 'reduisit': {'reduisites': []},
 'reduisoi': {'reduisoient': []},
 'reduison': {'reduisons': []},
 'reduit': {'reduite': ['reduites'], 'reduits': []},
 'reduite': ['reduites'],
 'redukcj': {'redukcje': []},
 'redukt': {'reduktion': ['reduktions'], 'reduktive': []},
 'reduktas': {'reduktase': []},
 'reduktion': ['reduktions'],
 'reduktionismu': {'reduktionismus': []},
 'reduktionistisch': {'reduktionistische': []},
 'reduktionsprodukt': {'reduktionsprodukte': []},
 'reduktionsprozess': {'reduktionsprozesse': []},
 'redul': {'redulity': [], 'redulous': []},
 'redump': {'redumped': []},
 'redumpt': {'redumption': []},
 'redun': {'redunancy': [], 'redunant': []},
 'redunc': {'reduncancy': []},
 'reduncin': {'reduncine': ['reduncines']},
 'reduncina': {'reduncinae': []},
 'reduncine': ['reduncines'],
 'reduncu': {'reduncus': []},
 'redund': {'redundance': [],
            'redundancy': [],
            'redundant': ['redundants'],
            'redunde': ['redundent', 'redundency', 'redundencies']},
 'redundab': {'redundabant': []},
 'redundaci': {'redundacies': [], 'redundacy': []},
 'redundan': {'redundans': []},
 'redundanci': {'redundancie': []},
 'redundandi': {'redundandy': []},
 'redundani': {'redundany': []},
 'redundant': {'redundante': ['redundanter', 'redundantes']},
 'redundante': ['redundanter', 'redundantes'],
 'redundantli': {'redundantly': []},
 'redundar': {'redundare': ['redundarent']},
 'redundare': ['redundarent'],
 'redundass': {'redundasse': []},
 'redunde': ['redundent', 'redundency', 'redundencies'],
 'reduniform': {'reduniformed': []},
 'redunt': {'reduntant': []},
 'reduntantli': {'reduntantly': []},
 'reduo': {'reduoe': ['reduoes', 'reduoed'], 'reduoing': []},
 'reduoe': ['reduoes', 'reduoed'],
 'reduot': {'reduotion': ['reduotions']},
 'reduotion': ['reduotions'],
 'redup': {'reduped': [], 'redupers': []},
 'redupholst': {'redupholstered': []},
 'redupl': {'reduplicate': ['reduplicates', 'reduplicated'],
            'reduplicating': [],
            'reduplication': ['reduplicational'],
            'reduplicative': ['reduplicatives', 'reduplicatively'],
            'reduplicator': []},
 'reduplic': {'reduplicable': [], 'reduplicant': ['reduplicants']},
 'reduplicant': ['reduplicants'],
 'reduplicate': ['reduplicates', 'reduplicated'],
 'reduplication': {'reduplicatione': []},
 'reduplicative': ['reduplicatives', 'reduplicatively'],
 'reduplicatori': {'reduplicatory': []},
 'reduplicatur': {'reduplicature': []},
 'reduplik': {'reduplikation': []},
 'redupliziert': {'reduplizierte': []},
 'reduq': {'reduqed': []},
 'redur': {'redure': ['redured'], 'reduring': []},
 'redure': ['redured'],
 'redurt': {'redurtion': []},
 'redus': {'reduse': ['redused'], 'redusing': [], 'redusion': []},
 'reduse': ['redused'],
 'reduser': {'redusere': ['reduseres', 'reduserer']},
 'redusere': ['reduseres', 'reduserer'],
 'reduserend': {'reduserende': []},
 'redusert': {'reduserte': []},
 'redusii': {'redusiis': []},
 'reduss': {'redusse': []},
 'redust': {'redusted': [], 'redusting': [], 'redustion': []},
 'redut': {'redute': ['reduted'], 'redution': []},
 'redutas': {'redutase': []},
 'redute': ['reduted'],
 'reduttion': {'reduttione': []},
 'reduvida': {'reduvidae': []},
 'reduviid': {'reduviid': []},
 'reduviida': {'reduviidae': []},
 'reduviidc': {'reduviidce': []},
 'reduviids': {'reduviidse': []},
 'reduviina': {'reduviinae': []},
 'reduviolu': {'reduviolus': []},
 'reduviu': {'reduvius': []},
 'reduzida': {'reduzidas': []},
 'reduzido': {'reduzidos': []},
 'reduzier': {'reduziere': []},
 'reduzierend': {'reduzierende': ['reduzierender']},
 'reduzierende': ['reduzierender'],
 'reduziert': {'reduzierte': ['reduzierter', 'reduziertes']},
 'reduzierte': ['reduzierter', 'reduziertes'],
 'redval': {'redvale': ['redvales']},
 'redvale': ['redvales'],
 'redvanli': {'redvanly': []},
 'redvcr': {'redvcrs': []},
 'redvein': {'redveined': []},
 'redvent': {'redvented': []},
 'redver': {'redvers': []},
 'redvest': {'redvested': []},
 'redvil': {'redville': []},
 'redw': {'redwing': []},
 'redwal': {'redwall': ['redwalled']},
 'redwall': ['redwalled'],
 'redwar': {'redware': ['redwares']},
 'redward': {'redwards': []},
 'redware': ['redwares'],
 'redwash': {'redwashed': []},
 'redwat': {'redwater': []},
 'redwattl': {'redwattled': []},
 'redway': {'redways': []},
 'redwe': {'redweed': []},
 'redwel': {'redwell': []},
 'redwheel': {'redwheeled': []},
 'redwheelweis': {'redwheelweiser': []},
 'redwhisk': {'redwhiskered': []},
 'redwhit': {'redwhite': []},
 'redwin': {'redwine': []},
 'redwing': {'redwinged': []},
 'redwood': {'redwood': []},
 'redword': {'redwords': []},
 'redworm': {'redworms': []},
 'redworth': {'redworths': []},
 'redwrap': {'redwrapped': []},
 'redy': {'redye': ['redyeing'], 'redyness': []},
 'redye': ['redyeing'],
 'redyli': {'redyly': []},
 'redyn': {'redynes': []},
 'redynam': {'redynamization': [], 'redynamize': []},
 'redynamis': {'redynamisation': [], 'redynamise': ['redynamiser']},
 'redynamise': ['redynamiser'],
 'redyness': {'redynesse': []},
 'redyng': {'redynge': ['redynges']},
 'redynge': ['redynges'],
 'redynvr': {'redynvre': []},
 'redzon': {'redzone': []},
 'ree': {'reeing': [], 'rees': []},
 'reea': {'reeas': []},
 'reeabl': {'reeable': []},
 'reeal': {'reealed': [], 'reeals': []},
 'reeall': {'reealled': [], 'reealling': [], 'reealls': []},
 'reean': {'reeans': []},
 'reearcher': {'reearchers': []},
 'reeard': {'reearded': [], 'reearding': [], 'reeards': []},
 'reearn': {'reearned': []},
 'reeas': {'reease': ['reeased']},
 'reease': ['reeased'],
 'reeat': {'reeated': [], 'reeating': []},
 'reeb': {'reebe': [], 'reebs': []},
 'reebe': {'reebee': []},
 'reebi': {'reebie': ['reebies'], 'reeby': []},
 'reebie': ['reebies'],
 'reebl': {'reeble': []},
 'reebock': {'reebocks': []},
 'reebok': {'reeboks': []},
 'reeboot': {'reebooting': []},
 'reeby': {'reebye': []},
 'reec': {'reece': ['reeces']},
 'reeccho': {'reecchoing': []},
 'reece': ['reeces'],
 'reeceiv': {'reeceived': []},
 'reecent': {'reecently': []},
 'reech': {'reeched': [], 'reeches': [], 'reeching': []},
 'reechelonn': {'reechelonnement': []},
 'reechi': {'reechy': []},
 'reecho': {'reechoed': [], 'reechoes': [], 'reechoing': ['reechoings']},
 'reechoing': ['reechoings'],
 'reeci': {'reecie': [], 'reecy': []},
 'reecipt': {'reecipts': []},
 'reeciv': {'reecive': ['reecived', 'reeciver', 'reecives'], 'reeciving': []},
 'reecive': ['reecived', 'reeciver', 'reecives'],
 'reecken': {'reeckening': []},
 'reecntli': {'reecntly': []},
 'reecrir': {'reecrire': []},
 'reecrit': {'reecrite': []},
 'reecritur': {'reecriture': ['reecritures']},
 'reecriture': ['reecritures'],
 'reect': {'reected': [], 'reecting': [], 'reects': []},
 'reection': {'reections': []},
 'reectiv': {'reective': []},
 'reed': ['reede', 'reeded', 'reedes', 'reeding', 'reedness', 'reedings'],
 'reedal': {'reedall': []},
 'reedb': {'reedbed': ['reedbeds']},
 'reedbank': {'reedbanks': []},
 'reedbed': ['reedbeds'],
 'reedbird': {'reedbird': []},
 'reedbook': {'reedbooks': []},
 'reedbord': {'reedbordered': []},
 'reedbuck': {'reedbucks': []},
 'reedbulwinkl': {'reedbulwinkle': []},
 'reedbunt': {'reedbunting': []},
 'reedchok': {'reedchoked': []},
 'reedcov': {'reedcovered': []},
 'reedcutt': {'reedcutter': ['reedcutters']},
 'reedcutter': ['reedcutters'],
 'reeddraw': {'reeddrawing': []},
 'reedeem': {'reedeemed': [], 'reedeemer': []},
 'reedem': {'reedemed': [], 'reedemer': []},
 'reeder': {'reederer': [], 'reeders': []},
 'reedfil': {'reedfilled': []},
 'reedfish': {'reedfishes': []},
 'reedflut': {'reedflute': []},
 'reedfring': {'reedfringed': []},
 'reedgrass': {'reedgrasses': []},
 'reedi': {'reedie': ['reedies'], 'reediness': [], 'reedy': ['reedys']},
 'reedicion': {'reediciones': []},
 'reedicul': {'reediculous': []},
 'reedie': ['reedies'],
 'reediemadeasi': {'reediemadeasy': []},
 'reedif': {'reedification': []},
 'reedifi': {'reedifie': ['reedified'], 'reedify': ['reedifying']},
 'reedificar': {'reedificare': []},
 'reedifie': ['reedified'],
 'reedify': ['reedifying'],
 'reedili': {'reedily': []},
 'reedinstru': {'reedinstrument': ['reedinstruments']},
 'reedinstrument': ['reedinstruments'],
 'reedit': {'reedite': ['reediter', 'reedited', 'reedites'],
            'reediting': ['reeditings'],
            'reedition': ['reeditions'],
            'reedits': []},
 'reedite': {'reeditee': ['reeditees']},
 'reeditee': ['reeditees'],
 'reediting': ['reeditings'],
 'reedition': ['reeditions'],
 'reedl': {'reedle': [], 'reedling': ['reedlings']},
 'reedland': {'reedlands': []},
 'reedli': {'reedly': []},
 'reedlik': {'reedlike': []},
 'reedlin': {'reedlined': []},
 'reedling': ['reedlings'],
 'reedmac': {'reedmace': []},
 'reedmak': {'reedmaker': ['reedmakers'], 'reedmaking': []},
 'reedmaker': ['reedmakers'],
 'reedmat': {'reedmats': [], 'reedmatting': []},
 'reedmergnerit': {'reedmergnerite': []},
 'reedminst': {'reedminster': []},
 'reedmul': {'reedmuller': []},
 'reedolithu': {'reedolithus': []},
 'reedom': {'reedome': [], 'reedoms': []},
 'reedpip': {'reedpipe': ['reedpipes']},
 'reedpipe': ['reedpipes'],
 'reedplain': {'reedplains': []},
 'reedprentic': {'reedprentice': []},
 'reedsdal': {'reedsdale': []},
 'reedsmer': {'reedsmere': []},
 'reedstalk': {'reedstalks': []},
 'reedstem': {'reedstems': []},
 'reedsvil': {'reedsville': []},
 'reedswamp': {'reedswamps': []},
 'reedswir': {'reedswire': []},
 'reedthatch': {'reedthatched': []},
 'reedtyp': {'reedtype': []},
 'reedu': {'reedus': []},
 'reeduc': {'reeducate': ['reeducated', 'reeducates'],
            'reeducating': [],
            'reeducation': ['reeducations', 'reeducational'],
            'reeducative': [],
            'reeducator': ['reeducators']},
 'reeducate': ['reeducated', 'reeducates'],
 'reeducation': ['reeducations', 'reeducational'],
 'reeducator': ['reeducators'],
 'reeduct': {'reeduction': []},
 'reeduqu': {'reeduquer': []},
 'reedvil': {'reedville': []},
 'reedwarbl': {'reedwarbler': ['reedwarblers']},
 'reedwarbler': ['reedwarblers'],
 'reedwat': {'reedwater': []},
 'reedy': ['reedys'],
 'reedyvil': {'reedyville': []},
 'reee': {'reees': []},
 'reeealli': {'reeeally': []},
 'reeeat': {'reeeated': []},
 'reeed': {'reeede': ['reeeded'], 'reeeding': []},
 'reeede': ['reeeded'],
 'reeeealli': {'reeeeally': []},
 'reeeeealli': {'reeeeeally': []},
 'reeeeeealli': {'reeeeeeally': []},
 'reeeh': {'reeehed': []},
 'reeeipt': {'reeeipts': []},
 'reeeir': {'reeeire': ['reeeired']},
 'reeeire': ['reeeired'],
 'reeeit': {'reeeited': []},
 'reeeiv': {'reeeive': ['reeeived', 'reeeives'], 'reeeiving': []},
 'reeeive': ['reeeived', 'reeeives'],
 'reeeiver': {'reeeivers': []},
 'reeeli': {'reeely': []},
 'reeelv': {'reeelve': ['reeelved']},
 'reeelve': ['reeelved'],
 'reeembl': {'reeemble': [], 'reeembling': []},
 'reeen': {'reeens': []},
 'reeent': {'reeented': []},
 'reeentli': {'reeently': []},
 'reeeon': {'reeeone': []},
 'reeeptacl': {'reeeptacle': []},
 'reeeptiv': {'reeeptive': []},
 'reeeptor': {'reeeptors': []},
 'reeer': {'reeerred': []},
 'reeerenc': {'reeerence': ['reeerences']},
 'reeerence': ['reeerences'],
 'reeerv': {'reeerve': ['reeerved', 'reeerves']},
 'reeerve': {'reeervee': []},
 'reeess': {'reeesses': []},
 'reef': ['reefe', 'reefed', 'reefing'],
 'reefabl': {'reefable': []},
 'reefassoci': {'reefassociated': []},
 'reefband': {'reefbands': []},
 'reefbas': {'reefbase': []},
 'reefbuild': {'reefbuilders': [], 'reefbuilding': []},
 'reefcor': {'reefcorals': []},
 'reefderiv': {'reefderived': []},
 'reefdwel': {'reefdwellers': [], 'reefdwelling': []},
 'reefer': {'reefer': []},
 'reefermak': {'reefermakers': []},
 'reefform': {'reefforming': []},
 'reeffring': {'reeffringed': []},
 'reefhui': {'reefhuis': []},
 'reefi': {'reefy': []},
 'reefian': {'reefians': []},
 'reefin': {'reefined': []},
 'reefinfest': {'reefinfested': []},
 'reeflik': {'reeflike': []},
 'reeflimeston': {'reeflimestones': []},
 'reeflin': {'reefline': []},
 'reefogen': {'reefogenic': []},
 'reefoid': {'reefoidal': []},
 'reefpoint': {'reefpoints': []},
 'reefprotect': {'reefprotected': []},
 'reefscap': {'reefscape': []},
 'reeftackl': {'reeftackles': []},
 'reefward': {'reefwards': []},
 'reeg': {'reege': []},
 'reegin': {'reegineering': []},
 'reegiou': {'reegious': []},
 'reehabit': {'reehabites': []},
 'reehart': {'reeharter': []},
 'reeherch': {'reeherches': []},
 'reehereh': {'reeherehes': []},
 'reehl': {'reehling': []},
 'reehold': {'reeholders': []},
 'reehristen': {'reehristened': []},
 'reeht': {'reehte': [], 'reehts': []},
 'reehui': {'reehuis': []},
 'reei': {'reeis': []},
 'reeid': {'reeide': ['reeided']},
 'reeide': ['reeided'],
 'reeidenc': {'reeidence': []},
 'reeident': {'reeidente': []},
 'reeidu': {'reeidue': []},
 'reeietanc': {'reeietance': []},
 'reeim': {'reeime': []},
 'reeingin': {'reeingineering': []},
 'reeion': {'reeions': []},
 'reeip': {'reeipe': ['reeipes']},
 'reeipe': ['reeipes'],
 'reeiper': {'reeipere': []},
 'reeipient': {'reeipients': []},
 'reeiproc': {'reeiprocal': []},
 'reeistanc': {'reeistance': []},
 'reeister': {'reeistered': []},
 'reeistrat': {'reeistration': []},
 'reeit': {'reeite': ['reeited'], 'reeiting': []},
 'reeitat': {'reeitation': []},
 'reeite': ['reeited'],
 'reeiv': {'reeive': ['reeived'], 'reeiving': []},
 'reeive': ['reeived'],
 'reeject': {'reejected': []},
 'reek': ['reeke', 'reekes', 'reeked', 'reeking', 'reekings'],
 'reeker': {'reekers': []},
 'reeki': {'reekie': [], 'reeky': []},
 'reekingli': {'reekingly': []},
 'reekman': {'reekmans': []},
 'reekon': {'reekoned': [], 'reekoning': []},
 'reel': ['reele', 'reeled', 'reeles', 'reeling', 'reelings'],
 'reelabl': {'reelability': [], 'reelable': []},
 'reelabor': {'reelaborate': ['reelaborates', 'reelaborated'],
              'reelaborating': [],
              'reelaboration': ['reelaborations']},
 'reelaborate': ['reelaborates', 'reelaborated'],
 'reelaboration': ['reelaborations'],
 'reelaim': {'reelaimed': [], 'reelaiming': []},
 'reelam': {'reelamation': []},
 'reelanc': {'reelance': []},
 'reelcct': {'reelccted': []},
 'reelect': {'reelectability': [],
             'reelectable': [],
             'reelected': [],
             'reelecting': [],
             'reelection': [],
             'reelects': []},
 'reelection': {'reelectionism': []},
 'reelectionist': {'reelectionists': []},
 'reelecto': {'reelectos': []},
 'reelector': {'reelectoral': []},
 'reelectrophores': {'reelectrophoresed': []},
 'reelectrophoresi': {'reelectrophoresis': []},
 'reeled': {'reeleder': []},
 'reeleet': {'reeleeted': []},
 'reeleot': {'reeleoted': []},
 'reeler': {'reeler': []},
 'reelev': {'reelevate': ['reelevated'],
            'reelevating': [],
            'reelevation': ['reelevations']},
 'reelevate': ['reelevated'],
 'reelevation': ['reelevations'],
 'reelf': {'reelfs': []},
 'reeli': {'reelied': [], 'reely': []},
 'reelicit': {'reelicitation': [], 'reelicited': [], 'reeliciting': []},
 'reelig': {'reeligibility': [], 'reeligible': ['reeligibles']},
 'reeligible': ['reeligibles'],
 'reelin': {'reelining': []},
 'reelingli': {'reelingly': []},
 'reelis': {'reelise': ['reelises']},
 'reelise': ['reelises'],
 'reelist': {'reelistic': []},
 'reeliti': {'reelity': []},
 'reeliz': {'reelize': ['reelized']},
 'reelize': ['reelized'],
 'reell': {'reelle': ['reelles']},
 'reelle': ['reelles'],
 'reelli': {'reelly': []},
 'reellin': {'reelline': []},
 'reelmak': {'reelmakers': []},
 'reelsvil': {'reelsville': []},
 'reelu': {'reelus': []},
 'reelus': {'reeluse': [], 'reelusion': []},
 'reem': {'reeme': ['reemes', 'reemed'], 'reeming': [], 'reems': []},
 'reemasonri': {'reemasonry': []},
 'reemb': {'reembed': ['reembeds']},
 'reembark': {'reembarkation': [],
              'reembarked': [],
              'reembarking': [],
              'reembarkment': [],
              'reembarks': []},
 'reembed': {'reembedded': [], 'reembedding': []},
 'reembellish': {'reembellished': []},
 'reember': {'reembered': []},
 'reembodi': {'reembodied': [],
              'reembodies': [],
              'reembodiment': ['reembodiments'],
              'reembody': ['reembodying']},
 'reembodiment': ['reembodiments'],
 'reembody': ['reembodying'],
 'reembol': {'reembolization': []},
 'reembols': {'reembolsable': ['reembolsables']},
 'reembolsable': ['reembolsables'],
 'reembolso': {'reembolsos': []},
 'reembrac': {'reembrace': ['reembraced', 'reembraces'], 'reembracing': []},
 'reembrace': ['reembraced', 'reembraces'],
 'reembroid': {'reembroidered': []},
 'reemburs': {'reemburse': ['reembursement']},
 'reemburse': ['reembursement'],
 'reeme': ['reemes', 'reemed'],
 'reememori': {'reememory': []},
 'reement': {'reements': []},
 'reemer': {'reemers': []},
 'reemerg': {'reemerge': ['reemerged',
                          'reemerges',
                          'reemergent',
                          'reemergence',
                          'reemergences'],
             'reemerging': []},
 'reemerge': ['reemerged',
              'reemerges',
              'reemergent',
              'reemergence',
              'reemergences'],
 'reemi': {'reemy': []},
 'reemigr': {'reemigrants': [],
             'reemigrate': ['reemigrated'],
             'reemigrating': [],
             'reemigration': []},
 'reemigrate': ['reemigrated'],
 'reemiss': {'reemission': ['reemissions']},
 'reemission': ['reemissions'],
 'reemit': {'reemits': [], 'reemitted': [], 'reemitting': []},
 'reemphas': {'reemphases': [],
              'reemphasize': ['reemphasized', 'reemphasizes'],
              'reemphasizing': []},
 'reemphasi': {'reemphasis': []},
 'reemphasis': {'reemphasise': ['reemphasises', 'reemphasised'],
                'reemphasising': []},
 'reemphasise': ['reemphasises', 'reemphasised'],
 'reemphasize': ['reemphasized', 'reemphasizes'],
 'reemphaslz': {'reemphaslzed': []},
 'reemplac': {'reemplace': ['reemplacement']},
 'reemplace': ['reemplacement'],
 'reemplazada': {'reemplazadas': []},
 'reemplazado': {'reemplazados': []},
 'reemplazarlo': {'reemplazarlos': []},
 'reemplazars': {'reemplazarse': []},
 'reemplazo': {'reemplazos': []},
 'reemplot': {'reemplotment': []},
 'reemploy': {'reemployability': [],
              'reemployable': [],
              'reemployed': [],
              'reemploying': [],
              'reemployment': ['reemployments'],
              'reemploys': []},
 'reemployment': ['reemployments'],
 'reempow': {'reempower': ['reempowers', 'reempowered', 'reempowering']},
 'reempower': {'reempowerment': []},
 'reempt': {'reempts': []},
 'reempti': {'reemptied': []},
 'reemsnyd': {'reemsnyder': []},
 'reemulsif': {'reemulsification': []},
 'reemulsifi': {'reemulsified': [], 'reemulsify': []},
 'reen': {'reene': ['reened', 'reenes'], 'reening': [], 'reens': []},
 'reenabl': {'reenable': ['reenabled', 'reenables'], 'reenabling': []},
 'reenable': ['reenabled', 'reenables'],
 'reenacr': {'reenacrment': []},
 'reenact': {'reenactable': [],
             'reenacted': [],
             'reenacters': [],
             'reenacting': [],
             'reenaction': ['reenactions'],
             'reenactive': [],
             'reenactment': [],
             'reenacts': []},
 'reenaction': ['reenactions'],
 'reenactor': {'reenactor': []},
 'reenaet': {'reenaeted': [], 'reenaetment': []},
 'reenag': {'reenage': ['reenager', 'reenagers']},
 'reenage': ['reenager', 'reenagers'],
 'reenamel': {'reenameled': []},
 'reenaot': {'reenaoted': []},
 'reenc': {'reence': []},
 'reencapsul': {'reencapsulated': []},
 'reenchant': {'reenchanted': [],
               'reenchanting': [],
               'reenchantment': [],
               'reenchants': []},
 'reenciph': {'reenciphered': []},
 'reencipher': {'reencipherment': []},
 'reenclos': {'reenclose': ['reencloses', 'reenclosed'], 'reenclosing': []},
 'reenclose': ['reencloses', 'reenclosed'],
 'reenclosur': {'reenclosure': []},
 'reencod': {'reencode': ['reencoded', 'reencodes'], 'reencoding': []},
 'reencode': ['reencoded', 'reencodes'],
 'reencount': {'reencounter': ['reencounters',
                               'reencountered',
                               'reencountering']},
 'reencounter': ['reencounters', 'reencountered', 'reencountering'],
 'reencourag': {'reencourage': ['reencouraged']},
 'reencourage': ['reencouraged'],
 'reencrypt': {'reencrypted': [],
               'reencrypting': [],
               'reencryption': [],
               'reencrypts': []},
 'reencultur': {'reenculturation': []},
 'reender': {'reenders': []},
 'reendors': {'reendorse': ['reendorsed', 'reendorses', 'reendorsement'],
              'reendorsing': []},
 'reendorse': ['reendorsed', 'reendorses', 'reendorsement'],
 'reendothel': {'reendothelization': []},
 'reendotheli': {'reendothelialization': [], 'reendothelialized': []},
 'reendow': {'reendowed': [], 'reendowing': [], 'reendowment': []},
 'reene': {'reenee': []},
 'reenen': {'reenens': []},
 'reenerg': {'reenergization': [],
             'reenergize': ['reenergizer', 'reenergizes', 'reenergized'],
             'reenergizing': []},
 'reenergis': {'reenergise': ['reenergised'], 'reenergising': []},
 'reenergise': ['reenergised'],
 'reenergize': ['reenergizer', 'reenergizes', 'reenergized'],
 'reenfor': {'reenforeement': ['reenforeements'], 'reenforeing': []},
 'reenforc': {'reenforce': ['reenforced',
                            'reenforcer',
                            'reenforces',
                            'reenforcers',
                            'reenforcement'],
              'reenforcing': []},
 'reenforcc': {'reenforccment': ['reenforccments']},
 'reenforccment': ['reenforccments'],
 'reenforce': ['reenforced',
               'reenforcer',
               'reenforces',
               'reenforcers',
               'reenforcement'],
 'reenforcein': {'reenforceinents': []},
 'reenforcemcnt': {'reenforcemcnts': []},
 'reenforcement': {'reenforcemente': []},
 'reenforceni': {'reenforcenients': []},
 'reenfore': {'reenforee': ['reenforeed']},
 'reenforee': ['reenforeed'],
 'reenforeement': ['reenforeements'],
 'reenforo': {'reenforoed': []},
 'reenfranchis': {'reenfranchise': ['reenfranchised', 'reenfranchisement'],
                  'reenfranchising': []},
 'reenfranchise': ['reenfranchised', 'reenfranchisement'],
 'reengag': {'reengage': ['reengages',
                          'reengaged',
                          'reengagement',
                          'reengagements'],
             'reengaging': []},
 'reengage': ['reengages', 'reengaged', 'reengagement', 'reengagements'],
 'reengend': {'reengender': ['reengenders', 'reengendered', 'reengendering']},
 'reengender': ['reengenders', 'reengendered', 'reengendering'],
 'reengin': {'reengine': ['reengined',
                          'reengineer',
                          'reengineers',
                          'reengineered',
                          'reengineering',
                          'reengineerings'],
             'reengining': []},
 'reenginc': {'reengincering': []},
 'reengine': ['reengined',
              'reengineer',
              'reengineers',
              'reengineered',
              'reengineering',
              'reengineerings'],
 'reenginecr': {'reenginecring': []},
 'reengmeer': {'reengmeering': []},
 'reengrav': {'reengrave': ['reengraved'], 'reengraving': ['reengravings']},
 'reengrave': ['reengraved'],
 'reengraving': ['reengravings'],
 'reengross': {'reengrossed': []},
 'reengu': {'reengus': []},
 'reengulf': {'reengulfed': [], 'reengulfment': []},
 'reenhanc': {'reenhanced': [], 'reenhancement': []},
 'reenhous': {'reenhouse': []},
 'reeni': {'reenie': [], 'reeny': []},
 'reenjoy': {'reenjoyed': [], 'reenjoyment': []},
 'reenkindl': {'reenkindle': ['reenkindled']},
 'reenkindle': ['reenkindled'],
 'reenlarg': {'reenlarge': ['reenlarged', 'reenlargement']},
 'reenlarge': ['reenlarged', 'reenlargement'],
 'reenlighten': {'reenlightened': []},
 'reenlist': {'reenlisted': [],
              'reenlisting': [],
              'reenlistment': [],
              'reenlists': []},
 'reenliste': {'reenlistee': ['reenlistees']},
 'reenlistee': ['reenlistees'],
 'reenliven': {'reenlivened': [], 'reenlivening': [], 'reenlivens': []},
 'reenmesh': {'reenmeshed': []},
 'reenrich': {'reenriched': [], 'reenriching': [], 'reenrichment': []},
 'reenrol': {'reenroll': ['reenrolls',
                          'reenrolled',
                          'reenrolling',
                          'reenrollment',
                          'reenrollments'],
             'reenrolment': []},
 'reenroll': ['reenrolls',
              'reenrolled',
              'reenrolling',
              'reenrollment',
              'reenrollments'],
 'reensconc': {'reensconced': []},
 'reenserf': {'reenserfment': []},
 'reenshrin': {'reenshrined': [], 'reenshrinement': []},
 'reenslav': {'reenslave': ['reenslaved', 'reenslavement'], 'reenslaving': []},
 'reenslave': ['reenslaved', 'reenslavement'],
 'reensur': {'reensure': []},
 'reent': {'reents': []},
 'reentangl': {'reentangle': ['reentangled', 'reentanglement']},
 'reentangle': ['reentangled', 'reentanglement'],
 'reenter': {'reenterable': [],
             'reentered': [],
             'reentering': [],
             'reenters': []},
 'reenthron': {'reenthrone': ['reenthroned', 'reenthronement'],
               'reenthroning': []},
 'reenthrone': ['reenthroned', 'reenthronement'],
 'reentitl': {'reentitled': [], 'reentitlement': [], 'reentitling': []},
 'reentli': {'reently': []},
 'reentomb': {'reentombed': [], 'reentombment': []},
 'reentr': {'reentred': []},
 'reentrain': {'reentrained': [], 'reentraining': [], 'reentrainment': []},
 'reentranc': {'reentrance': ['reentrances'],
               'reentrancies': [],
               'reentrancy': []},
 'reentrance': ['reentrances'],
 'reentrant': {'reentrants': []},
 'reentrantli': {'reentrantly': []},
 'reentrap': {'reentrapment': []},
 'reentrench': {'reentrenched': [], 'reentrenching': [], 'reentrenchment': []},
 'reentri': {'reentrie': [], 'reentry': []},
 'reentrust': {'reentrusted': []},
 'reenumer': {'reenumerate': ['reenumerated'], 'reenumeration': []},
 'reenumerate': ['reenumerated'],
 'reenunci': {'reenunciate': ['reenunciated'], 'reenunciation': []},
 'reenunciate': ['reenunciated'],
 'reenvelop': {'reenveloped': []},
 'reenvis': {'reenvision': ['reenvisions',
                            'reenvisioned',
                            'reenvisioning',
                            'reenvisionings']},
 'reenvisag': {'reenvisage': ['reenvisaged'], 'reenvisaging': []},
 'reenvisage': ['reenvisaged'],
 'reenvision': ['reenvisions',
                'reenvisioned',
                'reenvisioning',
                'reenvisionings'],
 'reenvoic': {'reenvoicement': []},
 'reeognis': {'reeognise': ['reeognises', 'reeognised']},
 'reeognise': ['reeognises', 'reeognised'],
 'reeognit': {'reeognition': []},
 'reeogniz': {'reeognizable': [],
              'reeognize': ['reeognized', 'reeognizes'],
              'reeognizing': []},
 'reeognize': ['reeognized', 'reeognizes'],
 'reeoh': {'reeohed': []},
 'reeoinag': {'reeoinage': []},
 'reeoiv': {'reeoived': []},
 'reeollect': {'reeollected': [], 'reeollection': ['reeollections']},
 'reeollection': ['reeollections'],
 'reeolleet': {'reeolleeted': [], 'reeolleetion': ['reeolleetions']},
 'reeolleetion': ['reeolleetions'],
 'reeollet': {'reeollets': []},
 'reeolut': {'reeolution': []},
 'reeolv': {'reeolve': ['reeolved']},
 'reeolve': ['reeolved'],
 'reeombin': {'reeombinant': [],
              'reeombine': ['reeombined'],
              'reeombining': []},
 'reeombine': ['reeombined'],
 'reeommend': {'reeommendation': ['reeommendations'],
               'reeommended': [],
               'reeommending': [],
               'reeommends': []},
 'reeommendation': ['reeommendations'],
 'reeompenc': {'reeompence': []},
 'reeompens': {'reeompense': []},
 'reeomposit': {'reeomposition': []},
 'reeoncil': {'reeoncile': ['reeonciled', 'reeoncileable']},
 'reeoncile': ['reeonciled', 'reeoncileable'],
 'reeoncili': {'reeonciliation': []},
 'reeoneil': {'reeoneile': ['reeoneiled']},
 'reeoneile': ['reeoneiled'],
 'reeoneili': {'reeoneiliation': []},
 'reeonnoiss': {'reeonnoissance': ['reeonnoissances']},
 'reeonnoissance': ['reeonnoissances'],
 'reeonnoit': {'reeonnoiter': ['reeonnoitered', 'reeonnoitering']},
 'reeonnoiter': ['reeonnoitered', 'reeonnoitering'],
 'reeonstitut': {'reeonstitution': []},
 'reeonstruct': {'reeonstruction': []},
 'reeonstruet': {'reeonstruetion': []},
 'reeord': {'reeorde': ['reeorded'], 'reeording': [], 'reeords': []},
 'reeorde': ['reeorded'],
 'reeort': {'reeorted': []},
 'reeourc': {'reeource': ['reeources']},
 'reeource': {'reeourcee': []},
 'reeouro': {'reeouroes': []},
 'reeouroe': {'reeouroee': []},
 'reeours': {'reeourse': []},
 'reeov': {'reeoved': []},
 'reeover': {'reeovered': [], 'reeovering': []},
 'reeoveri': {'reeovery': []},
 'reep': {'reepe': ['reeped'], 'reeping': [], 'reeps': []},
 'reepe': ['reeped'],
 'reepect': {'reepectable': [],
             'reepecte': ['reepected'],
             'reepecting': [],
             'reepective': ['reepectively'],
             'reepects': []},
 'reepecte': ['reepected'],
 'reepective': ['reepectively'],
 'reepeot': {'reepeotive': ['reepeotively']},
 'reepeotive': ['reepeotively'],
 'reeper': {'reepers': []},
 'reepir': {'reepiration': []},
 'reepiratori': {'reepiratory': []},
 'reepithel': {'reepithelization': [], 'reepithelize': ['reepithelized']},
 'reepitheli': {'reepithelialization': [],
                'reepithelialize': ['reepithelializes', 'reepithelialized'],
                'reepithelializing': []},
 'reepithelialis': {'reepithelialisation': []},
 'reepithelialize': ['reepithelializes', 'reepithelialized'],
 'reepithelize': ['reepithelized'],
 'reepjir': {'reepjired': []},
 'reepmak': {'reepmaker': []},
 'reepmey': {'reepmeyer': []},
 'reepon': {'reeponeibility': [], 'reeponeible': []},
 'reepona': {'reeponae': []},
 'reepond': {'reeponded': []},
 'reepone': {'reeponee': []},
 'reeponee': {'reeponeee': []},
 'reepons': {'reeponse': ['reeponses'],
             'reeponsibility': [],
             'reeponsible': []},
 'reeponse': ['reeponses'],
 'reepos': {'reepose': []},
 'reequal': {'reequalization': [], 'reequalize': ['reequalized']},
 'reequalize': ['reequalized'],
 'reequilibr': {'reequilibrate': ['reequilibrates', 'reequilibrated'],
                'reequilibrating': [],
                'reequilibration': ['reequilibrations'],
                'reequilibre': ['reequilibrer']},
 'reequilibrag': {'reequilibrage': []},
 'reequilibrate': ['reequilibrates', 'reequilibrated'],
 'reequilibration': ['reequilibrations'],
 'reequilibre': ['reequilibrer'],
 'reequip': {'reequiping': [],
             'reequipment': [],
             'reequipped': [],
             'reequipping': [],
             'reequips': []},
 'reequir': {'reequired': [], 'reequirements': []},
 'reer': {'reere': ['reered', 'reeres'],
          'reering': [],
          'reerred': [],
          'reers': []},
 'reere': ['reered', 'reeres'],
 'reereat': {'reereate': [], 'reereation': ['reereations', 'reereational']},
 'reereation': ['reereations', 'reereational'],
 'reerect': {'reerected': [],
             'reerecting': [],
             'reerection': [],
             'reerects': []},
 'reerenc': {'reerence': ['reerences']},
 'reerence': ['reerences'],
 'reeri': {'reery': []},
 'reerimin': {'reeriminations': []},
 'reerod': {'reeroded': []},
 'reeros': {'reerosion': []},
 'reeross': {'reerossed': [], 'reerosses': [], 'reerossing': []},
 'reerotic': {'reeroticization': []},
 'reershemiu': {'reershemius': []},
 'reeruit': {'reeruited': [],
             'reeruiting': [],
             'reeruitment': [],
             'reeruits': []},
 'reerupt': {'reerupted': [], 'reerupting': [], 'reeruption': []},
 'reerv': {'reerve': ['reerves', 'reerved']},
 'reerve': ['reerves', 'reerved'],
 'reerystal': {'reerystallization': [], 'reerystallized': []},
 'reerystallis': {'reerystallisation': [], 'reerystallised': []},
 'rees': {'reese': ['reeses', 'reesed'], 'reesing': []},
 'reesbi': {'reesby': []},
 'reescal': {'reescalate': ['reescalated'],
             'reescalating': [],
             'reescalation': []},
 'reescalate': ['reescalated'],
 'reescompt': {'reescompte': []},
 'reese': ['reeses', 'reesed'],
 'reesevil': {'reeseville': []},
 'reeshe': {'reeshees': []},
 'reesi': {'reesie': [], 'reesy': []},
 'reesid': {'reeside': ['reesides']},
 'reeside': ['reesides'],
 'reesidit': {'reesidites': []},
 'reesimermi': {'reesimermis': []},
 'reesjon': {'reesjones': []},
 'reeson': {'reesonable': [], 'reesonably': [], 'reesons': []},
 'reesonebl': {'reesoneble': []},
 'reesourc': {'reesources': []},
 'reespac': {'reespace': []},
 'reess': {'reesse': []},
 'reessenti': {'reessentializing': []},
 'reest': {'reeste': ['reested'], 'reesting': []},
 'reestabhsh': {'reestabhshment': []},
 'reestabiish': {'reestabiishment': []},
 'reestabish': {'reestabished': []},
 'reestablec': {'reestablecer': []},
 'reestabliah': {'reestabliahment': []},
 'reestablis': {'reestablised': [], 'reestablisment': []},
 'reestablisb': {'reestablisbment': []},
 'reestablish': {'reestablished': [],
                 'reestablishement': [],
                 'reestablisher': [],
                 'reestablishes': [],
                 'reestablishing': [],
                 'reestablishment': ['reestablishments']},
 'reestablishin': {'reestablishinent': []},
 'reestablishment': ['reestablishments'],
 'reestablishni': {'reestablishnient': []},
 'reestablishra': {'reestablishraent': []},
 'reestablishrn': {'reestablishrnent': []},
 'reestabllsh': {'reestabllshment': []},
 'reestahlish': {'reestahlished': [],
                 'reestahlishing': [],
                 'reestahlishment': []},
 'reestand': {'reestanding': []},
 'reeste': ['reested'],
 'reesterif': {'reesterification': []},
 'reesterifi': {'reesterified': [],
                'reesterifies': [],
                'reesterify': ['reesterifying']},
 'reesterify': ['reesterifying'],
 'reestim': {'reestimate': ['reestimates', 'reestimated'],
             'reestimating': [],
             'reestimation': ['reestimations']},
 'reestimate': ['reestimates', 'reestimated'],
 'reestimation': ['reestimations'],
 'reesvil': {'reesville': []},
 'reeswilliam': {'reeswilliams': []},
 'reet': {'reete': ['reeted'], 'reeting': ['reetings'], 'reets': []},
 'reetangl': {'reetangle': []},
 'reetch': {'reetched': [], 'reetching': []},
 'reete': ['reeted'],
 'reeth': {'reeths': []},
 'reethink': {'reethinking': []},
 'reethnic': {'reethnicization': []},
 'reethnif': {'reethnification': []},
 'reetifi': {'reetify': []},
 'reeting': ['reetings'],
 'reetion': {'reetions': []},
 'reetitud': {'reetitude': []},
 'reetli': {'reetly': []},
 'reetor': {'reetore': ['reetored']},
 'reetore': ['reetored'],
 'reetori': {'reetory': []},
 'reetrict': {'reetricted': [], 'reetriction': []},
 'reetriot': {'reetrioted': []},
 'reetu': {'reetus': []},
 'reetz': {'reetze': []},
 'reeue': {'reeues': []},
 'reeuforc': {'reeuforce': ['reeuforced', 'reeuforcements']},
 'reeuforce': ['reeuforced', 'reeuforcements'],
 'reeularli': {'reeularly': []},
 'reeulat': {'reeulate': ['reeulated'], 'reeulation': ['reeulations']},
 'reeulate': ['reeulated'],
 'reeulation': ['reeulations'],
 'reeult': {'reeulte': ['reeulted'], 'reeulting': [], 'reeults': []},
 'reeulte': ['reeulted'],
 'reeum': {'reeumed': []},
 'reeur': {'reeurring': []},
 'reev': {'reef': [],
          'reeve': ['reeved', 'reevely'],
          'reeving': [],
          'reevs': []},
 'reevacu': {'reevacuate': ['reevacuated'],
             'reevacuating': [],
             'reevacuation': []},
 'reevacuate': ['reevacuated'],
 'reevaiuat': {'reevaiuation': []},
 'reevalu': {'reevaluate': ['reevaluates', 'reevaluated'],
             'reevaluating': [],
             'reevaluation': [],
             'reevaluative': [],
             'reevalue': ['reevaluer']},
 'reevaluar': {'reevaluare': []},
 'reevaluate': ['reevaluates', 'reevaluated'],
 'reevalue': ['reevaluer'],
 'reevalut': {'reevalutation': [],
              'reevalute': ['reevaluted'],
              'reevalution': []},
 'reevalute': ['reevaluted'],
 'reevangel': {'reevangelization': [],
               'reevangelize': ['reevangelized'],
               'reevangelizing': []},
 'reevangelize': ['reevangelized'],
 'reevapor': {'reevaporate': ['reevaporates', 'reevaporated'],
              'reevaporating': [],
              'reevaporation': []},
 'reevaporate': ['reevaporates', 'reevaporated'],
 'reevaul': {'reevaulation': []},
 'reeve': ['reeved', 'reevely'],
 'reevel': {'reevell': []},
 'reever': {'reevers': []},
 'reeveri': {'reevery': []},
 'reevert': {'reeverts': []},
 'reeves': {'reef': []},
 'reevesbi': {'reevesby': []},
 'reeveship': {'reeveships': []},
 'reevessteven': {'reevesstevens': []},
 'reevesvil': {'reevesville': []},
 'reevi': {'reevie': [], 'reevis': [], 'reevy': []},
 'reevoc': {'reevocation': ['reevocations']},
 'reevocation': ['reevocations'],
 'reevok': {'reevoke': ['reevoked', 'reevokes'], 'reevoking': []},
 'reevoke': ['reevoked', 'reevokes'],
 'reevolut': {'reevolution': []},
 'reevolv': {'reevolve': ['reevolved'], 'reevolving': []},
 'reevolve': ['reevolved'],
 'reey': {'reeye': ['reeyes']},
 'reeye': ['reeyes'],
 'reeyel': {'reeyellities': []},
 'reez': {'reeze': ['reezed', 'reezes'], 'reezing': []},
 'reeze': ['reezed', 'reezes'],
 'reezingli': {'reezingly': []},
 'ref': ['reffed', 'reffing', 'refative'],
 'refa': {'refaeli': [], 'refaely': [], 'refas': []},
 'refabr': {'refabricate': ['refabricates', 'refabricated'],
            'refabricating': [],
            'refabrication': []},
 'refabricate': ['refabricates', 'refabricated'],
 'refac': {'reface': ['refacer', 'refaced', 'refaces', 'refacers'],
           'refacing': ['refacings']},
 'refaccimento': {'refaccimentos': []},
 'refaccion': {'refacciones': []},
 'refaccionario': {'refaccionarios': []},
 'reface': ['refacer', 'refaced', 'refaces', 'refacers'],
 'refacing': ['refacings'],
 'refact': {'refaction': ['refactions'], 'refactive': []},
 'refaction': ['refactions'],
 'refactor': {'refactored': [],
              'refactoring': ['refactorings'],
              'refactorization': [],
              'refactorized': [],
              'refactors': []},
 'refactori': {'refactories': [], 'refactoriness': [], 'refactory': []},
 'refactoring': ['refactorings'],
 'refae': {'refaee': []},
 'refag': {'refage': []},
 'refahiy': {'refahiye': []},
 'refai': {'refaie': [], 'refais': []},
 'refain': {'refained': []},
 'refair': {'refaire': []},
 'refais': {'refaisant': []},
 'refait': {'refaite': ['refaites'], 'refaits': []},
 'refaite': ['refaites'],
 'refajo': {'refajos': []},
 'refal': {'refall': ['refalling']},
 'refall': ['refalling'],
 'refamiliar': {'refamiliarization': [],
                'refamiliarize': ['refamiliarized', 'refamiliarizes'],
                'refamiliarizing': []},
 'refamiliaris': {'refamiliarisation': [],
                  'refamiliarise': [],
                  'refamiliarising': []},
 'refamiliarize': ['refamiliarized', 'refamiliarizes'],
 'refan': {'refaned': [], 'refanned': []},
 'refar': {'refared': [], 'refarence': [], 'refarred': []},
 'refard': {'refarded': [], 'refarding': [], 'refards': []},
 'refarm': {'refarmed': [], 'refarming': []},
 'refas': {'refasal': [], 'refase': ['refased'], 'refasing': []},
 'refase': ['refased'],
 'refashion': {'refashioned': [],
               'refashioner': ['refashioners'],
               'refashioning': ['refashionings'],
               'refashions': []},
 'refashioner': ['refashioners'],
 'refashioning': ['refashionings'],
 'refass': {'refasse': []},
 'refasten': {'refastenable': [],
              'refastened': [],
              'refastening': [],
              'refastens': []},
 'refat': {'refate': ['refated'],
           'refating': [],
           'refation': ['refations'],
           'refatting': []},
 'refate': ['refated'],
 'refation': ['refations'],
 'refaun': {'refaunated': [], 'refaunation': []},
 'refauss': {'refausse': []},
 'refay': {'refaye': []},
 'refayn': {'refayned': []},
 'refaz': {'refazer': []},
 'refbcu': {'refbcus': []},
 'refbcus': {'refbcused': []},
 'refblut': {'refblution': []},
 'refblv': {'refblved': []},
 'refbrmat': {'refbrmation': []},
 'refc': {'refce': []},
 'refcind': {'refcinded': []},
 'refclos': {'refclose': []},
 'refcmblanc': {'refcmblance': []},
 'refcr': {'refcred': [], 'refcring': [], 'refcrred': [], 'refcrs': []},
 'refcre': {'refcreed': []},
 'refcrenc': {'refcrence': ['refcrences']},
 'refcrence': ['refcrences'],
 'refcrendum': {'refcrendums': []},
 'refcrr': {'refcrre': []},
 'refcrribl': {'refcrrible': []},
 'refcrv': {'refcrved': []},
 'refcu': {'refcue': ['refcued'], 'refcuing': []},
 'refcue': ['refcued'],
 'refdl': {'refdled': []},
 'refe': {'refed': [], 'refeed': ['refeeds'], 'refes': [], 'refing': []},
 'refearch': {'refearches': []},
 'refeas': {'refease': ['refeased']},
 'refease': ['refeased'],
 'refeat': {'refeated': []},
 'refeath': {'refeather': ['refeathered', 'refeathering']},
 'refeather': ['refeathered', 'refeathering'],
 'refeb': {'refebence': ['refebences']},
 'refebence': ['refebences'],
 'refeccion': {'refeccione': []},
 'refeceri': {'refeceris': []},
 'refeciss': {'refecisse': []},
 'refect': {'refected': [],
            'refecting': [],
            'refection': [],
            'refective': [],
            'refects': []},
 'refecta': {'refectas': []},
 'refecti': {'refectis': []},
 'refection': {'refectione': ['refectiones', 'refectioner']},
 'refectione': ['refectiones', 'refectioner'],
 'refectioni': {'refectionis': []},
 'refectionibu': {'refectionibus': []},
 'refecto': {'refectos': []},
 'refectoir': {'refectoire': []},
 'refector': {'refectorer': []},
 'refectorariu': {'refectorarius': []},
 'refectori': {'refectorial': [], 'refectorie': [], 'refectory': []},
 'refectu': {'refectus': []},
 'refectur': {'refectural': [], 'refecture': []},
 'refeder': {'refederalization': [], 'refederation': []},
 'refeed': {'refeeding': ['refeedings']},
 'refeeding': ['refeedings'],
 'refeeenc': {'refeeence': ['refeeences']},
 'refeeence': ['refeeences'],
 'refeel': {'refeeling': []},
 'refeen': {'refeened': []},
 'refeenc': {'refeence': ['refeences']},
 'refeence': ['refeences'],
 'refeer': {'refeered': []},
 'refef': {'refefence': []},
 'refeh': {'refehences': []},
 'refei': {'refeis': []},
 'refeico': {'refeicoes': []},
 'refeienc': {'refeience': ['refeiences']},
 'refeience': ['refeiences'],
 'refeir': {'refeired': [], 'refeiring': []},
 'refeit': {'refeited': []},
 'refek': {'refekences': []},
 'refel': {'refell': ['refelled', 'refelling']},
 'refelct': {'refelcted': [],
             'refelcting': [],
             'refelction': ['refelctions'],
             'refelcts': []},
 'refelction': ['refelctions'],
 'refelect': {'refelected': [],
              'refelecting': [],
              'refelection': ['refelections'],
              'refelects': []},
 'refelection': ['refelections'],
 'refell': ['refelled', 'refelling'],
 'refellen': {'refellens': []},
 'refeller': {'refellere': []},
 'refelli': {'refellis': []},
 'refellimu': {'refellimus': []},
 'refelt': {'refelted': []},
 'refembl': {'refemblance': ['refemblances'],
             'refemble': ['refembles', 'refembled'],
             'refembling': []},
 'refemblance': ['refemblances'],
 'refemble': ['refembles', 'refembled'],
 'refemc': {'refemce': ['refemces']},
 'refemce': ['refemces'],
 'refemin': {'refeminization': [],
             'refeminize': ['refeminized'],
             'refeminizing': []},
 'refeminize': ['refeminized'],
 'refen': {'refenal': ['refenals'],
           'refened': [],
           'refenes': [],
           'refening': [],
           'refens': []},
 "refen'": {"refen'ed": []},
 'refenal': ['refenals'],
 'refenc': {'refence': ['refences', 'refenced'], 'refencing': []},
 'refence': ['refences', 'refenced'],
 'refenestr': {'refenestrated': [], 'refenestration': []},
 'refenr': {'refenred': []},
 'refent': {'refente': ['refented'],
            'refenting': [],
            'refentment': ['refentments']},
 'refente': ['refented'],
 'refenti': {'refential': []},
 'refentment': ['refentments'],
 'refeoff': {'refeoffment': []},
 'refer': {'referability': [],
           'referable': [],
           'referably': [],
           'referal': ['referals'],
           'referance': ['referances'],
           'referant': ['referants'],
           'referate': ['referates'],
           'refere': ['refered',
                      'referer',
                      'referes',
                      'referent',
                      'referers',
                      'reference',
                      'referered',
                      'referency',
                      'refereing',
                      'referenci',
                      'refererred',
                      'refereence',
                      'referented',
                      'referencies',
                      'referenting'],
           'referible': [],
           'refering': [],
           'referment': ['referments', 'refermented', 'refermenting'],
           'referred': [],
           'referring': ['referrings'],
           'refers': []},
 'refera': {'referas': []},
 'referaci': {'referacie': []},
 'referahl': {'referahle': []},
 'referai': {'referaient': [], 'referais': []},
 'referal': ['referals'],
 'referamu': {'referamus': []},
 'referance': ['referances'],
 'referans': {'referanse': ['referanser']},
 'referanse': ['referanser'],
 'referant': ['referants'],
 'referat': {'referater': [], 'referats': []},
 'referate': ['referates'],
 'referati': {'referatis': [], 'referaty': []},
 'referativni': {'referativny': []},
 'referatqu': {'referatque': []},
 'referatsleit': {'referatsleiter': []},
 'referbnc': {'referbnce': []},
 'referc': {'referced': []},
 'refercnc': {'refercnce': ['refercnces']},
 'refercnce': ['refercnces'],
 'refere': {'referee': ['refereed', 'refereeing']},
 'refereac': {'refereace': []},
 'refereb': {'referebant': []},
 'referec': {'referece': ['refereces']},
 'referece': ['refereces'],
 'referecn': {'referecne': []},
 'referee': {'refereee': []},
 'refereeship': {'refereeships': []},
 'referehc': {'referehce': ['referehces']},
 'referehce': ['referehces'],
 'referemc': {'referemce': ['referemces']},
 'referemce': ['referemces'],
 'referemu': {'referemus': []},
 'referen': {'referene': ['referenes'], 'referens': []},
 'referenc': {'referencable': [],
              'referenceability': [],
              'referenceable': [],
              'referenced': [],
              'referencer': ['referencers'],
              'referencing': ['referencings'],
              'referencs': []},
 'referencc': {'referenccs': []},
 'reference': {'referencee': ['referencees']},
 'referencebas': {'referencebased': []},
 'referencebodi': {'referencebodies': [], 'referencebody': []},
 'referencebook': {'referencebooks': []},
 'referencecheck': {'referencechecking': []},
 'referencecount': {'referencecounting': []},
 'referencedepend': {'referencedependent': []},
 'referencee': ['referencees'],
 'referenceequ': {'referenceequals': []},
 'referencefram': {'referenceframe': ['referenceframes']},
 'referenceframe': ['referenceframes'],
 'referencei': {'referenceis': []},
 'referencejunct': {'referencejunction': []},
 'referencemark': {'referencemarks': []},
 'referencepoint': {'referencepoints': []},
 'referencequeu': {'referencequeue': []},
 'referencer': ['referencers'],
 'referencesrefer': {'referencesreferences': []},
 'referencesystem': {'referencesystems': []},
 'referencetak': {'referencetakers': []},
 'referencetoth': {'referencetothe': []},
 'referencetyp': {'referencetype': []},
 'referenci': {'referencial': ['referenciality']},
 'referencia': {'referencias': []},
 'referencial': {'referenciales': []},
 'referencing': ['referencings'],
 'referenck': {'referencks': []},
 'referend': {'referendal': [], 'referends': []},
 'referenda': {'referendae': [], 'referendas': []},
 'referendair': {'referendaire': ['referendaires']},
 'referendaire': ['referendaires'],
 'referendar': {'referendare': [], 'referendars': []},
 'referendari': {'referendaries': [], 'referendary': []},
 'referendariu': {'referendarius': []},
 'referendi': {'referendis': []},
 'referendo': {'referendos': []},
 'referendu': {'referendus': []},
 'referendum': {'referendum': []},
 'referene': {'referenee': ['referenees']},
 'referenec': {'referenece': ['refereneces']},
 'referenece': ['refereneces'],
 'referenee': ['referenees'],
 'refereni': {'referenial': []},
 'refereno': {'referenoe': ['referenoes'], 'referenos': []},
 'referenoe': ['referenoes'],
 'referenr': {'referenre': ['referenres']},
 'referenre': ['referenres'],
 'referens': {'referense': ['referenser', 'referenses']},
 'referense': ['referenser', 'referenses'],
 'referent': {'referente': ['referentes']},
 'referente': ['referentes'],
 'referenti': {'referentiability': [],
               'referential': ['referentials',
                               'referentially',
                               'referentiality',
                               'referentialism',
                               'referentialized',
                               'referentialities',
                               'referentialization'],
               'referentiation': [],
               'referentie': ['referenties'],
               'referentis': []},
 'referential': ['referentials',
                 'referentially',
                 'referentiality',
                 'referentialism',
                 'referentialized',
                 'referentialities',
                 'referentialization'],
 'referentialiri': {'referentialiry': []},
 'referentialist': {'referentialists': []},
 'referentialit': {'referentialite': []},
 'referentibu': {'referentibus': []},
 'referentie': ['referenties'],
 'referentiekad': {'referentiekader': []},
 'referentiel': {'referentiell': ['referentielle',
                                  'referentieller',
                                  'referentielles'],
                 'referentiels': []},
 'referentiell': ['referentielle', 'referentieller', 'referentielles'],
 'referenz': {'referenze': []},
 'referenzial': {'referenziale': []},
 'referenzmodel': {'referenzmodell': ['referenzmodelle']},
 'referenzmodell': ['referenzmodelle'],
 'referenzpunkt': {'referenzpunkte': []},
 'referenzwert': {'referenzwerte': []},
 'refereoc': {'refereoce': []},
 'referepc': {'referepce': []},
 'referer': {'referere': ['refereres',
                          'refererer',
                          'refererence',
                          'refererences']},
 'referera': {'refereras': []},
 'refererad': {'refererade': []},
 'refererc': {'refererce': []},
 'referere': ['refereres', 'refererer', 'refererence', 'refererences'],
 'refereric': {'refererice': []},
 'referernc': {'referernce': []},
 'refereron': {'refererons': []},
 'referert': {'refererte': []},
 'referesh': {'referesher': [], 'refereshing': []},
 'refereuc': {'refereuce': ['refereuces']},
 'refereuce': ['refereuces'],
 'referf': {'referfs': []},
 'referfnc': {'referfnces': []},
 'referi': {'referied': [], 'referiing': []},
 'referida': {'referidas': []},
 'referido': {'referidos': []},
 'referier': {'referiere': []},
 'referierend': {'referierende': []},
 'referiert': {'referierte': []},
 'referiger': {'referigerator': []},
 'referimo': {'referimos': []},
 'referimu': {'referimus': []},
 'referir': {'referire': []},
 'referiremo': {'referiremos': []},
 'referirm': {'referirme': []},
 'referirno': {'referirnos': []},
 'referirs': {'referirse': []},
 'referisc': {'referisce': []},
 'referit': {'referite': []},
 'referitoar': {'referitoare': []},
 'referknc': {'referknces': []},
 'referm': {'refermant': [],
            'refermation': [],
            'referme': ['refermer', 'refermes']},
 'referme': {'refermee': ['refermees']},
 'refermee': ['refermees'],
 'referment': {'refermentation': []},
 'refernc': {'refernce': ['refernces']},
 'refernce': ['refernces'],
 'refernec': {'refernece': ['referneces']},
 'refernece': ['referneces'],
 'referon': {'referons': []},
 'referonc': {'referonce': []},
 'referono': {'referonoe': []},
 'referopportun': {'referopportunity': []},
 'referr': {'referrable': [],
            'referral': [],
            'referrant': ['referrants'],
            'referre': ['referres',
                        'referrer',
                        'referrent',
                        'referrers',
                        'referreing',
                        'referrents',
                        'referrence',
                        'referrences'],
            'referrible': [],
            'referrred': [],
            'referrring': [],
            'referrs': []},
 'referrant': ['referrants'],
 'referre': {'referree': ['referreed', 'referrees']},
 'referredbi': {'referredby': []},
 'referredtoa': {'referredtoas': []},
 'referredtoth': {'referredtothe': []},
 'referree': ['referreed', 'referrees'],
 'referrel': {'referrels': []},
 'referrenc': {'referrenced': []},
 'referrenti': {'referrential': []},
 'referri': {'referries': [], 'referris': []},
 'referring': {'referringe': []},
 'referringli': {'referringly': []},
 'referringtoth': {'referringtothe': []},
 'referrr': {'referrral': ['referrrals']},
 'referrral': ['referrrals'],
 'refersnc': {'refersnce': []},
 'referstoth': {'referstothe': []},
 'refert': {'referte': ['referted'], 'referting': [], 'referts': []},
 'referta': {'refertae': [], 'refertas': []},
 'refertaqu': {'refertaque': []},
 'referte': ['referted'],
 'referth': {'referthe': []},
 'referti': {'refertis': []},
 'refertil': {'refertilization': [],
              'refertilize': ['refertilized', 'refertilizes'],
              'refertilizing': []},
 'refertilis': {'refertilisation': [],
                'refertilise': ['refertilised'],
                'refertilising': []},
 'refertilise': ['refertilised'],
 'refertilize': ['refertilized', 'refertilizes'],
 'refertissimu': {'refertissimus': []},
 'referto': {'refertos': []},
 'refertoth': {'refertothe': []},
 'refertqu': {'refertque': []},
 'refertu': {'refertus': []},
 'referu': {'referue': ['referued']},
 'referue': ['referued'],
 'referv': {'refervation': ['refervations'],
            'referve': ['referved', 'referves'],
            'referving': []},
 'refervation': ['refervations'],
 'referve': ['referved', 'referves'],
 'refervednef': {'refervednefs': []},
 'refervoir': {'refervoirs': []},
 'refery': {'referyou': []},
 'refescen': {'refescens': []},
 'refesh': {'refeshed': [], 'refeshing': [], 'refeshment': ['refeshments']},
 'refeshment': ['refeshments'],
 'refet': {'refetence': ['refetences'], 'refets': []},
 'refetch': {'refetched': [], 'refetches': [], 'refetching': []},
 'refetence': ['refetences'],
 'refetr': {'refetred': [], 'refetring': []},
 'refett': {'refettered': []},
 'refettl': {'refettled': []},
 'refeud': {'refeudalization': [],
            'refeudalize': ['refeudalized'],
            'refeudalizing': []},
 'refeudalis': {'refeudalisation': [], 'refeudalised': []},
 'refeudalize': ['refeudalized'],
 'reff': {'reffe': [], 'reffs': []},
 'reffect': {'reffected': [],
             'reffecting': [],
             'reffection': ['reffections'],
             'reffective': [],
             'reffects': []},
 'reffection': ['reffections'],
 'reffel': {'reffell': []},
 'reffenti': {'reffentiment': [], 'reffenty': []},
 'reffer': {'refferal': [],
            'refferance': [],
            'reffered': [],
            'refference': ['refferences'],
            'reffering': [],
            'refferred': [],
            'refferring': [],
            'reffers': []},
 'refference': ['refferences'],
 'refferr': {'refferrence': []},
 'reffi': {'reffy': []},
 'reffirm': {'reffirmed': []},
 'reffl': {'reffle': []},
 'reffli': {'reffly': []},
 'reffo': {'reffos': []},
 'reffort': {'refforts': []},
 'reffrenc': {'reffrences': []},
 'reffu': {'reffus': []},
 'reffug': {'reffuge': []},
 'reffus': {'reffuse': ['reffuser', 'reffused']},
 'reffuse': ['reffuser', 'reffused'],
 'reffy': {'reffye': []},
 'refi': {'refie': ['refied', 'refies'], 'refis': [], 'refy': []},
 'refiactori': {'refiactory': []},
 'refiain': {'refiained': []},
 'refiationari': {'refiationary': []},
 'refibril': {'refibrillation': []},
 'refic': {'refice': []},
 'reficea': {'reficeas': []},
 'reficer': {'reficere': ['reficerent']},
 'reficere': ['reficerent'],
 'refici': {'reficiant': [], 'reficis': []},
 'reficien': {'reficiens': []},
 'reficienda': {'reficiendas': []},
 'reficiendi': {'reficiendis': []},
 'reficimu': {'reficimus': []},
 'refid': {'refide': ['refided',
                      'refides',
                      'refident',
                      'refidence',
                      'refidents',
                      'refidences'],
           'refiding': []},
 'refide': ['refided',
            'refides',
            'refident',
            'refidence',
            'refidents',
            'refidences'],
 'refidu': {'refidue': []},
 'refie': ['refied', 'refies'],
 'refieclion': {'refieclions': []},
 'refiect': {'refiected': [],
             'refiecting': [],
             'refiection': ['refiections'],
             'refiective': ['refiectively'],
             'refiects': []},
 'refiection': ['refiections'],
 'refiective': ['refiectively'],
 'refiectomet': {'refiectometer': []},
 'refiectometri': {'refiectometry': []},
 'refier': {'refiere': ['refieres']},
 'refiere': ['refieres'],
 'refiesh': {'refieshing': []},
 'refiev': {'refieve': []},
 'refievo': {'refievos': []},
 'refifl': {'refiflance': []},
 'refift': {'refiftance': [],
            'refifted': [],
            'refifter': [],
            'refifting': [],
            'refifts': []},
 'refiftlef': {'refiftlefs': []},
 'refiger': {'refigeration': [], 'refigerator': ['refigerators']},
 'refigerator': ['refigerators'],
 'refight': {'refighting': [], 'refights': []},
 'refigi': {'refigious': []},
 'refign': {'refignation': [], 'refigned': [], 'refigning': [], 'refigns': []},
 'refigur': {'refiguration': ['refigurations'],
             'refigurative': [],
             'refigure': ['refigures', 'refigured', 'refigurement'],
             'refiguring': ['refigurings']},
 'refiguration': ['refigurations'],
 'refigure': ['refigures', 'refigured', 'refigurement'],
 'refiguring': ['refigurings'],
 'refiig': {'refiige': []},
 'refiige': {'refiigee': ['refiigees']},
 'refiigee': ['refiigees'],
 'refiiger': {'refiigerator': ['refiigerators']},
 'refiigerator': ['refiigerators'],
 'refiis': {'refiisal': [],
            'refiise': ['refiised', 'refiises'],
            'refiising': []},
 'refiise': ['refiised', 'refiises'],
 'refiit': {'refiite': []},
 'refil': {'refile': ['refiled', 'refiles'],
           'refiling': ['refilings'],
           'refill': ['refiller',
                      'refilled',
                      'refilling',
                      'refillers',
                      'refillable',
                      'refillables'],
           'refils': []},
 'refile': ['refiled', 'refiles'],
 'refiling': ['refilings'],
 'refill': ['refiller',
            'refilled',
            'refilling',
            'refillers',
            'refillable',
            'refillables'],
 'refilm': {'refilmed': [], 'refilming': []},
 'refilo': {'refiloe': []},
 'refils': {'refilsed': []},
 'refilt': {'refilted': [], 'refilter': ['refiltered', 'refiltering']},
 'refilter': ['refiltered', 'refiltering'],
 'refiltr': {'refiltration': []},
 'refilw': {'refilwe': []},
 'refimd': {'refimds': []},
 'refin': {'refinability': [],
           'refinable': [],
           'refinance': ['refinances'],
           'refination': [],
           'refine': ['refines',
                      'refiner',
                      'refined',
                      'refinely',
                      'refineing',
                      'refineness',
                      'refinement',
                      'refineable'],
           'refining': [],
           'refinment': ['refinments'],
           'refinous': [],
           'refins': []},
 'refinact': {'refinacted': []},
 'refinada': {'refinadas': []},
 'refinado': {'refinados': []},
 'refinador': {'refinadores': []},
 'refinag': {'refinage': []},
 'refinamiento': {'refinamientos': []},
 'refinanc': {'refinanceable': [],
              'refinanced': [],
              'refinancement': [],
              'refinancer': ['refinancers'],
              'refinancing': ['refinancings']},
 'refinance': ['refinances'],
 'refinancer': ['refinancers'],
 'refinancing': ['refinancings'],
 'refinari': {'refinaries': [], 'refinary': []},
 'refind': {'refinde': ['refinded'], 'refinding': [], 'refinds': []},
 'refinde': ['refinded'],
 'refine': ['refines',
            'refiner',
            'refined',
            'refinely',
            'refineing',
            'refineness',
            'refinement',
            'refineable'],
 'refined': {'refinedness': []},
 'refinedcarbohydr': {'refinedcarbohydrate': []},
 'refinedli': {'refinedly': []},
 'refinedlook': {'refinedlooking': []},
 'refinen': {'refinenent': [], 'refinenes': []},
 'refineri': {'refinery': []},
 'refineria': {'refinerias': []},
 'refinesqu': {'refinesque': []},
 'refinforc': {'refinforce': ['refinforced', 'refinforcements']},
 'refinforce': ['refinforced', 'refinforcements'],
 'refing': {'refinger': ['refingered', 'refingering']},
 'refinger': ['refingered', 'refingering'],
 'refinieri': {'refinieries': []},
 'refinin': {'refinining': []},
 'refiningli': {'refiningly': []},
 'refinish': {'refinished': [],
              'refinisher': [],
              'refinishes': [],
              'refinishing': ['refinishings']},
 'refinishing': ['refinishings'],
 'refinit': {'refinite': []},
 'refinment': ['refinments'],
 'refion': {'refions': []},
 'refiort': {'refiorts': []},
 'refir': {'refire': ['refired', 'refires', 'refirence', 'refirement'],
           'refiring': ['refirings']},
 'refire': ['refired', 'refires', 'refirence', 'refirement'],
 'refiriendono': {'refiriendonos': []},
 'refiriendos': {'refiriendose': []},
 'refiring': ['refirings'],
 'refirm': {'refirmed': [], 'refirming': []},
 'refirs': {'refirse': ['refirsed']},
 'refirse': ['refirsed'],
 'refish': {'refished': []},
 'refist': {'refistance': [], 'refisted': [], 'refisting': []},
 'refistablish': {'refistablishment': []},
 'refistul': {'refistulization': []},
 'refit': ['refited',
           'refiting',
           'refitted',
           'refitting',
           'refitment',
           'refittings',
           'refitments'],
 'refitge': {'refitgees': []},
 'refitl': {'refitled': []},
 'refits': {'refitsed': []},
 'refitt': {'refittal': [], 'refitter': ['refitters']},
 'refitter': ['refitters'],
 'refiu': {'refiued': []},
 'refkrenc': {'refkrences': []},
 'refl': {'refle': ['refles', 'refled'], 'refling': [], 'refls': []},
 'reflact': {'reflacted': [], 'reflaction': []},
 'reflag': {'reflagged': [], 'reflagging': []},
 'reflak': {'reflaked': [], 'reflaking': []},
 'reflam': {'reflame': ['reflamed'], 'reflaming': []},
 'reflamb': {'reflambes': []},
 'reflame': ['reflamed'],
 'reflang': {'reflange': []},
 'reflar': {'reflare': [], 'reflaring': []},
 'reflash': {'reflashed': [], 'reflashing': []},
 'reflat': {'reflate': ['reflated', 'reflates'],
            'reflating': [],
            'reflation': []},
 'reflate': ['reflated', 'reflates'],
 'reflationari': {'reflationary': []},
 'reflationist': {'reflationists': []},
 'reflatten': {'reflattened': []},
 'reflavor': {'reflavored': []},
 'reflcct': {'reflccted': []},
 'reflct': {'reflcted': []},
 'refle': {'reflee': []},
 'reflea': {'refleas': []},
 'reflebion': {'reflebions': []},
 'reflec': {'refleced': [], 'reflecing': []},
 'refleccion': {'reflecciones': []},
 'reflechi': {'reflechie': ['reflechies'], 'reflechis': []},
 'reflechie': ['reflechies'],
 'reflechiss': {'reflechissant': ['reflechissants'],
                'reflechisse': ['reflechissent']},
 'reflechissai': {'reflechissaient': [], 'reflechissais': []},
 'reflechissant': {'reflechissante': ['reflechissantes']},
 'reflechissante': ['reflechissantes'],
 'reflechisse': ['reflechissent'],
 'reflechisson': {'reflechissons': []},
 'refleci': {'reflecied': [], 'reflecis': []},
 'reflecion': {'reflecions': []},
 'reflecl': {'reflecled': [], 'reflecling': [], 'reflecls': []},
 'refleclion': {'refleclions': []},
 'reflecr': {'reflecred': [], 'reflecring': [], 'reflecrs': []},
 'reflect': {'reflectability': [],
             'reflectable': [],
             'reflectance': [],
             'reflectancy': [],
             'reflectant': ['reflectants'],
             'reflecte': ['reflectes',
                          'reflected',
                          'reflecter',
                          'reflecters',
                          'reflectent',
                          'reflectence'],
             'reflectful': [],
             'reflectibility': [],
             'reflectible': [],
             'reflectic': [],
             'reflecting': ['reflectings'],
             'reflection': ['reflectional', 'reflectionally'],
             'reflective': ['reflectives', 'reflectively', 'reflectiveness'],
             'reflectivity': [],
             'reflects': []},
 'reflectant': ['reflectants'],
 'reflectarray': {'reflectarrays': []},
 'reflecte': ['reflectes',
              'reflected',
              'reflecter',
              'reflecters',
              'reflectent',
              'reflectence'],
 'reflected': {'reflectedness': []},
 'reflectedinth': {'reflectedinthe': []},
 'reflectedli': {'reflectedly': []},
 'reflectedth': {'reflectedthe': []},
 'reflecten': {'reflectens': []},
 'reflecter': {'reflectere': []},
 'reflecteur': {'reflecteurs': []},
 'reflectf': {'reflectfed': [], 'reflectfs': []},
 'reflecti': {'reflectie': ['reflecties'], 'reflectiou': ['reflectious']},
 'reflectie': ['reflecties'],
 'reflectil': {'reflectile': []},
 'reflecting': ['reflectings'],
 'reflectingli': {'reflectingly': []},
 'reflectingth': {'reflectingthe': []},
 'reflection': {'reflectione': ['reflectiones'], 'reflectionism': []},
 'reflectionabsorpt': {'reflectionabsorption': []},
 'reflectionact': {'reflectionaction': []},
 'reflectione': ['reflectiones'],
 'reflectionfre': {'reflectionfree': []},
 'reflectioni': {'reflectionis': []},
 'reflectionimpuls': {'reflectionimpulsivity': []},
 'reflectionist': {'reflectionists': []},
 'reflectionpermiss': {'reflectionpermission': []},
 'reflectiontransmiss': {'reflectiontransmission': []},
 'reflectiontyp': {'reflectiontype': []},
 'reflectiou': ['reflectious'],
 'reflectirend': {'reflectirende': []},
 'reflectiv': {'reflectivism': []},
 'reflective': ['reflectives', 'reflectively', 'reflectiveness'],
 'reflectivethink': {'reflectivethinking': []},
 'reflectivist': {'reflectivists': []},
 'reflectivit': {'reflectivite': ['reflectivites']},
 'reflectivite': ['reflectivites'],
 'reflectivityimpuls': {'reflectivityimpulsivity': []},
 'reflectlon': {'reflectlons': []},
 'reflectlv': {'reflectlve': []},
 'reflectogram': {'reflectograms': []},
 'reflectograph': {'reflectographic': [], 'reflectographs': []},
 'reflectographi': {'reflectography': []},
 'reflectomet': {'reflectometer': []},
 'reflectometr': {'reflectometric': []},
 'reflectometri': {'reflectometry': []},
 'reflecton': {'reflectone': [], 'reflectons': []},
 'reflector': ['reflectored',
               'reflectoric',
               'reflectores',
               'reflectorized',
               'reflectorizing',
               'reflectorization'],
 'reflectori': {'reflectorial': ['reflectorially'], 'reflectory': []},
 'reflectorial': ['reflectorially'],
 'reflectorili': {'reflectorily': []},
 'reflectoris': {'reflectorised': []},
 'reflectorisch': {'reflectorische': []},
 'reflectortyp': {'reflectortype': []},
 'reflectoscop': {'reflectoscope': ['reflectoscopes']},
 'reflectoscope': ['reflectoscopes'],
 'reflectpermiss': {'reflectpermission': []},
 'reflectrometr': {'reflectrometric': []},
 'reflectrometri': {'reflectrometry': []},
 'reflectron': {'reflectrons': []},
 'reflectsth': {'reflectsthe': []},
 'reflectt': {'reflecttion': []},
 'reflectth': {'reflectthe': []},
 'reflectton': {'reflecttons': []},
 'refled': {'refleded': []},
 'refledt': {'refledted': [], 'refledtion': []},
 'refleet': {'refleeted': [],
             'refleeting': [],
             'refleetion': ['refleetions'],
             'refleetive': [],
             'refleets': []},
 'refleetion': ['refleetions'],
 'refleft': {'reflefted': [], 'reflefting': [], 'refleftion': ['refleftions']},
 'refleftion': ['refleftions'],
 'reflej': {'refleje': []},
 'refleja': {'reflejas': []},
 'reflejada': {'reflejadas': []},
 'reflejado': {'reflejados': []},
 'reflejandos': {'reflejandose': []},
 'reflejars': {'reflejarse': []},
 'reflejo': {'reflejos': []},
 'reflek': {'refleks': []},
 'refleksi': {'refleksy': []},
 'refleksj': {'refleksje': []},
 'refleksjon': {'refleksjoner': []},
 'reflekt': {'reflektion': []},
 'reflekter': {'reflekterer': []},
 'reflektier': {'reflektiere': []},
 'reflektierend': {'reflektierende': ['reflektierender']},
 'reflektierende': ['reflektierender'],
 'reflektiert': {'reflektierte': ['reflektierter', 'reflektiertes']},
 'reflektierte': ['reflektierter', 'reflektiertes'],
 'reflektion': {'reflektioner': []},
 'reflektorisch': {'reflektorische': ['reflektorischer']},
 'reflektorische': ['reflektorischer'],
 'refleot': {'refleoted': [],
             'refleoting': [],
             'refleotion': ['refleotions'],
             'refleotive': [],
             'refleots': []},
 'refleotion': ['refleotions'],
 'reflert': {'reflertion': ['reflertions']},
 'reflertion': ['reflertions'],
 'reflesh': {'refleshed': [], 'refleshing': []},
 'reflession': {'reflessione': []},
 'reflet': {'refletant': [],
            'reflete': ['refleter', 'refleted', 'refletes', 'refletent'],
            'refletion': ['refletions'],
            'reflets': []},
 'refletai': {'refletaient': []},
 'reflete': {'refletee': ['refletees']},
 'refletee': ['refletees'],
 'refleterai': {'refleteraient': []},
 'refletion': ['refletions'],
 'refletlion': {'refletlions': []},
 'reflett': {'reflettions': []},
 'reflgur': {'reflgured': [], 'reflguring': []},
 'refli': {'refly': ['reflying']},
 'reflight': {'reflights': []},
 'reflip': {'reflipe': []},
 'refll': {'reflle': ['reflled']},
 'reflle': ['reflled'],
 'refllect': {'refllected': []},
 'reflli': {'reflly': []},
 'reflllabl': {'reflllable': []},
 'refln': {'reflned': [], 'reflning': []},
 'reflnish': {'reflnished': [], 'reflnishing': []},
 'refloat': {'refloatation': [],
             'refloated': [],
             'refloating': [],
             'refloats': []},
 'refloccul': {'reflocculate': ['reflocculated'], 'reflocculation': []},
 'reflocculate': ['reflocculated'],
 'refloct': {'reflocted': []},
 'reflood': {'reflooded': [], 'reflooding': [], 'refloods': []},
 'refloor': {'refloored': [], 'reflooring': ['refloorings']},
 'reflooring': ['refloorings'],
 'reflor': {'refloration': [],
            'reflore': ['reflored', 'reflorent'],
            'refloring': []},
 'reflore': ['reflored', 'reflorent'],
 'refloresc': {'reflorescence': []},
 'reflorescer': {'reflorescere': []},
 'reflot': {'reflotation': []},
 'reflourish': {'reflourished': [], 'reflourishes': [], 'reflourishing': []},
 'reflow': {'reflowed': [],
            'reflower': ['reflowers', 'reflowered', 'reflowering'],
            'reflowing': [],
            'reflows': []},
 'reflower': ['reflowers', 'reflowered', 'reflowering'],
 'reflrain': {'reflrained': []},
 'reflu': {'reflue': [], 'reflus': []},
 'refluenc': {'refluence': ['refluences']},
 'refluence': ['refluences'],
 'refluentibu': {'refluentibus': []},
 'refluer': {'refluere': []},
 'refluf': {'refluffed': []},
 'refluitqu': {'refluitque': []},
 'reflush': {'reflushed': [], 'reflushing': []},
 'refluz': {'refluzed': []},
 'refly': ['reflying'],
 'refm': {'refme': ['refmed', 'refmes'], 'refming': []},
 'refmanc': {'refmance': [], 'refmancing': []},
 'refme': ['refmed', 'refmes'],
 'refmement': {'refmements': []},
 'refmer': {'refmers': []},
 'refmeri': {'refmeries': [], 'refmery': []},
 'refmish': {'refmished': [], 'refmishing': []},
 'refn': {'refned': [], 'refnes': []},
 'refng': {'refnge': []},
 'refnge': {'refngees': []},
 'refnger': {'refngeration': [], 'refngerator': ['refngerators']},
 'refngerator': ['refngerators'],
 'refnod': {'refnode': []},
 'refns': {'refnse': ['refnses', 'refnsed'], 'refnsing': []},
 'refnse': ['refnses', 'refnsed'],
 'refnt': {'refnte': ['refnted']},
 'refntat': {'refntation': []},
 'refnte': ['refnted'],
 'refo': {'refos': []},
 'refob': {'refobe': []},
 'refobm': {'refobmation': []},
 'refoc': {'refocalization': [], 'refocalized': []},
 'refocil': {'refocillate': ['refocillated'], 'refocillation': []},
 'refocillar': {'refocillare': []},
 'refocillate': ['refocillated'],
 'refocillatu': {'refocillatus': []},
 'refocu': {'refocus': []},
 'refocus': {'refocused': [],
             'refocuser': [],
             'refocuses': [],
             'refocusing': []},
 'refocuss': {'refocussed': [], 'refocusses': [], 'refocussing': []},
 'refoem': {'refoemation': []},
 'refog': {'refoge': []},
 'refoh': {'refohed': []},
 'refoi': {'refois': []},
 'refoim': {'refoimation': [],
            'refoimed': [],
            'refoimer': ['refoimers'],
            'refoiming': [],
            'refoims': []},
 'refoimer': ['refoimers'],
 'refoin': {'refoined': []},
 'refoio': {'refoios': []},
 'refoiv': {'refoived': []},
 'refokm': {'refokmation': []},
 'refold': {'refolded': [], 'refolding': ['refoldings'], 'refolds': []},
 'refolding': ['refoldings'],
 'refoli': {'refoliate': ['refoliated'],
            'refoliating': [],
            'refoliation': [],
            'refolyed': []},
 'refoliate': ['refoliated'],
 'refollow': {'refollowing': []},
 'refolu': {'refolue': ['refolued'], 'refolus': []},
 'refolue': ['refolued'],
 'refolur': {'refolurent': []},
 'refolut': {'refolute': ['refolutely'], 'refolution': ['refolutions']},
 'refolute': ['refolutely'],
 'refolution': ['refolutions'],
 'refolv': {'refolvable': [],
            'refolve': ['refolves', 'refolved'],
            'refolving': []},
 'refolve': ['refolves', 'refolved'],
 'refom': {'refomation': [],
           'refomed': [],
           'refomer': ['refomers'],
           'refoms': []},
 'refomer': ['refomers'],
 'refomi': {'refomiation': [], 'refomiing': [], 'refomis': []},
 'refomr': {'refomrs': []},
 'refomt': {'refomts': []},
 'refon': {'refonned': [], 'refonning': []},
 'refond': {'refondation': [], 'refonde': ['refonder']},
 'refonde': ['refonder'],
 'refondr': {'refondre': []},
 'refondu': {'refondue': ['refondues'], 'refondus': []},
 'refondue': ['refondues'],
 'refonn': {'refonnation': [],
            'refonne': ['refonner', 'refonners'],
            'refonns': []},
 'refonne': ['refonner', 'refonners'],
 'refonnul': {'refonnulated': [], 'refonnulation': []},
 'refont': {'refonte': ['refontes']},
 'refonte': ['refontes'],
 'refoos': {'refoose': ['refoosed'], 'refoosing': []},
 'refoose': ['refoosed'],
 'refoot': {'refooted': [], 'refooting': []},
 'refor': {'refore': ['refores', 'reforence'],
           'reforment': [],
           'reforred': [],
           'reforring': [],
           'refors': []},
 'refora': {'reforas': []},
 'reforc': {'reforce': ['reforced', 'reforcement'], 'reforcing': []},
 'reforce': ['reforced', 'reforcement'],
 'reford': {'reforded': [], 'refording': []},
 'refore': ['refores', 'reforence'],
 'reforecast': {'reforecasting': [], 'reforecasts': []},
 'reforeno': {'reforenoe': []},
 'reforest': {'reforestate': [],
              'reforestation': [],
              'reforested': [],
              'reforester': ['reforesters'],
              'reforesting': [],
              'reforests': []},
 'reforester': ['reforesters'],
 'reforestr': {'reforestration': []},
 'reforestri': {'reforestry': []},
 'reforg': {'reforge': ['reforger', 'reforged', 'reforges'], 'reforging': []},
 'reforge': ['reforger', 'reforged', 'reforges'],
 'reforin': {'reforination': []},
 'reform': ['reforme',
            'reformer',
            'reformes',
            'reformed',
            'reformeds',
            'reformity',
            'reformism',
            'reformant',
            'reformate',
            'reforming',
            'reformance',
            'reformable',
            'reformeing',
            'reformings',
            'reformator',
            'reformated',
            'reformates',
            'reformation',
            'reformative',
            'reformalize',
            'reformering',
            'reformating',
            'reformators',
            'reformalized',
            'reformability',
            'reformational',
            'reformalizing',
            'reformatively',
            'reformalization'],
 'reforma': {'reformas': []},
 'reformac': {'reformace': []},
 'reformacion': {'reformacione': [], 'reformacions': []},
 'reformacioni': {'reformacionis': []},
 'reformad': {'reformade': ['reformades']},
 'reformada': {'reformadas': []},
 'reformade': ['reformades'],
 'reformado': {'reformadoes': [], 'reformados': []},
 'reformador': {'reformadores': []},
 'reformalis': {'reformalisation': []},
 'reformam': {'reformamation': []},
 'reforman': {'reformans': []},
 'reformanda': {'reformandae': []},
 'reformandi': {'reformandis': []},
 'reformando': {'reformandos': []},
 'reformansatz': {'reformansatze': []},
 'reformar': {'reformare': []},
 'reformars': {'reformarse': []},
 'reformat': {'reformats': [], 'reformatted': [], 'reformatting': []},
 'reformata': {'reformatae': [], 'reformatas': []},
 'reformateur': {'reformateurs': []},
 'reformati': {'reformatie': [], 'reformatiou': [], 'reformatis': []},
 'reformation': {'reformatione': ['reformationes'], 'reformationism': []},
 'reformationari': {'reformationary': []},
 'reformatione': ['reformationes'],
 'reformationen': {'reformationens': []},
 'reformationgeschicht': {'reformationgeschichte': []},
 'reformationi': {'reformationis': []},
 'reformationibu': {'reformationibus': []},
 'reformationist': {'reformationists': []},
 'reformationsgeschicht': {'reformationsgeschichte': []},
 'reformationsgeschichtlich': {'reformationsgeschichtliche': []},
 'reformationshistori': {'reformationshistorie': []},
 'reformationsjahrhundert': {'reformationsjahrhunderts': []},
 'reformationsperiod': {'reformationsperiode': []},
 'reformationszeitalt': {'reformationszeitalter': ['reformationszeitalters']},
 'reformationszeitalter': ['reformationszeitalters'],
 'reformato': {'reformatos': []},
 'reformator': {'reformatores': []},
 'reformatori': {'reformatory': []},
 'reformatoribu': {'reformatoribus': []},
 'reformatorisch': {'reformatorische': ['reformatorisches',
                                        'reformatorischer']},
 'reformatorische': ['reformatorisches', 'reformatorischer'],
 'reformatric': {'reformatrice': ['reformatrices']},
 'reformatrice': ['reformatrices'],
 'reformatsionny': {'reformatsionnye': []},
 'reformatski': {'reformatsky': []},
 'reformatt': {'reformatter': ['reformatters']},
 'reformatter': ['reformatters'],
 'reformatu': {'reformatus': []},
 'reformatzki': {'reformatzky': []},
 'reformbas': {'reformbased': []},
 'reformbil': {'reformbill': []},
 'reformconsci': {'reformconscious': []},
 'reformd': {'reformde': []},
 'reformdebatt': {'reformdebatte': []},
 'reformdiskuss': {'reformdiskussion': []},
 'reformdtu': {'reformdtus': []},
 'reforme': {'reformee': ['reformees']},
 'reformedli': {'reformedly': []},
 'reformee': ['reformees'],
 'reformei': {'reformeis': []},
 'reformer': {'reformerent': []},
 'reformfreund': {'reformfreunde': []},
 'reformgemeind': {'reformgemeinde': []},
 'reformgrupp': {'reformgruppe': []},
 'reformhau': {'reformhaus': []},
 'reformi': {'reformie': ['reformies'], 'reformis': [], 'reformy': []},
 'reformid': {'reformidant': [], 'reformident': []},
 'reformida': {'reformidas': []},
 'reformidan': {'reformidans': []},
 'reformidar': {'reformidare': []},
 'reformide': {'reformidee': []},
 'reformie': ['reformies'],
 'reformiert': {'reformierte': ['reformiertes', 'reformierter']},
 'reformierte': ['reformiertes', 'reformierter'],
 'reforming': {'reforminge': []},
 'reformingth': {'reformingthe': []},
 'reformirt': {'reformirte': ['reformirter']},
 'reformirte': ['reformirter'],
 'reformism': {'reformisme': []},
 'reformismu': {'reformismus': []},
 'reformiss': {'reformission': []},
 'reformist': ['reformiste', 'reformistes', 'reformistic', 'reformistically'],
 'reformista': {'reformistas': []},
 'reformistmind': {'reformistminded': []},
 'reformjuda': {'reformjudaism': []},
 'reformkatholizismu': {'reformkatholizismus': []},
 'reformkommunismu': {'reformkommunismus': []},
 'reformkur': {'reformkurs': []},
 'reformmind': {'reformminded': []},
 'reformminded': {'reformmindedness': []},
 'reformmodel': {'reformmodelle': []},
 'reformmong': {'reformmonger': ['reformmongering']},
 'reformmonger': ['reformmongering'],
 'reformmov': {'reformmovement': ['reformmovements']},
 'reformmovement': ['reformmovements'],
 'reformori': {'reformoriented': []},
 'reformpapsttum': {'reformpapsttums': []},
 'reformplan': {'reformplane': []},
 'reformprojekt': {'reformprojekte': []},
 'reformprozess': {'reformprozesse': ['reformprozesses']},
 'reformprozesse': ['reformprozesses'],
 'reformrel': {'reformrelated': []},
 'reformschul': {'reformschule': []},
 'reformt': {'reformtion': []},
 'reformth': {'reformthe': []},
 'reformul': {'reformulable': [],
              'reformulate': ['reformulates', 'reformulated'],
              'reformulating': [],
              'reformulation': ['reformulations'],
              'reformulative': [],
              'reformulator': ['reformulators'],
              'reformule': ['reformuler']},
 'reformular': {'reformulare': ['reformulared']},
 'reformulare': ['reformulared'],
 'reformulate': ['reformulates', 'reformulated'],
 'reformulation': ['reformulations'],
 'reformulator': ['reformulators'],
 'reformulatori': {'reformulatory': []},
 'reformule': {'reformulee': []},
 'reformversuch': {'reformversuche': []},
 'reformvorschlag': {'reformvorschlage': []},
 'reformyng': {'reformynge': []},
 'reformzeitalt': {'reformzeitalter': []},
 'reforn': {'reforne': [], 'reforns': []},
 'reforni': {'reforniation': []},
 'reforonc': {'reforonce': []},
 'reforrn': {'reforrnation': [], 'reforrners': [], 'reforrns': []},
 'refort': {'reforted': [], 'reforter': [], 'reforting': [], 'reforts': []},
 'refortif': {'refortification': ['refortifications']},
 'refortifi': {'refortified': [],
               'refortifies': [],
               'refortify': ['refortifying']},
 'refortification': ['refortifications'],
 'refortify': ['refortifying'],
 'refortn': {'refortnation': []},
 'reforward': {'reforwarded': [], 'reforwarding': []},
 'reforzada': {'reforzadas': []},
 'reforzado': {'reforzados': []},
 'reforzars': {'reforzarse': []},
 'refos': {'refose': ['refosed'], 'refosing': []},
 'refose': ['refosed'],
 'refotm': {'refotmation': []},
 'refoudr': {'refoudre': []},
 'refoul': {'refoulant': [],
            'refoule': ['refoules',
                        'refouler',
                        'refouled',
                        'refoulent',
                        'refoulement',
                        'refoulements'],
            'refoulment': []},
 'refoule': {'refoulee': ['refoulees']},
 'refoulee': ['refoulees'],
 'refound': {'refoundation': ['refoundations', 'refoundational'],
             'refounded': [],
             'refounder': ['refounders'],
             'refounding': ['refoundings'],
             'refounds': []},
 'refoundation': ['refoundations', 'refoundational'],
 'refounder': ['refounders'],
 'refounding': ['refoundings'],
 'refourc': {'refource': ['refources']},
 'refource': ['refources'],
 'refourm': {'refourme': ['refourmed']},
 'refourme': ['refourmed'],
 'refouss': {'refousse': []},
 'refov': {'refove': []},
 'refover': {'refovere': []},
 'refp': {'refpe': ['refped', 'refpes', 'refpeds']},
 'refpe': ['refped', 'refpes', 'refpeds'],
 'refpecl': {'refpeclable': [],
             'refpecled': [],
             'refpeclful': ['refpeclfully'],
             'refpecling': [],
             'refpeclive': ['refpeclively'],
             'refpecls': []},
 'refpeclful': ['refpeclfully'],
 'refpeclive': ['refpeclively'],
 'refpect': {'refpectability': [],
             'refpectable': [],
             'refpected': [],
             'refpectful': ['refpectfully'],
             'refpecting': [],
             'refpective': ['refpectively'],
             'refpects': []},
 'refpectful': ['refpectfully'],
 'refpective': ['refpectively'],
 'refpecy': {'refpecyive': []},
 'refped': {'refpedable': [], 'refpeding': [], 'refpedive': ['refpedively']},
 'refpedive': ['refpedively'],
 'refpedl': {'refpedlable': [],
             'refpedling': [],
             'refpedlive': [],
             'refpedls': []},
 'refpedt': {'refpedtable': [],
             'refpedted': [],
             'refpedting': [],
             'refpedtive': ['refpedtively'],
             'refpedts': []},
 'refpedtive': ['refpedtively'],
 'refpefl': {'refpeflable': [],
             'refpefling': [],
             'refpeflive': [],
             'refpefls': []},
 'refpeft': {'refpeftable': [],
             'refpefted': [],
             'refpeftful': ['refpeftfully'],
             'refpefting': [],
             'refpeftive': ['refpeftively'],
             'refpefts': []},
 'refpeftful': ['refpeftfully'],
 'refpeftive': ['refpeftively'],
 'refpetl': {'refpetling': [], 'refpetlive': []},
 'refpett': {'refpettive': []},
 'refpir': {'refpirable': [], 'refpiration': [], 'refpire': ['refpirer']},
 'refpire': ['refpirer'],
 'refpit': {'refpite': ['refpited']},
 'refpite': ['refpited'],
 'refplend': {'refplendent': []},
 'refpond': {'refpondence': [], 'refpondent': []},
 'refponder': {'refpondere': []},
 'refpondr': {'refpondre': []},
 'refponf': {'refponfe': ['refponfes'],
             'refponfibility': [],
             'refponfible': []},
 'refponfe': ['refponfes'],
 'refr': {'refrative': [], 'refre': ['refres'], 'refrred': [], 'refrs': []},
 'refraclori': {'refraclory': []},
 'refract': {'refractability': [],
             'refractable': [],
             'refractance': [],
             'refracte': ['refractes', 'refracted'],
             'refractibility': [],
             'refractible': [],
             'refracting': [],
             'refraction': ['refractional'],
             'refractive': ['refractives', 'refractively', 'refractiveness'],
             'refractivity': [],
             'refracts': []},
 'refractair': {'refractaire': ['refractaires']},
 'refractaire': ['refractaires'],
 'refractari': {'refractary': []},
 'refractario': {'refractarios': []},
 'refracte': {'refractee': []},
 'refractedli': {'refractedly': []},
 'refracti': {'refractiou': ['refractious'], 'refractis': []},
 'refractic': {'refractice': []},
 'refractil': {'refractile': [], 'refractility': []},
 'refraction': {'refractionate': ['refractionated'],
                'refractionating': [],
                'refractionation': ['refractionations'],
                'refractione': ['refractiones']},
 'refractionate': ['refractionated'],
 'refractionation': ['refractionations'],
 'refractiondiffract': {'refractiondiffraction': []},
 'refractione': ['refractiones'],
 'refractioni': {'refractionis': []},
 'refractionibu': {'refractionibus': []},
 'refractionist': {'refractionists': []},
 'refractionomet': {'refractionometer': []},
 'refractiou': ['refractious'],
 'refractive': ['refractives', 'refractively', 'refractiveness'],
 'refracto': {'refractos': []},
 'refractom': {'refractomer': []},
 'refractomct': {'refractomcter': []},
 'refractomet': {'refractometer': []},
 'refractometr': {'refractometric': ['refractometrically']},
 'refractometri': {'refractometry': []},
 'refractometric': ['refractometrically'],
 'refractor': {'refractors': []},
 'refractori': {'refractorie': [], 'refractoriness': [], 'refractory': []},
 'refractorili': {'refractorily': []},
 'refractorylin': {'refractorylined': []},
 'refractorymet': {'refractorymetal': []},
 'refractrometr': {'refractrometric': []},
 'refractu': {'refractus': []},
 'refractur': {'refracture': ['refractured', 'refractures'],
               'refracturing': []},
 'refracture': ['refractured', 'refractures'],
 'refradt': {'refradtion': []},
 'refraenar': {'refraenare': []},
 'refraet': {'refraetion': [], 'refraetive': []},
 'refraetil': {'refraetile': []},
 'refraetomet': {'refraetometer': []},
 'refraetori': {'refraetory': []},
 'refraftori': {'refraftory': []},
 'refrag': {'refragability': [],
            'refragable': [],
            'refragment': ['refragmented']},
 'refragant': {'refragante': []},
 'refragantibu': {'refragantibus': []},
 'refragation': {'refragatione': []},
 'refragment': {'refragmentation': []},
 'refrain': ['refraine',
             'refrained',
             'refrainer',
             'refraining',
             'refrainers',
             'refrainings',
             'refrainment'],
 'refrainlik': {'refrainlike': []},
 'refrakt': {'refraktion': ['refraktions']},
 'refraktar': {'refraktare': []},
 'refraktion': ['refraktions'],
 'refraktionsseismisch': {'refraktionsseismische': ['refraktionsseismischer']},
 'refraktionsseismische': ['refraktionsseismischer'],
 'refraktomet': {'refraktometer': []},
 'refram': {'reframe': ['reframes', 'reframed', 'reframer', 'reframers'],
            'reframing': ['reframings']},
 'reframe': ['reframes', 'reframed', 'reframer', 'reframers'],
 'reframing': ['reframings'],
 'refran': {'refranation': [], 'refrane': ['refranes']},
 'refranc': {'refrance': []},
 'refranchis': {'refranchise': ['refranchised'], 'refranchising': []},
 'refranchise': ['refranchised'],
 'refrane': ['refranes'],
 'refranero': {'refraneros': []},
 'refrang': {'refrangent': [],
             'refrangibilities': [],
             'refrangibility': [],
             'refrangible': []},
 'refrangibihti': {'refrangibihty': []},
 'refrangibilit': {'refrangibilite': []},
 'refrangihil': {'refrangihility': []},
 'refraot': {'refraotion': [], 'refraotive': []},
 'refraotomet': {'refraotometer': []},
 'refraotori': {'refraotory': []},
 'refrarn': {'refrarning': []},
 'refrat': {'refration': []},
 'refratn': {'refratning': []},
 'refratori': {'refratory': []},
 'refraug': {'refraugibility': []},
 'refrayn': {'refrayne': ['refrayned']},
 'refrayne': ['refrayned'],
 'refrazion': {'refrazione': []},
 'refre': {'refree': ['refrees']},
 'refrect': {'refrection': [], 'refrective': []},
 'refrectori': {'refrectory': []},
 'refree': ['refrees'],
 'refreez': {'refreezable': [],
             'refreeze': ['refreezes'],
             'refreezing': ['refreezings']},
 'refreeze': ['refreezes'],
 'refreezing': ['refreezings'],
 'refrefh': {'refrefhed': [],
             'refrefhing': [],
             'refrefhment': ['refrefhments']},
 'refrefhment': ['refrefhments'],
 'refrefli': {'refreflied': [], 'refrefliing': [], 'refrefliment': []},
 'refreger': {'refregerator': []},
 'refregi': {'refregier': []},
 'refreih': {'refreihing': []},
 'refrein': {'refreine': []},
 'refrejh': {'refrejhed': []},
 'refrelh': {'refrelhed': [], 'refrelhing': [], 'refrelhment': []},
 'refrem': {'refremed': [], 'refremment': []},
 'refren': {'refrener': []},
 'refrenar': {'refrenare': []},
 'refrenc': {'refrence': ['refrences']},
 'refrence': ['refrences'],
 'refrendada': {'refrendadas': []},
 'refrendado': {'refrendados': []},
 'refrer': {'refrerred': []},
 'refres': {'refresentative': ['refresentatives'],
            'refresing': [],
            'refresments': []},
 'refresca': {'refrescas': []},
 'refrescant': {'refrescante': ['refrescantes']},
 'refrescante': ['refrescantes'],
 'refrescars': {'refrescarse': []},
 'refresch': {'refresche': []},
 'refresco': {'refrescoed': [], 'refrescos': []},
 'refresent': {'refresentation': []},
 'refresentative': ['refresentatives'],
 'refresh': {'refreshable': [],
             'refreshe': ['refreshes',
                          'refreshed',
                          'refresher',
                          'refreshement',
                          'refreshements'],
             'refreshful': ['refreshfully'],
             'refreshing': ['refreshings'],
             'refreshment': ['refreshmenting'],
             'refreshness': []},
 'refreshe': ['refreshes',
              'refreshed',
              'refresher',
              'refreshement',
              'refreshements'],
 'refreshen': {'refreshened': [],
               'refreshener': ['refresheners'],
               'refreshening': [],
               'refreshens': []},
 'refreshener': ['refresheners'],
 'refreshful': {'refreshfull': []},
 'refreshing': {'refreshinge': [], 'refreshingness': []},
 'refreshingli': {'refreshingly': []},
 'refreshment': {'refreshmenters': []},
 'refreshmenthous': {'refreshmenthouses': []},
 'refreshmentroom': {'refreshmentrooms': []},
 'refreshpolici': {'refreshpolicy': []},
 'refreshproperti': {'refreshproperties': []},
 'refresli': {'refreslied': [], 'refresliing': [], 'refresliment': []},
 'refress': {'refression': []},
 'refressh': {'refresshe': ['refresshed'], 'refresshing': []},
 'refresshe': ['refresshed'],
 'refresshyng': {'refresshynge': []},
 'refresti': {'refrestied': [], 'refrestiing': [], 'refrestiment': []},
 'refret': {'refretted': [], 'refretting': []},
 'refreyn': {'refreyne': []},
 'refri': {'refried': ['refrieds'], 'refries': [], 'refry': ['refrying']},
 'refricar': {'refricare': []},
 'refridg': {'refridge': []},
 'refridger': {'refridgerated': [],
               'refridgeration': [],
               'refridgerator': ['refridgerators']},
 'refridgerator': ['refridgerators'],
 'refried': ['refrieds'],
 'refrig': {'refrigation': [],
            'refrigator': ['refrigators'],
            'refrige': ['refriger', 'refrigerative', 'refrigeratives']},
 'refrigator': ['refrigators'],
 'refrige': ['refriger', 'refrigerative', 'refrigeratives'],
 'refriger': {'refrigerant': [],
              'refrigerate': ['refrigerated', 'refrigerates'],
              'refrigerating': [],
              'refrigeration': [],
              'refrigerator': [],
              'refrigere': ['refrigerer', 'refrigerent', 'refrigerents']},
 'refrigerador': {'refrigeradores': []},
 'refrigeran': {'refrigerans': []},
 'refrigerant': {'refrigerante': ['refrigerantes']},
 'refrigerante': ['refrigerantes'],
 'refrigerar': {'refrigerare': []},
 'refrigerat': {'refrigerater': []},
 'refrigerate': ['refrigerated', 'refrigerates'],
 'refrigerateur': {'refrigerateurs': []},
 'refrigeration': {'refrigeratione': []},
 'refrigerationi': {'refrigerationis': []},
 'refrigeratorcar': {'refrigeratorcars': []},
 'refrigeratorfreez': {'refrigeratorfreezer': ['refrigeratorfreezers']},
 'refrigeratorfreezer': ['refrigeratorfreezers'],
 'refrigeratori': {'refrigeratories': [], 'refrigeratory': []},
 'refrigerators': {'refrigeratorsized': []},
 'refrigere': ['refrigerer', 'refrigerent', 'refrigerents'],
 'refrigescent': {'refrigescente': []},
 'refrigescer': {'refrigescere': ['refrigescerent']},
 'refrigescere': ['refrigescerent'],
 'refrigi': {'refrigier': []},
 'refrigir': {'refrigirator': ['refrigirators']},
 'refrigirator': ['refrigirators'],
 'refrigr': {'refrigration': [], 'refrigrator': []},
 'refring': {'refringence': [],
             'refringency': [],
             'refringent': ['refringents']},
 'refringen': {'refringens': []},
 'refringent': {'refringentes': []},
 'refringer': {'refringere': []},
 'refrint': {'refrinted': []},
 'refrito': {'refritos': []},
 'refrlger': {'refrlgerator': []},
 'refroduc': {'refroduced': []},
 'refroidi': {'refroidie': ['refroidies', 'refroidier'], 'refroidis': []},
 'refroidie': ['refroidies', 'refroidier'],
 'refroidiss': {'refroidissant': [],
                'refroidisse': ['refroidissent',
                                'refroidissement',
                                'refroidissements']},
 'refroidisse': ['refroidissent', 'refroidissement', 'refroidissements'],
 'refrom': {'refroms': []},
 'refront': {'refronted': [], 'refronting': []},
 'refroz': {'refroze': []},
 'refry': ['refrying'],
 'refs': {'refsing': []},
 'refsel': {'refsell': []},
 'refshaug': {'refshauge': []},
 'refsn': {'refsnes': []},
 'refsna': {'refsnaes': []},
 'refsti': {'refstie': []},
 'refsum': {'refsums': []},
 'reft': {'refte': ['reftes', 'refted'], 'refting': [], 'refts': []},
 'reftaur': {'reftauration': []},
 'refte': ['reftes', 'refted'],
 'reftect': {'reftected': [],
             'reftecting': [],
             'reftection': ['reftections'],
             'reftective': [],
             'reftects': []},
 'reftection': ['reftections'],
 'reftel': {'reftele': [], 'reftels': []},
 'refter': {'refters': []},
 'reftgur': {'reftguring': []},
 'refth': {'refthe': []},
 'refti': {'refty': []},
 'reftifi': {'reftify': []},
 'reftig': {'reftige': []},
 'reftis': {'reftisal': [], 'reftise': ['reftised']},
 'reftise': ['reftised'],
 'reftitud': {'reftitude': []},
 'reftitut': {'reftitution': []},
 'reftlef': {'reftlefs': []},
 'reftn': {'reftne': ['reftned'], 'reftning': []},
 'reftne': ['reftned'],
 'reftor': {'reftoration': [],
            'reftore': ['reftored', 'reftorer', 'reftores'],
            'reftoring': []},
 'reftore': ['reftored', 'reftorer', 'reftores'],
 'reftori': {'reftory': []},
 'reftr': {'reftrred': []},
 'reftrain': {'reftrained': [], 'reftraining': [], 'reftrains': []},
 'reftraint': {'reftraints': []},
 'reftrenc': {'reftrence': []},
 'reftriclion': {'reftriclions': []},
 'reftrict': {'reftricted': [], 'reftriction': ['reftrictions']},
 'reftriction': ['reftrictions'],
 'reftrift': {'reftriftion': ['reftriftions']},
 'reftriftion': ['reftriftions'],
 'reftyp': {'reftype': []},
 'refu': {'refue': ['refued', 'refues'], 'refus': []},
 'refua': {'refuae': ['refuaed'], 'refuaing': []},
 'refuae': ['refuaed'],
 'refuat': {'refuation': []},
 'refubl': {'refublic': []},
 'refubliqu': {'refublique': []},
 'refuc': {'refuce': ['refuced']},
 'refuce': ['refuced'],
 'refue': {'refuee': ['refueed', 'refuees']},
 'refuee': ['refueed', 'refuees'],
 'refuel': {'refuelable': [],
            'refueled': [],
            'refueler': ['refuelers'],
            'refueling': [],
            'refuelled': [],
            'refueller': ['refuellers'],
            'refuelling': ['refuellings'],
            'refuels': []},
 'refueler': ['refuelers'],
 'refueller': ['refuellers'],
 'refuelling': ['refuellings'],
 'refuerzo': {'refuerzos': []},
 'refuf': {'refufal': ['refufals'],
           'refufe': ['refufer', 'refufes', 'refufed'],
           'refufing': []},
 'refufal': ['refufals'],
 'refufe': ['refufer', 'refufes', 'refufed'],
 'refug': {'refuge': ['refuged'], 'refuging': [], 'refugs': []},
 'refuge': {'refugee': ['refugeed', 'refugeeing', 'refugeeism', 'refugeeness']},
 'refugee': {'refugeee': ['refugeees']},
 'refugeee': ['refugeees'],
 'refugeelik': {'refugeelike': []},
 'refugeeproduc': {'refugeeproducing': []},
 'refugeereceiv': {'refugeereceiving': []},
 'refugeerel': {'refugeerelated': []},
 'refuger': {'refugere': ['refugerent']},
 'refugere': ['refugerent'],
 'refugg': {'refugges': []},
 'refugi': {'refugial': [],
            'refugiant': [],
            'refugie': ['refugier', 'refugies', 'refugient'],
            'refugis': []},
 'refugia': {'refugias': []},
 'refugiado': {'refugiados': []},
 'refugiai': {'refugiaient': []},
 'refugiandos': {'refugiandose': []},
 'refugiars': {'refugiarse': []},
 'refugie': {'refugiee': ['refugiees']},
 'refugiee': ['refugiees'],
 'refugien': {'refugiens': []},
 'refugient': {'refugientes': []},
 'refugientibu': {'refugientibus': []},
 'refugier': {'refugierent': []},
 'refugii': {'refugiis': []},
 'refugimu': {'refugimus': []},
 'refugio': {'refugios': []},
 'refugiss': {'refugisse': []},
 'refugitqu': {'refugitque': []},
 'refugium': {'refugiums': []},
 'refugue': {'refuguees': []},
 'refui': {'refuie': ['refuied'], 'refuis': []},
 'refuie': ['refuied'],
 'refuis': {'refuise': ['refuised', 'refuises'], 'refuising': []},
 'refuise': ['refuised', 'refuises'],
 'refuiss': {'refuissed': []},
 'refuissi': {'refuissis': []},
 'refujew': {'refujews': []},
 'reful': {'refule': ['refuled'], 'refuling': []},
 'refule': ['refuled'],
 'refulfil': {'refulfilled': []},
 'refulg': {'refulge': ['refulges',
                        'refulgent',
                        'refulgence',
                        'refulgency',
                        'refulgently']},
 'refulge': ['refulges',
             'refulgent',
             'refulgence',
             'refulgency',
             'refulgently'],
 'refulgen': {'refulgens': []},
 'refulgent': {'refulgente': ['refulgentes']},
 'refulgente': ['refulgentes'],
 'refulgenti': {'refulgentis': []},
 'refulger': {'refulgere': []},
 'refulli': {'refully': []},
 'refuls': {'refulse': []},
 'refult': {'refulted': [], 'refulting': [], 'refults': []},
 'refum': {'refume': ['refumes', 'refumed'], 'refuming': []},
 'refume': ['refumes', 'refumed'],
 'refumig': {'refumigated': []},
 'refumpt': {'refumption': []},
 'refun': {'refuned': []},
 'refunct': {'refunction': ['refunctions',
                            'refunctioned',
                            'refunctioning',
                            'refunctionings']},
 'refunction': {'refunctionalization': [],
                'refunctionalize': ['refunctionalized'],
                'refunctionalizing': []},
 'refunctionalis': {'refunctionalisation': []},
 'refunctionalize': ['refunctionalized'],
 'refund': ['refunde',
            'refunder',
            'refunded',
            'refunding',
            'refunders',
            'refundings',
            'refundment',
            'refundable',
            'refundments',
            'refundability'],
 'refunder': {'refundere': []},
 'refundicion': {'refundiciones': []},
 'refundidor': {'refundidores': []},
 'refundl': {'refundle': []},
 'refunnel': {'refunneled': []},
 'refur': {'refuration': [], 'refure': ['refured'], 'refurred': []},
 'refurbish': {'refurbishable': [],
               'refurbished': [],
               'refurbisher': ['refurbishers'],
               'refurbishes': [],
               'refurbishing': ['refurbishings'],
               'refurbishment': []},
 'refurbisher': ['refurbishers'],
 'refurbishing': ['refurbishings'],
 'refure': ['refured'],
 'refurhish': {'refurhished': []},
 'refurl': {'refurled': [], 'refurling': []},
 'refurn': {'refurned': [], 'refurns': []},
 'refurnish': {'refurnished': [],
               'refurnishes': [],
               'refurnishing': ['refurnishings'],
               'refurnishment': []},
 'refurnishing': ['refurnishings'],
 'refurr': {'refurre': []},
 'refurrect': {'refurrection': []},
 'refurredt': {'refurredtion': []},
 'refurreft': {'refurreftion': []},
 'refurrett': {'refurrettion': []},
 'refus': {'refusable': [],
           'refusal': [],
           'refusant': [],
           'refuse': ['refuser',
                      'refused',
                      'refusent',
                      'refusers',
                      'refuseing'],
           'refusing': ['refusings'],
           'refusion': ['refusions']},
 'refusai': {'refusaient': [], 'refusais': []},
 'refusal': {'refusall': ['refusalls']},
 'refusall': ['refusalls'],
 'refusass': {'refusassent': []},
 'refuscen': {'refuscens': []},
 'refusd': {'refusde': []},
 'refuse': {'refusee': ['refusees']},
 'refuseal': {'refuseall': []},
 'refusecollect': {'refusecollection': []},
 'refusederiv': {'refusederived': []},
 'refusedispos': {'refusedisposal': []},
 'refusednik': {'refusedniks': []},
 'refusee': ['refusees'],
 'refuseheap': {'refuseheaps': []},
 'refuseing': {'refuseinge': []},
 'refusenik': {'refuseniks': []},
 'refuser': {'refuserent': []},
 'refuserai': {'refuseraient': [], 'refuserais': []},
 'refuserion': {'refuserions': []},
 'refuseroi': {'refuseroient': []},
 'refuseron': {'refuserons': []},
 'refuseth': {'refusethe': []},
 'refush': {'refushed': []},
 'refusi': {'refusis': []},
 'refusing': {'refusinge': []},
 'refusion': ['refusions'],
 'refusnik': {'refusniks': []},
 'refuso': {'refusos': []},
 'refusoi': {'refusoient': []},
 'refuson': {'refusons': []},
 'refuss': {'refusse': ['refusses', 'refussed'], 'refussing': []},
 'refusse': ['refusses', 'refussed'],
 'refusu': {'refusual': [], 'refusus': []},
 'refusyng': {'refusynge': []},
 'refut': {'refutability': [],
           'refutable': [],
           'refutably': [],
           'refutal': [],
           'refutant': [],
           'refutating': [],
           'refutation': ['refutational', 'refutationally'],
           'refutative': [],
           'refute': ['refuter', 'refuted', 'refutes', 'refutent'],
           'refuting': [],
           'refution': [],
           'refutive': []},
 'refutacion': {'refutaciones': []},
 'refutamu': {'refutamus': []},
 'refutan': {'refutans': []},
 'refutandi': {'refutandis': []},
 'refutant': {'refutantes': []},
 'refutar': {'refutare': []},
 'refutati': {'refutatis': []},
 'refutation': {'refutatione': ['refutationes'], 'refutationism': []},
 'refutatione': ['refutationes'],
 'refutationibu': {'refutationibus': []},
 'refutationist': {'refutationists': []},
 'refutatori': {'refutatory': []},
 'refute': {'refutee': ['refutees']},
 'refutee': ['refutees'],
 'refutori': {'refutory': []},
 'refuz': {'refuze': ['refuzed']},
 'refuze': ['refuzed'],
 'refwork': {'refworks': []},
 'refyn': {'refyne': ['refyned'], 'refyning': []},
 'refyne': ['refyned'],
 'reg': {'regative': [], 'regs': []},
 "reg'i": {"reg'is": []},
 "reg'm": {"reg'me": []},
 "reg't": {"reg'ts": []},
 'rega': {'regae': ['regaed'], 'regas': []},
 'regabi': {'regaby': []},
 'regad': {'regaded': [], 'regading': [], 'regads': []},
 'regada': {'regadas': []},
 'regadera': {'regaderas': []},
 'regadio': {'regadios': []},
 'regado': {'regados': []},
 'regador': {'regadores': []},
 'regae': ['regaed'],
 'regafd': {'regafded': []},
 'regag': {'regaged': [], 'regaging': []},
 'regagn': {'regagnant': [], 'regagne': ['regagner', 'regagnent']},
 'regagne': ['regagner', 'regagnent'],
 'regagner': {'regagnerent': []},
 'regaid': {'regaided': [], 'regaiding': [], 'regaids': []},
 'regaii': {'regaiis': []},
 'regail': {'regailed': [], 'regailing': [], 'regails': []},
 'regain': {'regainable': [],
            'regaine': ['regained', 'regainer', 'regainers'],
            'regaining': [],
            'regainment': [],
            'regains': []},
 'regaine': ['regained', 'regainer', 'regainers'],
 'regaird': {'regairded': [], 'regairding': []},
 'regaiu': {'regaiued': []},
 'regal': {'regalate': ['regalates', 'regalated'],
           'regalation': ['regalations'],
           'regale': ['regales',
                      'regaled',
                      'regaler',
                      'regalement',
                      'regalements'],
           'regaling': [],
           'regalism': [],
           'regalities': [],
           'regality': [],
           'regalization': [],
           'regalized': [],
           'regall': ['regalls', 'regalle', 'regally', 'regalles', 'regalled'],
           'regalness': [],
           'regals': []},
 'regala': {'regalas': []},
 'regalad': {'regalade': ['regalades']},
 'regalada': {'regaladas': []},
 'regalade': ['regalades'],
 'regalado': {'regalados': []},
 'regalam': {'regalames': []},
 'regalamo': {'regalamos': []},
 'regalar': {'regalare': []},
 'regalarl': {'regalarle': []},
 'regalarli': {'regalarly': []},
 'regalarlo': {'regalarlos': []},
 'regalars': {'regalarse': []},
 'regalate': ['regalates', 'regalated'],
 'regalation': ['regalations'],
 'regalatu': {'regalatus': []},
 'regalbook': {'regalbooks': []},
 'regale': ['regales', 'regaled', 'regaler', 'regalement', 'regalements'],
 'regalecida': {'regalecidae': []},
 'regalecu': {'regalecus': []},
 'regaler': {'regalerent': []},
 'regalfa': {'regalfas': []},
 'regali': {'regalie': [], 'regalis': []},
 'regalia': ['regaliae'],
 'regalian': {'regalians': []},
 'regalianu': {'regalianus': []},
 'regalibu': {'regalibus': []},
 'regalien': {'regaliens': []},
 'regalio': {'regalios': []},
 'regaliqu': {'regalique': []},
 'regalist': {'regalistic': [], 'regalists': []},
 'regalista': {'regalistas': []},
 'regalit': {'regalitate': [], 'regalite': ['regaliter']},
 'regalita': {'regalitas': []},
 'regalitati': {'regalitatis': []},
 'regalite': ['regaliter'],
 'regaliti': {'regalitie': []},
 'regalito': {'regalitos': []},
 'regall': ['regalls', 'regalle', 'regally', 'regalles', 'regalled'],
 'regallook': {'regallooking': []},
 'regallop': {'regalloped': []},
 'regalment': {'regalmente': []},
 'regalo': {'regalos': []},
 'regalski': {'regalsky': []},
 'regalti': {'regalty': []},
 'regalu': {'regalus': []},
 'regalvan': {'regalvanize': ['regalvanized'], 'regalvanizing': []},
 'regalvanis': {'regalvanise': ['regalvanised'], 'regalvanising': []},
 'regalvanise': ['regalvanised'],
 'regalvanize': ['regalvanized'],
 'regam': {'regamed': []},
 'regami': {'regamy': []},
 'regamu': {'regamus': []},
 'regan': {'regane': [], 'reganism': [], 'regans': []},
 'reganadient': {'reganadientes': []},
 'reganbook': {'reganbooks': []},
 'regani': {'reganis': []},
 'reganl': {'reganled': [], 'reganling': [], 'reganls': []},
 'regann': {'reganne': []},
 'reganom': {'reganomics': []},
 'regant': {'regantes': []},
 'regap': {'regapped': [], 'regapping': []},
 'regar': {'regare': ['regared'],
           'regaring': [],
           'regarmented': [],
           'regars': []},
 'regara': {'regaraed': [], 'regaraing': [], 'regaras': []},
 'regarb': {'regarbed': []},
 'regard': ['regarde',
            'regardes',
            'regarded',
            'regarder',
            'regardant',
            'regarders',
            'regarding',
            'regardent',
            'regardful',
            'regardness',
            'regardable',
            'regardator',
            'regardding',
            'regardings',
            'regardance',
            'regardants',
            'regardation',
            'regardfully',
            'regardfulness'],
 'regarda': {'regardas': []},
 'regardai': {'regardaient': [], 'regardais': []},
 'regardan': {'regardans': []},
 'regarde': {'regardee': ['regardees']},
 'regardecta': {'regardectas': []},
 'regarded': {'regardedness': []},
 'regardeda': {'regardedas': []},
 'regardedbi': {'regardedby': []},
 'regardee': ['regardees'],
 'regarder': {'regarderent': []},
 'regardera': {'regarderas': []},
 'regarderai': {'regarderaient': [], 'regarderais': []},
 'regarderion': {'regarderions': []},
 'regarderon': {'regarderons': []},
 'regardf': {'regardfed': []},
 'regardful': {'regardfull': []},
 'regardi': {'regardie': ['regardies'], 'regardis': []},
 'regardie': ['regardies'],
 'regardin': {'regardine': [], 'regardins': []},
 'regarding': {'regardinge': [], 'regardingness': []},
 'regardingli': {'regardingly': []},
 'regardingth': {'regardingthe': []},
 'regardingthi': {'regardingthis': []},
 'regardion': {'regardions': []},
 'regardl': {'regardle': ['regardles']},
 'regardle': {'regardlees': []},
 'regardlea': {'regardleas': []},
 'regardlee': {'regardleee': []},
 'regardlef': {'regardlefs': []},
 'regardles': {'regardlese': []},
 'regardlesli': {'regardlesly': []},
 'regardless': {'regardlesse': [], 'regardlessness': []},
 'regardlessli': {'regardlessly': []},
 'regardlessofth': {'regardlessofthe': []},
 'regardoi': {'regardoient': [], 'regardois': []},
 'regardon': {'regardons': []},
 'regardsth': {'regardsthe': []},
 'regardth': {'regardthe': []},
 'regardtoth': {'regardtothe': []},
 'regardyng': {'regardynge': []},
 'regare': ['regared'],
 'regared': {'regareded': []},
 'regarg': {'regarged': []},
 'regarnish': {'regarnished': []},
 'regaro': {'regaroing': []},
 'regarrison': {'regarrisoned': [], 'regarrisoning': []},
 'regars': {'regarse': []},
 'regasif': {'regasification': []},
 'regasifi': {'regasified': [], 'regasify': ['regasifying']},
 'regasify': ['regasifying'],
 'regass': {'regassed': [], 'regassing': []},
 'regassif': {'regassification': []},
 'regat': {'regate': ['regates', 'regated'],
           'regating': [],
           'regation': ['regations', 'regational'],
           'regatting': []},
 'regata': {'regatas': []},
 'regatd': {'regatded': [], 'regatding': [], 'regatds': []},
 'regate': ['regates', 'regated'],
 'regath': {'regather': ['regathers',
                         'regathered',
                         'regathering',
                         'regatherings']},
 'regather': ['regathers', 'regathered', 'regathering', 'regatherings'],
 'regati': {'regatis': []},
 'regation': ['regations', 'regational'],
 'regato': {'regatoes': []},
 'regaton': {'regatones': []},
 'regatona': {'regatonas': []},
 'regatqu': {'regatque': []},
 'regatta': {'regatta': []},
 'regaug': {'regauge': ['regauged'], 'regauging': []},
 'regauge': ['regauged'],
 'regav': {'regave': []},
 'regayn': {'regayne': ['regayned']},
 'regayne': ['regayned'],
 'regazet': {'regazetted': []},
 'regc': {'regcs': []},
 'regconnectregistri': {'regconnectregistry': []},
 'regcr': {'regcre': []},
 'regdat': {'regdate': []},
 'regdelet': {'regdelete': []},
 'regdeletevalu': {'regdeletevalue': []},
 'rege': {'reged': [], 'reges': [], 'reging': []},
 'regeant': {'regeants': []},
 'regear': {'regeared': [], 'regearing': []},
 'regeb': {'regebant': []},
 'regect': {'regected': []},
 'regeczi': {'regeczy': []},
 'regedor': {'regedores': []},
 'regedoria': {'regedorias': []},
 'regeer': {'regeering': ['regeerings']},
 'regeerd': {'regeerders': []},
 'regeering': {'regeeringe': []},
 'regeeringsregl': {'regeeringsreglement': []},
 'regehli': {'regehly': []},
 'regeimb': {'regeimbal': []},
 'regel': {'regelate': ['regelates', 'regelated'],
           'regelating': [],
           'regelation': ['regelations'],
           'regele': [],
           'regeling': [],
           'regell': [],
           'regelous': [],
           'regels': []},
 'regelate': ['regelates', 'regelated'],
 'regelation': ['regelations'],
 'regelationi': {'regelationis': []},
 'regelbar': {'regelbare': []},
 'regelbrugg': {'regelbrugge': []},
 'regelfal': {'regelfall': []},
 'regelgev': {'regelgeving': []},
 'regelhaft': {'regelhafte': []},
 'regelia': {'regelias': []},
 'regelindi': {'regelindis': []},
 'regelkrei': {'regelkreis': []},
 'regelkreis': {'regelkreise': ['regelkreises']},
 'regelkreise': ['regelkreises'],
 'regello': {'regellos': []},
 'regellos': {'regellose': ['regelloser']},
 'regellose': ['regelloser'],
 'regelmabig': {'regelmabige': ['regelmabiger']},
 'regelmabige': ['regelmabiger'],
 'regelmafiig': {'regelmafiige': ['regelmafiiger']},
 'regelmafiige': ['regelmafiiger'],
 'regelmassig': {'regelmassige': ['regelmassiger', 'regelmassiges']},
 'regelmassige': ['regelmassiger', 'regelmassiges'],
 'regelmatig': {'regelmatige': []},
 'regelmechanismu': {'regelmechanismus': []},
 'regelmessig': {'regelmessige': []},
 'regelnd': {'regelnde': []},
 'regelrecht': {'regelrechte': ['regelrechter', 'regelrechtes']},
 'regelrechte': ['regelrechter', 'regelrechtes'],
 'regelsberg': {'regelsberger': []},
 'regelschul': {'regelschule': []},
 'regelsperg': {'regelsperger': []},
 'regelsystem': {'regelsysteme': [], 'regelsystems': []},
 'regelt': {'regelte': []},
 'regelung': {'regelungs': []},
 'regelungssystem': {'regelungssysteme': []},
 'regelungstechnisch': {'regelungstechnische': []},
 'regelungstheori': {'regelungstheorie': []},
 'regelungsvorgang': {'regelungsvorgange': []},
 'regelvorgang': {'regelvorgange': []},
 'regelwerk': {'regelwerke': []},
 'regem': {'regeme': []},
 'regement': {'regemente': [], 'regements': []},
 'regemort': {'regemorte': ['regemorter', 'regemortes']},
 'regemorte': ['regemorter', 'regemortes'],
 'regemqu': {'regemque': []},
 'regen': {'regene': ['regener',
                      'regeners',
                      'regenerative',
                      'regeneratives',
                      'regeneratively',
                      'regenerativity',
                      'regenerativeness'],
           'regeniti': [],
           'regens': []},
 'regenad': {'regenade': []},
 'regenal': {'regenall': []},
 'regenar': {'regenaration': []},
 'regenau': {'regenauer': []},
 'regenbogen': {'regenbogens': []},
 'regenbogenforel': {'regenbogenforelle': []},
 'regenc': {'regence': ['regences'], 'regency': []},
 'regence': ['regences'],
 'regenci': {'regencie': []},
 'regencystyl': {'regencystyle': []},
 'regend': {'regende': ['regender', 'regenders', 'regendered', 'regendering']},
 'regenda': {'regendae': [], 'regendas': []},
 'regende': ['regender', 'regenders', 'regendered', 'regendering'],
 'regendi': {'regendis': []},
 'regendisqu': {'regendisque': []},
 'regendo': {'regendos': []},
 'regendu': {'regendus': []},
 'regendumqu': {'regendumque': []},
 'regene': ['regener',
            'regeners',
            'regenerative',
            'regeneratives',
            'regeneratively',
            'regenerativity',
            'regenerativeness'],
 'regenei': {'regeneiation': []},
 'regener': {'regenerability': [],
             'regenerable': [],
             'regeneral': ['regeneralized'],
             'regenerant': ['regenerants'],
             'regenerate': ['regenerated', 'regenerates'],
             'regenerating': [],
             'regeneration': ['regenerational'],
             'regenerator': ['regenerators'],
             'regenere': ['regenerer', 'regeneres', 'regenerent']},
 'regeneraci': {'regeneracy': []},
 'regeneracionista': {'regeneracionistas': []},
 'regenerador': {'regeneradores': []},
 'regeneral': ['regeneralized'],
 'regeneran': {'regenerans': []},
 'regenerant': ['regenerants'],
 'regenerar': {'regenerare': []},
 'regenerat': {'regeneratable': []},
 'regenerate': ['regenerated', 'regenerates'],
 'regenerateur': {'regenerateurs': []},
 'regenerati': {'regeneratie': [], 'regeneratis': []},
 'regeneration': {'regeneratione': [], 'regenerationism': []},
 'regenerationi': {'regenerationis': []},
 'regenerationist': {'regenerationists': []},
 'regenerationsprozess': {'regenerationsprozesse': []},
 'regenerationsversuch': {'regenerationsversuche': []},
 'regenerationsvorgang': {'regenerationsvorgange': []},
 'regenerativ': {'regenerativer': []},
 'regenerator': ['regenerators'],
 'regeneratori': {'regeneratory': []},
 'regeneratric': {'regeneratrice': []},
 'regeneratu': {'regeneratus': []},
 'regenerazion': {'regenerazione': []},
 'regenere': {'regeneree': ['regenerees']},
 'regeneree': ['regenerees'],
 'regeneresc': {'regenerescence': []},
 'regeneri': {'regenery': []},
 'regenerierend': {'regenerierende': ['regenerierender']},
 'regenerierende': ['regenerierender'],
 'regeneriert': {'regenerierte': ['regenerierter']},
 'regenerierte': ['regenerierter'],
 'regenert': {'regenertion': []},
 'regenesi': {'regenesis': [], 'regenesys': []},
 'regenf': {'regenfs': []},
 'regenfal': {'regenfall': ['regenfalle']},
 'regenfall': ['regenfalle'],
 'regenfu': {'regenfus': []},
 'regeni': {'regeny': []},
 'regenitu': {'regenitus': []},
 'regenli': {'regenlied': []},
 'regenmach': {'regenmacher': []},
 'regenmeng': {'regenmenge': []},
 'regenmod': {'regenmode': []},
 'regenmort': {'regenmortal': [], 'regenmorter': []},
 'regennitt': {'regennitter': []},
 'regeno': {'regenos': []},
 'regenpfeif': {'regenpfeifer': []},
 'regenr': {'regenration': []},
 'regenri': {'regenry': []},
 'regensberg': {'regensberger': []},
 'regensbergiana': {'regensbergianae': []},
 'regensbergsch': {'regensbergsche': []},
 'regensburg': {'regensburger': ['regensburgers'], 'regensburgs': []},
 'regensburger': ['regensburgers'],
 'regensburgisch': {'regensburgische': []},
 'regenschau': {'regenschauer': []},
 'regenstein': {'regensteiner': []},
 'regent': ['regente',
            'regental',
            'regenter',
            'regented',
            'regentes',
            'regenting',
            'regentent'],
 "regent'": {"regent's": []},
 'regentag': {'regentage': []},
 'regentenstrass': {'regentenstrasse': []},
 'regentess': {'regentesses': []},
 'regenth': {'regenthal': []},
 'regenti': {'regential': [], 'regentis': []},
 'regentibu': {'regentibus': []},
 'regentmoth': {'regentmother': []},
 'regentrif': {'regentrification': []},
 'regentrifi': {'regentrified': [], 'regentrifying': []},
 'regentrud': {'regentrude': []},
 'regentvil': {'regentville': []},
 'regenumvalu': {'regenumvalue': []},
 'regenv': {'regenval': []},
 'regenvolsciu': {'regenvolscius': []},
 'regenwald': {'regenwalde': ['regenwalder', 'regenwaldes']},
 'regenwalde': ['regenwalder', 'regenwaldes'],
 'regenwass': {'regenwasser': []},
 'regenwat': {'regenwater': []},
 'regenwett': {'regenwetter': []},
 'regenwiirm': {'regenwiirmer': []},
 'regenwurm': {'regenwurmer': [], 'regenwurmes': [], 'regenwurms': []},
 'regeny': {'regenye': []},
 'reger': {'regeration': [],
           'regerative': [],
           'regere': ['regeres', 'regerent', 'regerence'],
           'regering': ['regerings'],
           'regers': []},
 'regerd': {'regerded': [], 'regerding': [], 'regerds': []},
 'regere': ['regeres', 'regerent', 'regerence'],
 'regerend': {'regerende': []},
 'regerendariu': {'regerendarius': []},
 'regeri': {'regeris': []},
 'regering': ['regerings'],
 'regeringen': {'regeringens': []},
 'regeringsbesliss': {'regeringsbeslissing': []},
 'regeringskansliet': {'regeringskansliets': []},
 'regeringskri': {'regeringskris': []},
 'regeringsmakten': {'regeringsmaktens': []},
 'regeringsratten': {'regeringsrattens': []},
 'regeringsregl': {'regeringsreglement': []},
 'regerman': {'regermanization': []},
 'regermin': {'regerminate': ['regerminated'],
              'regerminating': [],
              'regermination': []},
 'regerminan': {'regerminans': []},
 'regerminate': ['regerminated'],
 'reges': {'regeser': []},
 'regesmort': {'regesmortes': []},
 'regesqu': {'regesque': []},
 'regess': {'regession': ['regessions']},
 'regession': ['regessions'],
 'regest': {'regeste': ['regestes',
                        'regester',
                        'regested',
                        'regesters',
                        'regestered'],
            'regests': []},
 'regeste': ['regestes', 'regester', 'regested', 'regesters', 'regestered'],
 'regesti': {'regestis': [], 'regesty': []},
 'regestr': {'regestre': ['regestred']},
 'regestre': ['regestred'],
 'reget': {'regetable': ['regetables'],
           'regetation': [],
           'regets': [],
           'regetted': [],
           'regetting': []},
 'regetable': ['regetables'],
 'regett': {'regettable': [], 'regettably': []},
 'regeuci': {'regeucy': []},
 'regfil': {'regfile': []},
 'regg': {'regge': ['reggeli'], 'reggs': []},
 'regga': {'reggae': []},
 'reggan': {'reggane': []},
 'regge': ['reggeli'],
 'reggebog': {'reggeboge': []},
 'reggeiz': {'reggeization': [], 'reggeized': []},
 'reggent': {'reggente': []},
 'reggeon': {'reggeons': []},
 'regger': {'reggere': [], 'reggers': []},
 'reggess': {'reggesse': []},
 'regget': {'reggete': []},
 'reggetkeysecur': {'reggetkeysecurity': []},
 'reggi': {'reggie': ['reggies'], 'reggis': [], 'reggy': []},
 'reggian': {'reggiane': [], 'reggians': []},
 'reggie': ['reggies'],
 'reggier': {'reggiere': []},
 'reggin': {'reggins': []},
 'reggio': {'reggios': []},
 'reggion': {'reggione': []},
 'reggitor': {'reggitore': []},
 'reggiu': {'reggius': []},
 'reggress': {'reggression': []},
 'reghetto': {'reghettoization': [], 'reghettoized': []},
 'reghino': {'reghinos': []},
 'reght': {'reghts': []},
 'regi': {'regie': ['regies'], 'regis': [], 'regy': []},
 'regia': {'regiae': [], 'regias': []},
 'regiaequ': {'regiaeque': []},
 'regiamqu': {'regiamque': []},
 'regian': {'regianal': [], 'regiane': [], 'regians': []},
 'regiaqu': {'regiaque': []},
 'regiat': {'regiater': ['regiatered']},
 'regiater': ['regiatered'],
 'regiatr': {'regiatration': []},
 'regibelu': {'regibelus': []},
 'regibn': {'regibns': []},
 'regibu': {'regibus': []},
 'regibusqu': {'regibusque': []},
 'regibv': {'regibvs': []},
 'regic': {'regice': []},
 'regicid': {'regicidal': [], 'regicide': []},
 'regicidi': {'regicidis': []},
 'regicn': {'regicnal': [], 'regicns': []},
 'regid': {'regidate': ['regidates', 'regidated'],
           'regidating': [],
           'regidation': ['regidations'],
           'regides': [],
           'regidities': [],
           'regidity': []},
 'regida': {'regidas': []},
 'regidar': {'regidarity': []},
 'regidarli': {'regidarly': []},
 'regidate': ['regidates', 'regidated'],
 'regidation': ['regidations'],
 'regidli': {'regidly': []},
 'regidn': {'regidns': []},
 'regido': {'regidos': []},
 'regidor': {'regidores': [], 'regidors': []},
 'regidorc': {'regidorcs': []},
 'regidu': {'regidus': []},
 'regie': {'regiee': []},
 'regiem': {'regieme': []},
 'regiement': {'regiementation': []},
 'regien': {'regienal': [], 'regiens': []},
 'regiens': {'regiense': []},
 'regiensi': {'regiensis': []},
 'regier': {'regiere': ['regierer'], 'regiering': [], 'regiers': []},
 'regiere': ['regierer'],
 'regieren': {'regierens': []},
 'regierend': {'regierende': ['regierender']},
 'regierende': ['regierender'],
 'regiert': {'regierte': []},
 'regierung': {'regierungs': []},
 'regierungsbaumeist': {'regierungsbaumeister': []},
 'regierungsbeamt': {'regierungsbeamte': []},
 'regierungsbericht': {'regierungsberichte': []},
 'regierungsbezirk': {'regierungsbezirke': ['regierungsbezirkes'],
                      'regierungsbezirks': []},
 'regierungsbezirke': ['regierungsbezirkes'],
 'regierungschef': {'regierungschefs': []},
 'regierungseben': {'regierungsebene': []},
 'regierungsgebaud': {'regierungsgebaude': []},
 'regierungsgeschaft': {'regierungsgeschafte': []},
 'regierungsgeschicht': {'regierungsgeschichte': []},
 'regierungsjahr': {'regierungsjahre': []},
 'regierungskoalit': {'regierungskoalition': []},
 'regierungskommiss': {'regierungskommission': []},
 'regierungskreis': {'regierungskreise': []},
 'regierungskris': {'regierungskrise': []},
 'regierungslehr': {'regierungslehre': []},
 'regierungsmitglied': {'regierungsmitglieder': []},
 'regierungsorgan': {'regierungsorgane': []},
 'regierungspartn': {'regierungspartner': []},
 'regierungspraesid': {'regierungspraesident': []},
 'regierungsprasid': {'regierungsprasident': []},
 'regierungsprdsid': {'regierungsprdsident': []},
 'regierungspress': {'regierungspresse': []},
 'regierungsprogramm': {'regierungsprogramme': []},
 'regierungsr': {'regierungsrate': ['regierungsrates']},
 'regierungsrate': ['regierungsrates'],
 'regierungsrath': {'regierungsrathes': []},
 'regierungsseit': {'regierungsseite': []},
 'regierungssprech': {'regierungssprecher': []},
 'regierungssystem': {'regierungssysteme': [], 'regierungssystems': []},
 'regierungsvertret': {'regierungsvertreter': []},
 'regierungsvorlag': {'regierungsvorlage': []},
 'regierungsweis': {'regierungsweise': []},
 'regiess': {'regiession': []},
 'regiet': {'regieter': ['regietered'], 'regietted': []},
 'regieter': ['regietered'],
 'regietheat': {'regietheater': []},
 'regific': {'regifice': []},
 'regifl': {'regifler': []},
 'regift': {'regifted': [],
            'regifter': ['regifters', 'regiftered', 'regiftering'],
            'regifting': []},
 'regifter': ['regifters', 'regiftered', 'regiftering'],
 'regiftr': {'regiftred': []},
 'regiftri': {'regiftry': []},
 'regifug': {'regifuge': []},
 'regihu': {'regihus': []},
 'regii': {'regiis': []},
 'regiil': {'regiilations': []},
 'regiilu': {'regiilus': []},
 'regiisqu': {'regiisque': []},
 'regiit': {'regiiter': ['regiitered']},
 'regiiter': ['regiitered'],
 'regij': {'regije': []},
 'regijl': {'regijler': []},
 'regil': {'regilation': ['regilations']},
 'regilarli': {'regilarly': []},
 'regilation': ['regilations'],
 'regild': {'regilded': [], 'regilding': [], 'regilds': []},
 'regili': {'regilious': []},
 'regilianu': {'regilianus': []},
 'regillens': {'regillenses': []},
 'regillensi': {'regillensis': []},
 'regillianu': {'regillianus': []},
 'regillu': {'regillus': []},
 'regim': {'regimant': [], 'regime': ['regimer'], 'regims': []},
 'regimanta': {'regimantas': []},
 'regimb': {'regimbal': [], 'regimbe': ['regimber']},
 'regimbe': ['regimber'],
 'regime': ['regimer'],
 'regimebuild': {'regimebuilding': []},
 'regimechang': {'regimechange': []},
 'regimen': ['regimenal', 'regimenes'],
 'regimenqu': {'regimenque': []},
 'regimenrel': {'regimenrelated': []},
 'regiment': ['regimente',
              'regimental',
              'regimented',
              'regimenter',
              'regimentes',
              'regimenters',
              'regimentals',
              'regimenting',
              'regimentated',
              'regimentally',
              'regimentating',
              'regimentalism',
              'regimentalize',
              'regimentality',
              'regimentative',
              'regimentation',
              'regimentalized',
              'regimentational',
              'regimentalization'],
 'regimentalist': {'regimentalists': []},
 'regimentari': {'regimentary': []},
 'regimento': {'regimentos': []},
 'regimentstocht': {'regimentstochter': []},
 'regimespecif': {'regimespecific': []},
 'regimesponsor': {'regimesponsored': []},
 'regimesupport': {'regimesupportive': []},
 'regimeswitch': {'regimeswitching': []},
 'regimethreaten': {'regimethreatening': []},
 'regimetyp': {'regimetype': ['regimetypes']},
 'regimetype': ['regimetypes'],
 'regimeut': {'regimeuts': []},
 'regimiento': {'regimientos': []},
 'regimin': {'regiminal': [], 'regimine': []},
 'regimini': {'regiminis': []},
 'regiminibu': {'regiminibus': []},
 'regimist': {'regimists': []},
 'regimont': {'regimonts': []},
 'regimontanu': {'regimontanus': []},
 'regimt': {'regimts': []},
 'regimu': {'regimus': []},
 'regin': {'reginal': [],
           'regine': ['regined', 'reginer', 'regines', 'reginent'],
           'regining': [],
           'reginned': [],
           'reginning': ['reginnings'],
           'regins': []},
 'regina': ['reginae'],
 'reginaequ': {'reginaeque': []},
 'reginal': {'reginale': [], 'reginall': []},
 'reginald': {'reginalde': [], 'reginalds': []},
 'reginaldu': {'reginaldus': []},
 'reginali': {'reginalis': []},
 'reginan': {'reginans': []},
 'reginaphon': {'reginaphone': []},
 'reginarumqu': {'reginarumque': []},
 'reginc': {'regince': []},
 'regine': {'reginee': []},
 'reginens': {'reginense': ['reginenses']},
 'reginense': ['reginenses'],
 'reginensi': {'reginensis': []},
 'reginfr': {'reginfred': []},
 'reging': {'reginger': []},
 'regini': {'reginie': [], 'reginis': []},
 'reginj': {'reginje': []},
 'reginn': {'reginnal': [], 'reginns': []},
 'reginning': ['reginnings'],
 'regino': {'reginoal': [], 'reginoe': [], 'reginos': []},
 'reginoni': {'reginonis': []},
 'regins': {'reginse': []},
 'reginsm': {'reginsmal': []},
 'reginst': {'reginster': []},
 'regint': {'reginte': []},
 'reginu': {'reginus': []},
 'regio': {'regioe': ['regioes'], 'regios': []},
 'regioa': {'regioas': []},
 'regiocentr': {'regiocentric': [], 'regiocentrism': []},
 'regiochem': {'regiochemical': ['regiochemically']},
 'regiochemical': ['regiochemically'],
 'regiochemistri': {'regiochemistry': []},
 'regioe': ['regioes'],
 'regioghn': {'regioghne': []},
 'regioin': {'regioinal': []},
 'regioisom': {'regioisomer': ['regioisomers']},
 'regioisomer': {'regioisomeric': [], 'regioisomerism': []},
 'regiolect': {'regiolects': []},
 'regiomantanu': {'regiomantanus': []},
 'regiomantu': {'regiomantus': []},
 'regiomont': {'regiomontance': [], 'regiomonte': []},
 'regiomontan': {'regiomontans': []},
 'regiomontana': {'regiomontanae': [], 'regiomontanas': []},
 'regiomontano': {'regiomontanos': []},
 'regiomontanu': {'regiomontanus': []},
 'region': ['regione',
            'regiones',
            'regional',
            'regioned',
            'regioner',
            'regionals',
            'regioning',
            'regionism',
            'regionally',
            'regionated',
            'regionness',
            'regionation',
            'regionality',
            'regionalize',
            'regionalism',
            'regionalizes',
            'regionalized',
            'regionalness',
            'regionization',
            'regionalizing',
            'regionalities',
            'regionalization',
            'regionalizations'],
 "region'": {"region's": []},
 'regiona': {'regionaal': [], 'regionas': []},
 'regionai': {'regionais': []},
 'regional': {'regionale': ['regionales', 'regionaler', 'regionalement']},
 'regionalanalys': {'regionalanalyse': []},
 'regionalbas': {'regionalbased': []},
 'regionalcultur': {'regionalcultural': []},
 'regionaldevelop': {'regionaldevelopment': []},
 'regionale': ['regionales', 'regionaler', 'regionalement'],
 'regionaleconom': {'regionaleconomic': []},
 'regionalect': {'regionalects': []},
 'regionalethn': {'regionalethnic': []},
 'regionalgeschicht': {'regionalgeschichte': []},
 'regionali': {'regionalis': []},
 'regionalintern': {'regionalinternational': []},
 'regionalis': {'regionalisation': ['regionalisations'],
                'regionalise': ['regionalised', 'regionalisering'],
                'regionalising': []},
 'regionalisation': ['regionalisations'],
 'regionalise': {'regionalisees': []},
 'regionalism': {'regionalisme': ['regionalismes']},
 'regionalisme': ['regionalismes'],
 'regionalismo': {'regionalismos': []},
 'regionalismu': {'regionalismus': []},
 'regionalist': {'regionaliste': ['regionalistes'],
                 'regionalistic': [],
                 'regionalists': []},
 'regionalista': {'regionalistas': []},
 'regionaliste': ['regionalistes'],
 'regionalizzazion': {'regionalizzazione': []},
 'regionallanguag': {'regionallanguage': []},
 'regionallinguist': {'regionallinguistic': []},
 'regionalloc': {'regionallocal': []},
 'regionallybas': {'regionallybased': []},
 'regionallyori': {'regionallyoriented': []},
 'regionallyspecif': {'regionallyspecific': []},
 'regionalment': {'regionalmente': []},
 'regionalmetamorf': {'regionalmetamorfe': []},
 'regionalmetamorph': {'regionalmetamorphic': []},
 'regionalmetamorphos': {'regionalmetamorphose': []},
 'regionaln': {'regionalnational': [], 'regionalne': []},
 'regionalni': {'regionalny': []},
 'regionalplan': {'regionalplanning': []},
 'regionalpolitisch': {'regionalpolitische': ['regionalpolitischer']},
 'regionalpolitische': ['regionalpolitischer'],
 'regionalproblem': {'regionalprobleme': []},
 'regionalscal': {'regionalscale': []},
 'regionalspecif': {'regionalspecific': []},
 'regionalspit': {'regionalspital': []},
 'regionalstudi': {'regionalstudie': []},
 'regionar': {'regionare': []},
 'regionari': {'regionaries': [], 'regionary': []},
 'regionariu': {'regionarius': []},
 'regionbas': {'regionbased': []},
 'regionbi': {'regionby': []},
 'regionbuild': {'regionbuilding': []},
 'regionc': {'regioncs': []},
 'regiondepend': {'regiondependent': []},
 'regiondescript': {'regiondescription': []},
 'regionen': {'regionens': []},
 'regionesqu': {'regionesque': []},
 'regionforskn': {'regionforskning': []},
 'regiongrow': {'regiongrowing': []},
 'regioni': {'regionie': [], 'regionis': [], 'regiony': []},
 'regionibu': {'regionibus': []},
 'regionindeln': {'regionindelning': []},
 'regionist': {'regionists': []},
 'regionmatch': {'regionmatches': []},
 'regionori': {'regionoriented': []},
 'regionsar': {'regionsare': []},
 'regionspecif': {'regionspecific': []},
 'regionst': {'regionstates': []},
 'regionstudi': {'regionstudier': []},
 'regionsvil': {'regionsville': []},
 'regionvil': {'regionville': []},
 'regionwid': {'regionwide': []},
 'regionwis': {'regionwise': []},
 'regioo': {'regioos': []},
 'regiopoli': {'regiopolis': []},
 'regiopolit': {'regiopolitics': []},
 'regioqu': {'regioque': []},
 'regior': {'regioral': [], 'regiors': []},
 'regioregular': {'regioregularity': []},
 'regioselect': {'regioselective': ['regioselectively'],
                 'regioselectivities': [],
                 'regioselectivity': []},
 'regioselective': ['regioselectively'],
 'regiospecif': {'regiospecific': ['regiospecificity',
                                   'regiospecifically',
                                   'regiospecificities']},
 'regiospecific': ['regiospecificity',
                   'regiospecifically',
                   'regiospecificities'],
 'regiou': {'regious': []},
 'regioun': {'regiouns': []},
 'regipn': {'regipnal': [], 'regipns': []},
 'regiqn': {'regiqns': []},
 'regiqu': {'regique': []},
 'regir': {'regirer': []},
 'regird': {'regirded': [], 'regirding': [], 'regirds': []},
 'regirn': {'regirne': ['regirnent']},
 'regirne': ['regirnent'],
 'regirs': {'regirse': []},
 'regirt': {'regirter': []},
 'regis': {'regise': ['regises', 'regiser', 'regisered']},
 'regiscop': {'regiscope': []},
 'regise': ['regises', 'regiser', 'regisered'],
 'regisi': {'regisier': ['regisiered']},
 'regisier': ['regisiered'],
 'regisir': {'regisiration': [], 'regisires': []},
 'regisl': {'regislation': [], 'regisler': ['regislered']},
 'regisler': ['regislered'],
 'regislr': {'regislration': [], 'regislres': []},
 'regisn': {'regisnation': []},
 'regisol': {'regisole': []},
 'regisqu': {'regisque': []},
 'regisr': {'regisration': [],
            'regisrer': ['regisrers', 'regisrered', 'regisrering']},
 'regisrer': ['regisrers', 'regisrered', 'regisrering'],
 'regisret': {'regisreting': []},
 'regiss': {'regissant': [], 'regisse': ['regissent']},
 'regissai': {'regissaient': []},
 'regisse': ['regissent'],
 'regisseur': {'regisseure': [], 'regisseurs': []},
 'regist': {'registance': [],
            'registation': [],
            'registe': ['register',
                        'registed',
                        'registered',
                        'registering',
                        'registerred',
                        'registerings']},
 'registada': {'registadas': []},
 'registado': {'registados': []},
 'registar': {'registars': []},
 'registart': {'registartion': []},
 'registb': {'registbation': []},
 'registcr': {'registcred': []},
 'registe': {'registee': ['registees']},
 'registee': ['registees'],
 'registei': {'registeied': [], 'registeis': []},
 'register': {'registerability': [],
              'registerable': [],
              'registeral': [],
              'registeration': [],
              'registere': ['registeres', 'registerer', 'registerers']},
 'registeraccount': {'registeraccountants': []},
 'registerarraydeclar': {'registerarraydeclaration': []},
 'registerbas': {'registerbased': []},
 'registerbook': {'registerbooks': []},
 'registercli': {'registerclient': []},
 'registercompon': {'registercomponents': []},
 'registerdn': {'registerdns': []},
 'registerdriv': {'registerdriver': []},
 'registere': ['registeres', 'registerer', 'registerers'],
 'registeredorgan': {'registeredorganization': []},
 'registeredown': {'registeredowner': []},
 'registergener': {'registergeneral': []},
 'registeri': {'registerial': [],
               'registeries': [],
               'registeris': [],
               'registery': []},
 'registerit': {'registerite': ['registerites']},
 'registerite': ['registerites'],
 'registerkeyboardact': {'registerkeyboardaction': []},
 'registeroffic': {'registeroffice': ['registeroffices']},
 'registeroffice': ['registeroffices'],
 'registeroutparamet': {'registeroutparameter': []},
 'registershellfiletyp': {'registershellfiletypes': []},
 'registership': {'registerships': []},
 'registerspecif': {'registerspecific': []},
 'registerth': {'registerthe': []},
 'registertransf': {'registertransfer': []},
 'registertribun': {'registertribune': []},
 'registervalid': {'registervalidation': []},
 'registerwellknownservicetyp': {'registerwellknownservicetype': []},
 'registerwindowmessag': {'registerwindowmessage': []},
 'registet': {'registeted': []},
 'registh': {'registhe': []},
 'registi': {'registiation': [], 'registy': []},
 'registo': {'registos': []},
 'registor': {'registors': []},
 'registr': {'registrability': [],
             'registrable': [],
             'registral': ['registrally'],
             'registrant': [],
             'registrate': ['registrated', 'registrates'],
             'registrating': [],
             'registration': ['registrational'],
             'registrative': [],
             'registrator': ['registrators'],
             'registre': ['registred',
                          'registres',
                          'registrer',
                          'registrered',
                          'registrering'],
             'registring': [],
             'registrou': []},
 'registra': {'registras': []},
 'registrada': {'registradas': []},
 'registrado': {'registrados': []},
 'registrador': {'registradores': []},
 'registrair': {'registraire': []},
 'registral': ['registrally'],
 'registramo': {'registramos': []},
 'registrandos': {'registrandose': []},
 'registrar': ['registrare'],
 'registrargener': {'registrargeneral': []},
 'registrari': {'registrarial': [], 'registraries': [], 'registrary': []},
 'registrariu': {'registrarius': []},
 'registrars': {'registrarse': []},
 'registrarsgener': {'registrarsgeneral': []},
 'registrarship': {'registrarships': []},
 'registrat': {'registratic': []},
 'registrate': ['registrated', 'registrates'],
 'registrati': {'registratie': ['registraties']},
 'registratie': ['registraties'],
 'registratiekam': {'registratiekamer': []},
 'registration': ['registrational'],
 'registrationist': {'registrationists': []},
 'registrationrequir': {'registrationrequired': []},
 'registrator': {'registratore': []},
 'registratr': {'registratration': []},
 'registrazion': {'registrazione': []},
 'registrc': {'registrcs': []},
 'registre': {'registree': ['registrees']},
 'registree': ['registrees'],
 'registrer': {'registrere': ['registreres']},
 'registrera': {'registreras': []},
 'registrerad': {'registrerade': ['registrerades']},
 'registrerade': ['registrerades'],
 'registrerat': {'registrerats': []},
 'registrere': ['registreres'],
 'registrering': {'registreringer': []},
 'registrert': {'registrerte': []},
 'registret': {'registretion': []},
 'registri': {'registrie': ['registrier'], 'registris': [], 'registry': []},
 'registrie': ['registrier'],
 'registrierbar': {'registrierbare': []},
 'registrierend': {'registrierende': []},
 'registriert': {'registrierte': ['registrierter']},
 'registrierte': ['registrierter'],
 'registro': {'registros': []},
 'registrogram': {'registrograms': []},
 'registrt': {'registrtion': []},
 'registrybas': {'registrybased': []},
 'registryoffic': {'registryoffice': []},
 'registrypermiss': {'registrypermission': []},
 'registryservic': {'registryservice': []},
 'registt': {'registtation': []},
 'registti': {'registty': []},
 'regisu': {'regisuation': []},
 'regit': {'regite': [], 'regits': []},
 'regiti': {'regitis': []},
 'regitin': {'regitine': []},
 'regitn': {'regitne': []},
 'regitqu': {'regitque': []},
 'regitr': {'regitre': []},
 'regitt': {'regitter': ['regittered']},
 'regitter': ['regittered'],
 'regittr': {'regittration': []},
 'regitz': {'regitze': []},
 'regiu': {'regius': []},
 'regiumqu': {'regiumque': []},
 'regiun': {'regiune': [], 'regiuns': []},
 'regiunil': {'regiunile': []},
 'regiv': {'regive': ['regives'], 'regiving': []},
 'regive': ['regives'],
 'regjer': {'regjering': ['regjerings']},
 'regjering': ['regjerings'],
 'regjeringen': {'regjeringens': []},
 'regjm': {'regjme': []},
 'regjon': {'regjonal': ['regjonalization'], 'regjons': []},
 'regjonal': ['regjonalization'],
 'regl': {'regle': ['regles'], 'regling': [], 'regls': []},
 'regla': {'reglas': []},
 'reglabl': {'reglable': ['reglables']},
 'reglable': ['reglables'],
 'reglac': {'reglace': []},
 'reglaci': {'reglaciation': []},
 'reglad': {'reglade': []},
 'reglag': {'reglage': ['reglages']},
 'reglage': ['reglages'],
 'reglament': {'reglamentation': [], 'reglamente': [], 'reglaments': []},
 'reglamentacion': {'reglamentaciones': []},
 'reglamentada': {'reglamentadas': []},
 'reglamentado': {'reglamentados': []},
 'reglamentari': {'reglamentary': []},
 'reglamentaria': {'reglamentarias': []},
 'reglamentariament': {'reglamentariamente': []},
 'reglamentario': {'reglamentarios': []},
 'reglamento': {'reglamentos': []},
 'reglar': {'reglars': []},
 'reglarli': {'reglarly': []},
 'reglass': {'reglassed': []},
 'reglat': {'reglater': [], 'reglates': [], 'reglation': ['reglations']},
 'reglation': ['reglations'],
 'reglatori': {'reglatory': []},
 'reglaz': {'reglaze': ['reglazed'], 'reglazing': []},
 'reglaze': ['reglazed'],
 'regle': {'reglee': ['reglees']},
 'reglect': {'reglected': []},
 'reglee': ['reglees'],
 'reglemen': {'reglemens': []},
 'reglement': {'reglementant': [],
               'reglementation': ['reglementations'],
               'reglemente': ['reglemented',
                              'reglementes',
                              'reglementer',
                              'reglementent',
                              'reglementering'],
               'reglements': []},
 'reglementair': {'reglementaire': ['reglementaires']},
 'reglementaire': ['reglementaires'],
 'reglementari': {'reglementary': []},
 'reglementation': ['reglementations'],
 'reglemente': {'reglementee': ['reglementees']},
 'reglementee': ['reglementees'],
 'reglen': {'reglene': []},
 'regler': {'reglering': [], 'reglers': []},
 'reglera': {'regleras': []},
 'reglerad': {'reglerade': []},
 'reglet': {'reglets': []},
 'reglett': {'reglette': []},
 'reglig': {'regligence': []},
 'regligi': {'regligious': []},
 'reglindi': {'reglindis': []},
 'regliou': {'reglious': []},
 'reglis': {'reglise': []},
 'regliss': {'reglisse': []},
 'reglitter': {'reglitterized': []},
 'reglm': {'reglme': ['reglmes']},
 'reglme': ['reglmes'],
 'reglo': {'reglos': []},
 'reglob': {'reglobalization': []},
 'reglon': {'reglonal': [], 'reglone': ['reglones'], 'reglons': []},
 'reglone': ['reglones'],
 'reglorif': {'reglorification': []},
 'reglorifi': {'reglorified': []},
 'regloss': {'reglossed': []},
 'reglov': {'reglove': ['regloved'], 'regloving': []},
 'reglove': ['regloved'],
 'reglow': {'reglows': []},
 'reglster': {'reglstered': [], 'reglsters': []},
 'reglstrat': {'reglstration': []},
 'reglstri': {'reglstry': []},
 'reglu': {'reglue': ['reglues', 'reglued', 'reglueing'], 'regluing': []},
 'regluat': {'regluation': ['regluations']},
 'regluation': ['regluations'],
 'reglucosyl': {'reglucosylation': []},
 'reglue': ['reglues', 'reglued', 'reglueing'],
 'regm': {'regme': []},
 'regmaglypt': {'regmaglypts': []},
 'regmat': {'regmatic': []},
 'regment': {'regments': []},
 'regmin': {'regmine': []},
 'regmt': {'regmts': []},
 'regn': {'regnative': [],
          'regne': ['regnes', 'regned'],
          'regning': [],
          'regns': []},
 'regna': {'regnas': []},
 'regnab': {'regnabant': []},
 'regnabi': {'regnabis': []},
 'regnact': {'regnacted': []},
 'regnal': {'regnall': []},
 'regnaldu': {'regnaldus': []},
 'regnam': {'regname': []},
 'regnan': {'regnans': []},
 'regnanc': {'regnance': [], 'regnancies': [], 'regnancy': []},
 'regnant': {'regnante': ['regnantes'], 'regnants': []},
 'regnante': ['regnantes'],
 'regnanti': {'regnantis': []},
 'regnantibu': {'regnantibus': []},
 'regnaqu': {'regnaque': []},
 'regnar': {'regnare': ['regnarent'], 'regnars': []},
 'regnard': {'regnards': []},
 'regnare': ['regnarent'],
 'regnari': {'regnary': []},
 'regnass': {'regnasse': []},
 'regnat': {'regnate': [], 'regnator': []},
 'regnatric': {'regnatrice': []},
 'regnaturu': {'regnaturus': []},
 'regnaul': {'regnaull': []},
 'regnaulf': {'regnaulfs': []},
 'regnault': {'regnaults': []},
 'regncri': {'regncry': []},
 'regne': ['regnes', 'regned'],
 'regned': {'regnede': []},
 'regnegad': {'regnegade': []},
 'regnel': {'regnell': []},
 'regnem': {'regnemer': []},
 'regnemu': {'regnemus': []},
 'regnens': {'regnenses': []},
 'regner': {'regnerating': [],
            'regneration': [],
            'regnerative': [],
            'regnerent': [],
            'regners': []},
 'regneri': {'regnery': []},
 'regneru': {'regnerus': []},
 'regnesentr': {'regnesentral': []},
 'regnet': {'regnete': []},
 'regnevil': {'regneville': []},
 'regnforc': {'regnforce': ['regnforced', 'regnforcements']},
 'regnforce': ['regnforced', 'regnforcements'],
 'regni': {'regnie': [], 'regnis': [], 'regny': []},
 'regnicol': {'regnicole': ['regnicoles']},
 'regnicola': {'regnicolae': [], 'regnicolas': []},
 'regnicole': ['regnicoles'],
 'regnicoli': {'regnicolis': []},
 'regnier': {'regniere': [], 'regniers': []},
 'regnievil': {'regnieville': []},
 'regniqu': {'regnique': []},
 'regnisqu': {'regnisque': []},
 'regnlar': {'regnlarity': []},
 'regnlarli': {'regnlarly': []},
 'regnlat': {'regnlate': ['regnlated'],
             'regnlating': [],
             'regnlation': ['regnlations']},
 'regnlate': ['regnlated'],
 'regnlation': ['regnlations'],
 'regnlu': {'regnlus': []},
 'regnn': {'regnne': []},
 'regno': {'regnos': []},
 'regnold': {'regnolds': []},
 'regnomeri': {'regnomeris': []},
 'regnon': {'regnons': []},
 'regnoqu': {'regnoque': []},
 'regnorumqu': {'regnorumque': []},
 'regnosauru': {'regnosaurus': []},
 'regnrd': {'regnrded': [], 'regnrding': [], 'regnrds': []},
 'regnrgit': {'regnrgitation': []},
 'regnskab': {'regnskaber': []},
 'regnter': {'regntered': []},
 'regnu': {'regnus': []},
 'regnumqu': {'regnumque': []},
 'rego': {'regoes': [], 'regoing': [], 'regos': []},
 'regocig': {'regocige': []},
 'regocijado': {'regocijados': []},
 'regocijars': {'regocijarse': []},
 'regocijo': {'regocijos': []},
 'regog': {'regoge': []},
 'regogn': {'regognize': ['regognized']},
 'regognit': {'regognition': []},
 'regognize': ['regognized'],
 'regoi': {'regois': []},
 'regoin': {'regoinal': [], 'regoins': []},
 'regoiv': {'regoive': ['regoivent']},
 'regoive': ['regoivent'],
 'regol': {'regolate': [],
           'regolation': ['regolations'],
           'regole': ['regoles']},
 'regolabil': {'regolabile': []},
 'regolamentar': {'regolamentare': []},
 'regolamentazion': {'regolamentazione': []},
 'regolar': {'regolare': []},
 'regolaribu': {'regolaribus': []},
 'regolarizzazion': {'regolarizzazione': []},
 'regolarli': {'regolarly': []},
 'regolarment': {'regolarmente': []},
 'regolarn': {'regolarne': []},
 'regolatament': {'regolatamente': []},
 'regolation': ['regolations'],
 'regolator': {'regolatore': []},
 'regolatric': {'regolatrice': []},
 'regolazion': {'regolazione': []},
 'regole': ['regoles'],
 'regolet': {'regolets': []},
 'regoli': {'regoly': []},
 'regolith': {'regolithic': [], 'regoliths': []},
 'regon': {'regonal': [], 'regone': [], 'regonized': [], 'regons': []},
 'regonflon': {'regonflons': []},
 'regonit': {'regonition': []},
 'regophoni': {'regophony': []},
 'regor': {'regorous': ['regorously']},
 'regord': {'regorded': [], 'regording': [], 'regords': []},
 'regorg': {'regorge': ['regorges',
                        'regorger',
                        'regorged',
                        'regorgent',
                        'regorgeant',
                        'regorgement'],
            'regorging': []},
 'regorge': ['regorges',
             'regorger',
             'regorged',
             'regorgent',
             'regorgeant',
             'regorgement'],
 'regori': {'regory': []},
 'regorous': ['regorously'],
 'regort': {'regorted': [], 'regorts': []},
 'regosol': ['regosolic'],
 'regoti': {'regotiation': ['regotiations']},
 'regotiation': ['regotiations'],
 'regour': {'regours': []},
 'regourd': {'regourdou': []},
 'regovern': {'regovernment': []},
 'regown': {'regowned': [], 'regowning': []},
 'regoyo': {'regoyos': []},
 'regozijado': {'regozijados': []},
 'regozijo': {'regozijos': []},
 'regqueri': {'regquery': []},
 'regqueryvalu': {'regqueryvalue': []},
 'regr': {'regre': ['regred', 'regres'], 'regrs': []},
 'regra': {'regras': []},
 'regrab': {'regrabbed': [], 'regrabbing': []},
 'regrad': {'regradation': [],
            'regrade': ['regraded', 'regrades'],
            'regrading': ['regradings'],
            'regrads': []},
 'regrade': ['regraded', 'regrades'],
 'regrading': ['regradings'],
 'regradu': {'regraduate': ['regraduated'],
             'regraduating': [],
             'regraduation': []},
 'regraduate': ['regraduated'],
 'regraft': {'regrafted': [], 'regrafting': [], 'regrafts': []},
 'regrain': {'regrained': [], 'regraining': []},
 'regrait': {'regraited': [], 'regraiting': []},
 'regrammatic': {'regrammaticalization': []},
 'regrammaticis': {'regrammaticising': []},
 'regrant': {'regranted': [], 'regranting': [], 'regrants': []},
 'regranul': {'regranulate': ['regranulated'],
              'regranulating': [],
              'regranulation': []},
 'regranulate': ['regranulated'],
 'regraph': {'regraphed': [], 'regraphing': []},
 'regrasp': {'regrasped': [], 'regrasping': [], 'regrasps': []},
 'regrass': {'regrassed': [], 'regrassing': []},
 'regrat': {'regrate': ['regrated', 'regrates', 'regrater', 'regraters'],
            'regrating': ['regratings'],
            'regrator': ['regrators'],
            'regratting': []},
 'regrate': ['regrated', 'regrates', 'regrater', 'regraters'],
 'regrating': ['regratings'],
 'regrator': ['regrators'],
 'regratour': {'regratours': []},
 'regratress': {'regratresses': []},
 'regratt': {'regratter': []},
 'regratti': {'regrattier': ['regrattiers']},
 'regrattier': ['regrattiers'],
 'regravel': {'regraveled': [],
              'regraveling': [],
              'regravelled': [],
              'regravelling': []},
 'regraz': {'regraze': ['regrazed'], 'regrazing': []},
 'regraze': ['regrazed'],
 'regrcssor': {'regrcssors': []},
 'regrd': {'regrded': [], 'regrding': [], 'regrds': []},
 'regre': {'regree': []},
 'regreas': {'regreasable': [],
             'regrease': ['regreased'],
             'regreasing': [],
             'regreasion': []},
 'regrease': ['regreased'],
 'regred': {'regrede': []},
 'regredien': {'regrediens': []},
 'regredient': {'regredientes': []},
 'regredir': {'regredire': []},
 'regreen': {'regreened': [], 'regreening': []},
 'regrees': {'regreesion': []},
 'regreet': {'regreeted': [], 'regreeting': [], 'regreets': []},
 'regref': {'regrefs': []},
 'regreni': {'regreny': []},
 'regrert': {'regrerted': []},
 'regres': {'regrese': ['regreses'],
            'regresion': ['regresions'],
            'regresive': []},
 'regresa': {'regresas': []},
 'regresamo': {'regresamos': []},
 'regresar': {'regresare': []},
 'regresars': {'regresarse': []},
 'regrese': ['regreses'],
 'regresemo': {'regresemos': []},
 'regresion': {'regresiones': []},
 'regresiva': {'regresivas': []},
 'regreso': {'regresos': []},
 'regress': ['regresse',
             'regresser',
             'regressou',
             'regressed',
             'regression',
             'regressing',
             'regressive',
             'regressent',
             'regressives',
             'regressivity',
             'regressively',
             'regressiveness'],
 'regressand': {'regressands': []},
 'regressi': {'regressie': []},
 'regressif': {'regressifs': []},
 'regression': {'regressional': [], 'regressione': [], 'regressionism': []},
 'regressionanalysi': {'regressionanalysis': []},
 'regressionari': {'regressionary': []},
 'regressionbas': {'regressionbased': []},
 'regressioncoeffici': {'regressioncoefficients': []},
 'regressiondiscontinu': {'regressiondiscontinuity': []},
 'regressionequ': {'regressionequation': []},
 'regressionist': {'regressionists': []},
 'regressionlik': {'regressionlike': []},
 'regressionlin': {'regressionline': []},
 'regressionmodel': {'regressionmodels': []},
 'regressionsanalys': {'regressionsanalyse': []},
 'regressionsgerad': {'regressionsgerade': []},
 'regressionskoeffizi': {'regressionskoeffizient': []},
 'regressionsmodel': {'regressionsmodell': ['regressionsmodelle']},
 'regressionsmodell': ['regressionsmodelle'],
 'regressiontyp': {'regressiontype': []},
 'regressiv': {'regressiver': [], 'regressivism': []},
 'regressiveprogress': {'regressiveprogressive': []},
 'regressivetransgress': {'regressivetransgressive': []},
 'regressor': {'regressors': []},
 'regresss': {'regresssion': ['regresssions'], 'regresssive': []},
 'regresssion': ['regresssions'],
 'regressu': {'regressus': []},
 'regret': ['regrete',
            'regreter',
            'regreted',
            'regretful',
            'regretted',
            'regreting',
            'regretable',
            'regretably',
            'regretting',
            'regrettings',
            'regretfully',
            'regretfulness'],
 'regreton': {'regretons': []},
 'regretr': {'regretred': []},
 'regrett': {'regrettability': [],
             'regrettable': ['regrettables'],
             'regrettably': [],
             'regrettant': [],
             'regrette': ['regrettes',
                          'regretter',
                          'regretters',
                          'regrettent']},
 'regrettable': ['regrettables'],
 'regrettahl': {'regrettahle': []},
 'regrettahli': {'regrettahly': []},
 'regrettai': {'regrettaient': [], 'regrettais': []},
 'regrette': {'regrettee': []},
 'regrettedli': {'regrettedly': []},
 'regrettera': {'regretteras': []},
 'regretterai': {'regretterais': []},
 'regrettingli': {'regrettingly': []},
 'regretton': {'regrettons': []},
 'regrid': {'regridded': [], 'regridding': []},
 'regriev': {'regrieve': [], 'regrieving': []},
 'regriger': {'regrigeration': [], 'regrigerator': []},
 'regrind': {'regrindable': [],
             'regrinder': ['regrinders'],
             'regrinding': ['regrindings'],
             'regrinds': []},
 'regrinder': ['regrinders'],
 'regrinding': ['regrindings'],
 'regrip': {'regripped': [], 'regripping': [], 'regrips': []},
 'regristr': {'regristration': []},
 'regron': {'regronal': [], 'regrons': []},
 'regroom': {'regroomed': [], 'regrooming': []},
 'regroov': {'regroove': ['regrooved'], 'regrooving': []},
 'regroove': ['regrooved'],
 'reground': {'regrounded': [],
              'regrounding': ['regroundings'],
              'regrounds': []},
 'regrounding': ['regroundings'],
 'regroup': {'regroupant': [],
             'regroupe': ['regrouped',
                          'regrouper',
                          'regroupes',
                          'regroupent',
                          'regroupement',
                          'regroupements'],
             'regrouping': ['regroupings'],
             'regroupment': ['regroupments'],
             'regroups': []},
 'regroupai': {'regroupaient': []},
 'regroupe': {'regroupee': ['regroupees']},
 'regroupee': ['regroupees'],
 'regrouper': {'regrouperent': []},
 'regrouping': ['regroupings'],
 'regroupment': ['regroupments'],
 'regroupon': {'regroupons': []},
 'regrout': {'regrouted': [], 'regrouting': []},
 'regrow': {'regrowing': [], 'regrows': []},
 'regrowth': {'regrowths': []},
 'regrster': {'regrstered': []},
 'regrstri': {'regrstry': []},
 'regserv': {'regserver': []},
 'regsetkeysecur': {'regsetkeysecurity': []},
 'regsetvalu': {'regsetvalue': []},
 'regsit': {'regsiter': []},
 'regspleg': {'regspleging': []},
 'regsrd': {'regsrded': [], 'regsrding': [], 'regsrds': []},
 'regstablish': {'regstablishment': []},
 'regster': {'regstered': []},
 'regstrat': {'regstration': []},
 'regsvc': {'regsvcs': []},
 'regt': {'regte': [], 'regts': []},
 'regter': {'regters': []},
 'regtet': {'regtets': [], 'regtetted': []},
 'regth': {'regthe': []},
 'regtm': {'regtme': []},
 'regton': {'regtonal': [], 'regtons': []},
 'regtspleg': {'regtspleging': []},
 'regtster': {'regtstered': []},
 'regu': {'regue': ['regues'], 'regus': []},
 'reguair': {'reguaires': []},
 'regual': {'regualations': []},
 'regualarli': {'regualarly': []},
 'regualrli': {'regualrly': []},
 'regualt': {'regualte': ['regualted'],
             'regualting': [],
             'regualtion': ['regualtions']},
 'regualte': ['regualted'],
 'regualtion': ['regualtions'],
 'regualtori': {'regualtory': []},
 'reguar': {'reguarity': []},
 'reguarante': {'reguaranteed': []},
 'reguard': {'reguardant': [],
             'reguarde': ['reguarded'],
             'reguarding': [],
             'reguards': []},
 'reguarde': ['reguarded'],
 'reguarli': {'reguarly': []},
 'reguat': {'reguate': ['reguated'],
            'reguating': [],
            'reguation': ['reguations']},
 'reguate': ['reguated'],
 'reguation': ['reguations'],
 'reguatori': {'reguatory': []},
 'regue': ['regues'],
 'reguenc': {'reguency': []},
 'reguengo': {'reguengos': []},
 'reguer': {'regueral': []},
 'reguera': {'regueras': []},
 'regueri': {'reguery': []},
 'reguero': {'regueros': []},
 'reguest': {'reguested': [], 'reguesting': [], 'reguests': []},
 'reguge': {'regugees': []},
 'regugit': {'regugitation': []},
 'reguhi': {'reguhis': []},
 'regui': {'reguis': []},
 'reguiarli': {'reguiarly': []},
 'reguiat': {'reguiate': ['reguiated'],
             'reguiating': [],
             'reguiation': ['reguiations']},
 'reguiate': ['reguiated'],
 'reguiation': ['reguiations'],
 'reguiatori': {'reguiatory': []},
 'reguid': {'reguided': []},
 'reguir': {'reguire': ['reguires', 'reguired', 'reguirement', 'reguirements'],
            'reguiring': []},
 'reguire': ['reguires', 'reguired', 'reguirement', 'reguirements'],
 'reguirli': {'reguirly': []},
 'reguisit': {'reguisite': []},
 'reguit': {'reguitions': []},
 'reguiu': {'reguius': []},
 'reguj': {'regujate': []},
 'regujarli': {'regujarly': []},
 'reguk': {'reguke': []},
 'regul': {'regulability': [],
           'regulable': [],
           'regulal': ['regulaled', 'regulaling'],
           'regulant': ['regulants'],
           'regulate': ['regulates', 'regulated', 'regulateing'],
           'regulating': [],
           'regulation': ['regulational'],
           'regulative': ['regulatives', 'regulatively'],
           'regulator': [],
           'regule': ['reguler', 'regules', 'regulent', 'regulering'],
           'reguls': []},
 'regula': {'regulae': [], 'regulaing': [], 'regulament': [], 'regulas': []},
 'regulac': {'regulace': []},
 'regulacij': {'regulacije': []},
 'regulacion': {'regulaciones': []},
 'regulada': {'reguladas': []},
 'reguladi': {'regulady': []},
 'regulado': {'regulados': []},
 'reguladon': {'reguladons': []},
 'regulador': {'reguladores': []},
 'reguladora': {'reguladoras': []},
 'regulaer': {'regulaere': []},
 'regulafion': {'regulafions': []},
 'regulai': {'regulaie': ['regulaied'], 'regulaiity': []},
 'regulaie': ['regulaied'],
 'regulaiion': {'regulaiions': []},
 'regulaili': {'regulaily': []},
 'regulaion': {'regulaions': []},
 'regulaiori': {'regulaiory': []},
 'regulaiton': {'regulaitons': []},
 'regulal': {'regulalation': ['regulalations'], 'regulale': []},
 'regulalation': ['regulalations'],
 'regulali': {'regulaly': []},
 'regulalion': {'regulalions': []},
 'regulalori': {'regulalory': []},
 'regulamentar': {'regulamentares': []},
 'regulamento': {'regulamentos': []},
 'regulan': {'regulans': []},
 'regulanon': {'regulanons': []},
 'regulant': {'regulante': []},
 'regulanti': {'regulanty': []},
 'regulanz': {'regulanzation': []},
 'regulaon': {'regulaons': []},
 'regular': ['regulare',
             'regularer',
             'regulares',
             'regulared',
             'regularize',
             'regularing',
             'regularity',
             'regularism',
             'regularely',
             'regularizes',
             'regularizer',
             'regularized',
             'regularness',
             'regularizing',
             'regularizers',
             'regularization'],
 'regulararmi': {'regulararmy': []},
 'regularbasi': {'regularbasis': []},
 'regularbr': {'regularbred': []},
 'regulareduc': {'regulareducation': []},
 'regularfeatur': {'regularfeatured': []},
 'regulargrad': {'regulargrade': []},
 'regulari': {'regularies': [], 'regularis': [], 'regulary': []},
 'regularibu': {'regularibus': []},
 'regularidad': {'regularidade': ['regularidades']},
 'regularidade': ['regularidades'],
 'regularili': {'regularily': []},
 'regularinterv': {'regularinterval': ['regularintervals']},
 'regularinterval': ['regularintervals'],
 'regularion': {'regularions': []},
 'regularis': {'regularisant': [],
               'regularisation': [],
               'regularise': ['regularises', 'regulariser', 'regularised'],
               'regularising': []},
 'regularise': {'regularisee': ['regularisees']},
 'regularisee': ['regularisees'],
 'regularist': {'regularistic': [], 'regularists': []},
 'regularit': {'regularite': ['regularites', 'regulariter']},
 'regularita': {'regularitas': []},
 'regularite': ['regularites', 'regulariter'],
 'regulariti': {'regularitie': []},
 'regulariz': {'regularizable': []},
 'regularkanonik': {'regularkanoniker': []},
 'regularl': {'regularlity': []},
 'regularli': {'regularly': []},
 'regularlook': {'regularlooking': []},
 'regularlyappoint': {'regularlyappointed': []},
 'regularlyarrang': {'regularlyarranged': []},
 'regularlyconstitut': {'regularlyconstituted': []},
 'regularlyemploy': {'regularlyemployed': []},
 'regularlyform': {'regularlyformed': []},
 'regularlyorgan': {'regularlyorganized': []},
 'regularlyrecur': {'regularlyrecurring': []},
 'regularlyschedul': {'regularlyscheduled': []},
 'regularlyshap': {'regularlyshaped': []},
 'regularlyspac': {'regularlyspaced': []},
 'regularlytrain': {'regularlytrained': []},
 'regularlz': {'regularlzation': []},
 'regularment': {'regularmente': []},
 'regularn': {'regularne': []},
 'regularni': {'regularnie': []},
 'regularori': {'regularory': []},
 'regularpr': {'regularpriced': []},
 'regularri': {'regularry': []},
 'regularrout': {'regularroute': []},
 'regulars': {'regularse': [], 'regularsize': ['regularsized']},
 'regularshap': {'regularshaped': []},
 'regularsize': ['regularsized'],
 'regularti': {'regularty': []},
 'regulartim': {'regulartime': []},
 'regulartori': {'regulartory': []},
 'regulartyp': {'regulartype': []},
 'regulasi': {'regulasies': []},
 'regulasqu': {'regulasque': []},
 'regulat': {'regulatability': [],
             'regulatable': [],
             'regulater': ['regulaters'],
             'regulatic': [],
             'regulatities': [],
             'regulatity': [],
             'regulats': []},
 'regulatari': {'regulatary': []},
 'regulate': {'regulatee': ['regulatees']},
 'regulated': {'regulatedness': []},
 'regulatedbi': {'regulatedby': []},
 'regulatee': ['regulatees'],
 'regulater': ['regulaters'],
 'regulatesth': {'regulatesthe': []},
 'regulateth': {'regulatethe': []},
 'regulateur': {'regulateurs': []},
 'regulath': {'regulathe': []},
 'regulati': {'regulatie': [], 'regulatiou': ['regulatious'], 'regulatis': []},
 'regulaticn': {'regulaticns': []},
 'regulatin': {'regulatins': []},
 'regulatingth': {'regulatingthe': []},
 'regulatio': {'regulatios': []},
 'regulatioa': {'regulatioas': []},
 'regulation': {'regulatione': [], 'regulationism': []},
 'regulationari': {'regulationary': []},
 'regulationinduc': {'regulationinduced': []},
 'regulationist': {'regulationists': []},
 'regulationmak': {'regulationmaking': []},
 'regulations': {'regulationsize': ['regulationsized']},
 'regulationsize': ['regulationsized'],
 'regulationsmechanismu': {'regulationsmechanismus': []},
 'regulatior': {'regulatiors': []},
 'regulatiou': ['regulatious'],
 'regulatipn': {'regulatipns': []},
 'regulativ': {'regulativer': []},
 'regulative': ['regulatives', 'regulatively'],
 'regulatli': {'regulatly': []},
 'regulatlon': {'regulatlons': []},
 'regulaton': {'regulatons': []},
 'regulatori': {'regulatories': [], 'regulatory': []},
 'regulatoria': {'regulatorias': []},
 'regulatorili': {'regulatorily': []},
 'regulatorisch': {'regulatorische': []},
 'regulatormoder': {'regulatormoderator': []},
 'regulatoryag': {'regulatoryagencies': [], 'regulatoryagency': []},
 'regulatorybodi': {'regulatorybodies': []},
 'regulatoti': {'regulatoty': []},
 'regulatri': {'regulatry': []},
 'regulatric': {'regulatrice': ['regulatrices']},
 'regulatrice': ['regulatrices'],
 'regulatton': {'regulattons': []},
 'regulatu': {'regulatus': []},
 'regulauon': {'regulauons': []},
 'regulc': {'regulce': []},
 'regule': {'regulee': ['regulees']},
 'regulee': ['regulees'],
 'reguler': {'regulere': ['regulerer', 'reguleres']},
 'regulere': ['regulerer', 'reguleres'],
 'regulerend': {'regulerende': []},
 'regulerli': {'regulerly': []},
 'regulet': {'regulete': ['reguleted'], 'reguletion': ['reguletions']},
 'regulete': ['reguleted'],
 'reguletion': ['reguletions'],
 'reguletori': {'reguletory': []},
 'reguli': {'regulier': ['reguliers'], 'regulis': [], 'reguly': []},
 'regulida': {'regulidae': []},
 'regulier': {'reguliere': ['regulieres', 'regulierement']},
 'reguliere': ['regulieres', 'regulierement'],
 'regulierend': {'regulierende': ['regulierender']},
 'regulierende': ['regulierender'],
 'reguliert': {'regulierte': ['regulierter']},
 'regulierte': ['regulierter'],
 'regulierung': {'regulierungs': []},
 'regulierungsbehord': {'regulierungsbehorde': []},
 'regulin': {'reguline': []},
 'regulina': {'regulinae': []},
 'reguliqu': {'regulique': []},
 'regulir': {'regulire': []},
 'regulirovani': {'regulirovanie': []},
 'regulirovaniy': {'regulirovaniye': []},
 'regulisanj': {'regulisanje': []},
 'reguln': {'regulns': []},
 'regulnrli': {'regulnrly': []},
 'regulnt': {'regulnte': [], 'regulntions': []},
 'regulo': {'regulos': []},
 'reguloid': {'reguloides': []},
 'regulon': {'regulons': []},
 'regulorli': {'regulorly': []},
 'regulot': {'regulotion': ['regulotions']},
 'regulotion': ['regulotions'],
 'reguls': {'regulse': []},
 'regulst': {'regulstion': ['regulstions']},
 'regulstion': ['regulstions'],
 'regult': {'regulte': ['regulted'],
            'regultion': ['regultions'],
            'regults': []},
 'regulte': ['regulted'],
 'regultion': ['regultions'],
 'regultori': {'regultory': []},
 'regulu': {'regulus': []},
 'regulurli': {'regulurly': []},
 'regulus': {'regulus': []},
 'regulut': {'regulute': ['reguluted']},
 'regulute': ['reguluted'],
 'regum': {'regumate': [], 'regummed': [], 'regumming': []},
 'regumqu': {'regumque': []},
 'regun': {'regune': [], 'regunned': [], 'reguns': []},
 'regundi': {'regundis': []},
 'regundisqu': {'regundisque': []},
 'regungslo': {'regungslos': []},
 'regupathi': {'regupathy': []},
 'regur': ['regural', 'reguration'],
 'regurarli': {'regurarly': []},
 'regurd': {'regurded': [], 'regurding': [], 'regurds': []},
 'regurgi': {'regurgiation': []},
 'regurgit': {'regurgitant': ['regurgitants'],
              'regurgitate': ['regurgitates', 'regurgitated'],
              'regurgitating': [],
              'regurgitation': [],
              'regurgitative': [],
              'regurgitator': ['regurgitators'],
              'regurgitive': []},
 'regurgitant': ['regurgitants'],
 'regurgitate': ['regurgitates', 'regurgitated'],
 'regurgitator': ['regurgitators'],
 'regurgitori': {'regurgitory': []},
 'regurit': {'reguritation': []},
 'regurlarli': {'regurlarly': []},
 'reguss': {'regusse': []},
 'regust': {'regusted': [], 'regusters': []},
 'regut': {'regutate': ['regutated'],
           'regutation': ['regutations'],
           'reguter': [],
           'regution': ['regutions']},
 'regutarli': {'regutarly': []},
 'regutarti': {'regutarty': []},
 'regutate': ['regutated'],
 'regutation': ['regutations'],
 'regutatori': {'regutatory': []},
 'reguth': {'reguthe': []},
 'regution': ['regutions'],
 'regved': {'regvedic': []},
 'regverdig': {'regverdige': []},
 'regvlu': {'regvlus': []},
 'regwrit': {'regwrite': []},
 'regyard': {'regyards': []},
 'regyn': {'regyne': []},
 'regyon': {'regyons': []},
 'regypt': {'regypte': []},
 'reh': {'rehs': []},
 'reha': {'rehas': []},
 'rehab': {'rehabbed': [],
           'rehabbing': [],
           'rehabed': [],
           'rehabing': [],
           'rehabs': []},
 'rehabb': {'rehabber': ['rehabbers']},
 'rehabber': ['rehabbers'],
 'rehabcar': {'rehabcare': []},
 'rehaber': {'rehabere': []},
 'rehabiht': {'rehabihtation': []},
 'rehabihti': {'rehabihty': []},
 'rehabiiit': {'rehabiiitation': []},
 'rehabiit': {'rehabiitation': []},
 'rehabil': {'rehabilate': ['rehabilated'],
             'rehabilation': [],
             'rehabilative': []},
 'rehabilat': {'rehabilatation': [], 'rehabilatative': []},
 'rehabilate': ['rehabilated'],
 'rehabilatori': {'rehabilatory': []},
 'rehabili': {'rehabiliate': ['rehabiliated'],
              'rehabiliation': [],
              'rehabiliment': []},
 'rehabiliat': {'rehabiliatation': []},
 'rehabiliate': ['rehabiliated'],
 'rehabilir': {'rehabiliration': []},
 'rehabilit': {'rehabilitable': [],
               'rehabilitant': ['rehabilitants'],
               'rehabilitate': ['rehabilitates', 'rehabilitated'],
               'rehabilitating': [],
               'rehabilitation': ['rehabilitational'],
               'rehabilitative': ['rehabilitatively'],
               'rehabilitator': ['rehabilitators'],
               'rehabilite': ['rehabilites',
                              'rehabilited',
                              'rehabiliter',
                              'rehabilitering'],
               'rehabiliting': [],
               'rehabilition': [],
               'rehabilitive': []},
 'rehabilitant': ['rehabilitants'],
 'rehabilitat': {'rehabilitatable': []},
 'rehabilitate': ['rehabilitates', 'rehabilitated'],
 'rehabilitation': {'rehabilitationism': []},
 'rehabilitationist': {'rehabilitationists': []},
 'rehabilitationori': {'rehabilitationoriented': []},
 'rehabilitative': ['rehabilitatively'],
 'rehabilitator': ['rehabilitators'],
 'rehabilitatori': {'rehabilitatory': []},
 'rehabilite': {'rehabilitee': ['rehabilitees']},
 'rehabilitee': ['rehabilitees'],
 'rehabiliti': {'rehabilitiation': []},
 'rehabilitori': {'rehabilitory': []},
 'rehabilm': {'rehabilmed': []},
 'rehabilt': {'rehabiltation': []},
 'rehabit': {'rehabitable': [],
             'rehabitate': ['rehabitated'],
             'rehabitating': [],
             'rehabitation': [],
             'rehabited': [],
             'rehabites': []},
 'rehabitate': ['rehabitated'],
 'rehabitit': {'rehabititation': []},
 'rehabitu': {'rehabituate': ['rehabituated'],
              'rehabituating': [],
              'rehabituation': []},
 'rehabituate': ['rehabituated'],
 'rehabl': {'rehability': [], 'rehable': []},
 'rehablit': {'rehablitation': []},
 'rehac': {'rehace': ['rehacer']},
 'rehace': ['rehacer'],
 'rehaft': {'rehafted': [], 'rehafting': []},
 'rehag': {'rehage': []},
 'rehahilit': {'rehahilitate': ['rehahilitated'],
               'rehahilitating': [],
               'rehahilitation': [],
               'rehahilitative': []},
 'rehahilitate': ['rehahilitated'],
 'rehair': {'rehaired': [], 'rehairing': []},
 'rehal': {'rehale': []},
 'rehallow': {'rehallowed': [], 'rehallowing': []},
 'rehalogen': {'rehalogenating': [],
               'rehalogenation': [],
               'rehalogenized': [],
               'rehalogenizing': []},
 'reham': {'rehame': []},
 'rehamm': {'rehammered': [], 'rehammering': []},
 'rehanc': {'rehance': []},
 'rehandcuf': {'rehandcuffed': []},
 'rehandl': {'rehandle': ['rehandler', 'rehandled', 'rehandles', 'rehandlers'],
             'rehandling': ['rehandlings']},
 'rehandle': ['rehandler', 'rehandled', 'rehandles', 'rehandlers'],
 'rehandling': ['rehandlings'],
 'rehang': {'rehanged': [], 'rehanging': [], 'rehangs': []},
 'rehani': {'rehany': []},
 'rehar': {'reharness': ['reharnessed', 'reharnessing']},
 'reharakht': {'reharakhte': []},
 'reharden': {'rehardened': [], 'rehardening': [], 'rehardens': []},
 'rehark': {'reharks': []},
 'reharmon': {'reharmonization': [],
              'reharmonize': ['reharmonized', 'reharmonizes'],
              'reharmonizing': []},
 'reharmonis': {'reharmonisation': [], 'reharmonise': ['reharmonised']},
 'reharmonise': ['reharmonised'],
 'reharmonize': ['reharmonized', 'reharmonizes'],
 'reharness': ['reharnessed', 'reharnessing'],
 'reharrow': {'reharrowed': []},
 'rehars': {'reharsal': []},
 'reharvest': {'reharvested': [], 'reharvesting': []},
 'rehash': ['rehasher', 'rehashed', 'rehashing', 'rehashers', 'rehashings'],
 'rehat': {'rehate': ['rehates'], 'rehator': []},
 'rehatch': {'rehatched': []},
 'rehate': ['rehates'],
 'rehaul': {'rehauled': [], 'rehauling': []},
 'rehaum': {'rehaume': []},
 'rehauss': {'rehaussant': [],
             'rehausse': ['rehausser',
                          'rehausses',
                          'rehaussent',
                          'rehaussement']},
 'rehausse': {'rehaussee': ['rehaussees']},
 'rehaussee': ['rehaussees'],
 'rehaut': {'rehauts': []},
 'rehav': {'rehave': [], 'rehaving': []},
 'rehavior': {'rehavioral': []},
 'rehberg': {'rehberge': ['rehberger'], 'rehbergs': []},
 'rehberge': ['rehberger'],
 'rehbind': {'rehbinder': []},
 'rehbriick': {'rehbriicke': []},
 'rehbruck': {'rehbrucke': []},
 'rehc': {'rehcs': []},
 'rehd': {'rehding': []},
 'rehder': {'rehdered': [], 'rehders': []},
 'rehdig': {'rehdiger': []},
 'rehdigeranu': {'rehdigeranus': []},
 'rehe': {'rehed': [], 'rehes': [], 'rehing': []},
 'rehead': {'reheaded': [], 'reheading': []},
 'reheal': {'rehealed': [], 'rehealing': []},
 'reheap': {'reheaped': [], 'reheaping': []},
 'rehear': {'reheared': [], 'rehearing': [], 'rehears': []},
 'rehearc': {'rehearce': []},
 'rehearf': {'rehearfal': [], 'rehearfe': ['rehearfed'], 'rehearfing': []},
 'rehearfe': ['rehearfed'],
 'rehears': {'rehearsable': [],
             'rehearsal': [],
             'rehearse': ['rehearses', 'rehearser', 'rehearsed', 'rehearsers'],
             'rehearsing': ['rehearsings']},
 'rehearsal': {'rehearsall': []},
 'rehearse': ['rehearses', 'rehearser', 'rehearsed', 'rehearsers'],
 'rehearsel': {'rehearsels': []},
 'rehearsing': ['rehearsings'],
 'rehearten': {'reheartened': []},
 'reheas': {'reheasal': ['reheasals'], 'rehease': []},
 'reheasal': ['reheasals'],
 'reheat': {'reheatable': [],
            'reheated': [],
            'reheater': ['reheaters'],
            'reheating': ['reheatings'],
            'reheats': []},
 'reheater': ['reheaters'],
 'reheating': ['reheatings'],
 'rehect': {'rehected': [], 'rehecting': [], 'rehection': [], 'rehects': []},
 'rehedg': {'rehedge': ['rehedged'], 'rehedging': []},
 'rehedge': ['rehedged'],
 'reheel': {'reheeled': [], 'reheeling': []},
 'rehef': {'rehefs': []},
 'rehei': {'reheis': []},
 'reheis': {'reheiser': []},
 'rehel': {'rehell': ['rehelled', 'rehelling'], 'rehels': []},
 'rehell': ['rehelled', 'rehelling'],
 'rehelli': {'rehellious': ['rehelliousness']},
 'rehellion': {'rehellions': []},
 'rehellious': ['rehelliousness'],
 'rehelm': {'rehelmed': []},
 'rehem': {'rehemmed': [], 'rehemming': []},
 'rehemorrhag': {'rehemorrhage': []},
 'rehen': {'rehenes': [], 'rehens': []},
 'rehend': {'rehended': [], 'rehending': []},
 'rehenri': {'rehenry': []},
 'rehens': {'rehensible': [], 'rehension': ['rehensions'], 'rehensive': []},
 'rehension': ['rehensions'],
 'reheparin': {'reheparinization': []},
 'reher': {'rehere': [], 'rehers': []},
 'reherc': {'reherce': ['reherced']},
 'reherce': ['reherced'],
 'reherni': {'reherniation': []},
 'rehers': {'rehersal': ['rehersals'],
            'reherse': ['rehersed'],
            'rehersing': []},
 'rehersal': {'rehersall': []},
 'reherse': ['rehersed'],
 'rehersyng': {'rehersynges': []},
 'rehetor': {'rehetoric': ['rehetorical']},
 'rehetoric': ['rehetorical'],
 'reheumat': {'reheumatism': []},
 'rehev': {'reheve': ['reheved'], 'reheving': []},
 'reheve': ['reheved'],
 'rehew': {'rehewed': []},
 'rehfou': {'rehfous': []},
 'rehfu': {'rehfues': [], 'rehfus': []},
 'rehgieus': {'rehgieuse': []},
 'rehgion': {'rehgions': []},
 'rehgionist': {'rehgionists': []},
 'rehgiou': {'rehgious': []},
 'rehgious': {'rehgiously': []},
 'rehi': {'rehis': [], 'rehy': []},
 'rehibilit': {'rehibilitation': []},
 'rehicl': {'rehicle': ['rehicles']},
 'rehicle': ['rehicles'],
 'rehid': {'rehide': [], 'rehiding': []},
 'rehierarch': {'rehierarchization': []},
 'rehil': {'rehill': []},
 'rehimen': {'rehimene': []},
 'rehin': {'rehine': []},
 'rehing': {'rehinge': ['rehinged'], 'rehinging': []},
 'rehinge': ['rehinged'],
 'rehir': {'rehire': ['rehires', 'rehired'], 'rehiring': ['rehirings']},
 'rehire': ['rehires', 'rehired'],
 'rehiring': ['rehirings'],
 'rehirn': {'rehirned': [], 'rehirning': []},
 'rehistor': {'rehistoric': [], 'rehistorization': []},
 'rehistori': {'rehistory': []},
 'rehistoric': {'rehistoricization': [],
                'rehistoricize': ['rehistoricizes', 'rehistoricized'],
                'rehistoricizing': []},
 'rehistoricis': {'rehistoricise': ['rehistoricised']},
 'rehistoricise': ['rehistoricised'],
 'rehistoricize': ['rehistoricizes', 'rehistoricized'],
 'rehitch': {'rehitched': [], 'rehitching': []},
 'rehiv': {'rehives': []},
 'rehkamp': {'rehkamper': []},
 'rehkemp': {'rehkemper': []},
 'rehkugl': {'rehkugler': []},
 'rehl': {'rehle': [], 'rehling': []},
 'rehlaend': {'rehlaender': []},
 'rehland': {'rehlander': []},
 'rehling': {'rehlinger': []},
 'rehm': {'rehme': [], 'rehms': []},
 'rehmannia': {'rehmanniae': []},
 'rehmey': {'rehmeyer': []},
 'rehmk': {'rehmke': []},
 'rehmu': {'rehmus': []},
 'rehn': {'rehne': ['rehned'], 'rehning': [], 'rehns': []},
 'rehne': ['rehned'],
 'rehnk': {'rehnke': []},
 'rehnmeidn': {'rehnmeidner': []},
 'rehnquish': {'rehnquishing': []},
 'rehnquisit': {'rehnquisition': []},
 'rehnquist': {'rehnquist': []},
 'reho': {'rehos': []},
 'rehoboam': {'rehoboams': []},
 'rehoboth': {'rehobother': ['rehobothers'], 'rehoboths': []},
 'rehobother': ['rehobothers'],
 'rehoist': {'rehoisted': [], 'rehoisting': []},
 'rehold': {'reholder': ['reholders'], 'reholding': []},
 'reholder': ['reholders'],
 'reholog': {'rehological': []},
 'reholst': {'reholster': ['reholsters', 'reholstered', 'reholstering']},
 'reholster': ['reholsters', 'reholstered', 'reholstering'],
 'rehom': {'rehome': ['rehomed'], 'rehoming': []},
 'rehome': ['rehomed'],
 'rehomogen': {'rehomogenization': [],
               'rehomogenize': ['rehomogenized'],
               'rehomogenizing': []},
 'rehomogenize': ['rehomogenized'],
 'rehon': {'rehone': ['rehoned'], 'rehoning': []},
 'rehone': ['rehoned'],
 'rehood': {'rehooded': []},
 'rehook': {'rehooked': [], 'rehooking': []},
 'rehoop': {'rehooped': []},
 'rehorakhti': {'rehorakhty': []},
 'rehors': {'rehorse': ['rehorsed']},
 'rehorse': ['rehorsed'],
 'rehospit': {'rehospital': ['rehospitalize',
                             'rehospitalized',
                             'rehospitalizing',
                             'rehospitalization',
                             'rehospitalizations']},
 'rehospital': ['rehospitalize',
                'rehospitalized',
                'rehospitalizing',
                'rehospitalization',
                'rehospitalizations'],
 'rehospitalis': {'rehospitalisation': [], 'rehospitalised': []},
 'rehost': {'rehosted': [], 'rehosting': []},
 'rehound': {'rehounded': [], 'rehounds': []},
 'rehour': {'rehours': []},
 'rehous': {'rehouse': ['rehouses', 'rehoused'], 'rehousing': []},
 'rehouse': ['rehouses', 'rehoused'],
 'rehowev': {'rehowever': []},
 'rehpen': {'rehpenning': []},
 'rehqu': {'rehques': []},
 'rehr': {'rehring': []},
 'rehra': {'rehras': []},
 'rehri': {'rehris': []},
 'rehriwala': {'rehriwalas': []},
 'rehs': {'rehse': []},
 'rehsei': {'rehseis': []},
 'rehspring': {'rehspringer': []},
 'rehstein': {'rehsteiner': []},
 'reht': {'rehte': ['rehtes', 'rehted'], 'rehting': []},
 'rehtctanc': {'rehtctance': []},
 'rehte': ['rehtes', 'rehted'],
 'rehtion': {'rehtions': []},
 'rehtiv': {'rehtive': []},
 'rehtmey': {'rehtmeyer': []},
 'rehtor': {'rehtoric': ['rehtorical']},
 'rehtoric': ['rehtorical'],
 'rehu': {'rehue': [], 'rehus': []},
 'rehuf': {'rehuffed': []},
 'rehuh': {'rehuher': []},
 'rehuild': {'rehuilding': []},
 'rehuk': {'rehuke': ['rehukes', 'rehuked'], 'rehuking': []},
 'rehuke': ['rehukes', 'rehuked'],
 'rehuman': {'rehumanization': [],
             'rehumanize': ['rehumanizes', 'rehumanized'],
             'rehumanizing': []},
 'rehumanis': {'rehumanisation': [],
               'rehumanise': ['rehumanised'],
               'rehumanising': []},
 'rehumanise': ['rehumanised'],
 'rehumanize': ['rehumanizes', 'rehumanized'],
 'rehumat': {'rehumatic': [], 'rehumatism': []},
 'rehumidif': {'rehumidification': []},
 'rehumidifi': {'rehumidified': [], 'rehumidify': ['rehumidifying']},
 'rehumidify': ['rehumidifying'],
 'rehus': {'rehuse': []},
 'rehusai': {'rehusais': []},
 'rehusar': {'rehusare': []},
 'rehusars': {'rehusarse': []},
 'rehut': {'rehutted': []},
 'rehutt': {'rehuttal': []},
 'rehuy': {'rehuye': []},
 'rehvdrat': {'rehvdration': []},
 'rehwinkl': {'rehwinkle': []},
 'rehybrid': {'rehybridization': ['rehybridizations'],
              'rehybridize': ['rehybridized', 'rehybridizes'],
              'rehybridizing': []},
 'rehybridis': {'rehybridisation': []},
 'rehybridization': ['rehybridizations'],
 'rehybridize': ['rehybridized', 'rehybridizes'],
 'rehydr': {'rehydrate': ['rehydrated', 'rehydrates'],
            'rehydrating': [],
            'rehydration': ['rehydrations'],
            'rehydrator': []},
 'rehydralyt': {'rehydralyte': []},
 'rehydrat': {'rehydratability': [], 'rehydratable': [], 'rehydratation': []},
 'rehydrate': ['rehydrated', 'rehydrates'],
 'rehydration': ['rehydrations'],
 'rehydrogen': {'rehydrogenate': ['rehydrogenated'], 'rehydrogenation': []},
 'rehydrogenate': ['rehydrogenated'],
 'rehydrolysi': {'rehydrolysis': []},
 'rehydrolyz': {'rehydrolyzed': []},
 'rehyphen': {'rehyphenate': []},
 'rehypnosi': {'rehypnosis': []},
 'rehypnot': {'rehypnotization': [],
              'rehypnotize': ['rehypnotized'],
              'rehypnotizing': []},
 'rehypnotis': {'rehypnotisation': [], 'rehypnotised': []},
 'rehypnotize': ['rehypnotized'],
 'rehypothec': {'rehypothecate': ['rehypothecates', 'rehypothecated'],
                'rehypothecating': [],
                'rehypothecation': []},
 'rehypothecate': ['rehypothecates', 'rehypothecated'],
 'rei': {'real': [], 'reied': [], 'reies': []},
 "rei'n": {"rei'ne": []},
 "rei'u": {"rei'ue": []},
 'reia': {'reias': []},
 'reiabl': {'reiable': []},
 'reiac': {'reiace': []},
 'reiain': {'reiained': [], 'reiaining': [], 'reiains': []},
 'reiak': {'reiake': []},
 'reial': {'reials': []},
 'reiat': {'reiate': ['reiated', 'reiates'], 'reiating': [], 'reiats': []},
 'reiate': ['reiated', 'reiates'],
 'reiated': {'reiatedness': []},
 'reiation': {'reiations': []},
 'reiationship': {'reiationships': []},
 'reiativ': {'reiative': ['reiatives', 'reiatively']},
 'reiative': ['reiatives', 'reiatively'],
 'reiativist': {'reiativistic': []},
 'reiaum': {'reiaume': []},
 'reib': {'reibe': []},
 'reibel': {'reibeling': [], 'reibell': []},
 'reibenspi': {'reibenspies': []},
 'reibey': {'reibeys': []},
 'reibi': {'reiby': []},
 'reibl': {'reible': [], 'reibling': []},
 'reiblut': {'reiblution': []},
 'reiblv': {'reiblved': []},
 'reibmay': {'reibmayer': []},
 'reibnegg': {'reibnegger': []},
 'reibr': {'reibring': []},
 'reibsam': {'reibsame': []},
 'reibung': {'reibungs': []},
 'reibungskoeffizi': {'reibungskoeffizient': []},
 'reibungskraft': {'reibungskrafte': []},
 'reibungslo': {'reibungslos': []},
 'reibungslos': {'reibungslose': ['reibungsloser']},
 'reibungslose': ['reibungsloser'],
 'reibungsverlust': {'reibungsverluste': []},
 'reic': {'reice': ['reiced'], 'reicing': [], 'reics': []},
 'reicb': {'reicbe': ['reicbes'], 'reicbs': []},
 'reicbe': ['reicbes'],
 'reicc': {'reiccs': []},
 'reice': ['reiced'],
 'reicer': {'reicere': []},
 'reicev': {'reiceved': []},
 'reich': ['reiche', 'reiched', 'reicheli'],
 "reich'": {"reich's": []},
 'reichard': {'reichards': []},
 'reichardt': {'reichardts': []},
 'reichart': {'reicharts': []},
 'reichbann': {'reichbanner': []},
 'reichc': {'reichcs': []},
 'reichchancelleri': {'reichchancellery': []},
 'reichdeutsch': {'reichdeutsche': []},
 'reichel': {'reichell': [], 'reichels': []},
 'reichelderf': {'reichelderfer': []},
 'reichenal': {'reichenall': []},
 'reichenau': {'reichenauer': []},
 'reichenbach': {'reichenbacher': [], 'reichenbachs': []},
 'reichenbachklink': {'reichenbachklinke': []},
 'reichenbachstrass': {'reichenbachstrasse': []},
 'reichenberg': {'reichenberger': []},
 'reichend': {'reichende': ['reichender']},
 'reichende': ['reichender'],
 'reicheneck': {'reichenecker': []},
 'reichened': {'reicheneder': []},
 'reichenek': {'reicheneker': []},
 'reichenfel': {'reichenfels': []},
 'reichenhain': {'reichenhainer': []},
 'reichenhal': {'reichenhall': ['reichenhaller']},
 'reichenhall': ['reichenhaller'],
 'reichenmil': {'reichenmiller': []},
 'reichensberg': {'reichensberger': []},
 'reichense': {'reichensee': []},
 'reichensperg': {'reichensperger': ['reichenspergers']},
 'reichensperger': ['reichenspergers'],
 'reichenspurn': {'reichenspurner': []},
 'reichenstein': {'reichensteiner': []},
 'reichenstrass': {'reichenstrasse': []},
 'reichent': {'reichental': []},
 'reichenth': {'reichenthal': []},
 'reichenwei': {'reichenweier': []},
 'reicher': {'reichere': ['reicherer', 'reicheres'], 'reichers': []},
 'reichere': ['reicherer', 'reicheres'],
 'reicherf': {'reicherfs': []},
 'reicherspergens': {'reicherspergenses': []},
 'reicherspergensi': {'reicherspergensis': []},
 'reicherstorff': {'reicherstorffer': []},
 'reichert': {'reicherter': [], 'reicherts': []},
 'reichertsch': {'reichertsche': []},
 'reichertwollni': {'reichertwollny': []},
 'reichfiihr': {'reichfiihrer': []},
 'reichfuehr': {'reichfuehrer': []},
 'reichfuhr': {'reichfuhrer': []},
 'reichgericht': {'reichgerichts': []},
 'reichhaltig': {'reichhaltige': ['reichhaltiger', 'reichhaltiges']},
 'reichhaltige': ['reichhaltiger', 'reichhaltiges'],
 'reichhaltiger': {'reichhaltigere': []},
 'reichhaltigst': {'reichhaltigste': []},
 'reichherz': {'reichherzer': []},
 'reichi': {'reichie': []},
 'reichian': {'reichianism': [], 'reichians': []},
 'reichisch': {'reichische': ['reichisches']},
 'reichische': ['reichisches'],
 'reichkanzl': {'reichkanzler': []},
 'reichl': {'reichle': [], 'reichling': [], 'reichls': []},
 'reichleit': {'reichleiter': ['reichleiters']},
 'reichleiter': ['reichleiters'],
 'reichleitn': {'reichleitner': []},
 'reichli': {'reichly': []},
 'reichlich': {'reichliche': ['reichlicher', 'reichliches']},
 'reichliche': ['reichlicher', 'reichliches'],
 'reichlicher': {'reichlichere': []},
 'reichlichst': {'reichlichste': []},
 'reichlin': {'reichline': []},
 'reichman': {'reichmans': []},
 'reichmani': {'reichmanis': []},
 'reichmann': {'reichmanns': []},
 'reichmark': {'reichmarks': []},
 'reichmarschal': {'reichmarschall': []},
 'reichmarsh': {'reichmarshal': []},
 'reichmarshal': {'reichmarshall': []},
 'reichmey': {'reichmeyer': []},
 'reichminist': {'reichminister': ['reichministers']},
 'reichminister': ['reichministers'],
 'reichpietschuf': {'reichpietschufer': []},
 'reichsabschi': {'reichsabschied': []},
 'reichsabschied': {'reichsabschiede': []},
 'reichsadl': {'reichsadler': []},
 'reichsamt': {'reichsamte': ['reichsamtes'], 'reichsamts': []},
 'reichsamte': ['reichsamtes'],
 'reichsamtsleit': {'reichsamtsleiter': []},
 'reichsangehorig': {'reichsangehorige': []},
 'reichsanzeig': {'reichsanzeiger': []},
 'reichsarbeit': {'reichsarbeits': []},
 'reichsarbeitsdienst': {'reichsarbeitsdienstes': []},
 'reichsarbeitsgericht': {'reichsarbeitsgerichts': []},
 'reichsarbeitsminist': {'reichsarbeitsminister': []},
 'reichsarchiv': {'reichsarchivs': []},
 'reichsaristokrati': {'reichsaristokratie': []},
 'reichsarme': {'reichsarmee': []},
 'reichsarztefuhr': {'reichsarztefuhrer': []},
 'reichsausschuss': {'reichsausschusses': []},
 'reichsaussenminist': {'reichsaussenminister': ['reichsaussenministers']},
 'reichsaussenminister': ['reichsaussenministers'],
 'reichsbahndirekt': {'reichsbahndirektion': []},
 'reichsbankprasid': {'reichsbankprasident': []},
 'reichsbann': {'reichsbanner': []},
 'reichsbauernfiihr': {'reichsbauernfiihrer': []},
 'reichsbauernfuhr': {'reichsbauernfuhrer': []},
 'reichsbeamt': {'reichsbeamte': []},
 'reichsbehord': {'reichsbehorde': []},
 'reichsbiirg': {'reichsbiirger': []},
 'reichsbot': {'reichsbote': []},
 'reichsbriick': {'reichsbriicke': []},
 'reichsbruck': {'reichsbrucke': []},
 'reichsbund': {'reichsbundes': []},
 'reichsburg': {'reichsburger': []},
 'reichschancelleri': {'reichschancellery': []},
 'reichschancellori': {'reichschancellory': []},
 'reichscommission': {'reichscommissioner': []},
 'reichsdenkmal': {'reichsdenkmale': []},
 'reichsdeput': {'reichsdeputation': ['reichsdeputations']},
 'reichsdeputation': ['reichsdeputations'],
 'reichsdeutsch': {'reichsdeutsche': ['reichsdeutscher']},
 'reichsdeutsche': ['reichsdeutscher'],
 'reichsehrenm': {'reichsehrenmal': []},
 'reichsend': {'reichsender': []},
 'reichserbhofgesetz': {'reichserbhofgesetzes': []},
 'reichseschatologi': {'reichseschatologie': []},
 'reichsfeind': {'reichsfeinde': []},
 'reichsfiihr': {'reichsfiihrer': ['reichsfiihrers']},
 'reichsfiihrer': ['reichsfiihrers'],
 'reichsfilhr': {'reichsfilhrer': []},
 'reichsfilmintend': {'reichsfilmintendant': []},
 'reichsfilmkamm': {'reichsfilmkammer': []},
 'reichsfinanzminist': {'reichsfinanzminister': []},
 'reichsflagg': {'reichsflagge': []},
 'reichsflihr': {'reichsflihrer': []},
 'reichsfluchtsteu': {'reichsfluchtsteuer': []},
 'reichsforstmeist': {'reichsforstmeister': []},
 'reichsfried': {'reichsfriede': []},
 'reichsftihr': {'reichsftihrer': []},
 'reichsfuehr': {'reichsfuehrer': ['reichsfuehrers']},
 'reichsfuehrer': ['reichsfuehrers'],
 'reichsfuhr': {'reichsfuhrer': ['reichsfuhrers']},
 'reichsfuhrer': ['reichsfuhrers'],
 'reichsgau': {'reichsgaue': []},
 'reichsgebiet': {'reichsgebietes': []},
 'reichsgedank': {'reichsgedanke': []},
 'reichsgedanken': {'reichsgedankens': []},
 'reichsgericht': {'reichsgerichte': ['reichsgerichtes'], 'reichsgerichts': []},
 'reichsgerichte': ['reichsgerichtes'],
 'reichsgeschicht': {'reichsgeschichte': []},
 'reichsgesetz': {'reichsgesetze': ['reichsgesetzes']},
 'reichsgesetze': ['reichsgesetzes'],
 'reichsgesundheitsamt': {'reichsgesundheitsamte': ['reichsgesundheitsamtes']},
 'reichsgesundheitsamte': ['reichsgesundheitsamtes'],
 'reichsgetreidestel': {'reichsgetreidestelle': []},
 'reichsglock': {'reichsglocke': []},
 'reichsgrenz': {'reichsgrenze': []},
 'reichsgriind': {'reichsgriinder': []},
 'reichsgrund': {'reichsgrunder': []},
 'reichsgrupp': {'reichsgruppe': []},
 'reichsgut': {'reichsgutes': []},
 'reichshalft': {'reichshalfte': []},
 'reichshauptkass': {'reichshauptkasse': []},
 'reichshaushalt': {'reichshaushalts': []},
 'reichsheer': {'reichsheeres': []},
 'reichshilf': {'reichshilfe': []},
 'reichshistori': {'reichshistorie': []},
 'reichside': {'reichsidee': []},
 'reichsideologi': {'reichsideologie': []},
 'reichsinnenminist': {'reichsinnenminister': []},
 'reichsinstitut': {'reichsinstituts': []},
 'reichsitalien': {'reichsitaliens': []},
 'reichsjagermeist': {'reichsjagermeister': []},
 'reichsjugendfiihr': {'reichsjugendfiihrer': []},
 'reichsjugendfuehr': {'reichsjugendfuehrer': []},
 'reichsjugendfuhr': {'reichsjugendfuhrer': []},
 'reichsjuhr': {'reichsjuhrer': []},
 'reichsjustizminist': {'reichsjustizminister': []},
 'reichskabinett': {'reichskabinetts': []},
 'reichskamm': {'reichskammer': []},
 'reichskammergericht': {'reichskammergerichts': []},
 'reichskanzl': {'reichskanzler': ['reichskanzlers']},
 'reichskanzler': ['reichskanzlers'],
 'reichskanzlerpalai': {'reichskanzlerpalais': []},
 'reichskass': {'reichskasse': []},
 'reichskassenschein': {'reichskassenscheine': []},
 'reichskirch': {'reichskirche': []},
 'reichskirchensystem': {'reichskirchensystems': []},
 'reichskolonialamt': {'reichskolonialamtes': [], 'reichskolonialamts': []},
 'reichskommiss': {'reichskommission': []},
 'reichskommissar': {'reichskommissare': [], 'reichskommissars': []},
 'reichskommissari': {'reichskommissariate': []},
 'reichskommissariat': {'reichskommissariats': []},
 'reichskonkordat': {'reichskonkordats': []},
 'reichskreditkass': {'reichskreditkasse': []},
 'reichskreditkassenschein': {'reichskreditkassenscheine': []},
 'reichskrei': {'reichskreis': []},
 'reichskreis': {'reichskreise': []},
 'reichskrieg': {'reichskriege': []},
 'reichskriegsflagg': {'reichskriegsflagge': []},
 'reichskriegsminist': {'reichskriegsminister': []},
 'reichskris': {'reichskrise': []},
 'reichskron': {'reichskrone': []},
 'reichskulturkamm': {'reichskulturkammer': []},
 'reichsland': {'reichslande': ['reichslander']},
 'reichslande': ['reichslander'],
 'reichslead': {'reichsleader': []},
 'reichsleit': {'reichsleiter': ['reichsleiters']},
 'reichsleiter': ['reichsleiters'],
 'reichslist': {'reichsliste': []},
 'reichsmarin': {'reichsmarine': []},
 'reichsmarineamt': {'reichsmarineamtes': [], 'reichsmarineamts': []},
 'reichsmark': {'reichsmarks': []},
 'reichsmarsch': {'reichsmarschal': []},
 'reichsmarschal': {'reichsmarschall': ['reichsmarschalls']},
 'reichsmarschall': ['reichsmarschalls'],
 'reichsmarsh': {'reichsmarshal': []},
 'reichsmarshal': {'reichsmarshall': []},
 'reichsminist': {'reichsminister': ['reichsministers']},
 'reichsminister': ['reichsministers'],
 'reichsministerium': {'reichsministeriums': []},
 'reichsministri': {'reichsministry': []},
 'reichsmu': {'reichsmus': []},
 'reichsmuseum': {'reichsmuseums': []},
 'reichsmusikkamm': {'reichsmusikkammer': []},
 'reichsmusiktag': {'reichsmusiktage': []},
 'reichsnahrstand': {'reichsnahrstandes': []},
 'reichsnotopf': {'reichsnotopfer': []},
 'reichsorganis': {'reichsorganisation': []},
 'reichsorganisationsleit': {'reichsorganisationsleiter': []},
 'reichsparteitag': {'reichsparteitage': ['reichsparteitages']},
 'reichsparteitage': ['reichsparteitages'],
 'reichsparteitagfilm': {'reichsparteitagfilms': []},
 'reichsparteitagsgeland': {'reichsparteitagsgelande': []},
 'reichspat': {'reichspatent': []},
 'reichspatriotismu': {'reichspatriotismus': []},
 'reichspraesid': {'reichspraesident': []},
 'reichsprasid': {'reichsprasident': []},
 'reichsprdsid': {'reichsprdsident': []},
 'reichspresid': {'reichspresident': []},
 'reichspressekamm': {'reichspressekammer': []},
 'reichspropagandaleit': {'reichspropagandaleiter': []},
 'reichspropagandaminist': {'reichspropagandaminister': []},
 'reichsprotektor': {'reichsprotektors': []},
 'reichsrat': {'reichsrate': ['reichsrates'], 'reichsrats': []},
 'reichsrate': ['reichsrates'],
 'reichsrath': {'reichsrathe': ['reichsrathes'], 'reichsraths': []},
 'reichsrathe': ['reichsrathes'],
 'reichsredn': {'reichsredner': []},
 'reichsregi': {'reichsregiment': []},
 'reichsritt': {'reichsritter': []},
 'reichsrundfunkkamm': {'reichsrundfunkkammer': []},
 'reichssach': {'reichssache': []},
 'reichsschatzmeist': {'reichsschatzmeister': []},
 'reichsschrifttumskamm': {'reichsschrifttumskammer': []},
 'reichsschriftumskamm': {'reichsschriftumskammer': []},
 'reichsschul': {'reichsschule': []},
 'reichssend': {'reichssender': []},
 'reichssicherheit': {'reichssicherheits': []},
 'reichssicherheitshauptamt': {'reichssicherheitshauptamtes': []},
 'reichssportfiihr': {'reichssportfiihrer': []},
 'reichssportfuhr': {'reichssportfuhrer': []},
 'reichsstadt': {'reichsstadte': []},
 'reichsstand': {'reichsstande': []},
 'reichsstatthalt': {'reichsstatthalter': ['reichsstatthalters']},
 'reichsstatthalter': ['reichsstatthalters'],
 'reichsstddt': {'reichsstddte': []},
 'reichsstdnd': {'reichsstdnde': []},
 'reichsstel': {'reichsstelle': []},
 'reichsstrass': {'reichsstrasse': []},
 'reichst': {'reichste': []},
 'reichstadt': {'reichstadte': ['reichstadter']},
 'reichstadte': ['reichstadter'],
 'reichstag': {'reichstage': ['reichstages'], 'reichstags': []},
 'reichstage': ['reichstages'],
 'reichstagsabgeordnet': {'reichstagsabgeordnete': ['reichstagsabgeordneter']},
 'reichstagsabgeordnete': ['reichstagsabgeordneter'],
 'reichstagsbrief': {'reichstagsbriefe': []},
 'reichstagsfrakt': {'reichstagsfraktion': []},
 'reichstagsgebaud': {'reichstagsgebaude': []},
 'reichstagsred': {'reichstagsrede': []},
 'reichstal': {'reichstaler': ['reichstalers']},
 'reichstaler': ['reichstalers'],
 'reichstand': {'reichstande': []},
 'reichstatthalt': {'reichstatthalter': []},
 'reichstddt': {'reichstddte': []},
 'reichstein': {'reichsteiner': []},
 'reichstel': {'reichstelle': []},
 'reichsthal': {'reichsthaler': ['reichsthalers']},
 'reichsthaler': ['reichsthalers'],
 'reichstheaterkamm': {'reichstheaterkammer': []},
 'reichstradit': {'reichstradition': []},
 'reichstrass': {'reichstrasse': []},
 'reichstreuhand': {'reichstreuhander': []},
 'reichsverband': {'reichsverbandes': []},
 'reichsverfassung': {'reichsverfassungs': []},
 'reichsverfassungskampagn': {'reichsverfassungskampagne': []},
 'reichsversicherungsamt': {'reichsversicherungsamts': []},
 'reichsverwes': {'reichsverweser': ['reichsverwesers']},
 'reichsverweser': ['reichsverwesers'],
 'reichsvizekanzl': {'reichsvizekanzler': []},
 'reichswehrminist': {'reichswehrminister': []},
 'reichswehrministerium': {'reichswehrministeriums': []},
 'reichswehroffizier': {'reichswehroffiziere': []},
 'reichswerk': {'reichswerke': []},
 'reichswirtschaft': {'reichswirtschafts': []},
 'reichswirtschaftskamm': {'reichswirtschaftskammer': []},
 'reichswirtschaftsminist': {'reichswirtschaftsminister': []},
 'reichswirtschaftsministerium': {'reichswirtschaftsministeriums': []},
 'reichszentral': {'reichszentrale': []},
 'reicht': {'reichte': [], 'reichts': []},
 'reichtag': {'reichtages': [], 'reichtags': []},
 'reichthal': {'reichthalers': []},
 'reichthiim': {'reichthiimer': []},
 'reichthum': {'reichthumer': [], 'reichthums': []},
 'reichtiim': {'reichtiimer': []},
 'reichtum': {'reichtumer': [], 'reichtums': []},
 'reichwald': {'reichwalder': []},
 'reichweit': {'reichweite': []},
 'reick': {'reicke': ['reickes'], 'reicks': []},
 'reicke': ['reickes'],
 'reicn': {'reicne': []},
 'reicoski': {'reicosky': []},
 'reict': {'reicts': []},
 'reiction': {'reictions': []},
 'reid': ['reide', 'reides', 'reiding'],
 'reidamin': {'reidamine': []},
 'reidanu': {'reidanus': []},
 'reidar': {'reidare': []},
 'reidari': {'reidaris': []},
 'reideal': {'reidealization': [], 'reidealize': []},
 'reidel': {'reidell': [], 'reidels': []},
 'reidelberg': {'reidelberger': []},
 'reidemeist': {'reidemeister': []},
 'reidenau': {'reidenauer': []},
 'reidenc': {'reidence': []},
 'reidentif': {'reidentification': ['reidentifications']},
 'reidentifi': {'reidentifiability': [],
                'reidentifiable': [],
                'reidentified': [],
                'reidentifies': [],
                'reidentify': ['reidentifying']},
 'reidentification': ['reidentifications'],
 'reidentify': ['reidentifying'],
 'reideolog': {'reideologization': []},
 'reider': {'reiderer': [], 'reiders': []},
 'reiderbeck': {'reiderbecke': []},
 'reidet': {'reidetal': []},
 'reidhal': {'reidhall': []},
 'reidhil': {'reidhill': []},
 'reidi': {'reidie': ['reidies'], 'reidis': [], 'reidy': ['reidys']},
 'reidie': ['reidies'],
 'reidig': {'reidiger': []},
 'reidili': {'reidily': []},
 'reiding': {'reidinger': []},
 'reidit': {'reidites': []},
 'reidl': {'reidle': [], 'reidling': []},
 'reidling': {'reidlinger': []},
 'reidmeist': {'reidmeister': []},
 'reidmil': {'reidmiller': []},
 'reidmor': {'reidmore': []},
 'reidsdal': {'reidsdale': []},
 'reidsvil': {'reidsville': []},
 'reidswir': {'reidswire': []},
 'reidu': {'reidus': []},
 'reidvil': {'reidville': []},
 'reidy': ['reidys'],
 'reieas': {'reiease': ['reieased'], 'reieasing': []},
 'reiease': ['reieased'],
 'reiect': {'reiecte': ['reiected'], 'reiecting': [], 'reiects': []},
 'reiecta': {'reiectae': []},
 'reiectaequ': {'reiectaeque': []},
 'reiecte': ['reiected'],
 'reiecti': {'reiectis': []},
 'reiection': {'reiectione': []},
 'reiectu': {'reiectus': []},
 'reieh': {'reiehe': ['reiehes'], 'reiehs': []},
 'reiehe': ['reiehes'],
 'reieiv': {'reieived': []},
 'reiembl': {'reiembling': []},
 'reiemblanc': {'reiemblance': []},
 'reien': {'reiened': [], 'reiens': []},
 'reiensi': {'reiensis': []},
 'reier': {'reierred': [], 'reierring': [], 'reiers': []},
 'reierenc': {'reierence': ['reierences']},
 'reierence': ['reierences'],
 'reierv': {'reierve': ['reierved']},
 'reierve': ['reierved'],
 'reiev': {'reieve': ['reieved']},
 'reievanc': {'reievance': []},
 'reieve': ['reieved'],
 'reiew': {'reiewed': []},
 'reiezion': {'reiezione': []},
 'reif': {'reife': ['reifes', 'reifed'], 'reifing': [], 'reifs': []},
 'reife': ['reifes', 'reifed'],
 'reifegerst': {'reifegerste': []},
 'reifei': {'reifeis': []},
 'reifen': {'reifens': []},
 'reifenberg': {'reifenberger': []},
 'reifend': {'reifende': ['reifender']},
 'reifende': ['reifender'],
 'reifenhaus': {'reifenhauser': []},
 'reifenwerk': {'reifenwerke': []},
 'reifer': {'reifere': [], 'reifers': []},
 'reifezeugni': {'reifezeugnis': []},
 'reiff': {'reiffe': [], 'reiffs': []},
 'reiffenberg': {'reiffenberger': []},
 'reiffer': {'reiffers': []},
 'reiffi': {'reiffis': []},
 'reifi': {'reified': [], 'reifies': [], 'reifis': [], 'reify': ['reifying']},
 'reifiabl': {'reifiable': []},
 'reific': {'reification': ['reificational'], 'reificative': []},
 'reification': ['reificational'],
 'reificatori': {'reificatory': []},
 'reifici': {'reificiation': []},
 'reifier': {'reifiers': []},
 'reifing': {'reifinger': []},
 'reifiy': {'reifiying': []},
 'reifk': {'reifke': []},
 'reifkat': {'reifkation': []},
 'reifl': {'reifling': []},
 'reiflcat': {'reiflcation': []},
 'reiflich': {'reiflicher': []},
 'reifling': {'reiflinger': []},
 'reiforc': {'reiforced': [], 'reiforcement': []},
 'reifschneid': {'reifschneider': []},
 'reifsneid': {'reifsneider': []},
 'reifsnid': {'reifsnider': []},
 'reifsnyd': {'reifsnyder': []},
 'reifst': {'reifste': []},
 'reifsynd': {'reifsynder': []},
 'reift': {'reifte': [], 'reifts': []},
 'reiftcat': {'reiftcation': []},
 'reifung': {'reifungs': []},
 'reifungsprozess': {'reifungsprozesse': []},
 'reify': ['reifying'],
 'reig': {'reige': [], 'reiging': [], 'reigs': []},
 'reigada': {'reigadas': []},
 'reigal': {'reigale': []},
 'reigat': {'reigate': []},
 'reigel': {'reigels': []},
 'reigelsvil': {'reigelsville': []},
 'reigentanz': {'reigentanze': []},
 'reiger': {'reigers': []},
 'reigh': {'reighed': []},
 'reight': {'reighte': [], 'reights': []},
 'reighteou': {'reighteous': []},
 'reighteous': {'reighteousness': []},
 'reigi': {'reigis': []},
 'reigion': {'reigions': []},
 'reigiou': {'reigious': []},
 'reigl': {'reigle': ['reigles']},
 'reigle': ['reigles'],
 'reigm': {'reigme': []},
 'reigment': {'reigments': []},
 'reign': ['reigne', 'reigned', 'reignes', 'reigning'],
 'reigner': {'reigners': []},
 'reigni': {'reigny': []},
 'reignit': {'reignite': ['reignites', 'reignited'],
             'reigniting': [],
             'reignition': ['reignitions']},
 'reignite': ['reignites', 'reignited'],
 'reignition': ['reignitions'],
 'reignold': {'reignolds': []},
 'reignot': {'reignots': []},
 'reignperiod': {'reignperiods': []},
 'reignti': {'reignties': [], 'reignty': []},
 'reigon': {'reigonal': [], 'reigons': []},
 'reigster': {'reigstered': []},
 'reigu': {'reigued': [], 'reiguing': [], 'reigus': []},
 'reih': {'reihe': [], 'reihing': [], 'reihs': []},
 'reihcat': {'reihcation': []},
 'reihenfolg': {'reihenfolge': []},
 'reihengrab': {'reihengraber': []},
 'reihengraberzivilis': {'reihengraberzivilisation': []},
 'reihengrdb': {'reihengrdber': []},
 'reihenhau': {'reihenhaus': []},
 'reihenhaus': {'reihenhauser': []},
 'reihenversuch': {'reihenversuche': []},
 'reihenweis': {'reihenweise': []},
 'reiherent': {'reiherente': []},
 'reiherwerd': {'reiherwerder': []},
 'reihi': {'reihy': []},
 'reihil': {'reihill': []},
 'reihl': {'reihle': []},
 'reihsau': {'reihsaus': []},
 'reiht': {'reihte': []},
 'reii': {'reiied': [], 'reiies': []},
 'reiiabiiiti': {'reiiabiiity': []},
 'reiianc': {'reiiance': []},
 'reiic': {'reiics': []},
 'reiicer': {'reiicere': []},
 'reiid': {'reiide': ['reiided'], 'reiiding': []},
 'reiide': ['reiided'],
 'reiidenc': {'reiidence': []},
 'reiiev': {'reiieve': ['reiieved']},
 'reiieve': ['reiieved'],
 'reiiew': {'reiiews': []},
 'reiigion': {'reiigions': []},
 'reiigiou': {'reiigious': []},
 'reiign': {'reiigned': []},
 'reiili': {'reiily': []},
 'reiilli': {'reiilly': []},
 'reiin': {'reiine': ['reiined'], 'reiining': []},
 'reiinact': {'reiinacted': []},
 'reiine': ['reiined'],
 'reiinforc': {'reiinforce': ['reiinforced']},
 'reiinforce': ['reiinforced'],
 'reiiolut': {'reiiolution': []},
 'reiiqu': {'reiiques': []},
 'reiir': {'reiire': ['reiired']},
 'reiire': ['reiired'],
 'reiis': {'reiised': []},
 'reiistablish': {'reiistablishment': []},
 'reiistanc': {'reiistance': []},
 'reij': {'reijing': [], 'reijs': []},
 'reijan': {'reijans': []},
 'reijer': {'reijers': []},
 'reijers': {'reijerse': []},
 'reijk': {'reijke': []},
 'reijland': {'reijlander': []},
 'reijmer': {'reijmers': []},
 'reijmyr': {'reijmyre': []},
 'reijn': {'reijns': []},
 'reijnder': {'reijnders': []},
 'reijner': {'reijners': []},
 'reijnier': {'reijniers': []},
 'reijniers': {'reijnierse': []},
 'reijntj': {'reijntjes': []},
 'reijs': {'reijse': []},
 'reijuir': {'reijuired': []},
 'reik': {'reike': ['reikes'], 'reiks': []},
 'reike': ['reikes'],
 'reikera': {'reikeras': []},
 'reikeraa': {'reikeraas': []},
 'reikerstorf': {'reikerstorfer': []},
 'reiki': {'reikie': [], 'reikis': []},
 'reikian': {'reikianes': []},
 'reikwijdt': {'reikwijdte': []},
 'reil': {'reile': [], 'reiling': [], 'reils': []},
 'reiland': {'reilander': []},
 'reilect': {'reilected': [],
             'reilecting': [],
             'reilection': ['reilections'],
             'reilects': []},
 'reilection': ['reilections'],
 'reilfi': {'reilfy': []},
 'reilgiou': {'reilgious': []},
 'reilh': {'reilhe': []},
 'reili': {'reilie': [], 'reily': ['reilys']},
 'reilic': {'reilication': []},
 'reiling': {'reilinger': []},
 'reiliti': {'reility': []},
 'reill': {'reille': ['reilles']},
 'reillan': {'reillane': []},
 'reillann': {'reillanne': []},
 'reille': ['reilles'],
 'reilley': {'reilleys': []},
 'reilli': {'reilly': ['reillys']},
 'reillum': {'reillume': ['reillumed'], 'reilluming': []},
 'reillume': ['reillumed'],
 'reillumin': {'reilluminate': ['reilluminates', 'reilluminated'],
               'reilluminating': [],
               'reillumination': [],
               'reillumine': ['reillumined', 'reillumines']},
 'reilluminate': ['reilluminates', 'reilluminated'],
 'reillumine': ['reillumined', 'reillumines'],
 'reillus': {'reillusioned': []},
 'reillustr': {'reillustrate': ['reillustrates', 'reillustrated'],
               'reillustrating': [],
               'reillustration': []},
 'reillustrate': ['reillustrates', 'reillustrated'],
 'reilly': ['reillys'],
 'reilor': {'reilored': []},
 'reilri': {'reilry': []},
 'reilt': {'reilts': []},
 'reilti': {'reilty': []},
 'reily': ['reilys'],
 'reim': {'reime': ['reimes', 'reimed'], 'reims': []},
 'reimag': {'reimage': ['reimaged', 'reimages'], 'reimaging': []},
 'reimage': ['reimaged', 'reimages'],
 'reimagin': {'reimagination': ['reimaginations'],
              'reimagine': ['reimagines', 'reimagined'],
              'reimagining': ['reimaginings']},
 'reimagination': ['reimaginations'],
 'reimagine': ['reimagines', 'reimagined'],
 'reimagining': ['reimaginings'],
 'reimam': {'reimams': []},
 'reiman': {'reimans': []},
 'reimani': {'reimanis': []},
 'reimann': {'reimanns': []},
 'reimar': {'reimars': []},
 'reimariu': {'reimarius': []},
 'reimarn': {'reimarns': []},
 'reimaru': {'reimarus': []},
 'reimb': {'reimbed': []},
 'reimbaldu': {'reimbaldus': []},
 'reimbark': {'reimbarkation': [], 'reimbarked': [], 'reimbarking': []},
 'reimbed': {'reimbedded': [], 'reimbedding': []},
 'reimbib': {'reimbibe': ['reimbibed'], 'reimbibing': []},
 'reimbibe': ['reimbibed'],
 'reimbibit': {'reimbibition': []},
 'reimbodi': {'reimbodied': [],
              'reimbodiment': ['reimbodiments'],
              'reimbody': ['reimbodying']},
 'reimbodiment': ['reimbodiments'],
 'reimbody': ['reimbodying'],
 'reimbu': {'reimbue': ['reimbued'], 'reimbuing': []},
 'reimbue': ['reimbued'],
 'reimbur': {'reimburs': []},
 'reimburf': {'reimburfe': ['reimburfed', 'reimburfement']},
 'reimburfe': ['reimburfed', 'reimburfement'],
 'reimburs': {'reimbursability': [],
              'reimbursable': ['reimbursables'],
              'reimbursal': [],
              'reimburse': ['reimburser',
                            'reimbursed',
                            'reimburses',
                            'reimbursers',
                            'reimbursement',
                            'reimburseable'],
              'reimbursible': [],
              'reimbursing': [],
              'reimbursment': ['reimbursments']},
 'reimbursable': ['reimbursables'],
 'reimburse': ['reimburser',
               'reimbursed',
               'reimburses',
               'reimbursers',
               'reimbursement',
               'reimburseable'],
 'reimbursment': ['reimbursments'],
 'reimbus': {'reimbuse': ['reimbused', 'reimbusement']},
 'reimbuse': ['reimbused', 'reimbusement'],
 'reimch': {'reimche': []},
 'reimcr': {'reimcrs': []},
 'reime': ['reimes', 'reimed'],
 'reimegr': {'reimegration': []},
 'reimel': {'reimels': []},
 'reimenschneid': {'reimenschneider': []},
 'reimensnyd': {'reimensnyder': []},
 'reimer': {'reimers': []},
 'reimerd': {'reimerdes': []},
 'reimerpret': {'reimerpretation': []},
 'reimersholm': {'reimersholme': []},
 'reimerswa': {'reimerswaal': []},
 'reimhurs': {'reimhurse': ['reimhursed', 'reimhursement']},
 'reimhurse': ['reimhursed', 'reimhursement'],
 'reimi': {'reimie': []},
 'reimk': {'reimke': []},
 'reimling': {'reimlinger': []},
 'reimlos': {'reimlose': []},
 'reimlut': {'reimlution': []},
 'reimmers': {'reimmerse': ['reimmersed', 'reimmerses'],
              'reimmersing': [],
              'reimmersion': []},
 'reimmerse': ['reimmersed', 'reimmerses'],
 'reimmigr': {'reimmigrants': [],
              'reimmigrate': ['reimmigrated'],
              'reimmigration': []},
 'reimmigrate': ['reimmigrated'],
 'reimmobil': {'reimmobilization': [], 'reimmobilized': []},
 'reimmun': {'reimmunization': ['reimmunizations'],
             'reimmunize': ['reimmunized'],
             'reimmunizing': []},
 'reimmunis': {'reimmunisation': []},
 'reimmunization': ['reimmunizations'],
 'reimmunize': ['reimmunized'],
 'reimmunoprecipit': {'reimmunoprecipitated': []},
 'reimo': {'reimos': []},
 'reimos': {'reimoser': []},
 'reimpaar': {'reimpaare': []},
 'reimpact': {'reimpacted': [], 'reimpaction': []},
 'reimpart': {'reimparted': []},
 'reimpel': {'reimpell': []},
 'reimplac': {'reimplace': ['reimplaced']},
 'reimplace': ['reimplaced'],
 'reimplant': {'reimplantation': ['reimplantations'],
               'reimplanted': [],
               'reimplanting': [],
               'reimplants': []},
 'reimplantation': ['reimplantations'],
 'reimplement': {'reimplementation': ['reimplementations'],
                 'reimplemented': [],
                 'reimplementing': [],
                 'reimplements': []},
 'reimplementation': ['reimplementations'],
 'reimplic': {'reimplicate': ['reimplicates', 'reimplicated'],
              'reimplication': []},
 'reimplicate': ['reimplicates', 'reimplicated'],
 'reimport': {'reimportation': ['reimportations'],
              'reimported': [],
              'reimporting': [],
              'reimports': []},
 'reimportation': ['reimportations'],
 'reimpos': {'reimpose': ['reimposed', 'reimposes'], 'reimposing': []},
 'reimpose': ['reimposed', 'reimposes'],
 'reimposit': {'reimposition': []},
 'reimpregn': {'reimpregnate': ['reimpregnated'],
               'reimpregnating': [],
               'reimpregnation': []},
 'reimpregnate': ['reimpregnated'],
 'reimpres': {'reimpresion': []},
 'reimpresion': {'reimpresiones': []},
 'reimpreso': {'reimpresos': []},
 'reimpress': {'reimpressed': [],
               'reimpresses': [],
               'reimpressing': [],
               'reimpression': ['reimpressions']},
 'reimpression': ['reimpressions'],
 'reimprim': {'reimprime': ['reimprimer', 'reimprimes']},
 'reimprime': {'reimprimee': ['reimprimees']},
 'reimprimee': ['reimprimees'],
 'reimprint': {'reimprinted': [], 'reimprinting': []},
 'reimprison': {'reimprisoned': [], 'reimprisoning': [], 'reimprisonment': []},
 'reimprov': {'reimproved': [], 'reimprovement': []},
 'reimring': {'reimringer': []},
 'reimschneid': {'reimschneider': []},
 'reimsdyk': {'reimsdyke': []},
 'reimsprach': {'reimsprache': []},
 'reimu': {'reimus': []},
 'reimul': {'reimuller': []},
 'reimundu': {'reimundus': []},
 'rein': ['reine', 'reines', 'reined', 'reining'],
 'reina': {'reinas': []},
 'reinach': {'reinacher': [], 'reinachs': []},
 'reinack': {'reinacker': []},
 'reinact': {'reinacted': [],
             'reinacting': [],
             'reinactment': ['reinactments'],
             'reinacts': []},
 'reinactiv': {'reinactivated': []},
 'reinactment': ['reinactments'],
 'reinado': {'reinados': []},
 'reinaerd': {'reinaerde': []},
 'reinaert': {'reinaerts': []},
 'reinaf': {'reinafe': ['reinafes']},
 'reinafe': ['reinafes'],
 'reinagl': {'reinagle': ['reinagles']},
 'reinagle': ['reinagles'],
 'reinain': {'reinained': [], 'reinaining': [], 'reinains': []},
 'reinaind': {'reinainder': []},
 'reinaiss': {'reinaissance': []},
 'reinaldo': {'reinaldos': []},
 'reinaldu': {'reinaldus': []},
 'reinalt': {'reinalter': []},
 'reinan': {'reinans': []},
 'reinant': {'reinante': ['reinantes']},
 'reinante': ['reinantes'],
 'reinar': {'reinares': []},
 'reinard': {'reinards': []},
 'reinardi': {'reinardy': []},
 'reinardu': {'reinardus': []},
 'reinark': {'reinarkable': [], 'reinarks': []},
 'reinass': {'reinassance': []},
 'reinaugur': {'reinaugural': [],
               'reinaugurate': ['reinaugurated', 'reinaugurates'],
               'reinaugurating': [],
               'reinauguration': []},
 'reinaugurate': ['reinaugurated', 'reinaugurates'],
 'reinbach': {'reinbacher': []},
 'reinbaldu': {'reinbaldus': []},
 'reinberg': {'reinberger': [], 'reinbergs': []},
 'reinboth': {'reinbothe': []},
 'reinburs': {'reinburse': ['reinbursed', 'reinbursement', 'reinbursements']},
 'reinburse': ['reinbursed', 'reinbursement', 'reinbursements'],
 'reinc': {'reince': [], 'reincs': []},
 'reincam': {'reincamated': [], 'reincamation': ['reincamations']},
 'reincamation': ['reincamations'],
 'reincar': {'reincaration': []},
 'reincarcer': {'reincarcerate': ['reincarcerated'],
                'reincarcerating': [],
                'reincarceration': ['reincarcerations']},
 'reincarcerate': ['reincarcerated'],
 'reincarceration': ['reincarcerations'],
 'reincarn': {'reincarnate': ['reincarnates', 'reincarnated'],
              'reincarnating': [],
              'reincarnation': ['reincarnational', 'reincarnationally'],
              'reincarnative': []},
 'reincarnat': {'reincarnatable': []},
 'reincarnate': ['reincarnates', 'reincarnated'],
 'reincarnation': {'reincarnationism': []},
 'reincarnationist': {'reincarnationists': []},
 'reincarnatori': {'reincarnatory': []},
 'reincarnazion': {'reincarnazione': []},
 'reincat': {'reincation': []},
 'reincck': {'reinccke': []},
 'reincept': {'reinception': []},
 'reincid': {'reincidence': []},
 'reincident': {'reincidentes': []},
 'reincis': {'reincised': [], 'reincision': []},
 'reincit': {'reincite': ['reincited']},
 'reincite': ['reincited'],
 'reinck': {'reincke': []},
 'reincken': {'reinckens': []},
 'reinclos': {'reinclose': ['reinclosed']},
 'reinclose': ['reinclosed'],
 'reinclud': {'reinclude': ['reincluded'], 'reincluding': []},
 'reinclude': ['reincluded'],
 'reinclus': {'reinclusion': []},
 'reincorpor': {'reincorporate': ['reincorporated', 'reincorporates'],
                'reincorporating': [],
                'reincorporation': ['reincorporations']},
 'reincorporate': ['reincorporated', 'reincorporates'],
 'reincorporation': ['reincorporations'],
 'reincreas': {'reincrease': ['reincreased', 'reincreases'],
               'reincreasing': []},
 'reincrease': ['reincreased', 'reincreases'],
 'reincrud': {'reincrudation': []},
 'reincub': {'reincubate': ['reincubated'],
             'reincubating': [],
             'reincubation': []},
 'reincubate': ['reincubated'],
 'reinculc': {'reinculcate': ['reinculcated'],
              'reinculcating': [],
              'reinculcation': []},
 'reinculcate': ['reinculcated'],
 'reincur': {'reincurred': [], 'reincurring': []},
 'reincurs': {'reincursion': []},
 'reind': {'reinds': []},
 'reindeer': {'reindeer': []},
 'reindeerbreed': {'reindeerbreeders': [], 'reindeerbreeding': []},
 'reindeerherd': {'reindeerherders': [], 'reindeerherding': []},
 'reindeerhunt': {'reindeerhunters': [], 'reindeerhunting': []},
 'reindeerskin': {'reindeerskins': []},
 'reindel': {'reindell': []},
 'reindentur': {'reindenture': ['reindentured', 'reindentures'],
                'reindenturing': []},
 'reindenture': ['reindentured', 'reindentures'],
 'reindepend': {'reindependence': []},
 'reinder': {'reinders': []},
 'reindi': {'reindis': []},
 'reindic': {'reindicate': ['reindicated']},
 'reindicate': ['reindicated'],
 'reindict': {'reindicted': [], 'reindicting': [], 'reindictment': []},
 'reindigen': {'reindigenization': []},
 'reindividu': {'reindividualization': [],
                'reindividualize': ['reindividualized'],
                'reindividuation': []},
 'reindividualize': ['reindividualized'],
 'reindoctrin': {'reindoctrinate': ['reindoctrinated'],
                 'reindoctrinating': [],
                 'reindoctrination': []},
 'reindoctrinate': ['reindoctrinated'],
 'reindors': {'reindorse': ['reindorses', 'reindorsed', 'reindorsement'],
              'reindorsing': []},
 'reindorse': ['reindorses', 'reindorsed', 'reindorsement'],
 'reindu': {'reindue': []},
 'reinduc': {'reinduce': ['reinduces', 'reinduced'],
             'reinducible': [],
             'reinducing': []},
 'reinduce': ['reinduces', 'reinduced'],
 'reinduct': {'reinducted': [],
              'reinducting': [],
              'reinduction': ['reinductions']},
 'reinduction': ['reinductions'],
 'reindulg': {'reindulge': []},
 'reindur': {'reinduration': []},
 'reindustri': {'reindustrial': ['reindustrialize',
                                 'reindustrialized',
                                 'reindustrializing',
                                 'reindustrialization']},
 'reindustrial': ['reindustrialize',
                  'reindustrialized',
                  'reindustrializing',
                  'reindustrialization'],
 'reindustrialis': {'reindustrialisation': [], 'reindustrialise': []},
 'reine': {'reinee': []},
 'reinecciu': {'reineccius': []},
 'reinech': {'reineche': []},
 'reineck': {'reineckate': ['reineckates'],
             'reinecke': ['reineckes', 'reinecker'],
             'reinecks': []},
 'reineckate': ['reineckates'],
 'reinecke': ['reineckes', 'reinecker'],
 'reined': {'reinede': []},
 'reinedi': {'reinedy': []},
 'reineek': {'reineeke': []},
 'reineg': {'reineger': []},
 'reinegg': {'reineggs': []},
 'reinek': {'reineke': ['reineker', 'reinekers'], 'reineking': []},
 'reineke': ['reineker', 'reinekers'],
 'reinel': {'reinell': [], 'reinels': []},
 'reineldi': {'reineldis': []},
 'reinem': {'reinemer': []},
 'reinemb': {'reinember': ['reinembered']},
 'reinember': ['reinembered'],
 'reinemey': {'reinemeyer': []},
 'reinentsprungen': {'reinentsprungenes': []},
 'reiner': {'reinere': ['reinerer'], 'reiners': []},
 'reinere': ['reinerer'],
 'reineriu': {'reinerius': []},
 'reinert': {'reinerts': []},
 'reineru': {'reinerus': []},
 'reinerv': {'reinervated': [], 'reinervation': []},
 'reinesiu': {'reinesius': []},
 'reinett': {'reinette': ['reinettes', 'reinetters']},
 'reinette': ['reinettes', 'reinetters'],
 'reinevil': {'reineville': []},
 'reinew': {'reinews': []},
 'reinfal': {'reinfall': []},
 'reinfarct': {'reinfarction': ['reinfarctions']},
 'reinfarction': ['reinfarctions'],
 'reinfbrcer': {'reinfbrcers': []},
 'reinfect': {'reinfected': [],
              'reinfecting': [],
              'reinfection': ['reinfections'],
              'reinfective': [],
              'reinfects': []},
 'reinfection': ['reinfections'],
 'reinfekt': {'reinfektion': []},
 'reinfel': {'reinfels': []},
 'reinfeld': {'reinfelder': [], 'reinfelds': []},
 'reinfeof': {'reinfeoffed': []},
 'reinfest': {'reinfestation': ['reinfestations'],
              'reinfested': [],
              'reinfesting': [],
              'reinfests': []},
 'reinfestation': ['reinfestations'],
 'reinfibul': {'reinfibulated': [], 'reinfibulation': []},
 'reinfiltr': {'reinfiltrate': ['reinfiltrated'],
               'reinfiltrating': [],
               'reinfiltration': []},
 'reinfiltrate': ['reinfiltrated'],
 'reinflam': {'reinflame': ['reinflamed'], 'reinflaming': []},
 'reinflame': ['reinflamed'],
 'reinflamm': {'reinflammation': []},
 'reinflat': {'reinflate': ['reinflates', 'reinflated'],
              'reinflating': [],
              'reinflation': []},
 'reinflate': ['reinflates', 'reinflated'],
 'reinflect': {'reinflected': [],
               'reinflecting': [],
               'reinflection': [],
               'reinflects': []},
 'reinflict': {'reinflicted': [], 'reinflicting': []},
 'reinfluenc': {'reinfluence': ['reinfluenced']},
 'reinfluence': ['reinfluenced'],
 'reinfoc': {'reinfoce': ['reinfoced', 'reinfocement']},
 'reinfoce': ['reinfoced', 'reinfocement'],
 'reinfoic': {'reinfoiced': []},
 'reinfor': {'reinfore': ['reinfored',
                          'reinforeer',
                          'reinforeing',
                          'reinforeers',
                          'reinforement',
                          'reinforeement',
                          'reinforements',
                          'reinforeements'],
             'reinforment': []},
 'reinforc': {'reinforcable': [],
              'reinforce': ['reinforcer',
                            'reinforces',
                            'reinforced',
                            'reinforceing',
                            'reinforcement',
                            'reinforceable',
                            'reinforceability'],
              'reinforcible': [],
              'reinforcing': ['reinforcings'],
              'reinforcive': [],
              'reinforcment': ['reinforcments']},
 'reinforccr': {'reinforccrs': []},
 'reinforce': ['reinforcer',
               'reinforces',
               'reinforced',
               'reinforceing',
               'reinforcement',
               'reinforceable',
               'reinforceability'],
 'reinforcedbi': {'reinforcedby': []},
 'reinforcedconcret': {'reinforcedconcrete': []},
 'reinforcedplast': {'reinforcedplastic': []},
 'reinforcement': {'reinforcemente': []},
 'reinforcementbas': {'reinforcementbased': []},
 'reinforcementlearn': {'reinforcementlearning': []},
 'reinforcemeut': {'reinforcemeuts': []},
 'reinforcen': {'reinforcenent': ['reinforcenents']},
 'reinforcenent': ['reinforcenents'],
 'reinforcesth': {'reinforcesthe': []},
 'reinforceth': {'reinforcethe': []},
 'reinforcing': ['reinforcings'],
 'reinforcingli': {'reinforcingly': []},
 'reinforcment': ['reinforcments'],
 'reinfore': {'reinforee': ['reinforees', 'reinforeed']},
 'reinforec': {'reinforeced': [], 'reinforecement': []},
 'reinforee': ['reinforees', 'reinforeed'],
 'reinform': {'reinformation': [],
              'reinformed': [],
              'reinforming': [],
              'reinforms': []},
 'reinformc': {'reinformcement': []},
 'reinforo': {'reinforoe': ['reinforoed', 'reinforoement', 'reinforoements'],
              'reinforoing': []},
 'reinforoe': ['reinforoed', 'reinforoement', 'reinforoements'],
 'reinfr': {'reinfred': []},
 'reinfri': {'reinfried': []},
 'reinftat': {'reinftate': ['reinftated']},
 'reinftate': ['reinftated'],
 'reinfund': {'reinfunds': []},
 'reinfus': {'reinfuse': ['reinfuses', 'reinfused'],
             'reinfusing': [],
             'reinfusion': ['reinfusions']},
 'reinfuse': ['reinfuses', 'reinfused'],
 'reinfusion': ['reinfusions'],
 'reing': {'reinges': []},
 'reingeld': {'reingelder': []},
 'reingend': {'reingendering': []},
 'reingest': {'reingested': [],
              'reingesting': [],
              'reingestion': [],
              'reingests': []},
 'reingrabn': {'reingrabner': []},
 'reingraft': {'reingrafted': []},
 'reingrati': {'reingratiate': ['reingratiated'], 'reingratiating': []},
 'reingratiate': ['reingratiated'],
 'reingrav': {'reingraved': []},
 'reingrub': {'reingruber': []},
 'reingulf': {'reingulfed': []},
 'reinhabit': {'reinhabitants': [],
               'reinhabitation': [],
               'reinhabited': [],
               'reinhabiting': [],
               'reinhabits': []},
 'reinhabitori': {'reinhabitory': []},
 'reinhal': {'reinhalation': [],
             'reinhale': ['reinhaled'],
             'reinhaling': [],
             'reinhall': []},
 'reinhale': ['reinhaled'],
 'reinhalt': {'reinhalter': []},
 'reinhamm': {'reinhammer': []},
 'reinhard': {'reinhards': []},
 'reinhardf': {'reinhardfs': []},
 'reinhardsbrunn': {'reinhardsbrunner': []},
 'reinhardsbrunnensi': {'reinhardsbrunnensis': []},
 'reinhardstoettn': {'reinhardstoettner': []},
 'reinhardstottn': {'reinhardstottner': []},
 'reinhardt': {'reinhardts': []},
 'reinhardtit': {'reinhardtites': []},
 'reinhardtiu': {'reinhardtius': []},
 'reinhardu': {'reinhardus': []},
 'reinhart': {'reinharts': []},
 'reinheim': {'reinheimer': []},
 'reinheit': {'reinheits': []},
 'reinheitsgrad': {'reinheitsgrades': []},
 'reinherit': {'reinheritance': [], 'reinherited': [], 'reinherits': []},
 'reinhibit': {'reinhibited': [], 'reinhibition': []},
 'reinhild': {'reinhilde': []},
 'reinhold': {'reinholds': []},
 'reinholdu': {'reinholdus': []},
 'reini': {'reinie': [], 'reinis': [], 'reiny': ['reinys']},
 'reinich': {'reiniche': []},
 'reinick': {'reinicke': ['reinicker']},
 'reinicke': ['reinicker'],
 'reinickendorf': {'reinickendorfer': []},
 'reinier': {'reiniers': []},
 'reinig': {'reinige': ['reiniger'], 'reiniging': []},
 'reinige': ['reiniger'],
 'reinigend': {'reinigende': []},
 'reinigt': {'reinigte': []},
 'reinigung': {'reinigungs': []},
 'reinik': {'reinike': []},
 'reining': {'reininger': []},
 'reininghau': {'reininghaus': []},
 'reiningu': {'reiningue': []},
 'reiniorc': {'reiniorced': []},
 'reinisch': {'reinische': ['reinisches']},
 'reinische': ['reinisches'],
 'reinit': {'reinitation': [], 'reinite': []},
 'reinita': {'reinitas': []},
 'reiniti': {'reinitialization': ['reinitializations'],
             'reinitialize': ['reinitializes', 'reinitialized'],
             'reinitializing': [],
             'reinitiate': ['reinitiated', 'reinitiates'],
             'reinitiating': [],
             'reinitiation': ['reinitiations']},
 'reinitialis': {'reinitialisation': [],
                 'reinitialise': ['reinitialises', 'reinitialised'],
                 'reinitialising': []},
 'reinitialise': ['reinitialises', 'reinitialised'],
 'reinitialization': ['reinitializations'],
 'reinitialize': ['reinitializes', 'reinitialized'],
 'reinitiate': ['reinitiated', 'reinitiates'],
 'reinitiation': ['reinitiations'],
 'reinitz': {'reinitzer': []},
 'reinitzhub': {'reinitzhuber': []},
 'reiniu': {'reinius': []},
 'reinject': {'reinjected': [],
              'reinjecting': [],
              'reinjection': ['reinjections'],
              'reinjects': []},
 'reinjection': ['reinjections'],
 'reinjur': {'reinjure': ['reinjured', 'reinjures'], 'reinjuring': []},
 'reinjure': ['reinjured', 'reinjures'],
 'reinjuri': {'reinjuries': [], 'reinjury': []},
 'reink': {'reinke': ['reinked', 'reinkes'], 'reinking': []},
 'reinkarn': {'reinkarnation': []},
 'reinke': ['reinked', 'reinkes'],
 'reinkemei': {'reinkemeier': []},
 'reinkemey': {'reinkemeyer': []},
 'reinken': {'reinkens': []},
 'reinkensmey': {'reinkensmeyer': []},
 'reinkob': {'reinkober': []},
 'reinl': {'reinle': []},
 'reinlaend': {'reinlaender': []},
 'reinland': {'reinlander': []},
 'reinlerpret': {'reinlerpretation': []},
 'reinlich': {'reinliche': ['reinlicher']},
 'reinliche': ['reinlicher'],
 'reinlist': {'reinlisted': [], 'reinlisting': [], 'reinlistment': []},
 'reinlorc': {'reinlorce': ['reinlorced', 'reinlorcement'], 'reinlorcing': []},
 'reinlorce': ['reinlorced', 'reinlorcement'],
 'reinmar': {'reinmars': []},
 'reinmenschlich': {'reinmenschliche': []},
 'reinmil': {'reinmiller': []},
 'reinmoel': {'reinmoeller': []},
 'reinmol': {'reinmoller': []},
 'reinmuel': {'reinmueller': []},
 'reinmul': {'reinmuller': []},
 'reinncrvat': {'reinncrvation': []},
 'reinnerv': {'reinnervate': ['reinnervated', 'reinnervates'],
              'reinnervating': [],
              'reinnervation': ['reinnervations']},
 'reinnervate': ['reinnervated', 'reinnervates'],
 'reinnervation': ['reinnervations'],
 'reinnov': {'reinnovated': [], 'reinnovation': []},
 'reino': {'reinoes': [], 'reinos': []},
 'reinocul': {'reinoculable': [],
              'reinoculate': ['reinoculates', 'reinoculated'],
              'reinoculating': [],
              'reinoculation': ['reinoculations']},
 'reinoculate': ['reinoculates', 'reinoculated'],
 'reinoculation': ['reinoculations'],
 'reinoi': {'reinois': []},
 'reinold': {'reinolds': []},
 'reinoldu': {'reinoldus': []},
 'reinosuk': {'reinosuke': []},
 'reinot': {'reinote': []},
 'reinov': {'reinoval': [], 'reinove': ['reinoved']},
 'reinove': ['reinoved'],
 'reinovski': {'reinovsky': []},
 'reinput': {'reinputting': []},
 'reinquir': {'reinquire': []},
 'reinquiri': {'reinquiry': []},
 'reinrerpr': {'reinrerprered': []},
 'reinrerpret': {'reinrerpretation': []},
 'reinrroduc': {'reinrroduced': []},
 'reinrroduct': {'reinrroduction': []},
 'reins': {'reinsed': []},
 'reinschk': {'reinschke': []},
 'reinschreib': {'reinschreiber': []},
 'reinscrib': {'reinscribe': ['reinscribed', 'reinscribes'],
               'reinscribing': []},
 'reinscribe': ['reinscribed', 'reinscribes'],
 'reinscript': {'reinscripted': [],
                'reinscription': ['reinscriptions'],
                'reinscriptive': []},
 'reinscription': ['reinscriptions'],
 'reinscrir': {'reinscrire': []},
 'reinscrt': {'reinscrting': []},
 'reinsemin': {'reinseminated': [], 'reinsemination': []},
 'reinser': {'reinserer': []},
 'reinsert': {'reinserted': [],
              'reinserting': [],
              'reinsertion': ['reinsertions'],
              'reinserts': []},
 'reinsertion': ['reinsertions'],
 'reinsfeld': {'reinsfelder': []},
 'reinsinu': {'reinsinuate': ['reinsinuated']},
 'reinsinuate': ['reinsinuated'],
 'reinsist': {'reinsisted': [], 'reinsistence': []},
 'reinslav': {'reinslave': ['reinslaved', 'reinslavement']},
 'reinslave': ['reinslaved', 'reinslavement'],
 'reinsorc': {'reinsorce': ['reinsorced', 'reinsorcement', 'reinsorcements']},
 'reinsorce': ['reinsorced', 'reinsorcement', 'reinsorcements'],
 'reinspect': {'reinspected': [],
               'reinspecting': [],
               'reinspection': ['reinspections'],
               'reinspects': []},
 'reinspection': ['reinspections'],
 'reinspir': {'reinspiration': [],
              'reinspire': ['reinspires', 'reinspired'],
              'reinspiring': []},
 'reinspire': ['reinspires', 'reinspired'],
 'reinspirit': {'reinspirited': [], 'reinspiriting': []},
 'reinst': {'reinste': ['reinstes']},
 'reinstadl': {'reinstadler': []},
 'reinstal': {'reinstall': ['reinstalls',
                            'reinstaller',
                            'reinstalled',
                            'reinstalling',
                            'reinstallment',
                            'reinstallation',
                            'reinstallations'],
              'reinstalment': []},
 'reinstall': ['reinstalls',
               'reinstaller',
               'reinstalled',
               'reinstalling',
               'reinstallment',
               'reinstallation',
               'reinstallations'],
 'reinstamp': {'reinstamped': []},
 'reinstanti': {'reinstantiate': ['reinstantiated', 'reinstantiates'],
                'reinstantiating': [],
                'reinstantiation': ['reinstantiations']},
 'reinstantiate': ['reinstantiated', 'reinstantiates'],
 'reinstantiation': ['reinstantiations'],
 'reinstat': {'reinstatable': [],
              'reinstate': ['reinstated', 'reinstates', 'reinstatement'],
              'reinstating': [],
              'reinstation': [],
              'reinstatment': []},
 'reinstate': ['reinstated', 'reinstates', 'reinstatement'],
 'reinstatl': {'reinstatler': []},
 'reinstaur': {'reinstauration': []},
 'reinste': ['reinstes'],
 'reinstig': {'reinstigate': ['reinstigated'],
              'reinstigating': [],
              'reinstigation': []},
 'reinstigate': ['reinstigated'],
 'reinstil': {'reinstill': ['reinstills',
                            'reinstilled',
                            'reinstilling',
                            'reinstillation']},
 'reinstill': ['reinstills', 'reinstilled', 'reinstilling', 'reinstillation'],
 'reinstin': {'reinstine': []},
 'reinstinctu': {'reinstinctualization': [], 'reinstinctualized': []},
 'reinstirut': {'reinstiruted': []},
 'reinstitut': {'reinstitute': ['reinstituted', 'reinstitutes'],
                'reinstituting': [],
                'reinstitution': ['reinstitutions']},
 'reinstitute': ['reinstituted', 'reinstitutes'],
 'reinstitution': {'reinstitutionalization': [],
                   'reinstitutionalize': ['reinstitutionalizes',
                                          'reinstitutionalized'],
                   'reinstitutionalizing': []},
 'reinstitutionalis': {'reinstitutionalisation': [],
                       'reinstitutionalise': ['reinstitutionalised']},
 'reinstitutionalise': ['reinstitutionalised'],
 'reinstitutionalize': ['reinstitutionalizes', 'reinstitutionalized'],
 'reinstoff': {'reinstoffe': []},
 'reinstruct': {'reinstructed': [],
                'reinstructing': [],
                'reinstruction': [],
                'reinstructs': []},
 'reinstrument': {'reinstrumentation': [],
                  'reinstrumented': [],
                  'reinstrumenting': []},
 'reinststoff': {'reinststoffe': []},
 'reinsuffl': {'reinsufflated': [], 'reinsufflation': []},
 'reinsul': {'reinsulate': ['reinsulated'],
             'reinsulating': [],
             'reinsulation': []},
 'reinsulate': ['reinsulated'],
 'reinsur': {'reinsurance': [],
             'reinsure': ['reinsured',
                          'reinsurer',
                          'reinsures',
                          'reinsureds',
                          'reinsurers'],
             'reinsuring': []},
 'reinsure': ['reinsured',
              'reinsurer',
              'reinsures',
              'reinsureds',
              'reinsurers'],
 'reint': {'reinte': [], 'reints': []},
 'reintcgrat': {'reintcgration': []},
 'reintcrprctat': {'reintcrprctation': []},
 'reintcrpret': {'reintcrpretation': []},
 'reintegr': {'reintegrant': [],
              'reintegrate': ['reintegrates', 'reintegrated'],
              'reintegrating': [],
              'reintegration': ['reintegrations'],
              'reintegrative': ['reintegratively'],
              'reintegrator': [],
              'reintegre': ['reintegrer', 'reintegres']},
 'reintegrado': {'reintegrados': []},
 'reintegramu': {'reintegramus': []},
 'reintegrar': {'reintegrare': []},
 'reintegrars': {'reintegrarse': []},
 'reintegrate': ['reintegrates', 'reintegrated'],
 'reintegration': {'reintegratione': []},
 'reintegrationist': {'reintegrationists': []},
 'reintegrative': ['reintegratively'],
 'reintegrazion': {'reintegrazione': []},
 'reintegre': {'reintegree': []},
 'reintegro': {'reintegros': []},
 'reintellectu': {'reintellectualization': []},
 'reintensif': {'reintensification': []},
 'reintensifi': {'reintensified': [],
                 'reintensifies': [],
                 'reintensify': ['reintensifying']},
 'reintensify': ['reintensifying'],
 'reintepret': {'reintepretation': [], 'reintepreted': []},
 'reinter': {'reinterate': ['reinterated', 'reinterates'],
             'reintered': [],
             'reinterment': ['reinterments'],
             'reinterred': [],
             'reinterring': [],
             'reinters': []},
 'reinteract': {'reinteraction': ['reinteractions']},
 'reinteraction': ['reinteractions'],
 'reinterate': ['reinterated', 'reinterates'],
 'reinterest': {'reinterested': []},
 'reintergr': {'reintergration': []},
 'reinterior': {'reinteriorization': []},
 'reintermedi': {'reintermediate': ['reintermediated'], 'reintermediation': []},
 'reintermediate': ['reintermediated'],
 'reinterment': ['reinterments'],
 'reintern': {'reinternalization': [],
              'reinternalize': ['reinternalized', 'reinternalizes'],
              'reinternalizing': [],
              'reinterned': [],
              'reinternment': []},
 'reinternalize': ['reinternalized', 'reinternalizes'],
 'reinternation': {'reinternationalization': []},
 'reinterpet': {'reinterpetation': [], 'reinterpeted': []},
 'reinterpol': {'reinterpolate': ['reinterpolated'], 'reinterpolation': []},
 'reinterpolate': ['reinterpolated'],
 'reinterpr': {'reinterpre': ['reinterpreation']},
 'reinterprct': {'reinterprctation': ['reinterprctations']},
 'reinterprctation': ['reinterprctations'],
 'reinterpre': ['reinterpreation'],
 'reinterprel': {'reinterprelation': []},
 'reinterprer': {'reinterpreration': []},
 'reinterpret': {'reinterpretability': [],
                 'reinterpretable': [],
                 'reinterpretant': [],
                 'reinterpretated': [],
                 'reinterpretating': [],
                 'reinterpretation': [],
                 'reinterpretative': [],
                 'reinterprete': ['reinterpretes',
                                  'reinterpreted',
                                  'reinterpreter',
                                  'reinterpreters'],
                 'reinterpreting': [],
                 'reinterpretion': [],
                 'reinterpretive': [],
                 'reinterprets': []},
 'reinterpretazion': {'reinterpretazione': []},
 'reinterprete': {'reinterpretee': []},
 'reinterr': {'reinterrment': []},
 'reinterrog': {'reinterrogate': ['reinterrogated'],
                'reinterrogating': [],
                'reinterrogation': ['reinterrogations']},
 'reinterrogate': ['reinterrogated'],
 'reinterrogation': ['reinterrogations'],
 'reinterrupt': {'reinterrupted': []},
 'reinterven': {'reintervene': ['reintervened'], 'reintervening': []},
 'reintervene': ['reintervened'],
 'reintervent': {'reintervention': ['reinterventions']},
 'reintervention': ['reinterventions'],
 'reinterview': {'reinterviewed': [], 'reinterviewing': [], 'reinterviews': []},
 'reintg': {'reintges': []},
 'reinth': {'reinthe': []},
 'reinthal': {'reinthaler': [], 'reinthaller': []},
 'reinthron': {'reinthrone': ['reinthroned']},
 'reinthrone': ['reinthroned'],
 'reintj': {'reintje': ['reintjes']},
 'reintje': ['reintjes'],
 'reinton': {'reintonate': []},
 'reintorc': {'reintorce': ['reintorced',
                            'reintorcers',
                            'reintorcement',
                            'reintorcements'],
              'reintorcing': []},
 'reintorce': ['reintorced', 'reintorcers', 'reintorcement', 'reintorcements'],
 'reintrar': {'reintrare': []},
 'reintrench': {'reintrenched': [], 'reintrenchment': []},
 'reintri': {'reintrie': []},
 'reintroduc': {'reintroduce': ['reintroduced', 'reintroduces'],
                'reintroducing': []},
 'reintroduce': ['reintroduced', 'reintroduces'],
 'reintroduct': {'reintroduction': []},
 'reintroductori': {'reintroductory': []},
 'reintroduet': {'reintroduetion': []},
 'reintroduir': {'reintroduire': []},
 'reintroduit': {'reintroduite': []},
 'reintroduzion': {'reintroduzione': []},
 'reintroject': {'reintrojected': [],
                 'reintrojecting': [],
                 'reintrojection': ['reintrojections'],
                 'reintrojects': []},
 'reintrojection': ['reintrojections'],
 'reintrud': {'reintrude': ['reintruded']},
 'reintrude': ['reintruded'],
 'reintrus': {'reintrusion': []},
 'reintub': {'reintubate': ['reintubated'],
             'reintubating': [],
             'reintubation': ['reintubations']},
 'reintubate': ['reintubated'],
 'reintubation': ['reintubations'],
 'reintzel': {'reintzell': []},
 'reinu': {'reinus': []},
 'reinund': {'reinundated': []},
 'reinvad': {'reinvade': ['reinvades', 'reinvaded'], 'reinvading': []},
 'reinvade': ['reinvades', 'reinvaded'],
 'reinvas': {'reinvasion': ['reinvasions']},
 'reinvasion': ['reinvasions'],
 'reinvent': {'reinventable': [],
              'reinvente': ['reinvented', 'reinventer', 'reinventers'],
              'reinventing': [],
              'reinvention': ['reinventions'],
              'reinventive': [],
              'reinvents': []},
 'reinventar': {'reinventare': []},
 'reinvente': {'reinventee': []},
 'reinvention': ['reinventions'],
 'reinventor': {'reinventors': []},
 'reinventori': {'reinventoried': [],
                 'reinventories': [],
                 'reinventory': ['reinventorying']},
 'reinventory': ['reinventorying'],
 'reinvenzion': {'reinvenzione': []},
 'reinvers': {'reinversion': ['reinversions']},
 'reinversion': ['reinversions'],
 'reinvert': {'reinverted': [], 'reinverting': [], 'reinverts': []},
 'reinvest': {'reinvestable': [],
              'reinvested': [],
              'reinvestible': [],
              'reinvesting': [],
              'reinvestment': ['reinvestments'],
              'reinvests': []},
 'reinvesti': {'reinvestie': [], 'reinvestis': []},
 'reinvestig': {'reinvestigate': ['reinvestigated', 'reinvestigates'],
                'reinvestigating': [],
                'reinvestigation': ['reinvestigations']},
 'reinvestigate': ['reinvestigated', 'reinvestigates'],
 'reinvestigation': ['reinvestigations'],
 'reinvestiss': {'reinvestissement': []},
 'reinvestitur': {'reinvestiture': []},
 'reinvestment': ['reinvestments'],
 'reinvestor': {'reinvestors': []},
 'reinvigor': {'reinvigorate': ['reinvigorated', 'reinvigorates'],
               'reinvigorating': [],
               'reinvigoration': ['reinvigorations'],
               'reinvigorative': [],
               'reinvigorator': [],
               'reinvigorization': []},
 'reinvigorate': ['reinvigorated', 'reinvigorates'],
 'reinvigoration': ['reinvigorations'],
 'reinvigour': {'reinvigourated': []},
 'reinvil': {'reinville': []},
 'reinvis': {'reinvisioned': []},
 'reinvit': {'reinvitation': [],
             'reinvite': ['reinvited', 'reinvites'],
             'reinviting': []},
 'reinvite': ['reinvited', 'reinvites'],
 'reinvoc': {'reinvocation': ['reinvocations']},
 'reinvocation': ['reinvocations'],
 'reinvoic': {'reinvoice': ['reinvoiced'], 'reinvoicing': []},
 'reinvoice': ['reinvoiced'],
 'reinvok': {'reinvoke': ['reinvoked', 'reinvokes'], 'reinvoking': []},
 'reinvoke': ['reinvoked', 'reinvokes'],
 'reinvolut': {'reinvolution': []},
 'reinvolv': {'reinvolve': ['reinvolves',
                            'reinvolved',
                            'reinvolvement',
                            'reinvolvements'],
              'reinvolving': []},
 'reinvolve': ['reinvolves', 'reinvolved', 'reinvolvement', 'reinvolvements'],
 'reinwat': {'reinwater': []},
 'reiny': ['reinys'],
 'reio': {'reios': []},
 'reioh': {'reiohs': []},
 'reioic': {'reioice': ['reioiced'], 'reioicing': ['reioicings']},
 'reioice': ['reioiced'],
 'reioicing': ['reioicings'],
 'reioin': {'reioined': []},
 'reiois': {'reioise': []},
 'reiolut': {'reiolution': []},
 'reiolv': {'reiolve': ['reiolved']},
 'reiolve': ['reiolved'],
 'reion': {'reions': []},
 'reionis': {'reionisation': [], 'reionised': []},
 'reioniz': {'reionization': [], 'reionize': ['reionized'], 'reionizing': []},
 'reionize': ['reionized'],
 'reiorm': {'reiorme': [], 'reiorms': []},
 'reiormat': {'reiormation': []},
 'reiort': {'reiorted': []},
 'reiou': {'reious': []},
 'reiourc': {'reiource': ['reiources']},
 'reiource': ['reiources'],
 'reiov': {'reioved': [], 'reiovs': []},
 'reioyc': {'reioyce': ['reioyced'], 'reioycing': []},
 'reioyce': ['reioyced'],
 'reioys': {'reioyse': ['reioysed'], 'reioysing': []},
 'reioyse': ['reioysed'],
 'reioysing': {'reioysinge': []},
 'reip': {'reipe': [], 'reips': []},
 'reipa': {'reipas': []},
 'reipect': {'reipectable': [],
             'reipected': [],
             'reipecting': [],
             'reipective': ['reipectively'],
             'reipects': []},
 'reipective': ['reipectively'],
 'reipersecutori': {'reipersecutory': []},
 'reipertswil': {'reipertswiller': []},
 'reipiir': {'reipiired': []},
 'reipling': {'reiplinger': []},
 'reipnblica': {'reipnblicae': []},
 'reipons': {'reiponse': [], 'reiponsibility': [], 'reiponsible': []},
 'reiprivata': {'reiprivatae': []},
 'reipschlag': {'reipschlager': []},
 'reipu': {'reipus': []},
 'reipubl': {'reipublic': ['reipublics']},
 'reipublia': {'reipubliae': []},
 'reipublic': {'reipublice': []},
 'reipublica': {'reipublicae': [], 'reipublicas': []},
 'reipublicc': {'reipublicce': []},
 'reipublice': {'reipublicee': []},
 'reipublici': {'reipublicie': []},
 'reipublico': {'reipublicoe': []},
 'reipublicr': {'reipublicre': []},
 'reipublics': {'reipublicse': []},
 'reipublict': {'reipublicte': []},
 'reipubliea': {'reipublieae': []},
 'reipvblic': {'reipvblice': []},
 'reipvblica': {'reipvblicae': []},
 'reiqu': {'reique': []},
 'reir': {'reire': ['reired', 'reires'], 'reiring': [], 'reirs': []},
 'reirain': {'reirained': []},
 'reird': {'reirded': []},
 'reire': ['reired', 'reires'],
 'reirement': {'reirements': []},
 'reirerar': {'reirerare': ['reirerared', 'reirerares']},
 'reirerare': ['reirerared', 'reirerares'],
 'reiriev': {'reirieval': []},
 'reirm': {'reirme': []},
 'reirn': {'reirned': []},
 'reiron': {'reironed': []},
 'reirov': {'reiroved': []},
 'reirradi': {'reirradiate': ['reirradiated'],
              'reirradiating': [],
              'reirradiation': []},
 'reirradiate': ['reirradiated'],
 'reirrig': {'reirrigated': [], 'reirrigation': []},
 'reirs': {'reirse': []},
 'reis': {'reise': ['reised', 'reises', 'reiselied'], 'reising': []},
 'reisach': {'reisacher': []},
 'reisado': {'reisados': []},
 'reisaet': {'reisaeter': []},
 'reisbi': {'reisby': []},
 'reisbureau': {'reisbureaus': []},
 'reisch': {'reische': []},
 'reischan': {'reischaner': []},
 'reischauer': {'reischauers': []},
 'reischi': {'reischies': []},
 'reischl': {'reischle': []},
 'reisd': {'reisde': []},
 'reisdenc': {'reisdence': []},
 'reisdent': {'reisdents': []},
 'reise': ['reised', 'reises', 'reiselied'],
 'reiseabenteu': {'reiseabenteuer': []},
 'reiseanalys': {'reiseanalyse': []},
 'reisebegleit': {'reisebegleiter': []},
 'reisebericht': {'reiseberichte': ['reiseberichtes'], 'reiseberichts': []},
 'reiseberichte': ['reiseberichtes'],
 'reisebiich': {'reisebiicher': []},
 'reisebild': {'reisebilder': []},
 'reisebrief': {'reisebriefe': []},
 'reisebuch': {'reisebucher': []},
 'reiseburo': {'reiseburos': []},
 'reiseck': {'reisecker': []},
 'reiseeindriick': {'reiseeindriicke': []},
 'reiseeindruck': {'reiseeindrucke': []},
 'reiseerlebniss': {'reiseerlebnisse': []},
 'reisefieb': {'reisefieber': []},
 'reisefiihr': {'reisefiihrer': []},
 'reisefuhr': {'reisefuhrer': []},
 'reisejourn': {'reisejournal': []},
 'reisekad': {'reisekader': []},
 'reisekais': {'reisekaiser': []},
 'reisekart': {'reisekarte': []},
 'reisel': {'reisele': []},
 'reiselied': {'reiselieder': []},
 'reiseliu': {'reiselius': []},
 'reisen': {'reisener': [], 'reisens': []},
 'reisenau': {'reisenauer': []},
 'reisenberg': {'reisenberger': []},
 'reisenbichl': {'reisenbichler': []},
 'reisend': {'reisende': ['reisender']},
 'reisende': ['reisender'],
 'reisenegg': {'reisenegger': []},
 'reiseng': {'reisenger': []},
 'reisengebirg': {'reisengebirge': []},
 'reisenhau': {'reisenhauer': []},
 'reisenhof': {'reisenhofer': []},
 'reisenhub': {'reisenhuber': []},
 'reisenleit': {'reisenleiter': []},
 'reisenleitn': {'reisenleitner': []},
 'reisenweb': {'reisenweber': ['reisenwebers']},
 'reisenweber': ['reisenwebers'],
 'reisepredig': {'reiseprediger': []},
 'reiser': {'reiserer': [], 'reisers': []},
 'reiserf': {'reiserfs': []},
 'reiserout': {'reiseroute': []},
 'reisescheck': {'reiseschecks': []},
 'reisetagebiich': {'reisetagebiicher': []},
 'reisetagebuch': {'reisetagebuche': []},
 'reisetasch': {'reisetasche': []},
 'reisett': {'reisetter': []},
 'reiseveranstalt': {'reiseveranstalter': []},
 'reiseverkehr': {'reiseverkehrs': []},
 'reiseweg': {'reisewege': []},
 'reiseziel': {'reiseziele': []},
 'reisfeld': {'reisfelder': []},
 'reisgi': {'reisgies': []},
 'reisgid': {'reisgids': []},
 'reishau': {'reishaus': []},
 'reishi': {'reishis': []},
 'reishl': {'reishling': []},
 'reishu': {'reishus': []},
 'reisi': {'reisie': [], 'reisis': []},
 'reisig': {'reisiger': []},
 'reisim': {'reisimer': []},
 'reisin': {'reisine': [], 'reisins': []},
 'reising': {'reisinger': ['reisingers']},
 'reisinger': ['reisingers'],
 'reisist': {'reisistance': []},
 'reisk': {'reiske': []},
 'reiski': {'reisky': []},
 'reiskiu': {'reiskius': []},
 'reisklei': {'reiskleie': []},
 'reisl': {'reisling': ['reislings']},
 'reislam': {'reislamization': []},
 'reislamis': {'reislamisation': []},
 'reislauf': {'reislaufer': []},
 'reislc': {'reislce': []},
 'reisling': ['reislings'],
 'reisman': {'reismans': []},
 'reismiil': {'reismiiller': []},
 'reismul': {'reismuller': []},
 'reisn': {'reisning': []},
 'reisner': {'reisners': []},
 'reisnerstrass': {'reisnerstrasse': []},
 'reisol': {'reisolate': ['reisolates', 'reisolated'],
            'reisolating': [],
            'reisolation': ['reisolations']},
 'reisolate': ['reisolates', 'reisolated'],
 'reisolation': ['reisolations'],
 'reisomer': {'reisomerization': [], 'reisomerized': []},
 'reison': {'reisonable': [], 'reisons': []},
 'reispflanz': {'reispflanze': []},
 'reisqu': {'reisque': []},
 'reiss': {'reisse': ['reisses'], 'reissing': []},
 'reissau': {'reissaus': []},
 'reissberg': {'reissberger': []},
 'reisse': ['reisses'],
 'reissel': {'reissell': []},
 'reissenberg': {'reissenberger': []},
 'reissend': {'reissende': ['reissender']},
 'reissende': ['reissender'],
 'reissenweb': {'reissenweber': []},
 'reissig': {'reissiger': []},
 'reissing': {'reissinger': []},
 'reissmul': {'reissmuller': []},
 'reissner': {'reissners': []},
 'reisssu': {'reisssued': []},
 'reissu': {'reissue': ['reissued'], 'reissuing': ['reissuings']},
 'reissuabl': {'reissuable': []},
 'reissuanc': {'reissuance': ['reissuances']},
 'reissuance': ['reissuances'],
 'reissue': ['reissued'],
 'reissuing': ['reissuings'],
 'reist': {'reiste': ['reisted'], 'reisting': [], 'reists': []},
 'reistablish': {'reistablishment': []},
 'reistanc': {'reistance': []},
 'reiste': ['reisted'],
 'reistei': {'reisteis': []},
 'reister': {'reisterer': [], 'reisters': []},
 'reistett': {'reistetter': []},
 'reistl': {'reistle': []},
 'reistr': {'reistres': []},
 'reistroff': {'reistroffer': []},
 'reisuk': {'reisuke': []},
 'reisverha': {'reisverhaal': []},
 'reisweb': {'reisweber': []},
 'reit': ['reite', 'reited', 'reites', 'reiting'],
 'reita': {'reitas': []},
 'reitberg': {'reitberger': []},
 'reitel': {'reitell': []},
 'reitemei': {'reitemeier': []},
 'reitemey': {'reitemeyer': []},
 'reitenau': {'reitenauer': []},
 'reitend': {'reitende': []},
 'reitenfel': {'reitenfels': []},
 'reiter': ['reitere',
            'reitered',
            'reiterer',
            'reiteres',
            'reiterate',
            'reiterant',
            'reiterator',
            'reiterated',
            'reiterates',
            'reiterable',
            'reiterance',
            'reiteration',
            'reiterating',
            'reitereated',
            'reiterators',
            'reiterative',
            'reiterability',
            'reiteratively',
            'reiterativeness'],
 'reiteracion': {'reiteraciones': []},
 'reiterada': {'reiteradas': []},
 'reiteradament': {'reiteradamente': []},
 'reiterado': {'reiterados': []},
 'reiterantli': {'reiterantly': []},
 'reiterar': {'reiterare': []},
 'reiterarl': {'reiterarle': []},
 'reiteratament': {'reiteratamente': []},
 'reiteratedli': {'reiteratedly': []},
 'reiteratingli': {'reiteratingly': []},
 'reiterazion': {'reiterazione': []},
 'reiterdenkm': {'reiterdenkmal': []},
 'reitere': {'reiteree': ['reiterees']},
 'reiteree': ['reiterees'],
 'reitergass': {'reitergasse': []},
 'reitergeschicht': {'reitergeschichte': []},
 'reitergott': {'reitergottes': []},
 'reiterkrabb': {'reiterkrabbe': []},
 'reiterli': {'reiterlied': []},
 'reiteron': {'reiterons': []},
 'reiterr': {'reiterrated': []},
 'reiterspiel': {'reiterspiele': []},
 'reiterstandbild': {'reiterstandbilder': []},
 'reiterstatu': {'reiterstatue': []},
 'reitest': {'reiteste': []},
 'reith': {'reithe': [], 'reiths': []},
 'reithal': {'reithalle': []},
 'reithian': {'reithianism': [], 'reithians': []},
 'reithing': {'reithinger': []},
 'reithlingshoef': {'reithlingshoefer': []},
 'reithmay': {'reithmayer': []},
 'reithmey': {'reithmeyer': []},
 'reithmil': {'reithmiller': []},
 'reithmul': {'reithmuller': []},
 'reithof': {'reithofer': []},
 'reithoff': {'reithoffer': []},
 'reithrodontomi': {'reithrodontomys': []},
 'reithroparami': {'reithroparamys': []},
 'reiti': {'reity': []},
 'reitic': {'reitication': []},
 'reiting': {'reitinger': []},
 'reition': {'reitions': []},
 'reitli': {'reitly': []},
 'reitling': {'reitlinger': []},
 'reitman': {'reitmans': []},
 'reitmay': {'reitmayer': []},
 'reitmeij': {'reitmeijer': []},
 'reitmeist': {'reitmeister': []},
 'reitmey': {'reitmeyer': []},
 'reitor': {'reitore': ['reitored', 'reitores']},
 'reitore': ['reitored', 'reitores'],
 'reitpferd': {'reitpferde': []},
 'reitr': {'reitre': ['reitres', 'reitred']},
 'reitrag': {'reitrage': []},
 'reitrat': {'reitrate': ['reitrated']},
 'reitrate': ['reitrated'],
 'reitre': ['reitres', 'reitred'],
 'reitrict': {'reitricted': [], 'reitrictions': []},
 'reitriig': {'reitriige': []},
 'reitrv': {'reitrved': []},
 'reitsam': {'reitsamer': []},
 'reitschul': {'reitschule': []},
 'reitschulgass': {'reitschulgasse': []},
 'reitsperg': {'reitsperger': []},
 'reitstott': {'reitstotter': []},
 'reitter': {'reitterated': [], 'reitterer': []},
 'reitti': {'reittie': [], 'reitty': []},
 'reittier': {'reittiere': []},
 'reitting': {'reittinger': []},
 'reitumets': {'reitumetse': []},
 'reitwiesn': {'reitwiesner': []},
 'reitz': {'reitze': ['reitzes']},
 'reitzamm': {'reitzammer': []},
 'reitze': ['reitzes'],
 'reitzel': {'reitzell': [], 'reitzels': []},
 'reitziu': {'reitzius': []},
 'reitzl': {'reitzle': []},
 'reiu': {'reius': []},
 'reiuc': {'reiuced': []},
 'reiuctanc': {'reiuctance': []},
 'reiuforc': {'reiuforce': ['reiuforced', 'reiuforcement', 'reiuforcements']},
 'reiuforce': ['reiuforced', 'reiuforcement', 'reiuforcements'],
 'reiug': {'reiuge': []},
 'reiuge': {'reiugees': []},
 'reiuir': {'reiuired': []},
 'reiult': {'reiulted': [], 'reiulting': [], 'reiults': []},
 'reium': {'reiumed': []},
 'reiurn': {'reiurned': [], 'reiurning': [], 'reiurns': []},
 'reiurrect': {'reiurrection': []},
 'reius': {'reiuse': ['reiuses', 'reiused'], 'reiusing': []},
 'reiuse': ['reiuses', 'reiused'],
 'reiv': {'reive': ['reives', 'reived'], 'reiving': ['reivings']},
 'reivar': {'reivars': []},
 'reivard': {'reivards': []},
 'reive': ['reives', 'reived'],
 'reiver': {'reivers': []},
 'reivew': {'reivewed': [], 'reivews': []},
 'reivind': {'reivindication': []},
 'reivindicacion': {'reivindicaciones': []},
 'reivindicaco': {'reivindicacoes': []},
 'reiving': ['reivings'],
 'reivlut': {'reivlution': []},
 'reiw': {'reiwe': ['reiwed']},
 'reiwcat': {'reiwcation': []},
 'reiwe': ['reiwed'],
 'reiwlut': {'reiwlution': []},
 'reiwrt': {'reiwrted': [], 'reiwrts': []},
 'reiy': {'reiying': []},
 'reiz': {'reize': ['reizes', 'reized']},
 'reizbar': {'reizbare': ['reizbarer']},
 'reizbare': ['reizbarer'],
 'reizbiologisch': {'reizbiologische': []},
 'reize': ['reizes', 'reized'],
 'reizend': {'reizende': ['reizendes', 'reizender']},
 'reizende': ['reizendes', 'reizender'],
 'reizi': {'reizis': []},
 'reizig': {'reiziger': ['reizigers']},
 'reiziger': ['reizigers'],
 'reizin': {'reizine': []},
 'reiziu': {'reizius': []},
 'reizleitend': {'reizleitende': []},
 'reizleitungssystem': {'reizleitungssystems': []},
 'reizleitungsvorgang': {'reizleitungsvorgange': []},
 'reizlo': {'reizlos': []},
 'reizmetrisch': {'reizmetrische': []},
 'reizmust': {'reizmuster': []},
 'reizparamet': {'reizparameter': []},
 'reizphysiologi': {'reizphysiologie': []},
 'reizphysiologisch': {'reizphysiologische': []},
 'reizquel': {'reizquelle': []},
 'reizschwel': {'reizschwelle': []},
 'reizsitu': {'reizsituation': []},
 'reizstark': {'reizstarke': []},
 'reizstoff': {'reizstoffe': []},
 'reizt': {'reizte': []},
 'reizversuch': {'reizversuche': []},
 'reizvol': {'reizvoll': ['reizvolle', 'reizvoller', 'reizvolles']},
 'reizvoll': ['reizvolle', 'reizvoller', 'reizvolles'],
 'reizwert': {'reizwertes': []},
 'rej': {'rejative': ['rejatively'], 'rejs': []},
 'reja': {'rejas': []},
 'rejacket': {'rejacketed': []},
 'rejai': {'rejaie': []},
 'rejail': {'rejailed': []},
 'rejailliss': {'rejaillisse': ['rejaillissent']},
 'rejaillisse': ['rejaillissent'],
 'rejal': {'rejall': []},
 'rejam': {'rejames': []},
 'rejan': {'rejane': [], 'rejans': []},
 'rejang': {'rejangs': []},
 'rejat': {'rejate': ['rejated'], 'rejating': [], 'rejation': ['rejations']},
 'rejate': ['rejated'],
 'rejation': ['rejations'],
 'rejationship': {'rejationships': []},
 'rejative': ['rejatively'],
 'rejaul': {'rejaule': []},
 'rejct': {'rejcted': []},
 'reje': {'rejed': [], 'rejes': []},
 'rejeann': {'rejeanne': []},
 'rejeas': {'rejease': []},
 'rejeb': {'rejebed': []},
 'rejec': {'rejeced': []},
 'rejeci': {'rejecied': []},
 'rejeciss': {'rejecisse': []},
 'rejecl': {'rejecled': [], 'rejecling': [], 'rejecls': []},
 'rejecr': {'rejecred': [], 'rejecrs': []},
 'reject': ['rejecte',
            'rejectes',
            'rejected',
            'rejecter',
            'rejecters',
            'rejecting',
            'rejectful',
            'rejection',
            'rejective',
            'rejectant',
            'rejectings',
            'rejectible',
            'rejectment',
            'rejectance',
            'rejectable',
            'rejectivity',
            'rejectables',
            'rejectional',
            'rejectability'],
 'rejecta': {'rejectas': []},
 'rejectag': {'rejectage': []},
 'rejectan': {'rejectaneous': []},
 'rejectchang': {'rejectchanges': []},
 'rejecte': {'rejectee': ['rejectees']},
 'rejected': {'rejectedness': []},
 'rejectedbi': {'rejectedby': []},
 'rejectedth': {'rejectedthe': []},
 'rejectee': ['rejectees'],
 'rejectf': {'rejectfed': []},
 'rejecti': {'rejectiou': [], 'rejectis': []},
 'rejectingli': {'rejectingly': []},
 'rejectingth': {'rejectingthe': []},
 'rejection': {'rejectionable': [],
               'rejectione': ['rejectiones'],
               'rejectionism': []},
 'rejectionaccept': {'rejectionacceptance': []},
 'rejectionari': {'rejectionary': []},
 'rejectione': ['rejectiones'],
 'rejectioni': {'rejectionis': []},
 'rejectionist': {'rejectionists': []},
 'rejectionsensit': {'rejectionsensitive': []},
 'rejector': {'rejectors': []},
 'rejectori': {'rejectory': []},
 'rejectsth': {'rejectsthe': []},
 'rejectt': {'rejecttion': []},
 'rejectth': {'rejectthe': []},
 'rejectu': {'rejectus': []},
 'rejed': {'rejeded': []},
 'rejedt': {'rejedted': []},
 'rejeet': {'rejeeted': [], 'rejeeting': [], 'rejeetion': [], 'rejeets': []},
 'rejefl': {'rejefled': []},
 'rejeft': {'rejefted': [], 'rejefts': []},
 'rejeil': {'rejeiled': []},
 'rejeot': {'rejeoted': [], 'rejeoting': [], 'rejeotion': [], 'rejeots': []},
 'rejer': {'rejerence': ['rejerences'], 'rejerred': []},
 'rejerence': ['rejerences'],
 'rejero': {'rejeros': []},
 'rejert': {'rejerted': []},
 'rejes': {'rejesed': []},
 'rejesl': {'rejesled': []},
 'rejest': {'rejested': []},
 'rejestrowan': {'rejestrowane': []},
 'rejesu': {'rejesus': []},
 'rejet': {'rejetant': [],
           'rejete': ['rejeted', 'rejetes', 'rejeter'],
           'rejets': [],
           'rejetted': [],
           'rejetting': []},
 'rejetai': {'rejetaient': []},
 'rejete': {'rejetee': ['rejetees']},
 'rejetee': ['rejetees'],
 'rejeter': {'rejeterent': []},
 'rejetl': {'rejetled': []},
 'rejeton': {'rejetons': []},
 'rejett': {'rejettant': [], 'rejette': ['rejettes', 'rejetter', 'rejettent']},
 'rejette': {'rejettee': ['rejettees']},
 'rejettee': ['rejettees'],
 'rejetteron': {'rejetterons': []},
 'rejetton': {'rejettons': []},
 'rejeuniss': {'rejeunissement': []},
 'rejgn': {'rejgned': [], 'rejgns': []},
 'reji': {'rejied': [], 'rejy': []},
 'rejic': {'rejice': ['rejiced']},
 'rejice': ['rejiced'],
 'rejicer': {'rejicere': ['rejicerent']},
 'rejicere': ['rejicerent'],
 'rejici': {'rejiciant': []},
 'rejicia': {'rejicias': []},
 'rejiciamu': {'rejiciamus': []},
 'rejicien': {'rejiciens': []},
 'rejicienda': {'rejiciendae': [], 'rejiciendas': []},
 'rejiciendi': {'rejiciendis': []},
 'rejiciendu': {'rejiciendus': []},
 'rejicient': {'rejicientes': []},
 'rejicimu': {'rejicimus': []},
 'rejicit': {'rejicite': []},
 'rejid': {'rejide': []},
 'rejidor': {'rejidores': []},
 'rejieat': {'rejieated': []},
 'rejieatedli': {'rejieatedly': []},
 'rejiev': {'rejieve': []},
 'rejig': {'rejigged': [], 'rejigging': [], 'rejigs': []},
 'rejigg': {'rejigger': ['rejiggers', 'rejiggered', 'rejiggering']},
 'rejigger': ['rejiggers', 'rejiggered', 'rejiggering'],
 'rejigi': {'rejigious': []},
 'rejigur': {'rejiguring': []},
 'rejilla': {'rejillas': []},
 'rejim': {'rejime': []},
 'rejin': {'rejined': []},
 'rejion': {'rejions': []},
 'rejior': {'rejiore': []},
 'rejiort': {'rejiorted': [], 'rejiorts': []},
 'rejji': {'rejjy': []},
 'rejjort': {'rejjorted': []},
 'rejl': {'rejled': []},
 'rejland': {'rejlander': []},
 'rejlect': {'rejlected': [], 'rejlection': ['rejlections'], 'rejlects': []},
 'rejlection': ['rejlections'],
 'rejlor': {'rejloration': [], 'rejlore': ['rejlored'], 'rejloring': []},
 'rejlore': ['rejlored'],
 'rejnain': {'rejnained': [], 'rejnains': []},
 'rejnark': {'rejnarkable': []},
 'rejnemb': {'rejnember': []},
 'rejni': {'rejnis': []},
 'rejnov': {'rejnoved': []},
 'rejo': {'rejos': []},
 'rejoc': {'rejoce': [], 'rejocing': []},
 'rejoct': {'rejocted': [], 'rejoction': []},
 'rejoi': {'rejoieing': ['rejoieings'], 'rejois': []},
 'rejoib': {'rejoibings': []},
 'rejoic': {'rejoice': ['rejoiced',
                        'rejoicer',
                        'rejoices',
                        'rejoicers',
                        'rejoiceful',
                        'rejoiceing',
                        'rejoicement',
                        'rejoicefully',
                        'rejoicements'],
            'rejoicing': []},
 'rejoice': ['rejoiced',
             'rejoicer',
             'rejoices',
             'rejoicers',
             'rejoiceful',
             'rejoiceing',
             'rejoicement',
             'rejoicefully',
             'rejoicements'],
 'rejoicingli': {'rejoicingly': []},
 'rejoie': {'rejoiee': ['rejoieed']},
 'rejoiee': ['rejoieed'],
 'rejoieing': ['rejoieings'],
 'rejoign': {'rejoignant': [], 'rejoigne': ['rejoignent']},
 'rejoignai': {'rejoignaient': []},
 'rejoigne': ['rejoignent'],
 'rejoigni': {'rejoignis': []},
 'rejoignim': {'rejoignimes': []},
 'rejoignir': {'rejoignirent': []},
 'rejoignon': {'rejoignons': []},
 'rejoin': {'rejoined': [],
            'rejoiner': ['rejoiners'],
            'rejoining': ['rejoinings'],
            'rejoins': []},
 'rejoind': {'rejoinded': [], 'rejoinder': ['rejoindered']},
 'rejoinder': ['rejoindered'],
 'rejoindr': {'rejoindre': []},
 'rejoindron': {'rejoindrons': []},
 'rejoindur': {'rejoindure': []},
 'rejoiner': ['rejoiners'],
 'rejoining': ['rejoinings'],
 'rejoint': {'rejointe': ['rejointes', 'rejointed'],
             'rejointing': [],
             'rejoints': []},
 'rejointe': ['rejointes', 'rejointed'],
 'rejoio': {'rejoioe': ['rejoioed'], 'rejoioing': ['rejoioings']},
 'rejoioe': ['rejoioed'],
 'rejoioing': ['rejoioings'],
 'rejois': {'rejoise': ['rejoised'], 'rejoising': []},
 'rejoise': ['rejoised'],
 'rejoiu': {'rejoiued': []},
 'rejojc': {'rejojce': []},
 'rejollada': {'rejolladas': []},
 'rejolv': {'rejolved': []},
 'rejom': {'rejomed': []},
 'rejon': {'rejones': []},
 'rejoneador': {'rejoneadores': [], 'rejoneadors': []},
 'rejoni': {'rejonie': [], 'rejony': []},
 'rejooc': {'rejooced': []},
 'rejorm': {'rejormation': [], 'rejorme': [], 'rejorms': []},
 'rejort': {'rejorted': []},
 'rejos': {'rejose': []},
 'rejossyng': {'rejossynge': []},
 'rejou': {'rejoue': []},
 'rejoui': {'rejouie': [], 'rejouis': []},
 'rejouir': {'rejouirent': []},
 'rejouiss': {'rejouissance': ['rejouissances'],
              'rejouissant': [],
              'rejouisse': ['rejouissent']},
 'rejouissai': {'rejouissaient': [], 'rejouissais': []},
 'rejouissance': ['rejouissances'],
 'rejouissant': {'rejouissante': []},
 'rejouisse': ['rejouissent'],
 'rejouisson': {'rejouissons': []},
 'rejourn': {'rejourned': []},
 'rejoy': {'rejoys': []},
 'rejoyc': {'rejoyce': ['rejoyced', 'rejoyces', 'rejoyceing'],
            'rejoycing': ['rejoycings']},
 'rejoyce': ['rejoyced', 'rejoyces', 'rejoyceing'],
 'rejoycing': {'rejoycinge': []},
 'rejoyn': {'rejoyne': ['rejoyned']},
 'rejoynd': {'rejoynder': ['rejoynders']},
 'rejoynder': ['rejoynders'],
 'rejoyne': ['rejoyned'],
 'rejoys': {'rejoyse': ['rejoysed'], 'rejoysing': []},
 'rejoyse': ['rejoysed'],
 'rejp': {'rejpe': []},
 'rejpic': {'rejpice': []},
 'rejram': {'rejraming': []},
 'rejs': {'rejse': []},
 'rejst': {'rejste': []},
 'rejuc': {'rejuce': ['rejuced']},
 'rejuce': ['rejuced'],
 'rejud': {'rejudiced': []},
 'rejuda': {'rejudaization': []},
 'rejudg': {'rejudge': ['rejudged', 'rejudges'],
            'rejudging': [],
            'rejudgment': []},
 'rejudge': ['rejudged', 'rejudges'],
 'rejudic': {'rejudice': ['rejudices']},
 'rejudice': ['rejudices'],
 'rejudici': {'rejudicial': []},
 'rejug': {'rejuge': []},
 'rejuge': {'rejugee': ['rejugees']},
 'rejugee': ['rejugees'],
 'rejuggl': {'rejuggle': ['rejuggled'], 'rejuggling': []},
 'rejuggle': ['rejuggled'],
 'rejuic': {'rejuice': ['rejuiced']},
 'rejuice': ['rejuiced'],
 'rejuir': {'rejuire': ['rejuired']},
 'rejuire': ['rejuired'],
 'rejuli': {'rejuly': []},
 'rejun': {'rejune': []},
 'rejunct': {'rejunction': []},
 'rejus': {'rejuse': ['rejused'], 'rejusing': []},
 'rejuse': ['rejused'],
 'rejustif': {'rejustification': []},
 'rejustifi': {'rejustified': [],
               'rejustifies': [],
               'rejustify': ['rejustifying']},
 'rejustify': ['rejustifying'],
 'rejut': {'rejutation': []},
 'rejuv': {'rejuve': []},
 'rejuven': {'rejuvenance': [],
             'rejuvenant': ['rejuvenants'],
             'rejuvenate': ['rejuvenated', 'rejuvenates'],
             'rejuvenating': [],
             'rejuvenation': [],
             'rejuvenative': ['rejuvenatives'],
             'rejuvenator': ['rejuvenators'],
             'rejuvenization': [],
             'rejuvenize': ['rejuvenized'],
             'rejuvenizing': []},
 'rejuvenant': ['rejuvenants'],
 'rejuvenate': ['rejuvenated', 'rejuvenates'],
 'rejuvenative': ['rejuvenatives'],
 'rejuvenator': ['rejuvenators'],
 'rejuvenatori': {'rejuvenatory': []},
 'rejuvenec': {'rejuvenecer': []},
 'rejuvenesc': {'rejuvenesce': ['rejuvenesced',
                                'rejuvenescent',
                                'rejuvenescency',
                                'rejuvenescence',
                                'rejuvenescences'],
                'rejuvenescing': []},
 'rejuvenesce': ['rejuvenesced',
                 'rejuvenescent',
                 'rejuvenescency',
                 'rejuvenescence',
                 'rejuvenescences'],
 'rejuvenis': {'rejuvenised': []},
 'rejuvenisc': {'rejuveniscence': []},
 'rejuvenize': ['rejuvenized'],
 'rejuvent': {'rejuventated': [], 'rejuventation': [], 'rejuvention': []},
 'rejuvin': {'rejuvinate': ['rejuvinated', 'rejuvinates'],
             'rejuvinating': [],
             'rejuvination': []},
 'rejuvinate': ['rejuvinated', 'rejuvinates'],
 'rejwrt': {'rejwrted': [], 'rejwrts': []},
 'rek': {'reks': []},
 "rek's": {"rek'se": []},
 'reka': {'rekas': []},
 'rekabit': {'rekabites': []},
 'rekal': {'rekall': []},
 'rekald': {'rekalde': []},
 'rekanalis': {'rekanalisation': []},
 'rekap': {'rekapalli': []},
 'rekapal': {'rekapalle': []},
 'rekapitul': {'rekapitulation': []},
 'rekarn': {'rekarne': []},
 'rekas': {'rekase': ['rekased']},
 'rekase': ['rekased'],
 'rekasiu': {'rekasius': []},
 'rekat': {'rekate': []},
 'reke': {'reked': [], 'rekes': [], 'reking': []},
 'reked': {'rekedal': []},
 'rekel': {'rekeles': []},
 'rekemey': {'rekemeyer': []},
 'rekemmend': {'rekemmended': []},
 'reken': {'rekene': ['rekened'], 'rekening': ['rekenings']},
 'rekene': ['rekened'],
 'rekening': {'rekeninge': ['rekeninges']},
 'rekeninge': ['rekeninges'],
 'rekenkam': {'rekenkamer': []},
 'rekenmachin': {'rekenmachine': []},
 'rekenthal': {'rekenthaler': []},
 'rekenyng': {'rekenynge': ['rekenynges']},
 'rekenynge': ['rekenynges'],
 'reker': {'rekers': []},
 'rekey': {'rekeyed': [], 'rekeying': ['rekeyings'], 'rekeys': []},
 'rekeyboard': {'rekeyboarded': [], 'rekeyboarding': []},
 'rekeying': ['rekeyings'],
 'rekgiou': {'rekgious': []},
 'rekh': {'rekhe': ['rekhes'], 'rekhs': []},
 'rekha': {'rekhas': []},
 'rekhe': ['rekhes'],
 'rekhmar': {'rekhmare': []},
 'rekhmer': {'rekhmere': []},
 'rekhmir': {'rekhmire': []},
 'rekhta': {'rekhtas': []},
 'reki': {'rekis': [], 'reky': []},
 'rekil': {'rekill': ['rekilled', 'rekilling']},
 'rekill': ['rekilled', 'rekilling'],
 'rekindl': {'rekindle': ['rekindled', 'rekindles', 'rekindler'],
             'rekindling': ['rekindlings']},
 'rekindle': ['rekindled', 'rekindles', 'rekindler'],
 'rekindling': ['rekindlings'],
 'rekiss': {'rekissed': []},
 'rekit': {'rekitted': []},
 'rekiv': {'rekivered': []},
 'rekk': {'rekke': []},
 'rekka': {'rekkas': []},
 'rekked': {'rekkedal': []},
 'rekkefolg': {'rekkefolge': []},
 'rekkel': {'rekkeles': []},
 'rekker': {'rekkers': []},
 'rekl': {'rekles': [], 'rekling': []},
 'reklaiti': {'reklaitis': []},
 'reklam': {'reklamation': [], 'reklame': []},
 'reklami': {'reklamy': []},
 'reklamiert': {'reklamierte': []},
 'rekleiti': {'rekleitis': []},
 'rekli': {'reklis': []},
 'rekmir': {'rekmire': []},
 'rekn': {'rekne': ['rekned'], 'rekning': []},
 'rekne': ['rekned'],
 'reknead': {'rekneaded': [], 'rekneading': []},
 'reknit': {'reknits': [], 'reknitted': [], 'reknitting': []},
 'reknot': {'reknots': [], 'reknotted': [], 'reknotting': []},
 'reknow': {'reknowing': []},
 'reknowledg': {'reknowledge': []},
 'reknown': {'reknowned': []},
 'reko': {'rekos': []},
 'rekognosc': {'rekognoscering': []},
 'rekombin': {'rekombination': []},
 'rekommend': {'rekommendation': []},
 'rekommendation': {'rekommendationer': []},
 'rekommendera': {'rekommenderas': []},
 'rekommenderad': {'rekommenderade': []},
 'rekon': {'rekoned': [], 'rekoning': ['rekonings']},
 'rekonesan': {'rekonesans': []},
 'rekoning': ['rekonings'],
 'rekonstitut': {'rekonstitution': []},
 'rekonstruct': {'rekonstruction': []},
 'rekonstruer': {'rekonstruere': []},
 'rekonstruierbar': {'rekonstruierbare': []},
 'rekonstruierend': {'rekonstruierende': []},
 'rekonstruiert': {'rekonstruierte': ['rekonstruierter']},
 'rekonstruierte': ['rekonstruierter'],
 'rekonstrukt': {'rekonstruktion': ['rekonstruktions'], 'rekonstruktive': []},
 'rekonstruktion': {'rekonstruktioner': []},
 'rekonstruktionsperiod': {'rekonstruktionsperiode': []},
 'rekonstruktionsversuch': {'rekonstruktionsversuche': []},
 'rekopi': {'rekopis': []},
 'rekopisi': {'rekopisy': []},
 'rekord': {'rekorde': [], 'rekords': []},
 'rekosk': {'rekoske': []},
 'rekowski': {'rekowsky': []},
 'rekreat': {'rekreation': []},
 'rekristallis': {'rekristallisation': []},
 'rekrut': {'rekrutering': []},
 'rekrutiert': {'rekrutierte': []},
 'rekrutierungsmust': {'rekrutierungsmuster': []},
 'rekrutt': {'rekruttering': []},
 'rekryt': {'rekrytering': []},
 'rekstad': {'rekstads': []},
 'rekt': {'rekte': ['rekted', 'rektes'], 'rekting': []},
 'rektal': {'rektale': ['rektaler']},
 'rektale': ['rektaler'],
 'rekte': ['rekted', 'rektes'],
 'rektifik': {'rektifikation': []},
 'rektion': {'rektions': []},
 'rektionship': {'rektionships': []},
 'rektiv': {'rektive': ['rektives', 'rektively']},
 'rektive': ['rektives', 'rektively'],
 'rektor': {'rektorates': [], 'rektors': []},
 'rektorat': {'rektorats': []},
 'rektoratsfei': {'rektoratsfeier': []},
 'rektoratsred': {'rektoratsrede': []},
 'rektori': {'rektorys': []},
 'rektum': {'rektums': []},
 'rektumkarzinom': {'rektumkarzinoms': []},
 'reku': {'rekus': []},
 'rekur': {'rekurs': []},
 'rekurrent': {'rekurrente': []},
 'rekurrierend': {'rekurrierende': []},
 'rekurs': {'rekurses': [], 'rekursion': [], 'rekursive': []},
 'rekursiv': {'rekursiver': []},
 'rekv': {'rekve': []},
 'rekyl': {'rekyle': []},
 'rel': {'relative': ['relatively', 'relativeness'],
         'relativiti': [],
         'relativity': [],
         'rels': []},
 "rel'": {"rel'e": []},
 "rel'l": {"rel'le": []},
 "rel'si": {"rel'sy": []},
 'rela': {'relae': ['relaed', 'relaely'], 'relaing': [], 'relas': []},
 "rela'": {"rela'ed": []},
 'relaa': {'relaas': []},
 'relabel': {'relabeled': [],
             'relabelers': [],
             'relabeling': ['relabelings'],
             'relabelled': [],
             'relabelling': ['relabellings'],
             'relabels': []},
 'relabeling': ['relabelings'],
 'relabelling': ['relabellings'],
 'relabl': {'relability': [], 'relable': ['relabled']},
 'relable': ['relabled'],
 'relac': {'relace': ['relaces', 'relaced', 'relacement'],
           'relacing': [],
           'relacive': [],
           'relacs': []},
 'relaccion': {'relacciones': []},
 'relacd': {'relacdes': []},
 'relace': ['relaces', 'relaced', 'relacement'],
 'relach': {'relachant': [],
            'relache': ['relacher', 'relaches', 'relachent', 'relachement']},
 'relache': {'relachee': ['relachees']},
 'relachee': ['relachees'],
 'relachemen': {'relachemens': []},
 'relacidn': {'relacidnes': []},
 'relacij': {'relacije': []},
 'relacion': {'relacional': [], 'relacione': ['relaciones'], 'relacions': []},
 'relacionada': {'relacionadas': []},
 'relacionado': {'relacionados': []},
 'relacional': {'relacionales': []},
 'relacionamo': {'relacionamos': []},
 'relacionarm': {'relacionarme': []},
 'relacionars': {'relacionarse': []},
 'relacionc': {'relacioncs': []},
 'relacione': ['relaciones'],
 'relacj': {'relacje': []},
 'relaclon': {'relaclones': []},
 'relaco': {'relacoes': []},
 'relacon': {'relacons': []},
 'relacp': {'relacpes': []},
 'relacqu': {'relacquer': ['relacquered', 'relacquering']},
 'relacquer': ['relacquered', 'relacquering'],
 'relacs': {'relacses': []},
 'relact': {'relactate': [], 'relactating': [], 'relactation': []},
 'relacton': {'relactones': [], 'relactonization': []},
 'relacy': {'relacye': []},
 'relad': {'relade': ['reladed'], 'relading': []},
 'relade': ['reladed'],
 'reladl': {'reladling': []},
 'reladon': {'reladones': [], 'reladons': []},
 'reladonship': {'reladonships': []},
 'reladv': {'reladve': ['reladves', 'reladvely']},
 'reladve': ['reladves', 'reladvely'],
 'relae': ['relaed', 'relaely'],
 'relaeion': {'relaeiones': []},
 'relaes': {'relaese': ['relaesed']},
 'relaese': ['relaesed'],
 'relaf': {'relafed': [], 'relafive': ['relafively']},
 'relafd': {'relafdes': []},
 'relafiil': {'relafiile': []},
 'relafion': {'relafions': []},
 'relafionship': {'relafionships': []},
 'relafive': ['relafively'],
 'relafo': {'relafoes': []},
 'relag': {'relagated': [], 'relagating': []},
 'relago': {'relagoes': []},
 'relai': {'relaie': ['relaied'], 'relaiing': [], 'relais': [], 'relay': []},
 'relaiabl': {'relaiable': []},
 'relaibl': {'relaibility': [], 'relaible': []},
 'relaie': ['relaied'],
 'relaiif': {'relaiifs': []},
 'relaiion': {'relaiions': []},
 'relaiionship': {'relaiionships': []},
 'relaiiv': {'relaiive': ['relaiives', 'relaiively']},
 'relaiive': ['relaiives', 'relaiively'],
 'relaiivist': {'relaiivistic': []},
 'relain': {'relained': [], 'relaining': [], 'relains': []},
 'relainc': {'relaince': []},
 'relaion': {'relaions': []},
 'relaionship': {'relaionships': []},
 'relais': {'relaised': []},
 'relaist': {'relaistic': []},
 'relait': {'relaited': [], 'relaiting': []},
 'relaiti': {'relaities': [], 'relaity': []},
 'relaiton': {'relaitons': []},
 'relaitonship': {'relaitonships': []},
 'relaitv': {'relaitvely': []},
 'relaiv': {'relaive': ['relaives', 'relaively']},
 'relaive': ['relaives', 'relaively'],
 'relaiz': {'relaization': [], 'relaize': ['relaized']},
 'relaize': ['relaized'],
 'relaj': {'relaje': []},
 'relajado': {'relajados': []},
 'relajant': {'relajante': []},
 'relajars': {'relajarse': []},
 'relal': {'relalation': ['relalations'],
           'relalative': [],
           'relale': ['relales', 'relaled'],
           'relaling': [],
           'relality': [],
           'relalive': ['relalives', 'relalively']},
 'relalation': ['relalations'],
 'relalationship': {'relalationships': []},
 'relale': ['relales', 'relaled'],
 'relaled': {'relaledness': []},
 'relali': {'relaly': []},
 'relalif': {'relalifs': []},
 'relalion': {'relalions': []},
 'relalionship': {'relalionships': []},
 'relalive': ['relalives', 'relalively'],
 'relalivist': {'relalivistic': []},
 'relam': {'relamation': [], 'relams': []},
 'relamin': {'relaminated': [], 'relaminating': [], 'relamination': []},
 'relaminar': {'relaminarization': [],
               'relaminarize': ['relaminarized'],
               'relaminarizing': []},
 'relaminaris': {'relaminarisation': []},
 'relaminarize': ['relaminarized'],
 'relamp': {'relamped': [], 'relamping': ['relampings']},
 'relampago': {'relampagos': []},
 'relamping': ['relampings'],
 'relan': {'relans': []},
 'relanc': {'relance': ['relances', 'relancer', 'relancent']},
 'relance': {'relancee': []},
 'reland': {'relanded': [], 'relander': [], 'relanding': [], 'relands': []},
 'relandscap': {'relandscape': ['relandscaped'], 'relandscaping': []},
 'relandscape': ['relandscaped'],
 'relandu': {'relandus': []},
 'relanguag': {'relanguaging': []},
 'relanguescer': {'relanguescere': []},
 'relanon': {'relanons': []},
 'relanonship': {'relanonships': []},
 'relanv': {'relanve': ['relanvely']},
 'relanve': ['relanvely'],
 'relaon': {'relaons': []},
 'relaonship': {'relaonships': []},
 'relap': {'relapped': [], 'relapping': [], 'relaps': []},
 'relaparotomi': {'relaparotomies': [], 'relaparotomy': []},
 'relapf': {'relapfe': ['relapfed', 'relapfes'], 'relapfing': []},
 'relapfe': ['relapfed', 'relapfes'],
 'relaps': {'relapse': ['relapsed', 'relapser', 'relapsers'], 'relapsing': []},
 'relapse': ['relapsed', 'relapser', 'relapsers'],
 'relapsefre': {'relapsefree': []},
 'relapseprevent': {'relapseprevention': []},
 'relapsingremit': {'relapsingremitting': []},
 'relapso': {'relapsos': []},
 'relapsu': {'relapsus': []},
 'relaqo': {'relaqoes': []},
 'relar': {'relare': ['relares', 'relared'],
           'relaring': [],
           'relarive': ['relarives', 'relarively']},
 'relard': {'relarded': []},
 'relare': ['relares', 'relared'],
 'relarg': {'relarge': []},
 'relargag': {'relargage': []},
 'relarion': {'relariones': [], 'relarions': []},
 'relarionship': {'relarionships': []},
 'relarive': ['relarives', 'relarively'],
 'relarivist': {'relarivistic': []},
 'relark': {'relarkable': []},
 'relas': {'relase': ['relases', 'relased'], 'relasing': [], 'relasion': []},
 'relasch': {'relasche': ['relascher']},
 'relasche': ['relascher'],
 'relascop': {'relascope': []},
 'relase': ['relases', 'relased'],
 'relash': {'relashed': [], 'relashing': []},
 'relaship': {'relaships': []},
 'relashun': {'relashuns': []},
 'relasjon': {'relasjoner': []},
 'relasp': {'relasped': [], 'relasping': []},
 'relast': {'relasting': []},
 'relat': {'relatability': [],
           'relatable': [],
           'relatant': [],
           'relatation': [],
           'relate': ['relater',
                      'relates',
                      'related',
                      'relaters',
                      'relately',
                      'relateds',
                      'relatent',
                      'relateing',
                      'relateable'],
           'relatic': [],
           'relating': ['relatings'],
           'relation': ['relationed',
                        'relational',
                        'relationing',
                        'relationals',
                        'relationally'],
           'relator': ['relators'],
           'relats': [],
           'relatted': [],
           'relatting': []},
 "relat'v": {"relat've": []},
 'relata': {'relatae': [], 'relatas': []},
 'relatada': {'relatadas': []},
 'relatado': {'relatados': []},
 'relatavist': {'relatavistic': []},
 'relatcd': {'relatcdness': []},
 'relatch': {'relatched': [], 'relatches': [], 'relatching': []},
 'relatdrio': {'relatdrios': []},
 'relate': {'relatee': ['relatees']},
 'related': {'relatedness': []},
 'relatedact': {'relatedactivities': []},
 'relatedcolumn': {'relatedcolumns': []},
 'relatedissu': {'relatedissues': []},
 'relatedli': {'relatedly': []},
 'relatedn': {'relatednes': []},
 'relatedparti': {'relatedparty': []},
 'relatedproblem': {'relatedproblems': []},
 'relatedt': {'relatedtable': []},
 'relatedtop': {'relatedtopics': []},
 'relatedtoth': {'relatedtothe': []},
 'relatee': ['relatees'],
 'relatera': {'relateras': []},
 'relaterad': {'relaterade': []},
 'relatestoth': {'relatestothe': []},
 'relateth': {'relatethe': []},
 'relateur': {'relateurs': []},
 'relatev': {'relatevely': []},
 'relatfon': {'relatfons': []},
 'relath': {'relathe': ['relather', 'relathered', 'relathering']},
 'relathe': ['relather', 'relathered', 'relathering'],
 'relati': {'relatiation': [],
            'relatie': ['relaties', 'relatied', 'relatiely'],
            'relatiing': [],
            'relatiou': ['relatious'],
            'relatis': []},
 'relatian': {'relatians': []},
 'relatianship': {'relatianships': []},
 'relatiatori': {'relatiatory': []},
 'relatibn': {'relatibns': []},
 'relatibu': {'relatibus': []},
 'relatic': {'relatice': []},
 'relaticn': {'relaticns': []},
 'relaticnship': {'relaticnships': []},
 'relatidn': {'relatidns': []},
 'relatie': ['relaties', 'relatied', 'relatiely'],
 'relatien': {'relatiens': []},
 'relatiev': {'relatieve': []},
 'relatievli': {'relatievly': []},
 'relatif': {'relatife': [], 'relatifs': []},
 'relatiil': {'relatiile': []},
 'relatij': {'relatijs': []},
 'relatin': {'relatine': [], 'relatins': []},
 'relating': {'relatinge': []},
 'relatingth': {'relatingthe': []},
 'relatingtoth': {'relatingtothe': []},
 'relatinn': {'relatinns': []},
 'relatinnship': {'relatinnships': []},
 'relatinship': {'relatinships': []},
 'relatio': {'relatios': []},
 'relatioa': {'relatioas': []},
 'relatioaship': {'relatioaships': []},
 'relatioh': {'relatiohs': []},
 'relatiohship': {'relatiohships': []},
 'relation': {'relationalism': [],
              'relationalities': [],
              'relationality': [],
              'relationalization': [],
              'relationalized': [],
              'relationalizing': [],
              'relatione': ['relationer', 'relationes'],
              'relationism': []},
 'relationahip': {'relationahipe': [], 'relationahips': []},
 'relational': {'relationale': ['relationaler', 'relationales']},
 'relationaldatabas': {'relationaldatabase': []},
 'relationale': ['relationaler', 'relationales'],
 'relationaliri': {'relationaliry': []},
 'relationalist': {'relationalistic': [], 'relationalists': []},
 'relationari': {'relationary': []},
 'relationaship': {'relationaships': []},
 'relationbas': {'relationbased': []},
 'relationchang': {'relationchanging': []},
 'relationchip': {'relationchips': []},
 'relatione': ['relationer', 'relationes'],
 'relationehip': {'relationehipe': [], 'relationehips': []},
 'relationel': {'relationele': [], 'relationelle': []},
 'relationhip': {'relationhips': []},
 'relationhsip': {'relationhsips': []},
 'relationi': {'relationis': []},
 'relationibu': {'relationibus': []},
 'relationihip': {'relationihips': []},
 'relationip': {'relationips': []},
 'relationist': {'relationistic': [], 'relationists': []},
 'relationless': {'relationlessness': []},
 'relationlik': {'relationlike': []},
 'relationlip': {'relationlips': []},
 'relationn': {'relationnal': []},
 'relationnam': {'relationname': []},
 'relationnel': {'relationnelle': ['relationnelles'], 'relationnels': []},
 'relationnelle': ['relationnelles'],
 'relationori': {'relationoriented': []},
 'relationsar': {'relationsare': []},
 'relationsbip': {'relationsbips': []},
 'relationsconsci': {'relationsconscious': []},
 'relationshi': {'relationshis': []},
 'relationshin': {'relationshins': []},
 'relationshio': {'relationshios': []},
 'relationshiop': {'relationshiops': []},
 'relationship': ['relationshipe', 'relationshipping'],
 'relationshipbas': {'relationshipbased': []},
 'relationshipbetweenth': {'relationshipbetweenthe': []},
 'relationshipbuild': {'relationshipbuilding': []},
 'relationshipcent': {'relationshipcentered': []},
 'relationshipenhanc': {'relationshipenhancement': [],
                        'relationshipenhancing': []},
 'relationshipfocus': {'relationshipfocused': []},
 'relationshipi': {'relationshipis': []},
 'relationshipmanag': {'relationshipmanagement': []},
 'relationshipmarket': {'relationshipmarketing': []},
 'relationshipmotiv': {'relationshipmotivated': []},
 'relationshipori': {'relationshiporiented': []},
 'relationshiprel': {'relationshiprelated': []},
 'relationshiprelev': {'relationshiprelevant': []},
 'relationshipsar': {'relationshipsare': []},
 'relationshipspecif': {'relationshipspecific': []},
 'relationshipthreaten': {'relationshipthreatening': []},
 'relationshiptyp': {'relationshiptype': []},
 'relationshipwa': {'relationshipwas': []},
 'relationshipwis': {'relationshipwise': []},
 'relationshlp': {'relationshlps': []},
 'relationshop': {'relationshops': []},
 'relationshp': {'relationshps': []},
 'relationshsip': {'relationshsips': []},
 'relationshtp': {'relationshtps': []},
 'relationsihp': {'relationsihps': []},
 'relationsip': {'relationsips': []},
 'relationskip': {'relationskips': []},
 'relationsliip': {'relationsliips': []},
 'relationslup': {'relationslups': []},
 'relationsmind': {'relationsminded': []},
 'relationsnip': {'relationsnips': []},
 'relationsori': {'relationsoriented': []},
 'relationspecif': {'relationspecific': []},
 'relationsship': {'relationsships': []},
 'relationstheori': {'relationstheorie': []},
 'relationstructur': {'relationstructure': []},
 'relationsunit': {'relationsunited': []},
 'relationswis': {'relationswise': []},
 'relationt': {'relationtable': []},
 'relationth': {'relationthe': []},
 'relationthip': {'relationthips': []},
 'relationtoth': {'relationtothe': []},
 'relationtyp': {'relationtype': []},
 'relationword': {'relationwords': []},
 'relatioo': {'relatioos': []},
 'relatiop': {'relatiops': []},
 'relatior': {'relatiors': []},
 'relatiori': {'relatioris': []},
 'relatioship': {'relatioships': []},
 'relatioti': {'relatiotis': []},
 'relatiou': ['relatious'],
 'relatiouship': {'relatiouships': []},
 'relatipn': {'relatipns': []},
 'relatipnship': {'relatipnships': []},
 'relatiqn': {'relatiqns': []},
 'relatir': {'relatire': ['relatires', 'relatirely']},
 'relatire': ['relatires', 'relatirely'],
 'relatist': {'relatistic': []},
 'relatit': {'relatite': []},
 'relatiu': {'relatiue': ['relatiues', 'relatiuely']},
 'relatiue': ['relatiues', 'relatiuely'],
 'relatiun': {'relatiuns': []},
 'relativ': {'relatival': [],
             'relativate': ['relativated', 'relativates'],
             'relativating': [],
             'relativation': [],
             'relatived': [],
             'relativement': [],
             'relativer': [],
             'relativism': [],
             'relativization': ['relativizations'],
             'relativize': ['relativized',
                            'relativizes',
                            'relativizer',
                            'relativizers'],
             'relativizing': [],
             'relativs': []},
 'relativa': {'relativae': [], 'relativas': []},
 'relativali': {'relativaly': []},
 'relativament': {'relativamente': []},
 'relativate': ['relativated', 'relativates'],
 'relativcli': {'relativcly': []},
 'relative': {'relativee': []},
 "relative'i": {"relative'y": []},
 'relativeclaus': {'relativeclause': []},
 'relativedepriv': {'relativedeprivation': []},
 'relativefi': {'relativefy': []},
 'relativefrequ': {'relativefrequency': []},
 'relativehumid': {'relativehumidity': []},
 'relativeimport': {'relativeimportance': []},
 'relativeincom': {'relativeincome': []},
 'relativelli': {'relativelly': []},
 'relativelyadvanc': {'relativelyadvanced': []},
 'relativelyconst': {'relativelyconstant': []},
 'relativelyeasi': {'relativelyeasy': []},
 'relativelyendur': {'relativelyenduring': []},
 'relativelylarg': {'relativelylarge': []},
 'relativelylittl': {'relativelylittle': []},
 'relativelyrec': {'relativelyrecent': []},
 'relativelysimpl': {'relativelysimple': []},
 'relativelysmal': {'relativelysmall': ['relativelysmaller']},
 'relativelysmall': ['relativelysmaller'],
 'relativelyst': {'relativelystable': []},
 'relativement': {'relativemente': []},
 'relativemot': {'relativemotion': []},
 'relativeperm': {'relativepermeability': []},
 'relativeposit': {'relativeposition': []},
 'relativepric': {'relativeprice': []},
 'relativeri': {'relativery': []},
 'relativeti': {'relativety': []},
 'relativetoth': {'relativetothe': []},
 'relativevalu': {'relativevalue': []},
 'relativeveloc': {'relativevelocity': []},
 'relativi': {'relativies': [], 'relativis': []},
 'relativiat': {'relativiatic': []},
 'relativierend': {'relativierende': []},
 'relativiert': {'relativierte': []},
 'relativili': {'relativily': []},
 'relativis': {'relativisable': [],
               'relativisation': ['relativisations'],
               'relativise': ['relativiser',
                              'relativised',
                              'relativises',
                              'relativisers'],
               'relativising': []},
 'relativisation': ['relativisations'],
 'relativise': {'relativisee': []},
 'relativisit': {'relativisitic': []},
 'relativisl': {'relativislic': []},
 'relativism': {'relativisme': []},
 'relativismu': {'relativismus': []},
 'relativisr': {'relativisric': []},
 'relativist': {'relativiste': ['relativistes'],
                'relativistic': ['relativistics',
                                 'relativistical',
                                 'relativistically'],
                'relativists': []},
 'relativista': {'relativistas': []},
 'relativiste': ['relativistes'],
 'relativisti': {'relativistie': []},
 'relativistic': ['relativistics', 'relativistical', 'relativistically'],
 'relativistich': {'relativistiche': []},
 'relativistisch': {'relativistische': ['relativistischer']},
 'relativistische': ['relativistischer'],
 'relativit': {'relativite': [], 'relativitic': [], 'relativitism': []},
 'relativitaetstheori': {'relativitaetstheorie': []},
 'relativitat': {'relativitats': []},
 'relativitatspostul': {'relativitatspostulate': []},
 'relativitatsprinzip': {'relativitatsprinzips': []},
 'relativitatstheori': {'relativitatstheorie': []},
 'relativitdtstheori': {'relativitdtstheorie': []},
 'relativitiitstheori': {'relativitiitstheorie': []},
 'relativitist': {'relativitistic': [], 'relativitists': []},
 'relativitytheori': {'relativitytheory': []},
 'relativiz': {'relativizability': [], 'relativizable': []},
 'relativization': ['relativizations'],
 'relativize': ['relativized', 'relativizes', 'relativizer', 'relativizers'],
 'relativli': {'relativly': []},
 'relativlich': {'relativliches': []},
 'relativlst': {'relativlstic': []},
 'relativn': {'relativne': []},
 'relativo': {'relativos': []},
 'relativoli': {'relativoly': []},
 'relativpronomen': {'relativpronomens': []},
 'relativsatz': {'relativsatze': ['relativsatzes']},
 'relativsatze': ['relativsatzes'],
 'relativtheori': {'relativtheorie': []},
 'relativu': {'relativus': []},
 'relativwert': {'relativwerte': []},
 'relatiy': {'relatiye': ['relatiyes', 'relatiyely']},
 'relatiye': ['relatiyes', 'relatiyely'],
 'relatjon': {'relatjons': []},
 'relatlf': {'relatlfs': []},
 'relatlon': {'relatlonal': [], 'relatlons': []},
 'relatlonship': {'relatlonships': []},
 'relatlonshlp': {'relatlonshlps': []},
 'relatlv': {'relatlve': ['relatlves', 'relatlvely']},
 'relatlve': ['relatlves', 'relatlvely'],
 'relatlvist': {'relatlvistic': []},
 'relatlvlst': {'relatlvlstic': []},
 'relatlvlti': {'relatlvlty': []},
 'relatn': {'relatns': []},
 'relato': {'relatos': []},
 'relatoin': {'relatoins': []},
 'relaton': {'relatons': []},
 'relatonship': {'relatonships': []},
 'relator': {'relatore': ['relatores']},
 'relatore': ['relatores'],
 'relatorio': {'relatorios': []},
 'relatr': {'relatres': []},
 'relatron': {'relatrons': []},
 'relatrv': {'relatrve': []},
 'relatrvist': {'relatrvistic': []},
 'relatt': {'relattion': ['relattions']},
 'relattf': {'relattfs': []},
 'relattion': ['relattions'],
 'relatton': {'relattons': []},
 'relattonship': {'relattonships': []},
 'relattv': {'relattve': ['relattvely']},
 'relattve': ['relattvely'],
 'relattvist': {'relattvistic': []},
 'relatu': {'relatus': []},
 'relaturo': {'relaturos': []},
 'relaturu': {'relaturus': []},
 'relatv': {'relatve': ['relatves', 'relatvely']},
 'relatve': ['relatves', 'relatvely'],
 'relatw': {'relatwe': ['relatwely']},
 'relatwe': ['relatwely'],
 'relaunch': {'relaunched': [],
              'relaunches': [],
              'relaunching': ['relaunchings']},
 'relaunching': ['relaunchings'],
 'relaund': {'relaundered': []},
 'relauon': {'relauons': []},
 'relauonship': {'relauonships': []},
 'relauv': {'relauve': ['relauvely']},
 'relauve': ['relauvely'],
 'relauvist': {'relauvistic': []},
 'relav': {'relavance': [],
           'relavant': [],
           'relave': ['relaves',
                      'relaved',
                      'relavent',
                      'relavely',
                      'relavence'],
           'relaving': [],
           'relavs': []},
 'relave': ['relaves', 'relaved', 'relavent', 'relavely', 'relavence'],
 'relavist': {'relavistic': []},
 'relaw': {'relaws': []},
 'relawni': {'relawny': []},
 'relay': ['relaye',
           'relayed',
           'relayer',
           'relayes',
           'relayers',
           'relayant',
           'relaying',
           'relayered',
           'relayable',
           'relayings',
           'relayering'],
 'relaye': {'relayee': ['relayees']},
 'relayee': ['relayees'],
 'relayoper': {'relayoperated': []},
 'relayout': {'relayouts': []},
 'relayrac': {'relayrace': []},
 'relayst': {'relaystation': ['relaystations']},
 'relaystation': ['relaystations'],
 'relaytyp': {'relaytype': []},
 'relaz': {'relazation': [], 'relazed': []},
 'relazion': {'relazione': []},
 'relazional': {'relazionale': []},
 'relblut': {'relblution': []},
 'relblv': {'relblved': []},
 'relcaim': {'relcaimed': []},
 'relcarn': {'relcarning': []},
 'relcas': {'relcase': [], 'relcasing': []},
 'relch': {'relches': [], 'relchs': []},
 'relcom': {'relcome': []},
 'relcr': {'relcrred': []},
 'relct': {'relcted': []},
 'reld': {'relde': [], 'relding': [], 'relds': []},
 'reldch': {'reldche': []},
 'reldi': {'reldy': []},
 'reldmpago': {'reldmpagos': []},
 'reldres': {'reldresal': []},
 'rele': {'releative': ['releatively'],
          'reled': [],
          'relee': ['relees', 'releed'],
          'reles': [],
          'reling': []},
 'relea': {'releae': ['releaed'], 'releas': []},
 'releaa': {'releaae': ['releaaed']},
 'releaae': ['releaaed'],
 'releac': {'releace': ['releaced']},
 'releace': ['releaced'],
 'releach': {'releached': [], 'releaching': []},
 'relead': {'releaded': [], 'releading': []},
 'releae': {'releaee': ['releaeed']},
 'releaee': ['releaeed'],
 'releaf': {'releafe': ['releafes', 'releafed', 'releafement'],
            'releafing': []},
 'releafe': ['releafes', 'releafed', 'releafement'],
 'releag': {'releage': []},
 'releai': {'releaie': ['releaied']},
 'releaie': ['releaied'],
 'releal': {'relealed': []},
 'releam': {'releamed': [], 'releaming': [], 'releams': []},
 'relearn': {'relearned': [],
             'relearner': ['relearners'],
             'relearning': ['relearnings'],
             'relearns': []},
 'relearner': ['relearners'],
 'relearning': ['relearnings'],
 'releas': {'releasability': [],
            'releasable': [],
            'releasably': [],
            'releasate': ['releasates'],
            'release': ['released',
                        'releaser',
                        'releasers',
                        'releaseing',
                        'releasement',
                        'releaseable',
                        'releasements'],
            'releasibility': [],
            'releasible': [],
            'releasing': ['releasings'],
            'releasive': [],
            'releasment': []},
 'releasate': ['releasates'],
 'releasc': {'releascment': []},
 'release': {'releasee': ['releasees']},
 'releasecaptur': {'releasecapture': []},
 'released': {'releasedate': []},
 'releasedismiss': {'releasedismissal': []},
 'releasedtim': {'releasedtime': []},
 'releasee': ['releasees'],
 'releaseev': {'releaseevents': []},
 'releaseinhibit': {'releaseinhibiting': []},
 'releaseoutsid': {'releaseoutside': []},
 'releaserecaptur': {'releaserecapture': []},
 'releaserequestst': {'releaserequeststate': []},
 'releaseresourc': {'releaseresource': []},
 'releasesemaphor': {'releasesemaphore': []},
 'releaseth': {'releasethe': []},
 'releasetim': {'releasetime': []},
 'releash': {'releashed': [], 'releashing': []},
 'releasing': ['releasings'],
 'releasinghormon': {'releasinghormone': []},
 'releasingli': {'releasingly': []},
 'releasingth': {'releasingthe': []},
 'releasom': {'releasomers': []},
 'releasor': {'releasors': []},
 'releass': {'releasse': ['releassed']},
 'releasse': ['releassed'],
 'releat': {'releate': ['releated'],
            'releating': [],
            'releation': ['releations']},
 'releate': ['releated'],
 'releath': {'releathered': [], 'releathering': []},
 'releation': ['releations'],
 'releationship': {'releationships': []},
 'releative': ['releatively'],
 'releav': {'releave': ['releaves', 'releaved'], 'releaving': []},
 'releave': ['releaves', 'releaved'],
 'releaz': {'releazed': []},
 'relebohil': {'relebohile': []},
 'relebr': {'relebrated': []},
 'releccion': {'relecciones': []},
 'relecommun': {'relecommunications': []},
 'relect': {'relectance': [],
            'relectant': [],
            'relected': [],
            'relecting': [],
            'relection': ['relections'],
            'relective': [],
            'relectivity': [],
            'relects': []},
 'relection': {'relectiones': []},
 'relector': {'relectors': []},
 'relectur': {'relecture': ['relectures']},
 'relectura': {'relecturas': []},
 'relecture': ['relectures'],
 'relee': ['relees', 'releed'],
 'releef': {'releefe': []},
 'releeff': {'releeffe': []},
 'releegi': {'releegious': []},
 'relees': {'releese': ['releesed']},
 'releese': ['releesed'],
 'releeu': {'releeue': ['releeued'], 'releeuing': []},
 'releeue': ['releeued'],
 'releev': {'releeve': ['releeves', 'releeved'], 'releeving': []},
 'releeve': ['releeves', 'releeved'],
 'relef': {'relefe': []},
 'releff': {'releffe': []},
 'releg': {'relegalization': [],
           'relegalize': ['relegalized'],
           'relegalizing': [],
           'relegant': [],
           'relegate': ['relegates', 'relegated'],
           'relegating': [],
           'relegation': [],
           'relege': []},
 'relega': {'relegas': []},
 'relegada': {'relegadas': []},
 'relegado': {'relegados': []},
 'relegalis': {'relegalisation': [], 'relegalised': []},
 'relegalize': ['relegalized'],
 'relegar': {'relegare': ['relegared']},
 'relegare': ['relegared'],
 'relegate': ['relegates', 'relegated'],
 'relegati': {'relegatis': []},
 'relegation': {'relegatione': []},
 'relegationi': {'relegationis': []},
 'relegato': {'relegatos': []},
 'relegatu': {'relegatus': []},
 'relegazion': {'relegazione': []},
 'relegen': {'relegens': []},
 'relegendi': {'relegendis': []},
 'relegent': {'relegentes': []},
 'releger': {'relegere': ['relegerent']},
 'relegere': ['relegerent'],
 'relegi': {'relegious': []},
 'relegion': {'relegions': []},
 'relegisl': {'relegislate': ['relegislated'],
              'relegislating': [],
              'relegislation': []},
 'relegislate': ['relegislated'],
 'relegitim': {'relegitimate': ['relegitimated', 'relegitimates'],
               'relegitimating': [],
               'relegitimation': [],
               'relegitimization': [],
               'relegitimize': ['relegitimizes', 'relegitimized'],
               'relegitimizing': []},
 'relegitimate': ['relegitimated', 'relegitimates'],
 'relegitimis': {'relegitimisation': [],
                 'relegitimise': ['relegitimised'],
                 'relegitimising': []},
 'relegitimise': ['relegitimised'],
 'relegitimize': ['relegitimizes', 'relegitimized'],
 'relegu': {'releguant': [], 'relegue': ['releguer', 'relegues']},
 'relegue': {'releguee': ['releguees']},
 'releguee': ['releguees'],
 'releienc': {'releience': []},
 'releif': {'releife': ['releifes'], 'releifs': []},
 'releife': ['releifes'],
 'releiff': {'releiffe': []},
 'releis': {'releise': []},
 'releiu': {'releiue': ['releiued']},
 'releiue': ['releiued'],
 'releiv': {'releive': ['releives', 'releived', 'releiveing'], 'releiving': []},
 'releive': ['releives', 'releived', 'releiveing'],
 'relelv': {'relelvant': []},
 'relemb': {'relember': []},
 'relembl': {'relemblance': [], 'relembles': [], 'relembling': []},
 'relend': {'relending': [], 'relends': []},
 'relendess': {'relendessness': []},
 'relendessli': {'relendessly': []},
 'relengthen': {'relengthened': [], 'relengthening': []},
 'relenrlessli': {'relenrlessly': []},
 'relens': {'relense': ['relensed']},
 'relense': ['relensed'],
 'relent': {'relente': ['relented'],
            'relentful': [],
            'relenting': ['relentings'],
            'relention': [],
            'relentment': [],
            'relentness': [],
            'relents': []},
 'relente': ['relented'],
 'relentessli': {'relentessly': []},
 'relentiessli': {'relentiessly': []},
 'relenting': ['relentings'],
 'relentingli': {'relentingly': []},
 'relentl': {'relentles': []},
 'relentlef': {'relentlefs': []},
 'relentlesli': {'relentlesly': []},
 'relentless': {'relentlesse': [], 'relentlessness': []},
 'relentlessi': {'relentlessy': []},
 'relentlessli': {'relentlessly': []},
 'releolog': {'releological': []},
 'releos': {'releose': ['releosed']},
 'releose': ['releosed'],
 'relephon': {'relephone': ['relephones']},
 'relephone': ['relephones'],
 'reler': {'relerant': [],
           'relerence': ['relerences'],
           'relerred': [],
           'relerring': [],
           'relers': []},
 'relere': {'releree': []},
 'relerenc': {'relerenced': []},
 'relerence': ['relerences'],
 'relerr': {'relerral': []},
 'relerv': {'relerve': ['relerved']},
 'relerve': ['relerved'],
 'reles': {'relese': ['relesed']},
 'relescop': {'relescope': []},
 'relese': ['relesed'],
 'reless': {'relesse': ['relessed', 'relesser']},
 'relesse': {'relessee': []},
 'relet': {'relete': ['releted', 'reletes'],
           'releting': [],
           'reletion': ['reletions'],
           'reletive': ['reletives', 'reletively'],
           'relets': [],
           'reletting': ['relettings']},
 'relete': ['releted', 'reletes'],
 'reletion': ['reletions'],
 'reletionship': {'reletionships': []},
 'reletive': ['reletives', 'reletively'],
 'relett': {'reletter': ['relettered', 'relettering']},
 'reletter': ['relettered', 'relettering'],
 'reletting': ['relettings'],
 'releu': {'releue': ['releued']},
 'releue': ['releued'],
 'relev': {'relevance': [],
           'relevancy': [],
           'relevant': ['relevants'],
           'relevate': ['relevated'],
           'relevating': [],
           'relevation': ['relevations'],
           'releve': ['releves',
                      'relever',
                      'releved',
                      'relevent',
                      'relevency',
                      'releveant',
                      'relevered',
                      'relevence',
                      'relevently',
                      'relevement',
                      'relevering',
                      'relevements'],
           'releving': []},
 'relevado': {'relevados': []},
 'relevag': {'relevage': []},
 'relevai': {'relevaient': [], 'relevais': []},
 'relevail': {'relevailles': []},
 'relevan': {'relevans': []},
 'relevancerank': {'relevanceranked': []},
 'relevancetheoret': {'relevancetheoretic': []},
 'relevandi': {'relevandy': []},
 'relevane': {'relevanee': []},
 'relevano': {'relevanoe': []},
 'relevant': {'relevante': ['relevanter', 'relevantes'], 'relevantism': []},
 'relevantbook': {'relevantbooks': []},
 'relevante': ['relevanter', 'relevantes'],
 'relevanti': {'relevantie': []},
 'relevantinform': {'relevantinformation': []},
 'relevantist': {'relevantists': []},
 'relevantknowledg': {'relevantknowledge': []},
 'relevantli': {'relevantly': []},
 'relevantn': {'relevantne': []},
 'relevanttoth': {'relevanttothe': []},
 'relevar': {'relevare': []},
 'relevate': ['relevated'],
 'relevation': {'relevatione': []},
 'relevationi': {'relevationis': []},
 'relevatori': {'relevatory': []},
 'relevatu': {'relevatus': []},
 'relevd': {'relevds': []},
 'releve': {'relevee': ['relevees']},
 'relevee': ['relevees'],
 'relevel': {'releveled': [],
             'releveling': ['relevelings'],
             'relevelled': [],
             'relevelling': ['relevellings']},
 'releveling': ['relevelings'],
 'relevelling': ['relevellings'],
 'relever': {'releverent': []},
 'releverag': {'releverage': ['releveraged'], 'releveraging': []},
 'releverage': ['releveraged'],
 'releverai': {'releveraient': []},
 'releveron': {'releverons': []},
 'relevi': {'relevied': [], 'relevis': [], 'relevy': []},
 'relevii': {'releviis': []},
 'relevis': {'relevision': []},
 'relevo': {'relevos': []},
 'relevoi': {'relevoient': []},
 'relevon': {'relevons': []},
 'reley': {'releyance': [], 'releyant': []},
 'releyff': {'releyffe': []},
 'relf': {'relfe': ['relfes'], 'relfs': []},
 'relfar': {'relfare': []},
 'relfe': ['relfes'],
 'relfect': {'relfected': [],
             'relfecting': [],
             'relfection': ['relfections'],
             'relfective': [],
             'relfects': []},
 'relfection': ['relfections'],
 'relfgiou': {'relfgious': []},
 'relfic': {'relfication': []},
 'relgat': {'relgate': []},
 'relgi': {'relgis': []},
 'relgion': {'relgions': []},
 'relgiou': {'relgious': []},
 'relgiqu': {'relgique': []},
 'relh': {'relhe': []},
 'reli': {'relie': ['relied', 'relies'],
          'relis': [],
          'rely': ['relys', 'relyed', 'relying']},
 'relia': {'relias': []},
 'reliaabl': {'reliaable': []},
 'reliab': {'reliabe': [], 'reliabity': []},
 'reliabi': {'reliabiity': []},
 'reliabihti': {'reliabihty': []},
 'reliabil': {'reliabile': [], 'reliabilism': []},
 'reliabili': {'reliabily': []},
 'reliabililti': {'reliabililty': []},
 'reliabiliri': {'reliabiliry': []},
 'reliabilist': {'reliabilists': []},
 'reliabilit': {'reliabilitation': [], 'reliabilites': []},
 'reliabilitybas': {'reliabilitybased': []},
 'reliabilitycent': {'reliabilitycentered': []},
 'reliabilityrel': {'reliabilityrelated': []},
 'reliabilti': {'reliabilty': []},
 'reliabl': {'reliability': [],
             'reliable': ['reliables', 'reliableness'],
             'reliablism': [],
             'reliablity': [],
             'reliabllity': [],
             'reliably': []},
 'reliable': ['reliables', 'reliableness'],
 'reliablemessag': {'reliablemessaging': []},
 'reliablil': {'reliablility': []},
 'reliahil': {'reliahility': []},
 'reliahl': {'reliahle': []},
 'reliahli': {'reliahly': []},
 'reliaiou': {'reliaious': []},
 'relianc': {'reliance': [], 'reliancy': []},
 'reliane': {'relianee': []},
 'reliano': {'relianoe': []},
 'reliant': {'reliants': []},
 'reliantli': {'reliantly': []},
 'reliaol': {'reliaole': []},
 'reliau': {'reliaues': []},
 'reliauc': {'reliauce': []},
 'reliber': {'reliberalization': [],
             'reliberalized': [],
             'reliberate': ['reliberated'],
             'reliberation': []},
 'reliberate': ['reliberated'],
 'relibl': {'relibility': [], 'relible': []},
 'relic': ['relice', 'relices', 'relication'],
 'relicario': {'relicarios': []},
 'relicchamb': {'relicchamber': []},
 'relicens': {'relicense': ['relicenses', 'relicensed'], 'relicensing': []},
 'relicense': ['relicenses', 'relicensed'],
 'relicensur': {'relicensure': []},
 'relicf': {'relicfs': []},
 'relichunt': {'relichunter': ['relichunters'], 'relichunting': []},
 'relichunter': ['relichunters'],
 'relici': {'relicious': []},
 'relick': {'relicke': ['relickes'], 'relicks': []},
 'relicke': ['relickes'],
 'relicqu': {'relicques': []},
 'relict': ['relicte',
            'relictes',
            'relicted',
            'relictic',
            'reliction',
            'relictions'],
 'relicta': {'relictae': [], 'relictas': []},
 'relictc': {'relictce': []},
 'relicti': {'relictis': []},
 'relicto': {'relictos': []},
 'relicts': {'relictse': []},
 'relictu': {'relictual': [], 'relictus': []},
 'relicturu': {'relicturus': []},
 'reliculatu': {'reliculatus': []},
 'relicv': {'relicve': ['relicved']},
 'relicve': ['relicved'],
 'relid': {'relide': ['relided', 'relidence']},
 'relide': ['relided', 'relidence'],
 'relie': {'reliee': ['reliees']},
 'reliebl': {'reliebility': [], 'relieble': []},
 'reliee': ['reliees'],
 'relief': ['reliefe',
            'reliefes',
            'reliefed',
            'reliefer',
            'reliefers',
            'reliefing'],
 'reliefbild': {'reliefbilder': []},
 'reliefcarv': {'reliefcarved': []},
 'reliefdecor': {'reliefdecorated': []},
 'reliefdevelop': {'reliefdevelopment': []},
 'reliefenergi': {'reliefenergie': []},
 'relieff': {'relieffe': []},
 'reliefform': {'reliefforming': []},
 'reliefgiv': {'reliefgiving': []},
 'reliefi': {'reliefis': []},
 'relieflik': {'relieflike': []},
 'reliefmap': {'reliefmaps': []},
 'reliefmould': {'reliefmoulded': []},
 'reliefsculptur': {'reliefsculpture': []},
 'reliefvalv': {'reliefvalve': []},
 'reliefwa': {'reliefwas': []},
 'reliefwork': {'reliefworks': []},
 'relieiou': {'relieious': []},
 'reliel': {'reliels': []},
 'relienc': {'relience': []},
 'relier': {'reliere': ['reliered'], 'reliering': [], 'reliers': []},
 'reliere': ['reliered'],
 'relies': {'reliese': []},
 'reliet': {'reliete': [], 'reliets': []},
 'relieu': {'relieue': ['relieued'], 'relieuing': []},
 'relieue': ['relieued'],
 'relieur': {'relieure': [], 'relieurs': []},
 'reliev': {'relief': [],
            'relievable': [],
            'relieve': ['relieved', 'reliever', 'relieveing', 'relievement'],
            'relieving': ['relievings']},
 'relieve': ['relieved', 'reliever', 'relieveing', 'relievement'],
 'relievedli': {'relievedly': []},
 'relieveth': {'relievethe': []},
 'relieving': ['relievings'],
 'relievingli': {'relievingly': []},
 'relievingoffic': {'relievingofficer': []},
 'relievingth': {'relievingthe': []},
 'relievo': ['relievoes'],
 'reliey': {'relieye': ['relieyed']},
 'relieye': ['relieyed'],
 'relif': {'relife': [], 'relifs': []},
 'reliffi': {'reliffious': []},
 'relifh': {'relifhed': [], 'relifhing': []},
 'relifi': {'relifious': []},
 'relifli': {'reliflied': []},
 'relift': {'reliftance': [], 'relifted': [], 'relifting': [], 'relifts': []},
 'relig': {'religant': [],
           'religate': ['religated', 'religates'],
           'religating': [],
           'religation': [],
           'religeous': ['religeously'],
           'religic': [],
           'religous': ['religously', 'religousness']},
 'religa': {'religas': []},
 'religar': {'religare': []},
 'religata': {'religatas': []},
 'religate': ['religated', 'religates'],
 'religatu': {'religatus': []},
 'religbu': {'religbus': []},
 'religen': {'religens': []},
 'religent': {'religentes': []},
 'religeous': ['religeously'],
 'religer': {'religere': []},
 'religeus': {'religeuse': ['religeuses']},
 'religeuse': ['religeuses'],
 'religf': {'religfous': []},
 'relight': {'relighted': [], 'relighting': ['relightings'], 'relights': []},
 'relighting': ['relightings'],
 'religi': {'religie': ['religies'],
            'religiou': ['religious', 'religiously', 'religiousness']},
 'religiau': {'religiaus': []},
 'religib': {'religibs': []},
 'religibs': {'religibser': []},
 'religibu': {'religibus': []},
 'religicu': {'religicus': []},
 'religicus': {'religicuse': ['religicuses']},
 'religicuse': ['religicuses'],
 'religid': {'religids': []},
 'religids': {'religidse': ['religidses', 'religidser']},
 'religidse': ['religidses', 'religidser'],
 'religidu': {'religidus': []},
 'religie': ['religies'],
 'religiens': {'religiense': ['religienses']},
 'religiense': ['religienses'],
 'religieu': {'religieus': []},
 'religieuf': {'religieufes': []},
 'religieus': {'religieuse': ['religieuses', 'religieusement']},
 'religieusc': {'religieuscs': []},
 'religieuse': ['religieuses', 'religieusement'],
 'religieut': {'religieute': []},
 'religieuz': {'religieuze': []},
 'religif': {'religification': []},
 'religigi': {'religigious': []},
 'religii': {'religiious': []},
 'religij': {'religije': []},
 'religijn': {'religijne': []},
 'religijni': {'religijny': []},
 'religijo': {'religijos': []},
 'religinu': {'religinus': []},
 'religio': {'religioes': [], 'religios': []},
 'religioa': {'religioas': []},
 'religioaesthet': {'religioaesthetic': []},
 'religioas': {'religioase': []},
 'religioc': {'religiocity': []},
 'religiocentr': {'religiocentric': [], 'religiocentrism': []},
 'religiocommun': {'religiocommunal': []},
 'religiocultur': {'religiocultural': []},
 'religioeconom': {'religioeconomic': []},
 'religioerot': {'religioerotic': []},
 'religioes': {'religioese': ['religioeser']},
 'religioese': ['religioeser'],
 'religioeth': {'religioethical': []},
 'religioethn': {'religioethnic': []},
 'religiohistor': {'religiohistorical': []},
 'religioideolog': {'religioideological': []},
 'religioii': {'religioiis': []},
 'religiointellectu': {'religiointellectual': []},
 'religioiu': {'religioius': []},
 'religioleg': {'religiolegal': []},
 'religiolinguist': {'religiolinguistic': []},
 'religioliterari': {'religioliterary': []},
 'religiolog': {'religiology': []},
 'religiologiqu': {'religiologiques': []},
 'religiologist': {'religiologists': []},
 'religiom': {'religioms': []},
 'religiomag': {'religiomagical': []},
 'religiomed': {'religiomedical': []},
 'religiometaphys': {'religiometaphysical': []},
 'religiomilitari': {'religiomilitary': []},
 'religiomor': {'religiomoral': []},
 'religiomyst': {'religiomystical': []},
 'religiomyth': {'religiomythic': ['religiomythical']},
 'religiomythic': ['religiomythical'],
 'religiomytholog': {'religiomythological': []},
 'religion': ['religione',
              'religiones',
              'religioner',
              'religional',
              'religioned',
              'religioning',
              'religionize',
              'religionism',
              'religioners',
              'religionized',
              'religionalism',
              'religionizing',
              'religionational',
              'religionization'],
 'religiona': {'religionas': []},
 'religionair': {'religionaires': []},
 'religionari': {'religionaries': [], 'religionary': []},
 'religionation': {'religionationalism': []},
 'religionationalist': {'religionationalistic': []},
 'religionbas': {'religionbased': []},
 'religioncent': {'religioncentered': []},
 'religiondomin': {'religiondominated': []},
 'religionemqu': {'religionemque': []},
 'religionen': {'religionens': []},
 'religionfre': {'religionfree': []},
 'religiongeschicht': {'religiongeschichte': []},
 'religioni': {'religionis': [], 'religiony': []},
 'religionibu': {'religionibus': []},
 'religioninspir': {'religioninspired': []},
 'religioniqu': {'religionique': []},
 'religionis': {'religionisation': [],
                'religionise': ['religionised'],
                'religionising': []},
 'religionise': ['religionised'],
 'religionisqu': {'religionisque': []},
 'religionist': ['religionistic'],
 'religionless': {'religionlessness': []},
 'religionlik': {'religionlike': []},
 'religionmak': {'religionmaking': []},
 'religionnair': {'religionnaires': []},
 'religionneutr': {'religionneutral': []},
 'religionori': {'religionoriented': []},
 'religionpsychologi': {'religionpsychologie': []},
 'religionrel': {'religionrelated': []},
 'religionsbegriff': {'religionsbegriffs': []},
 'religionsethnographisch': {'religionsethnographische': []},
 'religionsethnologi': {'religionsethnologie': []},
 'religionsfrag': {'religionsfrage': []},
 'religionsfried': {'religionsfriede': []},
 'religionsfrieden': {'religionsfriedens': []},
 'religionsgcschicht': {'religionsgcschichte': []},
 'religionsgemeind': {'religionsgemeinde': []},
 'religionsgeographi': {'religionsgeographie': []},
 'religionsgeschichl': {'religionsgeschichle': []},
 'religionsgeschicht': {'religionsgeschichte': []},
 'religionsgeschichtl': {'religionsgeschichtler': []},
 'religionsgeschichtlich': {'religionsgeschichtliche': ['religionsgeschichtliches',
                                                        'religionsgeschichtlicher']},
 'religionsgeschichtliche': ['religionsgeschichtliches',
                             'religionsgeschichtlicher'],
 'religionsgesetz': {'religionsgesetze': []},
 'religionsgesprach': {'religionsgesprache': ['religionsgespraches']},
 'religionsgesprache': ['religionsgespraches'],
 'religionsgesprdch': {'religionsgesprdche': []},
 'religionshistori': {'religionshistorie': []},
 'religionshistorik': {'religionshistoriker': []},
 'religionshistorisch': {'religionshistorische': []},
 'religionsintern': {'religionsinterner': []},
 'religionskreis': {'religionskreise': []},
 'religionskrieg': {'religionskriege': []},
 'religionskund': {'religionskunde': []},
 'religionskundlich': {'religionskundliche': []},
 'religionslehr': {'religionslehre': ['religionslehrer']},
 'religionslehre': ['religionslehrer'],
 'religionslos': {'religionslose': []},
 'religionsoziologi': {'religionsoziologie': []},
 'religionspecif': {'religionspecific': []},
 'religionsphanomenologi': {'religionsphanomenologie': []},
 'religionsphanomenologisch': {'religionsphanomenologische': []},
 'religionsphdnomenologi': {'religionsphdnomenologie': []},
 'religionsphilo': {'religionsphilos': []},
 'religionsphilosoph': {'religionsphilosophic': []},
 'religionsphilosophi': {'religionsphilosophie': []},
 'religionsphilosophisch': {'religionsphilosophische': []},
 'religionsphuosophi': {'religionsphuosophie': []},
 'religionspolitik': {'religionspolitiker': []},
 'religionspolitisch': {'religionspolitische': []},
 'religionspsychologi': {'religionspsychologie': []},
 'religionspsychologisch': {'religionspsychologische': ['religionspsychologischer']},
 'religionspsychologische': ['religionspsychologischer'],
 'religionsschul': {'religionsschule': []},
 'religionssociologi': {'religionssociologie': []},
 'religionssoziologi': {'religionssoziologie': []},
 'religionssoziologisch': {'religionssoziologische': ['religionssoziologischer']},
 'religionssoziologische': ['religionssoziologischer'],
 'religionsstift': {'religionsstifter': ['religionsstifters']},
 'religionsstifter': ['religionsstifters'],
 'religionssystem': {'religionssysteme': [], 'religionssystems': []},
 'religionst': {'religionstate': [], 'religionsts': []},
 'religionstheologi': {'religionstheologie': []},
 'religionstheori': {'religionstheorie': []},
 'religionsundervisningen': {'religionsundervisningens': []},
 'religionsunterricht': {'religionsunterrichtes': [],
                         'religionsunterrichts': []},
 'religionswissenschaftl': {'religionswissenschaftler': []},
 'religionswissenschaftlich': {'religionswissenschaftliche': ['religionswissenschaftlicher',
                                                              'religionswissenschaftliches']},
 'religionswissenschaftliche': ['religionswissenschaftlicher',
                                'religionswissenschaftliches'],
 'religionwis': {'religionwise': []},
 'religioo': {'religioos': []},
 'religiopatriot': {'religiopatriotic': []},
 'religiophilosoph': {'religiophilosophic': ['religiophilosophical']},
 'religiophilosophi': {'religiophilosophy': []},
 'religiophilosophic': ['religiophilosophical'],
 'religiopoet': {'religiopoetic': []},
 'religiopolit': {'religiopolitical': [], 'religiopolitics': []},
 'religiopsycholog': {'religiopsychological': [], 'religiopsychology': []},
 'religioqu': {'religioque': []},
 'religior': {'religiors': []},
 'religioraci': {'religioracial': []},
 'religios': {'religiose': ['religioses', 'religioser'], 'religiosity': []},
 'religiosa': {'religiosae': [], 'religiosas': []},
 'religiosament': {'religiosamente': []},
 'religiosc': {'religiosce': []},
 'religioscientif': {'religioscientific': []},
 'religioscop': {'religioscope': []},
 'religiose': ['religioses', 'religioser'],
 'religiosequ': {'religioseque': []},
 'religiosi': {'religiosis': []},
 'religiosidad': {'religiosidade': []},
 'religiosior': {'religiosiores': []},
 'religiosissim': {'religiosissime': []},
 'religiosissima': {'religiosissimae': []},
 'religiosissimi': {'religiosissimis': []},
 'religiosissimu': {'religiosissimus': []},
 'religiosit': {'religiosite': []},
 'religiosita': {'religiositas': []},
 'religiositati': {'religiositatis': []},
 'religiosiu': {'religiosius': []},
 'religioso': {'religiosos': []},
 'religiosoci': {'religiosocial': []},
 'religiosociolog': {'religiosociological': []},
 'religiospiritu': {'religiospiritual': []},
 'religioss': {'religiosse': []},
 'religiosu': {'religiosus': []},
 'religiotheolog': {'religiotheological': []},
 'religioti': {'religiotis': []},
 'religiott': {'religiotts': []},
 'religiou': {'religioue': []},
 'religioufli': {'religioufly': []},
 'religioui': {'religiouis': []},
 'religiouist': {'religiouists': []},
 'religioun': {'religioune': [], 'religiouns': []},
 'religious': ['religiouse', 'religiousity'],
 'religiousaesthet': {'religiousaesthetic': []},
 'religiousaffili': {'religiousaffiliated': []},
 'religiousbas': {'religiousbased': []},
 'religiousbelief': {'religiousbeliefs': []},
 'religiouscommun': {'religiouscommunal': [], 'religiouscommunity': []},
 'religiousconserv': {'religiousconservative': []},
 'religiouscultur': {'religiouscultural': []},
 'religiousdidact': {'religiousdidactic': []},
 'religiousecclesiast': {'religiousecclesiastical': []},
 'religiouseconom': {'religiouseconomic': []},
 'religiouseduc': {'religiouseducation': ['religiouseducational']},
 'religiouseducation': ['religiouseducational'],
 'religiouseth': {'religiousethical': []},
 'religiousethn': {'religiousethnic': []},
 'religiousgroup': {'religiousgroups': []},
 'religioushistor': {'religioushistorical': []},
 'religioushistori': {'religioushistory': []},
 'religiousideolog': {'religiousideological': []},
 'religiousinspir': {'religiousinspired': []},
 'religiousinstruct': {'religiousinstruction': []},
 'religiousintellectu': {'religiousintellectual': []},
 'religiouslead': {'religiousleaders': []},
 'religiousleg': {'religiouslegal': []},
 'religiousli': {'religiouslie': []},
 'religiousliberti': {'religiousliberty': []},
 'religiouslif': {'religiouslife': []},
 'religiouslik': {'religiouslike': []},
 'religiousliterari': {'religiousliterary': []},
 'religiouslyaffili': {'religiouslyaffiliated': []},
 'religiouslybas': {'religiouslybased': []},
 'religiouslyinclin': {'religiouslyinclined': []},
 'religiouslyinspir': {'religiouslyinspired': []},
 'religiouslymind': {'religiouslyminded': []},
 'religiouslymotiv': {'religiouslymotivated': []},
 'religiouslyori': {'religiouslyoriented': []},
 'religiousmag': {'religiousmagical': []},
 'religiousmetaphys': {'religiousmetaphysical': []},
 'religiousmilitari': {'religiousmilitary': []},
 'religiousmind': {'religiousminded': []},
 'religiousminded': {'religiousmindedness': []},
 'religiousmor': {'religiousmoral': []},
 'religiousmyst': {'religiousmystical': []},
 'religiousmytholog': {'religiousmythological': []},
 'religiousn': {'religiousnational': []},
 'religiousnationalist': {'religiousnationalistic': []},
 'religiousori': {'religiousoriented': []},
 'religiousphilosoph': {'religiousphilosophic': ['religiousphilosophical']},
 'religiousphilosophic': ['religiousphilosophical'],
 'religiouspolit': {'religiouspolitical': []},
 'religiouspractic': {'religiouspractice': []},
 'religiouspsycholog': {'religiouspsychological': []},
 'religiousritu': {'religiousritual': []},
 'religiousscientif': {'religiousscientific': []},
 'religioussoci': {'religioussocial': []},
 'religioussound': {'religioussounding': []},
 'religiousspiritu': {'religiousspiritual': []},
 'religioussponsor': {'religioussponsored': []},
 'religiousstudi': {'religiousstudies': []},
 'religioussymbol': {'religioussymbolic': []},
 'religiousthem': {'religiousthemed': []},
 'religioustheolog': {'religioustheological': []},
 'religiousti': {'religiousty': []},
 'religioustoler': {'religioustolerance': []},
 'religioustrain': {'religioustraining': []},
 'religioustyp': {'religioustype': []},
 'religiousu': {'religiousus': []},
 'religiouswis': {'religiouswise': []},
 'religiov': {'religiovs': []},
 'religiow': {'religiows': []},
 'religioznawcz': {'religioznawcze': []},
 'religioznawczi': {'religioznawczy': []},
 'religiozno': {'religioznoe': []},
 'religiozny': {'religioznye': []},
 'religipu': {'religipus': []},
 'religiqu': {'religiqus': []},
 'religiss': {'religisse': []},
 'religiu': {'religius': []},
 'religiuo': {'religiuos': []},
 'religiuu': {'religiuus': []},
 'religj': {'religjous': []},
 'religkm': {'religkms': []},
 'religl': {'religlous': []},
 'relign': {'religned': []},
 'religoiu': {'religoius': []},
 'religon': {'religons': []},
 'religonist': {'religonists': []},
 'religos': {'religose': [], 'religosity': []},
 'religous': ['religously', 'religousness'],
 'religr': {'religrous': []},
 'religt': {'religtous': []},
 'religu': {'religues': [], 'religuous': [], 'religus': []},
 'religy': {'religyous': []},
 'reliig': {'reliigous': []},
 'reliiou': {'reliious': []},
 'reliiri': {'reliirious': []},
 'reliji': {'relijious': []},
 'relijri': {'relijrious': []},
 'relik': {'relike': ['relikes'], 'reliks': []},
 'relike': ['relikes'],
 'relikt': {'relikte': ['relikter']},
 'relikte': ['relikter'],
 'relikti': {'relikty': []},
 'relilh': {'relilhed': []},
 'reliligi': {'reliligious': []},
 'relim': {'relimed': [], 'reliming': []},
 'reliminari': {'reliminaries': [], 'reliminary': []},
 'relimit': {'relimitation': [], 'relimited': [], 'relimiting': []},
 'relimn': {'relimned': []},
 'relin': {'relinal': [],
           'reline': ['relined',
                      'reliner',
                      'relines',
                      'reliners',
                      'relineate',
                      'relinement',
                      'relineated',
                      'relineation'],
           'relining': ['relinings']},
 'relinbl': {'relinble': []},
 'relincho': {'relinchos': []},
 'relind': {'relinde': []},
 'relindi': {'relindis': []},
 'reline': ['relined',
            'reliner',
            'relines',
            'reliners',
            'relineate',
            'relinement',
            'relineated',
            'relineation'],
 'relinear': {'relinearization': [],
              'relinearize': ['relinearized'],
              'relinearizing': []},
 'relinearize': ['relinearized'],
 'relineri': {'relinery': []},
 'reling': {'relinger': []},
 'relingu': {'relingue': []},
 'relinguif': {'relinguification': []},
 'relinguish': {'relinguished': [],
                'relinguishes': [],
                'relinguishing': [],
                'relinguishment': []},
 'relini': {'relinious': []},
 'relining': ['relinings'],
 'relink': {'relinked': [], 'relinking': [], 'relinks': []},
 'relinkag': {'relinkage': ['relinkages']},
 'relinkage': ['relinkages'],
 'relino': {'relinoic': []},
 'relinqish': {'relinqished': []},
 'relinqnish': {'relinqnishment': []},
 'relinqu': {'relinquant': [], 'relinque': ['relinques', 'relinquent']},
 'relinqua': {'relinquas': []},
 'relinquamu': {'relinquamus': []},
 'relinquati': {'relinquatis': []},
 'relinqucr': {'relinqucre': []},
 'relinque': ['relinques', 'relinquent'],
 'relinqueb': {'relinquebant': []},
 'relinquemu': {'relinquemus': []},
 'relinquen': {'relinquens': []},
 'relinquenda': {'relinquendae': [], 'relinquendas': []},
 'relinquendi': {'relinquendis': []},
 'relinquendo': {'relinquendos': []},
 'relinquendu': {'relinquendus': []},
 'relinquent': {'relinquentes': []},
 'relinquenti': {'relinquentis': []},
 'relinquentibu': {'relinquentibus': []},
 'relinquer': {'relinquere': ['relinqueres', 'relinquerent']},
 'relinquere': ['relinqueres', 'relinquerent'],
 'relinqui': {'relinquis': []},
 'relinquifh': {'relinquifhed': [], 'relinquifhing': [], 'relinquifhment': []},
 'relinquifli': {'relinquiflied': []},
 'relinquiih': {'relinquiihed': []},
 'relinquilh': {'relinquilhed': []},
 'relinquimu': {'relinquimus': []},
 'relinquis': {'relinquised': [], 'relinquising': []},
 'relinquish': {'relinquishable': [],
                'relinquishe': ['relinquisher',
                                'relinquished',
                                'relinquishes',
                                'relinquishers'],
                'relinquishing': [],
                'relinquishment': []},
 'relinquishe': ['relinquisher',
                 'relinquished',
                 'relinquishes',
                 'relinquishers'],
 'relinquishrn': {'relinquishrnent': []},
 'relinquisli': {'relinquislied': []},
 'relinquit': {'relinquite': []},
 'relinski': {'relinsky': []},
 'relio': {'relios': []},
 'reliobl': {'relioble': []},
 'relioiou': {'relioious': []},
 'relion': {'relions': []},
 'reliou': {'relious': []},
 'reliov': {'reliove': ['relioved'], 'relioving': []},
 'reliove': ['relioved'],
 'relip': {'relipous': []},
 'relipi': {'relipious': []},
 'relipid': {'relipidated': [], 'relipidation': []},
 'reliqi': {'reliqious': []},
 'reliqn': {'reliqnes': []},
 'reliqu': {'relique': ['reliques'],
            'reliquic': ['reliquics'],
            'reliquism': []},
 'reliqua': {'reliquae': [], 'reliquas': []},
 'reliquair': {'reliquaire': ['reliquaires']},
 'reliquaire': ['reliquaires'],
 'reliquaqu': {'reliquaque': []},
 'reliquari': {'reliquary': []},
 'reliquarumqu': {'reliquarumque': []},
 'reliquasqu': {'reliquasque': []},
 'reliquat': {'reliquats': []},
 'reliquc': {'reliquce': [], 'reliqucs': []},
 'relique': ['reliques'],
 'reliquef': {'reliquefication': []},
 'reliquefact': {'reliquefaction': []},
 'reliquefi': {'reliquefied': [],
               'reliquefies': [],
               'reliquefy': ['reliquefying']},
 'reliquefy': ['reliquefying'],
 'reliquen': {'reliquens': []},
 'reliquer': {'reliquerant': [], 'reliquere': []},
 'reliqueri': {'reliqueris': []},
 'reliquerimu': {'reliquerimus': []},
 'reliqui': {'reliquie': ['reliquies'], 'reliquis': []},
 'reliquia': {'reliquiae': [], 'reliquias': []},
 'reliquiar': {'reliquiare': []},
 'reliquiari': {'reliquiaries': [], 'reliquiary': []},
 'reliquic': {'reliquice': []},
 'reliquid': {'reliquidate': ['reliquidated'], 'reliquidation': []},
 'reliquidate': ['reliquidated'],
 'reliquie': {'reliquiee': []},
 'reliquienkult': {'reliquienkultes': []},
 'reliquienkultu': {'reliquienkultus': []},
 'reliquif': {'reliquification': []},
 'reliquifi': {'reliquified': [],
               'reliquifies': [],
               'reliquify': ['reliquifying']},
 'reliquify': ['reliquifying'],
 'reliquii': {'reliquiie': [], 'reliquiis': []},
 'reliquij': {'reliquijs': []},
 'reliquimu': {'reliquimus': []},
 'reliquiqu': {'reliquique': []},
 'reliquir': {'reliquire': []},
 'reliquis': {'reliquise': []},
 'reliquish': {'reliquished': [],
               'reliquishes': [],
               'reliquishing': [],
               'reliquishment': []},
 'reliquisqu': {'reliquisque': []},
 'reliquiss': {'reliquisse': ['reliquissent']},
 'reliquisse': ['reliquissent'],
 'reliquisti': {'reliquistis': []},
 'reliquit': {'reliquite': []},
 'reliqul': {'reliqule': []},
 'reliquo': {'reliquos': []},
 'reliquoqu': {'reliquoque': []},
 'reliquorumqu': {'reliquorumque': []},
 'reliquosqu': {'reliquosque': []},
 'reliqus': {'reliquse': []},
 'reliqut': {'reliquts': []},
 'reliquu': {'reliquue': [], 'reliquus': []},
 'reliquumqu': {'reliquumque': []},
 'relir': {'relire': ['relired', 'relirement']},
 'relire': ['relired', 'relirement'],
 'reliri': {'relirious': []},
 'relis': {'relisant': [],
           'relisation': [],
           'relise': ['relised'],
           'relision': ['relisions']},
 'relisai': {'relisais': []},
 'relisariu': {'relisarius': []},
 'relisbl': {'relisbility': [], 'relisble': []},
 'relise': ['relised'],
 'relish': ['relishe',
            'relished',
            'relisher',
            'relishers',
            'relishing',
            'relishful',
            'relishable',
            'relishment',
            'relishfully',
            'relishability'],
 'relishi': {'relishy': []},
 'relishingli': {'relishingly': []},
 'relisi': {'relisious': [], 'relisys': []},
 'relision': ['relisions'],
 'relison': {'relisons': []},
 'relisri': {'relisrious': []},
 'relist': {'relisted': [],
            'relistic': [],
            'relisting': ['relistings'],
            'relists': []},
 'relisten': {'relistened': [], 'relistening': []},
 'relisti': {'relistied': []},
 'relisting': ['relistings'],
 'relisv': {'relisve': []},
 'relit': {'relite': ['relites', 'relited'],
           'reliting': [],
           'relition': ['relitions'],
           'relitive': ['relitives', 'relitively']},
 'relite': ['relites', 'relited'],
 'reliter': {'reliteralization': [], 'reliteralized': []},
 'relith': {'relithe': []},
 'reliti': {'relities': [], 'relitious': [], 'relity': []},
 'relitig': {'relitigate': ['relitigated'],
             'relitigating': [],
             'relitigation': ['relitigations']},
 'relitigate': ['relitigated'],
 'relitigation': ['relitigations'],
 'relition': ['relitions'],
 'relitive': ['relitives', 'relitively'],
 'relitri': {'relitrious': []},
 'reliu': {'reliue': ['reliued'], 'relius': []},
 'reliue': ['reliued'],
 'reliuquish': {'reliuquishment': []},
 'reliur': {'reliure': ['reliures']},
 'reliure': ['reliures'],
 'reliv': {'relivable': [],
           'relive': ['reliver', 'relives', 'relived'],
           'reliving': []},
 'relive': ['reliver', 'relives', 'relived'],
 'reliyi': {'reliyious': []},
 'reliz': {'relizable': [], 'relization': [], 'relize': ['relizes', 'relized']},
 'relizan': {'relizane': []},
 'relize': ['relizes', 'relized'],
 'reljanov': {'reljanovic': []},
 'reljgiou': {'reljgious': []},
 'reljkov': {'reljkovic': []},
 'relk': {'relke': []},
 'rell': {'rellative': [],
          'relle': ['relled', 'relles'],
          'relling': [],
          'rells': []},
 'rella': {'rellas': []},
 'rellabl': {'rellability': [], 'rellable': []},
 'rellablllti': {'rellablllty': []},
 'rellanc': {'rellance': []},
 'rellano': {'rellanos': []},
 'rellarmin': {'rellarmine': []},
 'relle': ['relled', 'relles'],
 'rellect': {'rellected': [],
             'rellecting': [],
             'rellection': ['rellections'],
             'rellective': [],
             'rellects': []},
 'rellection': ['rellections'],
 'rellena': {'rellenas': []},
 'relleno': {'rellenos': []},
 'reller': {'rellers': []},
 'rellev': {'relleve': ['relleved']},
 'relleve': ['relleved'],
 'rellevu': {'rellevue': []},
 'rellgiou': {'rellgious': []},
 'rellglon': {'rellglons': []},
 'rellglou': {'rellglous': []},
 'relli': {'rellie': ['rellies', 'rellied'],
           'rellis': [],
           'relly': ['rellys', 'rellying']},
 'rellie': ['rellies', 'rellied'],
 'rellig': {'relligeous': []},
 'relligi': {'relligious': []},
 'relligion': {'relligione': [], 'relligions': []},
 'relligioni': {'relligionis': []},
 'relling': {'rellinger': []},
 'rellinghau': {'rellinghaus': []},
 'relliquia': {'relliquiae': [], 'relliquias': []},
 'relliquii': {'relliquiis': []},
 'rellish': {'rellished': []},
 'rellli': {'rellly': []},
 'rello': {'rellos': []},
 'rellor': {'rellored': []},
 'rellow': {'rellows': []},
 'rellqu': {'rellques': []},
 'rellstab': {'rellstabs': []},
 'relly': ['rellys', 'rellying'],
 'relm': {'relme': [], 'relms': []},
 'relmagin': {'relmagining': []},
 'relmburs': {'relmbursement': []},
 'relmer': {'relmers': []},
 'relmquish': {'relmquished': [], 'relmquishing': [], 'relmquishment': []},
 'reln': {'relne': []},
 'relnam': {'relname': []},
 'relnctanc': {'relnctance': []},
 'relnctantli': {'relnctantly': []},
 'relneck': {'relnecke': []},
 'relnforc': {'relnforced': [],
              'relnforcement': [],
              'relnforcer': ['relnforcers']},
 'relnforcer': ['relnforcers'],
 'relnk': {'relnke': []},
 'relnot': {'relnotes': []},
 'relnt': {'relnte': ['relnted', 'relntes'], 'relnting': []},
 'relnte': ['relnted', 'relntes'],
 'relnterpret': {'relnterpretation': []},
 'relntion': {'relntions': []},
 'relntiv': {'relntive': []},
 'relo': {'relos': []},
 'reload': {'reloadable': [],
            'reloaded': [],
            'reloader': ['reloaders'],
            'reloading': ['reloadings'],
            'reloads': []},
 'reloader': ['reloaders'],
 'reloading': ['reloadings'],
 'reloan': {'reloaned': [], 'reloaning': [], 'reloans': []},
 'reloas': {'reloase': ['reloased']},
 'reloase': ['reloased'],
 'reloc': {'relocal': ['relocalize',
                       'relocalizes',
                       'relocalized',
                       'relocalizing',
                       'relocalization',
                       'relocalizations'],
           'relocate': ['relocated', 'relocates'],
           'relocating': [],
           'relocation': ['relocational'],
           'relocative': [],
           'relocator': ['relocators'],
           'relocities': [],
           'relocity': []},
 'relocal': ['relocalize',
             'relocalizes',
             'relocalized',
             'relocalizing',
             'relocalization',
             'relocalizations'],
 'relocalis': {'relocalisation': [], 'relocalise': ['relocalised']},
 'relocalise': ['relocalised'],
 'relocalizado': {'relocalizados': []},
 'relocar': {'relocare': ['relocared']},
 'relocare': ['relocared'],
 'relocat': {'relocatability': [],
             'relocatable': ['relocatables'],
             'relocateable': [],
             'relocaters': []},
 'relocatable': ['relocatables'],
 'relocate': {'relocatee': ['relocatees']},
 'relocatee': ['relocatees'],
 'relocation': ['relocational'],
 'relocator': ['relocators'],
 'relock': {'relocked': [], 'relocking': [], 'relocks': []},
 'relodg': {'relodge': ['relodged'], 'relodging': []},
 'relodge': ['relodged'],
 'relog': {'relogement': [], 'reloger': [], 'relogged': [], 'relogging': []},
 'relogio': {'relogios': []},
 'reloic': {'reloice': []},
 'reloj': {'relojes': []},
 'relojero': {'relojeros': []},
 'relolut': {'relolution': []},
 'relolv': {'relolve': ['relolved']},
 'relolve': ['relolved'],
 'relong': {'relonging': [], 'relongs': []},
 'relook': {'relooked': [], 'relooking': [], 'relooks': []},
 'reloop': {'relooped': [], 'relooping': []},
 'relop': {'reloped': [], 'reloping': [], 'relopment': []},
 'relorm': {'relormation': [], 'relormers': [], 'relorming': [], 'relorms': []},
 'relort': {'relorted': []},
 'relos': {'relose': [], 'relosing': []},
 'relot': {'reloted': [],
           'reloting': [],
           'relotion': ['relotions'],
           'relotive': ['relotives', 'relotively']},
 'relotion': ['relotions'],
 'relotionship': {'relotionships': []},
 'relotive': ['relotives', 'relotively'],
 'relourc': {'relources': []},
 'relov': {'relovant': [], 'relove': ['reloved'], 'reloving': []},
 'relove': ['reloved'],
 'relow': {'relowered': [], 'relowering': [], 'relowing': []},
 'relp': {'relps': []},
 'relpect': {'relpectable': [],
             'relpecting': [],
             'relpective': ['relpectively'],
             'relpects': []},
 'relpective': ['relpectively'],
 'relpi': {'relpied': [], 'relpy': []},
 'relr': {'relres': []},
 'relractori': {'relractory': []},
 'relresh': {'relreshing': []},
 'relrgiou': {'relrgious': []},
 'relriev': {'relrieval': []},
 'relriger': {'relrigerator': []},
 'relrod': {'relrods': []},
 'relrt': {'relrted': []},
 'relrtion': {'relrtions': []},
 'rels': {'relse': []},
 'relsing': {'relsinger': []},
 'relsom': {'relsome': []},
 'relst': {'relsted': [], 'relsting': []},
 'relstion': {'relstions': []},
 'relstionship': {'relstionships': []},
 'relstiv': {'relstive': ['relstively']},
 'relstive': ['relstively'],
 'relt': {'relted': [], 'relting': [], 'relts': []},
 'reltgiou': {'reltgious': []},
 'reltgtou': {'reltgtous': []},
 'reltion': {'reltions': []},
 'reltionship': {'reltionships': []},
 'reltiv': {'reltive': ['reltives', 'reltively']},
 'reltive': ['reltives', 'reltively'],
 'reltor': {'reltore': ['reltored']},
 'reltore': ['reltored'],
 'reltqu': {'reltques': []},
 'reltyp': {'reltype': []},
 'relu': {'relue': ['relues'], 'relus': []},
 'relub': {'relube': []},
 'relubbu': {'relubbus': []},
 'relubr': {'relubricate': ['relubricated'],
            'relubricating': [],
            'relubrication': []},
 'relubricate': ['relubricated'],
 'reluc': {'relucance': [],
           'relucant': [],
           'reluce': ['reluced',
                      'reluces',
                      'relucent',
                      'relucency',
                      'relucence']},
 'relucantli': {'relucantly': []},
 'reluce': ['reluced', 'reluces', 'relucent', 'relucency', 'relucence'],
 'relucen': {'relucens': []},
 'relucent': {'relucente': ['relucentes']},
 'relucente': ['relucentes'],
 'relucer': {'relucere': []},
 'relucient': {'reluciente': ['relucientes']},
 'reluciente': ['relucientes'],
 'relucl': {'reluclance': []},
 'relucr': {'relucrance': [], 'relucrant': []},
 'reluct': {'reluctance': [],
            'reluctancies': [],
            'reluctancy': [],
            'reluctant': ['reluctants'],
            'reluctate': ['reluctates', 'reluctated'],
            'reluctation': ['reluctations'],
            'relucted': [],
            'reluctence': [],
            'reluctent': ['reluctently'],
            'relucting': [],
            'reluction': [],
            'reluctive': [],
            'reluctivity': [],
            'relucts': []},
 'reluctamli': {'reluctamly': []},
 'reluctan': {'reluctans': []},
 'reluctanci': {'reluctancie': []},
 'reluctanctli': {'reluctanctly': []},
 'reluctandi': {'reluctandy': []},
 'reluctane': {'reluctanee': []},
 'reluctanli': {'reluctanly': []},
 'reluctano': {'reluctanoe': []},
 'reluctanrli': {'reluctanrly': []},
 'reluctant': {'reluctante': ['reluctantes']},
 'reluctante': ['reluctantes'],
 'reluctanti': {'reluctantis': []},
 'reluctantibu': {'reluctantibus': []},
 'reluctantli': {'reluctantly': []},
 'reluctate': ['reluctates', 'reluctated'],
 'reluctation': {'reluctatione': []},
 'reluctatu': {'reluctatus': []},
 'reluctauc': {'reluctauce': []},
 'reluctautli': {'reluctautly': []},
 'reluctent': ['reluctently'],
 'relucti': {'reluctiance': []},
 'reluctlantli': {'reluctlantly': []},
 'relud': {'relude': []},
 'reludt': {'reludtance': []},
 'relue': ['relues'],
 'reluet': {'reluetance': [], 'reluetant': []},
 'reluetane': {'reluetanee': []},
 'reluetantli': {'reluetantly': []},
 'reluft': {'reluftance': [], 'reluftant': []},
 'reluftantli': {'reluftantly': []},
 'relug': {'reluge': []},
 'reluga': {'relugas': []},
 'reluge': {'relugees': []},
 'relui': {'reluis': []},
 'reluir': {'reluire': ['reluired']},
 'reluire': ['reluired'],
 'reluis': {'reluisant': ['reluisants'], 'reluisent': []},
 'reluisant': {'reluisante': ['reluisantes']},
 'reluisante': ['reluisantes'],
 'relult': {'relults': []},
 'relum': {'relumal': [],
           'relume': ['relumed', 'relumes'],
           'reluming': [],
           'relums': []},
 'relumbr': {'relumbre': []},
 'relumbrant': {'relumbrante': ['relumbrantes']},
 'relumbrante': ['relumbrantes'],
 'relume': ['relumed', 'relumes'],
 'relumin': {'relumine': ['relumined', 'relumines']},
 'relumine': ['relumined', 'relumines'],
 'relunct': {'relunctance': [], 'relunctant': []},
 'relunctantli': {'relunctantly': []},
 'relund': {'relunded': [], 'relunds': []},
 'reluot': {'reluotance': [], 'reluotant': []},
 'reluotano': {'reluotanoe': []},
 'reluotantli': {'reluotantly': []},
 'relurn': {'relurned': [], 'relurning': [], 'relurns': []},
 'relus': {'relusal': [], 'reluse': ['relused', 'reluses'], 'relusing': []},
 'reluse': ['relused', 'reluses'],
 'relut': {'relutance': [],
           'relute': ['reluted', 'relutes'],
           'reluting': [],
           'relution': ['relutions'],
           'relutive': []},
 'relutant': {'relutante': []},
 'relutantement': {'relutantemente': []},
 'relute': ['reluted', 'relutes'],
 'relution': ['relutions'],
 'reluzent': {'reluzente': []},
 'relv': {'relving': []},
 'relva': {'relvas': []},
 'relvanc': {'relvance': []},
 'relvari': {'relvariance': []},
 'rely': {'relye': ['relyes']},
 'relyabl': {'relyable': []},
 'relyanc': {'relyance': []},
 'relye': ['relyes'],
 'relyef': {'relyefe': []},
 'relyf': {'relyfe': []},
 'relygi': {'relygious': []},
 'relygy': {'relygyous': []},
 'relygyous': {'relygyouse': []},
 'relygyu': {'relygyus': []},
 'relyk': {'relyke': ['relykes'], 'relyks': []},
 'relyke': ['relykes'],
 'relyophil': {'relyophilized': []},
 'relyqu': {'relyques': []},
 'relyv': {'relyve': ['relyved']},
 'relyve': ['relyved'],
 'relziu': {'relzius': []},
 'rem': ['remmed', 'remming'],
 'rema': {'remae': [], 'remaing': [], 'remas': []},
 "rema'k": {"rema'ks": []},
 "rema'n": {"rema'ns": []},
 'remabk': {'remabks': []},
 'remacadam': {'remacadamized': [], 'remacadamizing': []},
 'remacemid': {'remacemide': []},
 'remach': {'remache': []},
 'remachin': {'remachine': ['remachined'], 'remachining': []},
 'remachine': ['remachined'],
 'remaci': {'remacy': []},
 'remacl': {'remacle': []},
 'remaclu': {'remaclus': []},
 'remad': {'remade': []},
 'remadi': {'remady': []},
 'remaek': {'remaeks': []},
 'remaeu': {'remaeus': []},
 'remafk': {'remafkable': []},
 'remag': {'remage': []},
 'remagn': {'remagne': []},
 'remagnet': {'remagnetization': ['remagnetizations'],
              'remagnetize': ['remagnetizes', 'remagnetized'],
              'remagnetizing': []},
 'remagnetis': {'remagnetisation': [],
                'remagnetise': ['remagnetised'],
                'remagnetising': []},
 'remagnetise': ['remagnetised'],
 'remagnetization': ['remagnetizations'],
 'remagnetize': ['remagnetizes', 'remagnetized'],
 'remagnifi': {'remagnified': []},
 'remahk': {'remahks': []},
 'remai': {'remaie': ['remaied'], 'remais': []},
 'remaia': {'remaiaed': [], 'remaiaing': [], 'remaias': []},
 'remaiad': {'remaiader': []},
 'remaid': {'remaided': [], 'remaider': []},
 'remaie': ['remaied'],
 'remaign': {'remaigne': []},
 'remaih': {'remaihed': [], 'remaihing': []},
 'remaik': {'remaikable': [],
            'remaikably': [],
            'remaiked': [],
            'remaiking': [],
            'remaiks': []},
 'remail': {'remailed': [],
            'remailer': ['remailers'],
            'remailing': ['remailings'],
            'remails': []},
 'remailer': ['remailers'],
 'remaili': {'remaily': []},
 'remailing': ['remailings'],
 'remaim': {'remaimed': [], 'remaims': []},
 'remain': {'remainants': [],
            'remaine': ['remainer',
                        'remained',
                        'remaines',
                        'remainers',
                        'remaineing'],
            'remaining': ['remainings'],
            'remainned': [],
            'remainning': [],
            'remains': []},
 'remaina': {'remainas': []},
 'remaind': {'remainde': ['remainder',
                          'remainded',
                          'remaindered',
                          'remaindering'],
             'remainding': [],
             'remainds': []},
 'remainde': ['remainder', 'remainded', 'remaindered', 'remaindering'],
 'remainderperson': {'remainderpersons': []},
 'remaindr': {'remaindre': []},
 'remaine': {'remainees': []},
 'remained': {'remaineder': []},
 'remainedth': {'remainedthe': []},
 'remainf': {'remainfed': [], 'remainfs': []},
 'remaini': {'remainis': []},
 'remainin': {'remainine': [], 'remainining': [], 'remainins': []},
 'remaining': {'remaininge': []},
 'remainingjew': {'remainingjews': []},
 'remaino': {'remainoer': []},
 'remainsth': {'remainsthe': []},
 'remainsunchang': {'remainsunchanged': []},
 'remaint': {'remainted': [], 'remainting': []},
 'remainth': {'remainthe': []},
 'remaio': {'remaioed': [], 'remaios': []},
 'remaip': {'remaiped': []},
 'remair': {'remaired': [], 'remairing': [], 'remairs': []},
 'remairi': {'remairied': [], 'remairis': []},
 'remaiss': {'remaissance': []},
 'remaiu': {'remaiue': ['remaiued'], 'remaiuing': [], 'remaius': []},
 'remaiud': {'remaiuder': []},
 'remaiue': ['remaiued'],
 'remajenn': {'remajenne': []},
 'remajn': {'remajne': ['remajned'], 'remajns': []},
 'remajne': ['remajned'],
 'remak': {'remakable': [],
           'remakably': [],
           'remake': ['remaked', 'remaker', 'remakers'],
           'remaking': [],
           'remaks': []},
 'remake': ['remaked', 'remaker', 'remakers'],
 'remakk': {'remakks': []},
 'remaklu': {'remaklus': []},
 'remakr': {'remakrable': [], 'remakred': [], 'remakrs': []},
 'remal': {'remale': ['remales']},
 'remale': ['remales'],
 'remali': {'remaly': []},
 'remaln': {'remalned': [], 'remalning': [], 'remalns': []},
 'remalnd': {'remalnder': []},
 'remam': {'remame': ['remamed'], 'remaming': [], 'remams': []},
 'remamb': {'remamber': ['remambered']},
 'remamber': ['remambered'],
 'remamd': {'remamder': []},
 'remame': ['remamed'],
 'reman': {'remanance': [],
           'remanant': ['remanants'],
           'remanation': [],
           'remane': ['remanes',
                      'remaned',
                      'remaner',
                      'remanent',
                      'remanence',
                      'remanents',
                      'remaneant',
                      'remanences',
                      'remanently'],
           'remaning': [],
           'remanned': [],
           'remanning': [],
           'remans': []},
 'remanag': {'remanaged': [], 'remanagement': [], 'remanaging': []},
 'remanant': ['remanants'],
 'remanc': {'remance': []},
 'remancip': {'remancipate': ['remancipated'], 'remancipation': []},
 'remancipate': ['remancipated'],
 'remand': ['remanded', 'remander', 'remanding', 'remandment'],
 'remande': {'remandees': []},
 'remandr': {'remandre': []},
 'remane': ['remanes',
            'remaned',
            'remaner',
            'remanent',
            'remanence',
            'remanents',
            'remaneant',
            'remanences',
            'remanently'],
 'remaneb': {'remanebant': []},
 'remanen': {'remanens': []},
 'remanent': {'remanente': ['remanentes']},
 'remanente': ['remanentes'],
 'remanenti': {'remanentis': []},
 'remanentibu': {'remanentibus': []},
 'remaner': {'remanere': ['remanerent']},
 'remanere': ['remanerent'],
 'remanesc': {'remanescent': []},
 'remanescent': {'remanescente': ['remanescentes']},
 'remanescente': ['remanescentes'],
 'remanet': {'remanete': [], 'remanets': []},
 'remani': {'remaniant': [],
            'remanie': ['remanied',
                        'remanier',
                        'remanies',
                        'remaniement',
                        'remaniements'],
            'remanis': [],
            'remany': ['remanying']},
 'remanid': {'remanider': []},
 'remanie': {'remaniee': ['remaniees']},
 'remaniee': ['remaniees'],
 'remanieur': {'remanieurs': []},
 'remanifest': {'remanifestation': ['remanifestations'],
                'remanifested': [],
                'remanifesting': [],
                'remanifests': []},
 'remanifestation': ['remanifestations'],
 'remanin': {'remanined': [], 'remanining': []},
 'remanipul': {'remanipulate': ['remanipulated'],
               'remanipulating': [],
               'remanipulation': ['remanipulations']},
 'remanipulate': ['remanipulated'],
 'remanipulation': ['remanipulations'],
 'remannt': {'remannts': []},
 'remanser': {'remanserant': [], 'remansere': []},
 'remansimu': {'remansimus': []},
 'remansiss': {'remansisse': ['remansissent']},
 'remansisse': ['remansissent'],
 'remanso': {'remansos': []},
 'remansuri': {'remansuris': []},
 'remant': {'remantic': [], 'remants': []},
 'remantic': {'remanticism': []},
 'remantl': {'remantle': ['remantled']},
 'remantle': ['remantled'],
 'remanufactur': {'remanufacturability': [],
                  'remanufacturable': [],
                  'remanufacture': ['remanufacturer',
                                    'remanufactured',
                                    'remanufactures',
                                    'remanufacturers'],
                  'remanufacturing': []},
 'remanufacture': ['remanufacturer',
                   'remanufactured',
                   'remanufactures',
                   'remanufacturers'],
 'remany': ['remanying'],
 'remap': {'remapped': [], 'remapping': ['remappings'], 'remaps': []},
 'remapp': {'remappable': [], 'remapper': []},
 'remapping': ['remappings'],
 'remar': {'remarable': [], 'remarably': [], 'remare': ['remares']},
 'remarak': {'remarakable': []},
 'remarakbl': {'remarakble': []},
 'remarb': {'remarbable': [], 'remarbably': []},
 'remarc': {'remarcable': [], 'remarcably': []},
 'remarcabil': {'remarcabile': []},
 'remarch': {'remarched': [], 'remarching': []},
 'remard': {'remarded': [], 'remards': []},
 'remare': ['remares'],
 'remargin': {'remarginalization': [],
              'remarginalize': ['remarginalized'],
              'remargined': [],
              'remargining': []},
 'remarginalize': ['remarginalized'],
 'remargu': {'remargues': []},
 'remarh': {'remarhable': [], 'remarhably': [], 'remarhs': []},
 'remari': {'remarie': ['remarier', 'remaries']},
 'remariag': {'remariage': []},
 'remarie': {'remariee': []},
 'remarit': {'remarital': []},
 'remark': ['remarke',
            'remarkes',
            'remarker',
            'remarked',
            'remarkal',
            'remarkers',
            'remarking',
            'remarkible',
            'remarkable',
            'remarkably',
            'remarkings',
            'remarkeable',
            'remarkables',
            'remarkeably',
            'remarkablely',
            'remarkability',
            'remarkableness'],
 'remarka': {'remarkaable': []},
 'remarkab': {'remarkabe': []},
 "remarkab'": {"remarkab'e": []},
 'remarkabel': {'remarkabell': []},
 'remarkabf': {'remarkabfe': []},
 'remarkabi': {'remarkabie': [], 'remarkaby': []},
 'remarkabj': {'remarkabje': []},
 'remarkablelook': {'remarkablelooking': []},
 'remarkableplac': {'remarkableplaces': []},
 'remarkablli': {'remarkablly': []},
 'remarkabt': {'remarkabte': []},
 'remarkadl': {'remarkadle': []},
 'remarkahl': {'remarkahle': []},
 'remarkahli': {'remarkahly': []},
 'remarkakl': {'remarkakle': []},
 'remarkal': {'remarkale': []},
 'remarkam': {'remarkame': []},
 'remarkaol': {'remarkaole': []},
 'remarkarbl': {'remarkarble': []},
 'remarkarl': {'remarkarle': []},
 'remarkaw': {'remarkawe': []},
 'remarkbal': {'remarkbale': []},
 'remarkbl': {'remarkble': [], 'remarkbly': []},
 'remarkebl': {'remarkeble': [], 'remarkebly': []},
 'remarkedli': {'remarkedly': []},
 'remarket': {'remarketable': [],
              'remarketed': [],
              'remarketer': ['remarketers'],
              'remarketing': [],
              'remarketization': [],
              'remarkets': []},
 'remarketer': ['remarketers'],
 'remarkli': {'remarkly': []},
 'remarknbl': {'remarknble': [], 'remarknbly': []},
 'remarksbl': {'remarksble': []},
 'remarkth': {'remarkthe': []},
 'remarkubl': {'remarkuble': []},
 'remarl': {'remarle': ['remarles']},
 'remarlc': {'remarlcable': [], 'remarlcs': []},
 'remarle': ['remarles'],
 'remarn': {'remarned': [], 'remarning': []},
 'remarqn': {'remarqnes': []},
 'remarqu': {'remarquable': ['remarquables'],
             'remarquably': [],
             'remarquant': [],
             'remarque': ['remarques',
                          'remarqued',
                          'remarquer',
                          'remarquent',
                          'remarqueable']},
 'remarqua': {'remarquas': []},
 'remarquabl': {'remarquablement': []},
 'remarquable': ['remarquables'],
 'remarquai': {'remarquaient': [], 'remarquais': []},
 'remarquc': {'remarqucs': []},
 'remarque': {'remarquee': ['remarquees']},
 'remarquee': ['remarquees'],
 'remarquer': {'remarquerent': []},
 'remarqueron': {'remarquerons': []},
 'remarquion': {'remarquions': []},
 'remarquon': {'remarquons': []},
 'remarqv': {'remarqvable': []},
 'remarr': {'remarrs': []},
 'remarraig': {'remarraige': []},
 'remarri': {'remarried': ['remarrieds'],
             'remarriers': [],
             'remarries': [],
             'remarry': ['remarrying', 'remarryings']},
 'remarriag': {'remarriage': ['remarriageable', 'remarriageability']},
 'remarriage': ['remarriageable', 'remarriageability'],
 'remarried': ['remarrieds'],
 'remarrig': {'remarrige': []},
 'remarry': ['remarrying', 'remarryings'],
 'remarsh': {'remarshal': ['remarshaled', 'remarshaling']},
 'remarshal': {'remarshall': ['remarshalled', 'remarshalling']},
 'remarshall': ['remarshalled', 'remarshalling'],
 'remascul': {'remasculation': []},
 'remasculin': {'remasculinization': [],
                'remasculinize': ['remasculinizes', 'remasculinized'],
                'remasculinizing': []},
 'remasculinis': {'remasculinisation': []},
 'remasculinize': ['remasculinizes', 'remasculinized'],
 'remask': {'remaskable': [], 'remasked': [], 'remasking': []},
 'remass': {'remassed': [], 'remassing': []},
 'remast': {'remasted': [],
            'remaster': ['remasters',
                         'remastered',
                         'remastering',
                         'remasterings'],
            'remasticate': ['remasticated'],
            'remasticating': [],
            'remastication': [],
            'remasting': []},
 'remaster': ['remasters', 'remastered', 'remastering', 'remasterings'],
 'remasteri': {'remastery': []},
 'remasticate': ['remasticated'],
 'remat': {'remate': ['remated', 'remates'],
           'rematic': [],
           'remating': ['rematings'],
           'remation': [],
           'rematted': [],
           'rematting': []},
 'rematada': {'rematadas': []},
 'rematado': {'rematados': []},
 'rematch': ['rematched', 'rematching'],
 'remate': ['remated', 'remates'],
 'remateri': {'rematerialization': [],
              'rematerialize': ['rematerializes', 'rematerialized'],
              'rematerializing': []},
 'rematerialis': {'rematerialisation': [],
                  'rematerialise': ['rematerialised', 'rematerialises'],
                  'rematerialising': []},
 'rematerialise': ['rematerialised', 'rematerialises'],
 'rematerialize': ['rematerializes', 'rematerialized'],
 'remating': ['rematings'],
 'rematk': {'rematkable': [], 'rematkably': [], 'rematked': [], 'rematks': []},
 'rematn': {'rematned': [], 'rematning': [], 'rematns': []},
 'rematnd': {'rematnder': []},
 'rematricul': {'rematriculate': ['rematriculated'], 'rematriculation': []},
 'rematriculate': ['rematriculated'],
 'rematt': {'rematter': []},
 'rematur': {'rematuration': [], 'remature': []},
 'remaudier': {'remaudiere': []},
 'remaund': {'remaunded': []},
 'remauri': {'remaury': []},
 'remaurk': {'remaurkable': []},
 'remav': {'remaval': [], 'remave': ['remaved'], 'remaving': []},
 'remave': ['remaved'],
 'remayn': {'remayne': ['remayner', 'remayned', 'remaynes', 'remayneing'],
            'remayning': [],
            'remayns': []},
 'remaynd': {'remaynder': ['remaynders']},
 'remaynder': ['remaynders'],
 'remayne': ['remayner', 'remayned', 'remaynes', 'remayneing'],
 'remayneth': {'remaynethe': []},
 'remayning': {'remayninge': []},
 'remaynyng': {'remaynynge': []},
 'remb': {'rembe': []},
 'remba': {'rembas': []},
 'rembarqu': {'rembarquer': []},
 'rembemb': {'rembember': []},
 'rember': {'remberance': [], 'rembered': [], 'rembering': [], 'rembers': []},
 'remberg': {'remberger': []},
 'rembert': {'remberts': []},
 'rembertu': {'rembertus': []},
 'rembg': {'rembges': []},
 'rembi': {'rembis': [], 'remby': []},
 'rembl': {'remble': ['rembled'], 'rembling': []},
 'remblai': {'remblais': []},
 'remblanc': {'remblance': []},
 'remblay': {'remblaye': []},
 'remblayag': {'remblayage': []},
 'remble': ['rembled'],
 'remboitag': {'remboitage': []},
 'rembour': {'rembours': []},
 'rembours': {'remboursable': ['remboursables'],
              'remboursant': [],
              'rembourse': ['rembourser',
                            'rembourses',
                            'remboursement',
                            'remboursements']},
 'remboursable': ['remboursables'],
 'rembourse': {'remboursee': ['remboursees']},
 'remboursee': ['remboursees'],
 'rembr': {'rembred': []},
 'rembranc': {'rembrance': ['rembrancer', 'rembrances']},
 'rembrance': ['rembrancer', 'rembrances'],
 'rembrandf': {'rembrandfs': []},
 'rembrandt': ['rembrandtism'],
 'rembrandtdeutsch': {'rembrandtdeutsche': []},
 'rembrandtesqu': {'rembrandtesque': []},
 'rembrandthui': {'rembrandthuis': []},
 'rembrandtist': {'rembrandtists': []},
 'rembrandtlik': {'rembrandtlike': []},
 'rembrandtstrass': {'rembrandtstrasse': []},
 'rembrant': {'rembrants': []},
 'rembrantesqu': {'rembrantesque': []},
 'rembrants': {'rembrantse': []},
 'rembri': {'rembry': []},
 'rembv': {'rembved': []},
 'rembw': {'rembwe': []},
 'remcdio': {'remcdios': []},
 'remclt': {'remclted': [], 'remclting': []},
 'remcmbr': {'remcmbred': []},
 'remct': {'remcte': []},
 'remcv': {'remcve': ['remcved']},
 'remcve': ['remcved'],
 'remd': {'remde': []},
 'remdepriv': {'remdeprived': []},
 'remdi': {'remdies': [], 'remdy': []},
 'remdv': {'remdve': ['remdved']},
 'remdve': ['remdved'],
 'reme': {'remed': [],
          'remee': ['remeed'],
          'remely': [],
          'remes': [],
          'reming': []},
 'remeab': {'remeaber': ['remeabered']},
 'remeaber': ['remeabered'],
 'remeadi': {'remeadie': [], 'remeady': []},
 'remean': {'remeane': [], 'remeaning': [], 'remeans': []},
 'remeand': {'remeandering': []},
 'remeansqu': {'remeansque': []},
 'remeantibu': {'remeantibus': []},
 'remear': {'remeare': []},
 'remeass': {'remeasse': []},
 'remeasur': {'remeasurable': [],
              'remeasure': ['remeasures',
                            'remeasured',
                            'remeasurement',
                            'remeasurements'],
              'remeasuring': []},
 'remeasure': ['remeasures', 'remeasured', 'remeasurement', 'remeasurements'],
 'remeb': {'remeber': ['remebers', 'remebered', 'remebering']},
 'remeber': ['remebers', 'remebered', 'remebering'],
 'remebr': {'remebrance': [], 'remebre': ['remebred'], 'remebring': []},
 'remebre': ['remebred'],
 'remeck': {'remecke': []},
 'remectr': {'remectre': []},
 'remed': {'remedation': [],
           'remede': ['remedes', 'remeded'],
           'remedic': ['remedics', 'remedical', 'remedicated', 'remedication'],
           'remeding': []},
 'remede': ['remedes', 'remeded'],
 'remedi': {'remediability': [],
            'remediable': ['remediableness'],
            'remediably': [],
            'remedial': ['remedials',
                         'remedially',
                         'remedialism',
                         'remediality'],
            'remediate': ['remediates', 'remediated'],
            'remediating': [],
            'remediation': ['remediational'],
            'remediative': [],
            'remediator': ['remediators'],
            'remedie': ['remedied', 'remedier'],
            'remedy': ['remedyed', 'remedying']},
 'remedia': {'remedias': []},
 'remediable': ['remediableness'],
 'remediado': {'remediados': []},
 'remedial': ['remedials', 'remedially', 'remedialism', 'remediality'],
 'remedialist': {'remedialists': []},
 'remedialread': {'remedialreading': []},
 'remediar': {'remediare': []},
 'remediari': {'remediary': []},
 'remediarla': {'remediarlas': []},
 'remediars': {'remediarse': []},
 'remediate': ['remediates', 'remediated'],
 'remediation': ['remediational'],
 'remediator': ['remediators'],
 'remediatori': {'remediatory': []},
 'remedic': {'remedicalization': [], 'remedicalize': ['remedicalized']},
 'remedicalize': ['remedicalized'],
 'remedie': ['remedied', 'remedier'],
 'remedii': {'remediis': []},
 'remedij': {'remedijs': []},
 'remedil': {'remediles': []},
 'remediless': {'remedilesse': [], 'remedilessness': []},
 'remedilessli': {'remedilessly': []},
 'remedio': {'remedios': []},
 'remedit': {'remeditated': [], 'remeditation': []},
 'remediu': {'remedius': []},
 'remedl': {'remedles': []},
 'remedlo': {'remedlos': []},
 'remedt': {'remedtes': []},
 'remedv': {'remedving': []},
 'remedy': {'remedye': ['remedyes']},
 'remedye': ['remedyes'],
 'remedyi': {'remedyis': []},
 'remee': ['remeed'],
 'remeet': {'remeeting': ['remeetings'], 'remeets': []},
 'remeeting': ['remeetings'],
 'remeeu': {'remeeus': []},
 'remegiu': {'remegius': []},
 'remei': {'remeis': []},
 'remeid': {'remeided': []},
 'remeij': {'remeijer': []},
 'remeiki': {'remeikis': []},
 'remein': {'remeined': [], 'remeining': [], 'remeins': []},
 'remeinb': {'remeinber': ['remeinbered']},
 'remeinber': ['remeinbered'],
 'remeind': {'remeinder': []},
 'remel': {'remele': [], 'remels': []},
 'remele': {'remelee': []},
 'remelt': {'remeltable': [],
            'remelted': [],
            'remelter': ['remelters'],
            'remelting': ['remeltings'],
            'remelts': []},
 'remelter': ['remelters'],
 'remelting': ['remeltings'],
 'remem': {'rememer': ['rememered']},
 "remem'": {"remem'er": []},
 'rememb': {'remembance': [],
            'remembe': ['remembed',
                        'remember',
                        'remembers',
                        'remembeing',
                        'remembered',
                        'remembering',
                        'rememberred']},
 'rememba': {'remembas': []},
 'remembar': {'remembared': []},
 'remembe': {'remembeed': []},
 'remembei': {'remembeied': [], 'remembeiing': []},
 'remember': {'rememberability': [],
              'rememberable': [],
              'rememberably': [],
              'rememberance': ['rememberances'],
              'remembere': ['rememberer', 'rememberers', 'rememberence'],
              'rememberment': []},
 'rememberanc': {'rememberancer': []},
 'rememberance': ['rememberances'],
 'rememberaunc': {'rememberaunce': []},
 'remembere': {'remembereed': []},
 'rememberi': {'remembery': []},
 'rememberingli': {'rememberingly': []},
 'rememberingth': {'rememberingthe': []},
 'rememberth': {'rememberthe': []},
 'rememberthatth': {'rememberthatthe': []},
 'rememberthi': {'rememberthis': []},
 'remembery': {'rememberyou': []},
 'remembet': {'remembeted': [], 'remembeting': []},
 'remembi': {'remembiance': []},
 'remembl': {'rememblance': [], 'remembles': []},
 'remembor': {'remembored': []},
 'remembr': {'remembrance': [],
             'remembre': ['remembred',
                          'remembrer',
                          'remembrence',
                          'remembrement'],
             'remembring': []},
 'remembrac': {'remembrace': []},
 'remembran': {'remembrans': []},
 'remembranc': {'remembranced': [],
                'remembrancer': ['remembrancers'],
                'remembrancing': ['remembrancings']},
 'remembrancer': ['remembrancers'],
 'remembrancing': ['remembrancings'],
 'remembrane': {'remembranee': []},
 'remembrano': {'remembranoe': []},
 'remembranza': {'remembranzas': []},
 'remembrauc': {'remembrauce': []},
 'remembraunc': {'remembraunce': ['remembraunces']},
 'remembraunce': ['remembraunces'],
 'remembre': ['remembred', 'remembrer', 'remembrence', 'remembrement'],
 'remembreth': {'remembrethe': []},
 'remembring': {'remembringe': []},
 'remembryng': {'remembrynge': []},
 'remembsr': {'remembsred': []},
 'rememd': {'rememder': ['rememdered']},
 'rememder': ['rememdered'],
 'rememdi': {'rememdies': [], 'rememdy': []},
 'rememeb': {'rememeber': ['rememebered']},
 'rememeber': ['rememebered'],
 'rememebr': {'rememebred': []},
 'remememb': {'rememember': ['rememembered']},
 'rememember': ['rememembered'],
 'rememer': ['rememered'],
 'rememerri': {'rememerry': []},
 'rememh': {'rememher': ['rememhers', 'rememhered', 'rememhering']},
 'rememher': ['rememhers', 'rememhered', 'rememhering'],
 'rememhr': {'rememhrance': ['rememhrances']},
 'rememhranc': {'rememhrancer': []},
 'rememhrance': ['rememhrances'],
 'rememk': {'rememker': []},
 'rememli': {'rememlier': ['rememliered']},
 'rememlier': ['rememliered'],
 'rememlj': {'rememljer': []},
 'rememlwr': {'rememlwred': []},
 'rememo': {'rememoer': ['rememoered']},
 'rememoer': ['rememoered'],
 'rememor': {'rememorable': [],
             'rememorance': [],
             'rememorant': [],
             'rememorate': ['rememorated', 'rememorates'],
             'rememorating': [],
             'rememoration': ['rememorations'],
             'rememorative': [],
             'rememore': ['rememorer'],
             'rememoring': [],
             'rememorization': [],
             'rememorize': ['rememorized'],
             'rememorizing': []},
 'rememorar': {'rememorare': []},
 'rememorate': ['rememorated', 'rememorates'],
 'rememoration': ['rememorations'],
 'rememore': ['rememorer'],
 'rememori': {'rememoried': [], 'rememories': [], 'rememory': ['rememorying']},
 'rememorize': ['rememorized'],
 'rememory': ['rememorying'],
 'rememp': {'rememper': []},
 'rememr': {'rememrance': [], 'rememred': []},
 'rememt': {'rememter': []},
 'rememth': {'rememthe': []},
 'remen': {'remenance': [],
           'remenant': ['remenants'],
           'remene': ['remener'],
           'remens': []},
 'remenant': ['remenants'],
 'remenaunt': {'remenaunte': []},
 'remenauvil': {'remenauville': []},
 'remenb': {'remenber': ['remenbered', 'remenbering']},
 'remenber': ['remenbered', 'remenbering'],
 'remenbr': {'remenbrance': []},
 'remend': {'remended': [],
            'remender': [],
            'remending': [],
            'remendous': ['remendously']},
 'remendous': ['remendously'],
 'remene': ['remener'],
 'remeni': {'remeny': []},
 'remenib': {'remeniber': ['remenibered']},
 'remeniber': ['remenibered'],
 'remeniera': {'remenieras': []},
 'remenisc': {'remeniscences': [], 'remeniscent': []},
 'remens': {'remense': ['remenses']},
 'remensa': {'remensas': []},
 'remense': ['remenses'],
 'remensi': {'remensis': []},
 'remensnyd': {'remensnyder': []},
 'remensoqu': {'remensoque': []},
 'remensynd': {'remensynder': []},
 'rement': {'remental': [],
            'rementer': [],
            'remention': ['rementioned', 'rementioning'],
            'rements': []},
 'remention': ['rementioned', 'rementioning'],
 'remer': {'remere': [], 'remers': []},
 'remerb': {'remerber': []},
 'remerchandis': {'remerchandise': ['remerchandised'], 'remerchandising': []},
 'remerchandise': ['remerchandised'],
 'remerci': {'remerciant': [],
             'remercie': ['remercies',
                          'remercier',
                          'remercient',
                          'remerciement',
                          'remerciements'],
             'remerciment': ['remerciments']},
 'remercie': {'remerciee': []},
 'remerciemen': {'remerciemens': []},
 'remercier': {'remercierent': []},
 'remercimen': {'remercimens': []},
 'remerciment': ['remerciments'],
 'remercion': {'remercions': []},
 'remerevil': {'remereville': []},
 'remerg': {'remerge': ['remerger', 'remerged', 'remerges', 'remergence'],
            'remerging': []},
 'remerge': ['remerger', 'remerged', 'remerges', 'remergence'],
 'remeri': {'remery': []},
 'remerk': {'remerkable': [], 'remerkably': [], 'remerks': []},
 'remernb': {'remernber': ['remernbered']},
 'remernber': ['remernbered'],
 'remero': {'remeros': []},
 'remerqu': {'remerque': []},
 'remerrib': {'remerriber': []},
 'remes': {'remesal': [], 'remese': ['remeses']},
 'remesa': {'remesas': []},
 'remese': ['remeses'],
 'remesh': {'remeshed': [], 'remeshing': ['remeshings']},
 'remeshing': ['remeshings'],
 'remesi': {'remesy': []},
 'remesl': {'remesle': []},
 'remess': {'remesses': []},
 'remessa': {'remessas': []},
 'remet': {'remete': ['remeter', 'remetering'], 'remets': []},
 'remetabol': {'remetabolized': []},
 'remetal': {'remetalled': [], 'remetalling': []},
 'remetamorphos': {'remetamorphosed': []},
 'remetaphor': {'remetaphorization': [], 'remetaphorize': ['remetaphorized']},
 'remetaphorize': ['remetaphorized'],
 'remete': ['remeter', 'remetering'],
 'remethyl': {'remethylate': ['remethylated'],
              'remethylating': [],
              'remethylation': []},
 'remethylate': ['remethylated'],
 'remetido': {'remetidos': []},
 'remetnb': {'remetnber': []},
 'remetr': {'remetre': []},
 'remett': {'remettant': [], 'remette': ['remetter', 'remettent']},
 'remettai': {'remettaient': [], 'remettais': []},
 'remette': ['remetter', 'remettent'],
 'remettido': {'remettidos': []},
 'remetton': {'remettons': []},
 'remettr': {'remettre': []},
 'remettrai': {'remettraient': []},
 'remettron': {'remettrons': []},
 'remeu': {'remeue': ['remeued'], 'remeus': []},
 'remeue': ['remeued'],
 'remev': {'remeval': [], 'remeve': ['remeved']},
 'remeve': ['remeved'],
 'remew': {'remewed': []},
 'remeyn': {'remeyne': []},
 'remez': {'remeze': []},
 'remf': {'remfs': []},
 'remforc': {'remforce': ['remforced',
                          'remforcers',
                          'remforcement',
                          'remforcements'],
             'remforcing': []},
 'remforce': ['remforced', 'remforcers', 'remforcement', 'remforcements'],
 'remfri': {'remfry': []},
 'remgiou': {'remgious': []},
 'remhoogt': {'remhoogte': []},
 'remi': {'remie': ['remied', 'remies'], 'remis': [], 'remy': ['remys']},
 'remia': {'remias': []},
 'remian': {'remianed': [], 'remianing': [], 'remians': []},
 'remiand': {'remiander': []},
 'remic': {'remics': []},
 'remicad': {'remicade': []},
 'remich': {'remiche': []},
 'remichampagn': {'remichampagne': []},
 'remiciu': {'remicius': []},
 'remick': {'remicks': []},
 'remid': {'remide': ['remided', 'remides']},
 'remide': ['remided', 'remides'],
 'remidi': {'remidial': [],
            'remidie': ['remidies', 'remidier', 'remidied'],
            'remidy': []},
 'remidie': ['remidies', 'remidier', 'remidied'],
 'remidio': {'remidios': []},
 'remie': ['remied', 'remies'],
 'remien': {'remiens': []},
 'remiendo': {'remiendos': []},
 'remier': {'remiere': ['remieres']},
 'remiere': ['remieres'],
 'remif': {'remifer': [], 'remification': ['remifications'], 'remifs': []},
 'remiff': {'remiffness': []},
 'remiffnef': {'remiffnefs': []},
 'remifi': {'remified': []},
 'remification': ['remifications'],
 'remiflhef': {'remiflhefs': []},
 'remig': {'remige': ['remiges', 'remiger']},
 'remigantibu': {'remigantibus': []},
 'remigar': {'remigare': []},
 'remige': ['remiges', 'remiger'],
 'remigi': {'remigial': [], 'remigis': [], 'remigy': []},
 'remigibu': {'remigibus': []},
 'remigibusqu': {'remigibusque': []},
 'remigii': {'remigiis': []},
 'remigiju': {'remigijus': []},
 'remigin': {'remigins': []},
 'remigiu': {'remigius': []},
 'remigni': {'remigny': []},
 'remigolepi': {'remigolepis': []},
 'remigr': {'remigrant': ['remigrants'],
            'remigrate': ['remigrated'],
            'remigrating': [],
            'remigration': ['remigrations']},
 'remigrant': ['remigrants'],
 'remigrate': ['remigrated'],
 'remigration': ['remigrations'],
 'remigu': {'remigus': []},
 'remiin': {'remiined': [], 'remiining': [], 'remiins': []},
 'remiir': {'remiired': []},
 'remijns': {'remijnse': []},
 'remil': {'remill': ['remilled', 'remilling', 'remillers']},
 'remili': {'remily': []},
 'remilitar': {'remilitarization': [],
               'remilitarize': ['remilitarizes', 'remilitarized'],
               'remilitarizing': []},
 'remilitaris': {'remilitarisation': [],
                 'remilitarise': ['remilitarised'],
                 'remilitarising': []},
 'remilitarise': ['remilitarised'],
 'remilitarize': ['remilitarizes', 'remilitarized'],
 'remill': ['remilled', 'remilling', 'remillers'],
 'remilli': {'remilly': []},
 'remim': {'remimes': []},
 'remimb': {'remimber': ['remimbers', 'remimbered']},
 'remimber': ['remimbers', 'remimbered'],
 'remimbr': {'remimbrance': []},
 'remimer': {'remimeration': []},
 'remimsc': {'remimscences': []},
 'remin': {'reminant': ['reminants'],
           'remine': ['remines', 'remined'],
           'remining': [],
           'remins': []},
 'remina': {'reminaing': []},
 'reminant': ['reminants'],
 'remind': {'reminde': ['remindes', 'reminder', 'reminded'],
            'remindful': ['remindfully'],
            'reminding': ['remindings'],
            'reminds': []},
 'reminde': ['remindes', 'reminder', 'reminded'],
 'remindervil': {'reminderville': []},
 'remindful': ['remindfully'],
 'reminding': ['remindings'],
 'remindingli': {'remindingly': []},
 'remindingy': {'remindingyou': []},
 'remindsu': {'remindsus': []},
 'remindu': {'remindus': []},
 'remindy': {'remindyou': []},
 'remine': ['remines', 'remined'],
 'remined': {'remineded': []},
 'reminer': {'remineral': ['remineralize',
                           'remineralizes',
                           'remineralized',
                           'remineralizers',
                           'remineralizing',
                           'remineralization']},
 'remineral': ['remineralize',
               'remineralizes',
               'remineralized',
               'remineralizers',
               'remineralizing',
               'remineralization'],
 'remineralis': {'remineralisation': [],
                 'remineralise': ['remineralised'],
                 'remineralising': []},
 'remineralise': ['remineralised'],
 'remineraliz': {'remineralizable': []},
 'reminesc': {'reminesce': ['reminescent', 'reminescence', 'reminescences']},
 'reminesce': ['reminescent', 'reminescence', 'reminescences'],
 'reming': {'reminger': []},
 'remingl': {'remingle': ['remingled'], 'remingling': []},
 'remingle': ['remingled'],
 'remington': {'remingtons': []},
 'remini': {'reminis': []},
 'reminic': {'reminicences': [], 'reminicent': []},
 'reminiic': {'reminiicences': []},
 'reminim': {'reminimized': []},
 'reminin': {'reminine': []},
 'remininisc': {'remininiscences': []},
 'remininsc': {'remininscences': [], 'remininscent': []},
 'reminis': {'reminiseences': [],
             'reminiseent': [],
             'reminisence': ['reminisences'],
             'reminisent': []},
 'reminisc': {'reminisce': ['reminisced',
                            'reminisces',
                            'reminiscer',
                            'reminiscers',
                            'reminiscent',
                            'reminiscence',
                            'reminiscents',
                            'reminiscently',
                            'reminiscencies'],
              'reminiscing': ['reminiscings']},
 'reminiscari': {'reminiscaris': []},
 'reminisce': ['reminisced',
               'reminisces',
               'reminiscer',
               'reminiscers',
               'reminiscent',
               'reminiscence',
               'reminiscents',
               'reminiscently',
               'reminiscencies'],
 'reminiscen': {'reminiscene': ['reminiscenes'], 'reminiscens': []},
 'reminiscenc': {'reminiscenced': [],
                 'reminiscencer': [],
                 'reminiscencing': []},
 'reminiscencia': {'reminiscencias': []},
 'reminiscendi': {'reminiscendy': []},
 'reminiscene': {'reminiscenees': []},
 'reminisceno': {'reminiscenoes': []},
 'reminiscens': {'reminiscense': ['reminiscenses']},
 'reminiscensc': {'reminiscensces': []},
 'reminiscense': ['reminiscenses'],
 'reminiscent': {'reminiscente': ['reminiscentes']},
 'reminiscente': ['reminiscentes'],
 'reminiscenti': {'reminiscential': ['reminiscentially']},
 'reminiscential': ['reminiscentially'],
 'reminiscenz': {'reminiscenze': []},
 'reminiscer': {'reminiscere': []},
 'reminisci': {'reminiscience': ['reminisciences'], 'reminiscient': []},
 'reminiscience': ['reminisciences'],
 'reminiscing': ['reminiscings'],
 'reminiscingli': {'reminiscingly': []},
 'reminiscitori': {'reminiscitory': []},
 'reminiseene': {'reminiseenees': []},
 'reminisence': ['reminisences'],
 'reminiso': {'reminisoences': []},
 'reminiss': {'reminisse': []},
 'reminitc': {'reminitcences': []},
 'reminitski': {'reminitsky': []},
 'reminsc': {'reminsced': [],
             'reminscence': ['reminscences'],
             'reminscent': []},
 'reminscence': ['reminscences'],
 'reminsic': {'reminsicent': []},
 'remint': {'reminted': [], 'reminting': ['remintings'], 'remints': []},
 'reminting': ['remintings'],
 'reminuc': {'reminucences': []},
 'remip': {'remipes': []},
 'remiped': {'remipede': ['remipedes']},
 'remipede': ['remipedes'],
 'remiqu': {'remique': []},
 'remir': {'remirant': [],
           'remire': ['remirer', 'remires', 'remirent', 'remirement']},
 'remire': ['remirer', 'remires', 'remirent', 'remirement'],
 'remirk': {'remirkable': [], 'remirks': []},
 'remirror': {'remirrored': [], 'remirroring': []},
 'remis': {'remise': ['remised', 'remiser'],
           'remising': [],
           'remision': [],
           'remisness': []},
 'remisc': {'remiscences': [], 'remiscent': []},
 'remischovski': {'remischovsky': []},
 'remise': ['remised', 'remiser'],
 'remiser': {'remiseritis': []},
 'remiseri': {'remiseris': []},
 'remisi': {'remisier': ['remisiers']},
 'remisier': ['remisiers'],
 'remisimu': {'remisimus': []},
 'remision': {'remisiones': []},
 'remisiss': {'remisisse': []},
 'remisli': {'remisly': []},
 'remisn': {'remisnes': []},
 'remisness': {'remisnesse': []},
 'remiso': {'remisos': []},
 'remisqu': {'remisque': []},
 'remiss': {'remissable': [],
            'remisse': ['remisses', 'remisser', 'remissed', 'remissely'],
            'remissibility': [],
            'remissible': [],
            'remission': [],
            'remissive': ['remissively', 'remissiveness'],
            'remissness': []},
 'remissa': {'remissae': [], 'remissas': []},
 'remisse': ['remisses', 'remisser', 'remissed', 'remissely'],
 'remissen': {'remissenes': []},
 'remisseness': {'remissenesse': []},
 'remissi': {'remissiou': [], 'remissis': []},
 'remission': {'remissione': ['remissiones']},
 'remissione': ['remissiones'],
 'remissioni': {'remissionis': []},
 'remissionibu': {'remissionibus': []},
 'remissioninduc': {'remissioninducing': []},
 'remissioninduct': {'remissioninduction': []},
 'remissior': {'remissiore': ['remissiores']},
 'remissiore': ['remissiores'],
 'remissioribu': {'remissioribus': []},
 'remissiu': {'remissius': []},
 'remissive': ['remissively', 'remissiveness'],
 'remissli': {'remissly': []},
 'remissn': {'remissnes': []},
 'remissnef': {'remissnefs': []},
 'remissness': {'remissnesse': []},
 'remisso': {'remissos': []},
 'remissori': {'remissorial': ['remissorials'], 'remissory': []},
 'remissorial': ['remissorials'],
 'remisss': {'remisssion': []},
 'remissu': {'remissus': []},
 'remist': {'remister': []},
 'remit': ['remite',
           'remited',
           'remitted',
           'remiting',
           'remitment',
           'remitance',
           'remitting',
           'remitances'],
 'remitent': {'remitente': ['remitentes']},
 'remitente': ['remitentes'],
 'remiti': {'remities': [], 'remity': []},
 'remitida': {'remitidas': []},
 'remitido': {'remitidos': []},
 'remitiendol': {'remitiendole': []},
 'remitier': {'remitiere': []},
 'remities': {'remitiese': []},
 'remitimo': {'remitimos': []},
 'remitirl': {'remitirle': []},
 'remitirlo': {'remitirlos': []},
 'remitirm': {'remitirme': []},
 'remitirs': {'remitirse': []},
 'remitt': {'remittability': [],
            'remittable': [],
            'remittal': [],
            'remittance': [],
            'remittant': [],
            'remitte': ['remitter',
                        'remittes',
                        'remitters',
                        'remittent',
                        'remittence',
                        'remittents',
                        'remittency',
                        'remittences',
                        'remittently'],
            'remittive': [],
            'remitts': []},
 'remitta': {'remittas': []},
 'remittamu': {'remittamus': []},
 'remittancereceiv': {'remittancereceiving': []},
 'remittane': {'remittanees': []},
 'remittati': {'remittatis': []},
 'remitte': {'remittee': ['remittees']},
 'remittee': ['remittees'],
 'remittemu': {'remittemus': []},
 'remitten': {'remittens': []},
 'remittenda': {'remittendas': []},
 'remittendi': {'remittendis': []},
 'remittendo': {'remittendos': []},
 'remittent': {'remittente': ['remittentes']},
 'remittente': ['remittentes'],
 'remittenti': {'remittentis': []},
 'remittentibu': {'remittentibus': []},
 'remitter': {'remittere': ['remitterent']},
 'remittere': ['remitterent'],
 'remitti': {'remittis': []},
 'remittimu': {'remittimus': []},
 'remittingli': {'remittingly': []},
 'remittit': {'remittite': []},
 'remittitur': {'remittiturs': []},
 'remiu': {'remius': []},
 'remiud': {'remiuded': [], 'remiuds': []},
 'remium': {'remiums': []},
 'remiz': {'remize': []},
 'remizida': {'remizidae': []},
 'remizina': {'remizinae': []},
 'remizov': {'remizovs': []},
 'remk': {'remke': ['remkes']},
 'remke': ['remkes'],
 'remki': {'remky': []},
 'remku': {'remkus': []},
 'reml': {'remle': [], 'remling': []},
 'remlc': {'remlcs': []},
 'remli': {'remly': []},
 'remling': {'remlinger': []},
 'remlnlscenc': {'remlnlscences': []},
 'remlt': {'remlts': []},
 'remlu': {'remlus': []},
 'remlut': {'remlution': []},
 'remlv': {'remlved': []},
 'remm': {'remme': ['remmes']},
 'remmant': {'remmants': []},
 'remmber': {'remmbered': []},
 'remmciat': {'remmciation': []},
 'remmcr': {'remmcrs': []},
 'remmd': {'remmded': [], 'remmding': [], 'remmds': []},
 'remme': ['remmes'],
 'remmeb': {'remmeber': []},
 'remmel': {'remmele': [], 'remmell': []},
 'remmelga': {'remmelgas': []},
 'remmelt': {'remmelts': []},
 'remmelzwa': {'remmelzwaal': []},
 'remmemb': {'remmember': ['remmembered']},
 'remmember': ['remmembered'],
 'remmend': {'remmende': []},
 'remmer': {'remmers': []},
 'remmeri': {'remmerie': []},
 'remmerswa': {'remmerswaal': []},
 'remmey': {'remmeys': []},
 'remmi': {'remmie': [], 'remmy': []},
 'remmisc': {'remmiscences': []},
 'remmiss': {'remmission': []},
 'remmit': {'remmitted': []},
 'remmitt': {'remmittance': ['remmittances']},
 'remmittance': ['remmittances'],
 'remmiu': {'remmius': []},
 'remml': {'remmling': []},
 'remmling': {'remmlinger': []},
 'remmuner': {'remmuneration': []},
 'remn': {'remns': []},
 'remnanc': {'remnance': []},
 'remnanr': {'remnanrs': []},
 'remnant': ['remnante', 'remnantal', 'remnantes'],
 'remnat': {'remnats': []},
 'remnaunt': {'remnaunte': []},
 'remnaut': {'remnauts': []},
 'remnder': {'remnders': []},
 'remnent': {'remnents': []},
 'remni': {'remny': []},
 'remnin': {'remnined': [], 'remnining': [], 'remnins': []},
 'remnind': {'remninder': []},
 'remnisc': {'remniscence': ['remniscences'], 'remniscent': []},
 'remniscence': ['remniscences'],
 'remno': {'remnos': []},
 'remnrk': {'remnrked': [], 'remnrks': []},
 'remnrkabl': {'remnrkable': []},
 'remnv': {'remnved': []},
 'remo': {'remoe': [], 'remos': []},
 'remoat': {'remoate': []},
 'remobil': {'remobilization': ['remobilizations'],
             'remobilize': ['remobilized', 'remobilizes'],
             'remobilizing': []},
 'remobilis': {'remobilisation': [],
               'remobilise': ['remobilised'],
               'remobilising': []},
 'remobilise': ['remobilised'],
 'remobiliz': {'remobilizable': []},
 'remobilization': ['remobilizations'],
 'remobilize': ['remobilized', 'remobilizes'],
 'remoc': {'remoce': ['remoced']},
 'remoce': ['remoced'],
 'remock': {'remocker': []},
 'remod': {'remode': []},
 'remoddl': {'remoddled': []},
 'remodel': {'remodelation': [],
             'remodele': ['remodeled', 'remodeler', 'remodelers'],
             'remodeling': ['remodelings'],
             'remodelled': [],
             'remodeller': ['remodellers'],
             'remodelling': ['remodellings'],
             'remodelment': [],
             'remodels': []},
 'remodelag': {'remodelage': []},
 'remodele': {'remodelee': []},
 'remodeling': ['remodelings'],
 'remodeller': ['remodellers'],
 'remodelling': ['remodellings'],
 'remodelor': {'remodelors': []},
 'remoder': {'remoderation': [], 'remoderator': []},
 'remodern': {'remodernization': [],
              'remodernize': ['remodernized'],
              'remodernizing': []},
 'remodernis': {'remodernisation': [], 'remodernised': []},
 'remodernize': ['remodernized'],
 'remodi': {'remodies': [], 'remody': []},
 'remodif': {'remodification': ['remodifications']},
 'remodifi': {'remodified': [], 'remodify': ['remodifying']},
 'remodification': ['remodifications'],
 'remodify': ['remodifying'],
 'remodl': {'remodled': [], 'remodling': []},
 'remodul': {'remodulate': ['remodulates', 'remodulated'],
             'remodulating': [],
             'remodulation': [],
             'remodulator': ['remodulators']},
 'remodular': {'remodularization': []},
 'remodulate': ['remodulates', 'remodulated'],
 'remodulator': ['remodulators'],
 'remoev': {'remoeve': []},
 'remof': {'remofe': []},
 'remoi': {'remoie': ['remoied'], 'remois': []},
 'remoie': ['remoied'],
 'remoifoss': {'remoifosse': []},
 'remoin': {'remoined': [], 'remoining': [], 'remoins': []},
 'remois': {'remoise': []},
 'remoisten': {'remoistenable': [],
               'remoistened': [],
               'remoistening': [],
               'remoistens': []},
 'remoistur': {'remoisturize': ['remoisturized'], 'remoisturizing': []},
 'remoisturize': ['remoisturized'],
 'remoivil': {'remoiville': []},
 'remojada': {'remojadas': []},
 'remol': {'remole': []},
 'remolacha': {'remolachas': []},
 'remolar': {'remolares': []},
 'remold': {'remoldable': [],
            'remolded': [],
            'remolder': ['remolders'],
            'remolding': ['remoldings'],
            'remolds': []},
 'remolder': ['remolders'],
 'remolding': ['remoldings'],
 'remoldu': {'remoldus': []},
 'remolin': {'remolines': [], 'remolins': []},
 'remolino': {'remolinos': []},
 'remolqu': {'remolque': ['remolques']},
 'remolque': ['remolques'],
 'remomb': {'remomber': ['remombered']},
 'remomber': ['remombered'],
 'remon': {'remone': [], 'remons': []},
 'remond': {'remonde': [], 'remonds': []},
 'remonencq': {'remonencqs': []},
 'remonet': {'remonetization': [],
             'remonetize': ['remonetized', 'remonetizes'],
             'remonetizing': []},
 'remonetis': {'remonetisation': [],
               'remonetise': ['remonetised'],
               'remonetising': []},
 'remonetise': ['remonetised'],
 'remonetize': ['remonetized', 'remonetizes'],
 'remonflr': {'remonflrance': ['remonflrances']},
 'remonflrance': ['remonflrances'],
 'remonftr': {'remonftrance': ['remonftrances'],
              'remonftrate': ['remonftrated'],
              'remonftrating': []},
 'remonftrance': ['remonftrances'],
 'remonftrate': ['remonftrated'],
 'remoni': {'remonial': [], 'remonies': [], 'remony': []},
 'remonit': {'remonitization': []},
 'remonitor': {'remonitored': [], 'remonitoring': []},
 'remonopol': {'remonopolization': []},
 'remonst': {'remonstance': ['remonstances'], 'remonstate': ['remonstated']},
 'remonstance': ['remonstances'],
 'remonstate': ['remonstated'],
 'remonstr': {'remonstrance': [],
              'remonstrant': ['remonstrants'],
              'remonstrate': ['remonstrated', 'remonstrates'],
              'remonstrating': [],
              'remonstration': [],
              'remonstrative': ['remonstratively'],
              'remonstrator': ['remonstrators'],
              'remonstre': ['remonstrer']},
 'remonstrane': {'remonstranee': ['remonstranees']},
 'remonstranee': ['remonstranees'],
 'remonstrano': {'remonstranoe': ['remonstranoes']},
 'remonstranoe': ['remonstranoes'],
 'remonstrant': {'remonstrantes': [], 'remonstrantism': []},
 'remonstranti': {'remonstrantie': []},
 'remonstrantibu': {'remonstrantibus': []},
 'remonstrantli': {'remonstrantly': []},
 'remonstrants': {'remonstrantse': []},
 'remonstrantsch': {'remonstrantsche': []},
 'remonstrate': ['remonstrated', 'remonstrates'],
 'remonstrati': {'remonstratie': []},
 'remonstratingli': {'remonstratingly': []},
 'remonstrative': ['remonstratively'],
 'remonstrator': ['remonstrators'],
 'remonstratori': {'remonstratory': []},
 'remonstrauc': {'remonstrauce': ['remonstrauces']},
 'remonstrauce': ['remonstrauces'],
 'remonstre': ['remonstrer'],
 'remont': {'remontancy': [],
            'remontant': ['remontants'],
            'remonte': ['remontes', 'remonter', 'remontent']},
 'remontado': {'remontados': []},
 'remontag': {'remontage': ['remontages']},
 'remontage': ['remontages'],
 'remontai': {'remontaient': [], 'remontais': []},
 'remontant': ['remontants'],
 'remontars': {'remontarse': []},
 'remonte': {'remontee': ['remontees']},
 'remontee': ['remontees'],
 'remonter': {'remonterent': []},
 'remonterai': {'remonteraient': []},
 'remonth': {'remonths': []},
 'remontoir': {'remontoire': ['remontoires']},
 'remontoire': ['remontoires'],
 'remonton': {'remontons': []},
 'remontr': {'remontrance': ['remontrances'],
             'remontrant': [],
             'remontre': ['remontrer']},
 'remontrance': ['remontrances'],
 'remontre': ['remontrer'],
 'remonu': {'remonumented': []},
 'remonument': {'remonumentation': []},
 'remonvil': {'remonville': []},
 'remoor': {'remoored': [], 'remooring': []},
 'remoorter': {'remoortere': []},
 'remoou': {'remooue': ['remooued'], 'remoouing': []},
 'remooue': ['remooued'],
 'remoov': {'remoove': ['remooved'], 'remooving': []},
 'remooval': {'remoovall': []},
 'remoove': ['remooved'],
 'remop': {'remopped': []},
 'remopleurid': {'remopleurides': []},
 'remoqu': {'remoque': []},
 'remor': {'remoral': ['remoralize',
                       'remoralized',
                       'remoralizes',
                       'remoralizing',
                       'remoralization'],
           'remorant': [],
           'remore': ['remored', 'remores', 'remorely'],
           'remoring': [],
           'remors': []},
 'remora': ['remorae', 'remoraes'],
 'remoral': ['remoralize',
             'remoralized',
             'remoralizes',
             'remoralizing',
             'remoralization'],
 'remoralis': {'remoralisation': [],
               'remoralise': ['remoralised'],
               'remoralising': []},
 'remoralise': ['remoralised'],
 'remorant': {'remorante': []},
 'remorar': {'remorare': []},
 'remoratu': {'remoratus': []},
 'remorc': {'remorce': []},
 'remord': {'remorde': ['remordent'], 'remords': []},
 'remorde': ['remordent'],
 'remordimiento': {'remordimientos': []},
 'remore': ['remored', 'remores', 'remorely'],
 'remorf': {'remorfe': []},
 'remork': {'remorks': []},
 'remorph': {'remorphed': []},
 'remorqu': {'remorque': ['remorques', 'remorquer']},
 'remorquag': {'remorquage': []},
 'remorque': ['remorques', 'remorquer'],
 'remorqueur': {'remorqueurs': []},
 'remors': {'remorse': ['remorsed',
                        'remorsely',
                        'remorseful',
                        'remorsefully',
                        'remorsefulness']},
 'remorse': ['remorsed',
             'remorsely',
             'remorseful',
             'remorsefully',
             'remorsefulness'],
 'remorseful': {'remorsefull': []},
 'remorsel': {'remorseles': []},
 'remorseless': {'remorselessness': []},
 'remorselessli': {'remorselessly': []},
 'remorso': {'remorsos': []},
 'remorsu': {'remorsus': []},
 'remortar': {'remortared': [], 'remortaring': []},
 'remortgag': {'remortgage': ['remortgages', 'remortgaged'],
               'remortgaging': []},
 'remortgage': ['remortgages', 'remortgaged'],
 'remos': {'remose': ['remosed']},
 'remose': ['remosed'],
 'remostr': {'remostrances': []},
 'remot': {'remotable': [],
           'remotal': [],
           'remote': ['remoter', 'remoted', 'remotely', 'remoteness'],
           'remoting': [],
           'remotion': [],
           'remotive': [],
           'remotness': [],
           'remots': []},
 'remota': {'remotae': [], 'remotas': []},
 'remotament': {'remotamente': []},
 'remote': ['remoter', 'remoted', 'remotely', 'remoteness'],
 'remotecal': {'remotecall': []},
 'remotecontrol': {'remotecontrolled': []},
 'remotedli': {'remotedly': []},
 'remoteev': {'remoteevent': []},
 'remoteeventlisten': {'remoteeventlistener': []},
 'remotef': {'remotefs': []},
 'remotefil': {'remotefile': []},
 'remotehandl': {'remotehandling': []},
 'remoteind': {'remoteindicating': []},
 'remoteinstal': {'remoteinstall': []},
 'remotejd': {'remotejdent': []},
 'remotejjs': {'remotejjser': []},
 'remotelook': {'remotelooking': []},
 'remotelycontrol': {'remotelycontrolled': []},
 'remotelyoper': {'remotelyoperated': []},
 'remotelysens': {'remotelysensed': []},
 'remoten': {'remotenes': []},
 'remotenam': {'remotename': []},
 'remotenef': {'remotenefs': []},
 'remoteness': {'remotenesse': []},
 'remoteonli': {'remoteonly': []},
 'remoteoper': {'remoteoperated': []},
 'remoteprocedur': {'remoteprocedure': []},
 'remoteread': {'remotereading': []},
 'remotesens': {'remotesensing': []},
 'remoteserv': {'remoteserver': []},
 'remoteservernam': {'remoteservername': []},
 'remotesign': {'remotesigned': []},
 'remotesit': {'remotesite': []},
 'remoteview': {'remoteviewing': []},
 'remoth': {'remother': ['remothering']},
 'remother': ['remothering'],
 'remoti': {'remotis': []},
 'remotigu': {'remotigue': []},
 'remotingconfigur': {'remotingconfiguration': []},
 'remotingservic': {'remotingservices': []},
 'remotion': {'remotione': []},
 'remotioni': {'remotionis': []},
 'remotior': {'remotiore': ['remotiores']},
 'remotiore': ['remotiores'],
 'remotiori': {'remotioris': []},
 'remotioribu': {'remotioribus': []},
 'remotissim': {'remotissime': []},
 'remotissima': {'remotissimas': []},
 'remotissimi': {'remotissimis': []},
 'remotissimu': {'remotissimus': []},
 'remotiu': {'remotius': []},
 'remotiusculi': {'remotiusculis': []},
 'remotiv': {'remotivate': ['remotivated', 'remotivates'],
             'remotivating': [],
             'remotivation': ['remotivational'],
             'remotivator': []},
 'remotivate': ['remotivated', 'remotivates'],
 'remotivation': ['remotivational'],
 'remotli': {'remotly': []},
 'remoto': {'remotos': []},
 'remotor': {'remotors': []},
 'remotu': {'remotus': []},
 'remou': {'remoue': ['remoues', 'remoued', 'remoueing'],
           'remouing': [],
           'remous': []},
 'remoual': {'remouall': []},
 'remouchamp': {'remouchamps': []},
 'remoue': ['remoues', 'remoued', 'remoueing'],
 'remouer': {'remouere': []},
 'remoulad': {'remoulade': ['remoulades']},
 'remoulade': ['remoulades'],
 'remould': {'remouldable': [],
             'remoulded': [],
             'remoulder': ['remoulders'],
             'remoulding': ['remouldings'],
             'remoulds': []},
 'remoulder': ['remoulders'],
 'remoulding': ['remouldings'],
 'remoulin': {'remoulins': []},
 'remounc': {'remounce': []},
 'remound': {'remounded': []},
 'remoundo': {'remoundos': []},
 'remount': ['remounted', 'remounting', 'remountable', 'remountings'],
 'remour': {'remoured': [], 'remours': []},
 'remoustr': {'remoustrance': ['remoustrances']},
 'remoustrance': ['remoustrances'],
 'remouv': {'remouve': []},
 'remov': {'removability': [],
           'removable': ['removables', 'removableness'],
           'removably': [],
           'removal': [],
           'remove': ['removed',
                      'remover',
                      'removeds',
                      'removent',
                      'removeal',
                      'removeing',
                      'removeant',
                      'removement',
                      'removeable',
                      'removements',
                      'removeability'],
           'removing': ['removings'],
           'removs': []},
 'removable': ['removables', 'removableness'],
 'removabt': {'removabte': []},
 'removahl': {'removahle': []},
 'removal': {'removall': ['removalls']},
 'removalist': {'removalists': []},
 'removall': ['removalls'],
 'removc': {'removcable': []},
 'remove': {'removeed': [], 'removees': []},
 'removeactionlisten': {'removeactionlistener': []},
 'removeahel': {'removeahelements': []},
 'removeal': {'removeall': []},
 'removeallel': {'removeallelements': []},
 'removeamu': {'removeamus': []},
 'removeattribut': {'removeattribute': []},
 'removeattributen': {'removeattributens': []},
 'removeattributenod': {'removeattributenode': []},
 'removebimu': {'removebimus': []},
 'removeconnectioneventlisten': {'removeconnectioneventlistener': []},
 'removed': {'removedness': []},
 'removedbi': {'removedby': []},
 'removedfromth': {'removedfromthe': []},
 'removedirectori': {'removedirectory': []},
 'removedth': {'removedthe': []},
 'removeel': {'removeelement': []},
 'removeentri': {'removeentry': []},
 'removeev': {'removeevent': []},
 'removeeventlisten': {'removeeventlistener': []},
 'removefontresourc': {'removefontresource': []},
 'removehandl': {'removehandler': []},
 'removeing': {'removeinge': []},
 'removekeylisten': {'removekeylistener': []},
 'removelayoutcompon': {'removelayoutcomponent': []},
 'removelisten': {'removelistener': []},
 'removememb': {'removemember': []},
 'removemod': {'removemode': []},
 'removemouselisten': {'removemouselistener': []},
 'removemousemotionlisten': {'removemousemotionlistener': []},
 'removemu': {'removemus': []},
 'removen': {'removens': []},
 'removendi': {'removendis': []},
 'removendu': {'removendus': []},
 'removenetworkdr': {'removenetworkdrive': []},
 'removenod': {'removenode': []},
 'removenotifi': {'removenotify': []},
 'removent': {'removentes': []},
 'removeobserv': {'removeobserver': []},
 'removeprinterconnect': {'removeprinterconnection': []},
 'removepropertychangelisten': {'removepropertychangelistener': []},
 'remover': {'removere': []},
 'removerang': {'removerange': []},
 'removeri': {'removeris': []},
 'removers': {'removerse': []},
 'removesth': {'removesthe': []},
 'removet': {'removete': []},
 'removeth': {'removethe': []},
 'removeupd': {'removeupdate': []},
 'removeus': {'removeuser': []},
 'removeuserfromrol': {'removeuserfromrole': ['removeuserfromroles']},
 'removeuserfromrole': ['removeuserfromroles'],
 'removeusersfromrol': {'removeusersfromroles': []},
 'removevalu': {'removevalue': []},
 'removevetoablechangelisten': {'removevetoablechangelistener': []},
 'removida': {'removidas': []},
 'removido': {'removidos': []},
 'removimu': {'removimus': []},
 'removing': {'removinge': []},
 'removingal': {'removingall': []},
 'removingth': {'removingthe': []},
 'removiss': {'removisse': []},
 'remow': {'remowal': [], 'remowe': ['remowed'], 'remowing': []},
 'remowe': ['remowed'],
 'remoy': {'remoyal': [], 'remoye': ['remoyed'], 'remoying': []},
 'remoye': ['remoyed'],
 'remp': {'rempe': [], 'remps': []},
 'rempart': {'remparts': []},
 'rempel': {'rempell': [], 'rempels': []},
 'remper': {'rempered': []},
 'rempera': {'remperament': []},
 'remperarur': {'remperarure': []},
 'remperatur': {'remperature': ['remperatures']},
 'remperature': ['remperatures'],
 'remphi': {'remphis': []},
 'rempi': {'rempis': []},
 'rempir': {'rempire': []},
 'rempl': {'remple': ['remples']},
 'remplac': {'remplacable': [],
             'remplacant': ['remplacants'],
             'remplace': ['remplaces',
                          'remplaced',
                          'remplacer',
                          'remplacent',
                          'remplacement',
                          'remplacements']},
 'remplacai': {'remplacaient': []},
 'remplacant': {'remplacantes': []},
 'remplace': {'remplacee': ['remplacees']},
 'remplacee': ['remplacees'],
 'remplacer': {'remplacerent': []},
 'remplacerai': {'remplaceraient': []},
 'remplaceron': {'remplacerons': []},
 'remplacon': {'remplacons': []},
 'remplaf': {'remplafant': []},
 'remplag': {'remplagant': ['remplagants']},
 'remplagant': ['remplagants'],
 'remplaq': {'remplaqant': []},
 'remplar': {'remplare': []},
 'remple': ['remples'],
 'rempli': {'remplie': ['remplies'], 'remplis': [], 'remply': []},
 'remplie': ['remplies'],
 'remplir': {'remplirent': []},
 'remplirai': {'rempliraient': []},
 'rempliss': {'remplissant': [], 'remplisse': ['remplissent', 'remplissement']},
 'remplissag': {'remplissage': ['remplissages']},
 'remplissage': ['remplissages'],
 'remplissai': {'remplissaient': [], 'remplissais': []},
 'remplisse': ['remplissent', 'remplissement'],
 'remplissoi': {'remplissoient': []},
 'remplisson': {'remplissons': []},
 'remplit': {'remplites': []},
 'remploi': {'remplois': []},
 'remploy': {'remployment': []},
 'rempor': {'remporal': ['remporally', 'remporality']},
 'remporal': ['remporally', 'remporality'],
 'remporari': {'remporary': []},
 'remporarili': {'remporarily': []},
 'remporati': {'remporaty': []},
 'remporatili': {'remporatily': []},
 'remport': {'remportant': [],
             'remporte': ['remporter', 'remportes', 'remportent']},
 'remporte': {'remportee': ['remportees']},
 'remportee': ['remportees'],
 'remporter': {'remporterent': []},
 'remppi': {'remppis': []},
 'rempr': {'rempred': [], 'rempring': []},
 'remprat': {'rempration': []},
 'rempston': {'rempstone': []},
 'rempt': {'rempte': [], 'rempting': []},
 'remptat': {'remptation': []},
 'remptori': {'remptory': []},
 'remptorili': {'remptorily': []},
 'rempv': {'rempve': ['rempved']},
 'rempve': ['rempved'],
 'remqu': {'remque': []},
 'remqv': {'remqved': []},
 'remrel': {'remrelated': []},
 'remrk': {'remrks': []},
 'remrkabl': {'remrkable': []},
 'remrn': {'remrned': [], 'remrning': [], 'remrns': []},
 'rems': {'remse': ['remsed'], 'remsing': []},
 'remsburi': {'remsbury': []},
 'remscheid': {'remscheider': []},
 'remscheidensi': {'remscheidensis': []},
 'remschi': {'remschied': []},
 'remsdi': {'remsdy': []},
 'remse': ['remsed'],
 'remsen': {'remsens': []},
 'remsin': {'remsined': [], 'remsining': [], 'remsins': []},
 'remsind': {'remsinder': []},
 'remsperg': {'remsperger': []},
 'remsrk': {'remsrks': []},
 'remstat': {'remstated': []},
 'remt': {'remte': []},
 'remtdi': {'remtdy': []},
 'remtegr': {'remtegration': []},
 'remterpret': {'remterpretation': []},
 'remth': {'remthe': []},
 'remtntscenc': {'remtntscences': []},
 'remtroduc': {'remtroduced': []},
 'remtroduct': {'remtroduction': []},
 'remu': {'remue': ['remues'], 'remus': []},
 'remuabl': {'remuable': []},
 'remuag': {'remuage': []},
 'remuan': {'remuans': []},
 'remuant': {'remuante': [], 'remuants': []},
 'remucos': {'remucosalization': []},
 'remud': {'remudded': []},
 'remuda': {'remuda': []},
 'remuddl': {'remuddled': [], 'remuddling': []},
 'remue': {'remuee': ['remuees']},
 'remuee': ['remuees'],
 'remuement': {'remuements': []},
 'remueur': {'remueurs': []},
 'remuev': {'remueve': []},
 'remuf': {'remufe': []},
 'remuffl': {'remuffling': []},
 'remuin': {'remuined': [], 'remuining': [], 'remuins': []},
 'remulch': {'remulching': []},
 'remultipl': {'remultiplication': []},
 'remultipli': {'remultiplied': [], 'remultiply': ['remultiplying']},
 'remultiply': ['remultiplying'],
 'remulu': {'remulus': []},
 'remum': {'remumerative': []},
 'remumer': {'remumeration': []},
 'remumqu': {'remumque': []},
 'remun': {'remune': ['remuner',
                      'remunerative',
                      'remuneratively',
                      'remunerativeness']},
 'remunar': {'remunaration': []},
 'remunci': {'remunciation': []},
 'remundu': {'remundus': []},
 'remune': ['remuner', 'remunerative', 'remuneratively', 'remunerativeness'],
 'remunei': {'remuneiation': []},
 'remuner': {'remunerability': [],
             'remunerable': [],
             'remunerate': ['remunerated', 'remunerates'],
             'remunerating': [],
             'remuneration': [],
             'remunerator': [],
             'remunere': ['remunerer', 'remuneres']},
 'remuneracion': {'remuneracione': ['remuneraciones']},
 'remuneracione': ['remuneraciones'],
 'remuneraco': {'remuneracoes': []},
 'remunerada': {'remuneradas': []},
 'remunerado': {'remunerados': []},
 'remunerar': {'remunerare': []},
 'remunerarl': {'remunerarles': []},
 'remunerate': ['remunerated', 'remunerates'],
 'remunerateur': {'remunerateurs': []},
 'remuneration': {'remuneratione': ['remunerationes']},
 'remuneratione': ['remunerationes'],
 'remunerationi': {'remunerationis': []},
 'remunerator': {'remuneratore': []},
 'remuneratori': {'remuneratory': []},
 'remuneratric': {'remuneratrices': []},
 'remuneratu': {'remuneratus': []},
 'remunerazion': {'remunerazione': []},
 'remunere': {'remuneree': ['remunerees']},
 'remuneree': ['remunerees'],
 'remunert': {'remunertion': []},
 'remunicip': {'remunicipalization': []},
 'remuon': {'remuons': []},
 'remurk': {'remurkable': [], 'remurks': []},
 'remurmur': {'remurmured': [], 'remurmuring': [], 'remurmurs': []},
 'remurmurar': {'remurmurare': []},
 'remus': {'remus': []},
 'remusat': {'remusats': []},
 'remust': {'remuster': ['remustered', 'remustering']},
 'remuster': ['remustered', 'remustering'],
 'remut': {'remutation': []},
 'remutini': {'remutinied': []},
 'remuv': {'remuve': ['remuved']},
 'remuve': ['remuved'],
 'remv': {'remved': []},
 'remviko': {'remvikos': []},
 'remvo': {'remvoed': [], 'remvoing': []},
 'remy': ['remys'],
 'remyd': {'remyde': []},
 'remyelin': {'remyelinate': ['remyelinated'],
              'remyelinating': [],
              'remyelination': [],
              'remyelinization': []},
 'remyelinate': ['remyelinated'],
 'remyss': {'remysse': [], 'remyssion': []},
 'remystif': {'remystification': []},
 'remystifi': {'remystified': [],
               'remystifies': [],
               'remystify': ['remystifying']},
 'remystify': ['remystifying'],
 'remyt': {'remytted': []},
 'remyth': {'remything': []},
 'remythic': {'remythicization': [], 'remythicize': ['remythicized']},
 'remythicize': ['remythicized'],
 'remythif': {'remythification': []},
 'remythifi': {'remythify': ['remythifying']},
 'remythify': ['remythifying'],
 'remytholog': {'remythologization': [],
                'remythologize': ['remythologized', 'remythologizes'],
                'remythologizing': []},
 'remythologis': {'remythologisation': [],
                  'remythologise': ['remythologised'],
                  'remythologising': []},
 'remythologise': ['remythologised'],
 'remythologize': ['remythologized', 'remythologizes'],
 'remytt': {'remytte': []},
 'ren': {'renned': [], 'renness': [], 'renning': ['rennings'], 'rens': []},
 "ren'": {"ren'e": []},
 "ren'e": {"ren'ee": []},
 "ren's": {"ren'se": []},
 'rena': {'renae': [], 'renas': []},
 'renabi': {'renabie': []},
 'renabilit': {'renabilitation': []},
 'renabl': {'renable': []},
 'renac': {'renace': ['renacer'], 'renacity': []},
 'renace': ['renacer'],
 'renacentista': {'renacentistas': []},
 'renaci': {'renacious': []},
 'renacient': {'renaciente': []},
 'renacimiento': {'renacimientos': []},
 'renact': {'renacted': [], 'renactment': []},
 'renacuajo': {'renacuajos': []},
 'renad': {'renade': []},
 'renaer': {'renaered': []},
 'renaert': {'renaerts': []},
 'renaeu': {'renaeus': []},
 'renag': {'renage': ['renaged']},
 'renagad': {'renagade': ['renagades']},
 'renagade': ['renagades'],
 'renage': ['renaged'],
 'renai': {'renaie': [], 'renais': []},
 'renaiis': {'renaiisance': []},
 'renail': {'renailed': [], 'renailing': []},
 'renain': {'renained': [], 'renaining': [], 'renains': []},
 'renaind': {'renainder': []},
 'renair': {'renairs': []},
 'renais': {'renaisance': []},
 'renaisa': {'renaisaance': []},
 'renaisc': {'renaiscence': []},
 'renaisi': {'renaisiance': []},
 'renaiss': {'renaissance': [],
             'renaissant': ['renaissants'],
             'renaisse': ['renaissent', 'renaissence']},
 'renaissac': {'renaissace': []},
 'renaissai': {'renaissaient': []},
 'renaissainc': {'renaissaince': []},
 'renaissanc': {'renaissancism': []},
 'renaissancebaroqu': {'renaissancebaroque': []},
 'renaissancebild': {'renaissancebildes': []},
 'renaissancehumanismu': {'renaissancehumanismus': []},
 'renaissanceinspir': {'renaissanceinspired': []},
 'renaissancelik': {'renaissancelike': []},
 'renaissancepapst': {'renaissancepapste': []},
 'renaissancereform': {'renaissancereformation': []},
 'renaissancestyl': {'renaissancestyle': []},
 'renaissancetyp': {'renaissancetype': []},
 'renaissancist': {'renaissancists': []},
 'renaissane': {'renaissanee': []},
 'renaissano': {'renaissanoe': []},
 'renaissanr': {'renaissanre': []},
 'renaissans': {'renaissanse': []},
 'renaissant': {'renaissante': ['renaissantes']},
 'renaissante': ['renaissantes'],
 'renaissauc': {'renaissauce': []},
 'renaisse': ['renaissent', 'renaissence'],
 'renaissnac': {'renaissnace': []},
 'renaisss': {'renaisssance': []},
 'renaist': {'renaistance': []},
 'renaistr': {'renaistre': []},
 'renaiti': {'renaity': []},
 'renaitr': {'renaitre': []},
 'renaiuanc': {'renaiuance': []},
 'renak': {'renaker': []},
 'renal': {'renale': ['renaler', 'renales'],
           'renall': ['renalls', 'renally'],
           'renals': []},
 'renalarteri': {'renalartery': []},
 'renalc': {'renalcs': []},
 'renalcel': {'renalcell': []},
 'renalci': {'renalcis': []},
 'renald': {'renalds': []},
 'renaldi': {'renaldis': []},
 'renaldo': {'renaldos': []},
 'renaldu': {'renaldus': []},
 'renale': ['renaler', 'renales'],
 'renalfailur': {'renalfailure': []},
 'renalfunct': {'renalfunction': []},
 'renali': {'renalis': []},
 'renalin': {'renaline': []},
 'renall': ['renalls', 'renally'],
 'renalport': {'renalportal': []},
 'renalspar': {'renalsparing': []},
 'renalss': {'renalssance': []},
 'renalti': {'renalty': []},
 'renaltr': {'renaltre': []},
 'renaltranspl': {'renaltransplant': []},
 'renam': {'renamable': [],
           'rename': ['renamer', 'renamed', 'renames', 'renamers'],
           'renaming': ['renamings']},
 'rename': ['renamer', 'renamed', 'renames', 'renamers'],
 'renamefil': {'renamefile': []},
 'renaming': ['renamings'],
 'renan': {'renane': ['renaned'], 'renanism': [], 'renans': []},
 'renanc': {'renance': []},
 'renand': {'renander': []},
 'renane': ['renaned'],
 'renanesqu': {'renanesque': []},
 'renant': {'renants': []},
 'renanthera': {'renantheras': []},
 'renanthopsi': {'renanthopsis': []},
 'renantiom': {'renantiomer': []},
 'renap': {'renape': []},
 'renapoak': {'renapoaks': []},
 'renar': {'renare': ['renares'], 'renars': []},
 'renarcot': {'renarcotization': []},
 'renard': {'renarde': ['renardes'], 'renards': []},
 'renarde': ['renardes'],
 'renardesqu': {'renardesque': []},
 'renardet': {'renardets': []},
 'renardi': {'renardie': [], 'renardy': []},
 'renardienn': {'renardienne': []},
 'renardier': {'renardiere': ['renardieres']},
 'renardiere': ['renardieres'],
 'renardu': {'renardus': []},
 'renare': ['renares'],
 'renark': {'renarkable': [], 'renarkably': [], 'renarked': [], 'renarks': []},
 'renarn': {'renarned': []},
 'renarr': {'renarrate': ['renarrates', 'renarrated'],
            'renarrating': [],
            'renarration': ['renarrations'],
            'renarrative': []},
 'renarrate': ['renarrates', 'renarrated'],
 'renarration': ['renarrations'],
 'renarrativ': {'renarrativization': ['renarrativizations'],
                'renarrativize': ['renarrativized'],
                'renarrativizing': []},
 'renarrativization': ['renarrativizations'],
 'renarrativize': ['renarrativized'],
 'renarrow': {'renarrowed': [], 'renarrowing': []},
 'renas': {'renasence': []},
 'renasc': {'renasce': ['renascer', 'renascent', 'renascency', 'renascence']},
 'renasce': ['renascer', 'renascent', 'renascency', 'renascence'],
 'renascen': {'renascens': []},
 'renascens': {'renascense': ['renascenses']},
 'renascense': ['renascenses'],
 'renascent': {'renascentes': []},
 'renascenti': {'renascentis': []},
 'renascentibu': {'renascentibus': []},
 'renascido': {'renascidos': []},
 'renasela': {'renaselaer': []},
 'renasis': {'renasisance': []},
 'renasiss': {'renasissance': []},
 'renass': {'renassance': []},
 'renassainc': {'renassaince': []},
 'renassan': {'renassans': []},
 'renassi': {'renassiance': []},
 'renat': {'renatal': [], 'renate': ['renater', 'renates'], 'renation': []},
 'renata': {'renatae': [], 'renatas': []},
 'renate': ['renater', 'renates'],
 'renati': {'renatis': []},
 'renation': {'renationalization': ['renationalizations'],
              'renationalize': ['renationalizes', 'renationalized'],
              'renationalizing': []},
 'renationalis': {'renationalisation': [],
                  'renationalise': ['renationalised'],
                  'renationalising': []},
 'renationalise': ['renationalised'],
 'renationalization': ['renationalizations'],
 'renationalize': ['renationalizes', 'renationalized'],
 'renato': {'renatos': []},
 'renatss': {'renatssance': []},
 'renatt': {'renatte': []},
 'renattr': {'renattre': []},
 'renatu': {'renatus': []},
 'renatur': {'renaturability': [],
             'renaturable': [],
             'renaturalization': [],
             'renaturalize': ['renaturalized', 'renaturalizes'],
             'renaturalizing': [],
             'renaturated': [],
             'renaturating': [],
             'renaturation': [],
             'renature': ['renatured', 'renatures'],
             'renaturing': []},
 'renaturalis': {'renaturalisation': [], 'renaturalise': ['renaturalised']},
 'renaturalise': ['renaturalised'],
 'renaturalize': ['renaturalized', 'renaturalizes'],
 'renature': ['renatured', 'renatures'],
 'renau': {'renaus': []},
 'renaud': {'renaude': ['renaudes'], 'renauds': []},
 'renaude': ['renaudes'],
 'renaudel': {'renaudels': []},
 'renaudi': {'renaudie': ['renaudier']},
 'renaudie': ['renaudier'],
 'renaudier': {'renaudiere': []},
 'renaudotiu': {'renaudotius': []},
 'renault': {'renaults': []},
 'renaus': {'renausance': []},
 'renav': {'renaval': [], 'renavent': []},
 'renavig': {'renavigate': ['renavigated'], 'renavigating': []},
 'renavigate': ['renavigated'],
 'renay': {'renaying': []},
 'renaz': {'renaze': []},
 'renazif': {'renazification': []},
 'renazifi': {'renazified': []},
 'renb': {'renbing': []},
 'renbarg': {'renbarger': []},
 'renbourn': {'renbourne': []},
 'renc': {'rence': ['renced', 'rences'], 'rencing': [], 'rencs': []},
 'rencc': {'renccs': []},
 'rence': ['renced', 'rences'],
 'rencent': {'rencently': []},
 'rencesv': {'rencesvals': []},
 'rencev': {'rencevals': []},
 'rench': {'renched': [], 'renches': [], 'renching': []},
 'rencheriss': {'rencherissement': []},
 'renchev': {'renchevals': []},
 'renchym': {'renchymal': []},
 'renci': {'rencies': [], 'rencis': [], 'rency': []},
 'rencia': {'rencias': []},
 'rencilla': {'rencillas': []},
 'rencin': {'rencine': []},
 'renck': {'rencke': []},
 'rencken': {'renckens': []},
 'renclu': {'renclus': []},
 'renclus': {'rencluse': []},
 'rencont': {'renconter': ['renconters']},
 'renconter': ['renconters'],
 'rencontr': {'rencontrant': [],
              'rencontre': ['rencontres',
                            'rencontred',
                            'rencontrer',
                            'rencontrent']},
 'rencontrai': {'rencontraient': [], 'rencontrais': []},
 'rencontram': {'rencontrames': []},
 'rencontran': {'rencontrans': []},
 'rencontre': {'rencontree': ['rencontrees']},
 'rencontree': ['rencontrees'],
 'rencontrer': {'rencontrerent': []},
 'rencontrerai': {'rencontreraient': []},
 'rencontreron': {'rencontrerons': []},
 'rencontrion': {'rencontrions': []},
 'rencontroi': {'rencontroient': [], 'rencontrois': []},
 'rencontron': {'rencontrons': []},
 'rencor': {'rencores': []},
 'rencount': {'rencounter': ['rencounters', 'rencountered', 'rencountering']},
 'rencounter': ['rencounters', 'rencountered', 'rencountering'],
 'rencountr': {'rencountre': ['rencountred', 'rencountres'],
               'rencountring': []},
 'rencountre': ['rencountred', 'rencountres'],
 'renction': {'renctions': []},
 'rencuentro': {'rencuentros': []},
 'renculu': {'renculus': []},
 'rencw': {'rencwed': []},
 'rend': {'rende': ['rendes', 'rended', 'rendeli'],
          'rending': ['rendings'],
          'rends': []},
 'renda': {'rendas': []},
 'rendabl': {'rendability': [], 'rendable': []},
 'rendai': {'rendais': []},
 'rendal': {'rendale': [], 'rendall': ['rendalls', 'rendalli']},
 'rendalen': {'rendalens': []},
 'rendall': ['rendalls', 'rendalli'],
 'rendalp': {'rendalps': []},
 'rendan': {'rendans': []},
 'rendar': {'rendared': []},
 'rendatl': {'rendatler': []},
 'rendcomb': {'rendcombe': []},
 'rendcr': {'rendcred': []},
 'rende': ['rendes', 'rended', 'rendeli'],
 'rendei': {'rendeied': [], 'rendeiing': [], 'rendeis': []},
 'rendeiro': {'rendeiros': []},
 'rendel': {'rendell': ['rendells'], 'rendels': []},
 'rendell': ['rendells'],
 'rendellbak': {'rendellbaker': []},
 'rendelp': {'rendelps': []},
 'rendement': {'rendements': []},
 'rendenc': {'rendencies': [], 'rendency': []},
 'rendendol': {'rendendole': []},
 'rendendon': {'rendendone': []},
 'rendenng': {'rendenngs': []},
 'rendentor': {'rendentore': []},
 'render': ['rendere',
            'rendered',
            'renderer',
            'renderes',
            'rendering',
            'renderers',
            'renderred',
            'renderness',
            'renderable',
            'renderered',
            'renderability'],
 'rendercont': {'rendercontents': []},
 'renderebb': {'renderebbe': []},
 'renderet': {'renderete': []},
 'renderf': {'renderfed': []},
 'renderi': {'renderies': []},
 'renderinghint': {'renderinghints': []},
 'renderingth': {'renderingthe': []},
 'renderl': {'renderle': []},
 'rendermod': {'rendermode': []},
 'rendermorph': {'rendermorphics': []},
 'rendern': {'renderne': []},
 'rendero': {'renderos': []},
 'rendersen': {'rendersene': []},
 'rendersth': {'rendersthe': []},
 'renderth': {'renderthe': []},
 'renderwar': {'renderware': []},
 'rendess': {'rendesse': []},
 'rendesv': {'rendesvous': []},
 'rendet': {'rendete': ['rendeted'], 'rendeting': [], 'rendets': []},
 'rendete': ['rendeted'],
 'rendev': {'rendevous': ['rendevoused']},
 'rendevous': ['rendevoused'],
 'rendevouz': {'rendevouze': ['rendevouzed']},
 'rendevouze': ['rendevouzed'],
 'rendez': {'rendezous': []},
 'rendezt': {'rendezte': []},
 'rendezv': {'rendezvoued': [],
             'rendezvous': ['rendezvoused', 'rendezvousing']},
 'rendezvon': {'rendezvons': []},
 'rendezvous': ['rendezvouse'],
 'rendezvouz': {'rendezvouze': ['rendezvouzes', 'rendezvouzed']},
 'rendezvouze': ['rendezvouzes', 'rendezvouzed'],
 'rendi': {'rendie': [], 'rendis': [], 'rendy': []},
 'rendibl': {'rendible': []},
 'rendida': {'rendidas': []},
 'rendidament': {'rendidamente': []},
 'rendido': {'rendidos': []},
 'rendig': {'rendigs': []},
 'rendii': {'rendiis': []},
 'rendija': {'rendijas': []},
 'rendil': {'rendile': [], 'rendille': []},
 'rendili': {'rendily': []},
 'rendim': {'rendimes': []},
 'rendimento': {'rendimentos': []},
 'rendimiento': {'rendimientos': []},
 'rendimo': {'rendimos': []},
 'rendin': {'rendine': []},
 'rending': ['rendings'],
 'rendingli': {'rendingly': []},
 'rendion': {'rendions': []},
 'rendir': {'rendirent': []},
 'rendirl': {'rendirle': []},
 'rendirs': {'rendirse': []},
 'rendiss': {'rendisse': ['rendissent']},
 'rendisse': ['rendissent'],
 'rendit': {'rendite': ['rendited'],
            'rendition': ['renditioned'],
            'rendits': []},
 'rendite': ['rendited'],
 'rendition': ['renditioned'],
 'rendj': {'rendje': []},
 'rendl': {'rendle': []},
 'rendn': {'rendns': []},
 'rendo': {'rendos': []},
 'rendoi': {'rendois': []},
 'rendol': {'rendoll': ['rendolls']},
 'rendoll': ['rendolls'],
 'rendomli': {'rendomly': []},
 'rendon': {'rendons': []},
 'rendor': {'rendored': [], 'rendoring': [], 'rendors': []},
 'rendou': {'rendous': []},
 'rendr': {'rendre': ['rendres', 'rendred'], 'rendring': []},
 'rendra': {'rendras': []},
 'rendrai': {'rendrais': []},
 'rendre': ['rendres', 'rendred'],
 'rendring': {'rendringe': []},
 'rendrion': {'rendrions': []},
 'rendroi': {'rendrois': []},
 'rendron': {'rendrons': []},
 'rendry': {'rendrye': ['rendryes']},
 'rendrye': ['rendryes'],
 'rendsburg': {'rendsburger': []},
 'rendsr': {'rendsred': []},
 'rendszer': {'rendszere': ['rendszeres']},
 'rendszere': ['rendszeres'],
 'rendszervalta': {'rendszervaltas': []},
 'rendszervaltoza': {'rendszervaltozas': []},
 'rendszervdltd': {'rendszervdltds': []},
 'rendti': {'rendtis': []},
 'rendtorff': {'rendtorffs': []},
 'rendtt': {'rendtts': []},
 'rendu': {'rendue': ['rendues'], 'rendus': []},
 'rendue': ['rendues'],
 'renduel': {'rendueles': []},
 'rendul': {'rendulic': []},
 'renduosl': {'renduosler': []},
 'renduweb': {'renduweber': []},
 'rendv': {'rendvs': []},
 'rendvil': {'rendville': []},
 'rendzin': {'rendzines': []},
 'rendzina': {'rendzinas': []},
 'rene': {'rened': [],
          'renee': ['reneed', 'renees'],
          'renely': [],
          'renes': [],
          'rening': []},
 "rene'": {"rene'e": []},
 'renea': {'reneas': []},
 'reneagl': {'reneagle': []},
 'reneagu': {'reneague': ['reneagues']},
 'reneague': ['reneagues'],
 'renealmu': {'renealmus': []},
 'reneantoin': {'reneantoine': []},
 'reneat': {'reneated': []},
 'reneatedli': {'reneatedly': []},
 'reneaulm': {'reneaulme': []},
 'reneaum': {'reneaume': []},
 'renebi': {'reneby': []},
 'renecessari': {'renecessary': []},
 'reneck': {'renecke': ['renecker']},
 'renecke': ['renecker'],
 'renect': {'renected': [], 'renection': []},
 'rened': {'renede': ['renedered']},
 'renede': ['renedered'],
 'renedescart': {'renedescartes': []},
 'renedi': {'renedies': [], 'renedy': []},
 'renedictin': {'renedictine': []},
 'renee': ['reneed', 'renees'],
 'renef': {'renefer': []},
 'renefit': {'renefits': []},
 'reneg': {'renegate': ['renegates', 'renegated'],
           'renegation': [],
           'renege': ['reneged', 'reneger', 'renegers'],
           'renegged': [],
           'renegging': [],
           'reneging': [],
           'renegs': []},
 'renegaci': {'renegacy': []},
 'renegad': {'renegade': ['renegaded', 'renegaders'],
             'renegading': [],
             'renegadism': []},
 'renegade': ['renegaded', 'renegaders'],
 'renegado': {'renegadoes': [], 'renegados': []},
 'renegadoc': {'renegadocs': []},
 'renegat': {'renegats': []},
 'renegate': ['renegates', 'renegated'],
 'renege': ['reneged', 'reneger', 'renegers'],
 'reneger': {'renegeration': []},
 'renegoci': {'renegociation': [], 'renegocier': []},
 'renegot': {'renegotation': []},
 'renegoti': {'renegotiability': [],
              'renegotiable': [],
              'renegotiate': ['renegotiates', 'renegotiated'],
              'renegotiating': [],
              'renegotiation': ['renegotiations'],
              'renegotiator': ['renegotiators']},
 'renegotiate': ['renegotiates', 'renegotiated'],
 'renegotiation': ['renegotiations'],
 'renegotiator': ['renegotiators'],
 'renegrad': {'renegrade': ['renegrades']},
 'renegrade': ['renegrades'],
 'renegu': {'renegue': ['renegued'], 'reneguing': []},
 'renegue': ['renegued'],
 'renei': {'reneis': []},
 'reneiss': {'reneissance': []},
 'reneiv': {'reneival': [], 'reneived': []},
 'renek': {'reneke': ['reneker']},
 'reneke': ['reneker'],
 'renel': {'renell': ['renelle'], 'renels': []},
 'renelevesqu': {'renelevesque': []},
 'renell': ['renelle'],
 'renemauric': {'renemaurice': []},
 'renemb': {'renember': ['renembered']},
 'renember': ['renembered'],
 'renen': {'renens': []},
 'renenb': {'renenber': ['renenbered']},
 'renenber': ['renenbered'],
 'renent': {'renents': []},
 'renenu': {'renenue': []},
 'rener': {'renerable': [],
           'reneral': ['renerally'],
           'renerated': [],
           'reneration': [],
           'renere': ['renered'],
           'renerous': [],
           'reners': []},
 'reneral': ['renerally'],
 'renere': ['renered'],
 'renerg': {'renergic': []},
 'reneri': {'renery': []},
 'reneriu': {'renerius': []},
 'renero': {'reneros': []},
 'renerr': {'renerre': []},
 'reneru': {'renerus': []},
 'renerv': {'renervation': [], 'renerve': ['renerved'], 'renerving': []},
 'renerve': ['renerved'],
 'renes': {'renesance': [], 'renese': []},
 'renesa': {'renesas': []},
 'renesan': {'renesans': []},
 'renescur': {'renescure': []},
 'renesi': {'renesis': []},
 'reness': {'renesse': []},
 'renessan': {'renessans': []},
 'renessela': {'renesselaer': []},
 'renest': {'renested': [],
            'renesters': [],
            'renesting': ['renestings'],
            'renests': []},
 'renesting': ['renestings'],
 'renet': {'renetic': [], 'renets': []},
 'renett': {'renette': ['renettes']},
 'renette': ['renettes'],
 'renetzki': {'renetzky': []},
 'reneu': {'reneued': []},
 'reneur': {'reneurs': []},
 'reneuri': {'reneurial': []},
 'reneutr': {'reneutralization': [], 'reneutralize': ['reneutralized']},
 'reneutralize': ['reneutralized'],
 'renev': {'renevable': [],
           'reneval': [],
           'renevant': [],
           'reneved': [],
           'renevent': [],
           'renevs': []},
 'renevi': {'renevier': []},
 'renevil': {'reneville': []},
 'renew': {'renewability': [],
           'renewable': ['renewables'],
           'renewably': [],
           'renewal': ['renewalism'],
           'renewance': [],
           'renewe': ['renewes', 'renewer', 'renewed', 'renewers'],
           'renewing': ['renewings'],
           'renewment': [],
           'renews': []},
 'renewable': ['renewables'],
 'renewableenergi': {'renewableenergy': []},
 'renewableresourc': {'renewableresource': []},
 'renewahl': {'renewahle': []},
 'renewai': {'renewais': []},
 'renewal': {'renewall': []},
 'renewalist': {'renewalists': []},
 'renewat': {'renewats': []},
 'renewe': ['renewes', 'renewer', 'renewed', 'renewers'],
 'renewedli': {'renewedly': []},
 'renewi': {'renewis': []},
 'renewing': {'renewinge': []},
 'renewingli': {'renewingly': []},
 'renewingth': {'renewingthe': []},
 'renewl': {'renewls': []},
 'renewn': {'renewned': []},
 'renewol': {'renewols': []},
 'renewoncalltim': {'renewoncalltime': []},
 'renews': {'renewse': []},
 'renewth': {'renewthe': []},
 'reney': {'reneye': ['reneyed']},
 'reneye': ['reneyed'],
 'renf': {'renfe': [], 'renfs': []},
 'renfenn': {'renfenne': []},
 'renfer': {'renferment': []},
 'renferm': {'renfermant': [],
             'renferme': ['renfermer', 'renfermes', 'renfermement']},
 'renferma': {'renfermas': []},
 'renfermai': {'renfermaient': []},
 'renferme': {'renfermee': ['renfermees']},
 'renfermee': ['renfermees'],
 'renfermerai': {'renfermeraient': []},
 'renfermoi': {'renfermoient': []},
 'renfi': {'renfie': []},
 'renfield': {'renfields': []},
 'renfl': {'renfle': ['renfles']},
 'renfle': {'renflee': ['renflees']},
 'renflee': ['renflees'],
 'renflement': {'renflements': []},
 'renfonc': {'renfoncement': []},
 'renfor': {'renfors': []},
 'renforc': {'renforcant': [],
             'renforce': ['renforces',
                          'renforcer',
                          'renforced',
                          'renforcent',
                          'renforcement',
                          'renforcements'],
             'renforcing': []},
 'renforcai': {'renforcaient': []},
 'renforce': {'renforcee': ['renforcees']},
 'renforcee': ['renforcees'],
 'renforcer': {'renforcerent': []},
 'renformi': {'renformis': []},
 'renfort': {'renforts': []},
 'renfr': {'renfred': []},
 'renfre': {'renfree': []},
 'renfrew': {'renfrews': []},
 'renfrewshir': {'renfrewshire': []},
 'renfri': {'renfry': []},
 'renfro': {'renfroe': ['renfroes'], 'renfros': []},
 'renfroe': ['renfroes'],
 'renfrogn': {'renfrogne': []},
 'renftl': {'renftle': []},
 'reng': {'renge': ['renges', 'renged'], 'renging': [], 'rengs': []},
 'renga': {'rengas': []},
 'rengachari': {'rengachary': []},
 'rengacheri': {'rengachery': []},
 'rengad': {'rengade': []},
 'rengag': {'rengagement': []},
 'rengain': {'rengaine': ['rengaines']},
 'rengaine': ['rengaines'],
 'rengako': {'rengakos': []},
 'rengasami': {'rengasamy': []},
 'rengaswami': {'rengaswamy': []},
 'renge': ['renges', 'renged'],
 'rengeanc': {'rengeance': []},
 'rengefor': {'rengefors': []},
 'rengel': {'rengeling': []},
 'renger': {'rengers': []},
 'rengerisch': {'rengerische': []},
 'rengersch': {'rengersche': []},
 'renggani': {'rengganis': []},
 'rengha': {'renghas': []},
 'rengiou': {'rengious': []},
 'renglon': {'renglones': []},
 'rengma': {'rengmas': []},
 'rengrati': {'rengratiate': []},
 'rengstorf': {'rengstorfs': []},
 'rength': {'rengths': []},
 'rengthen': {'rengthened': [], 'rengthening': []},
 'rengu': {'rengue': []},
 'renh': {'renhe': []},
 'reni': {'renie': ['renied', 'renies'],
          'renis': [],
          'reny': ['renys', 'renying']},
 'reniain': {'reniained': [], 'reniaining': [], 'reniains': []},
 'renialm': {'renialme': []},
 'renian': {'renians': []},
 'reniark': {'reniarkable': [], 'reniarks': []},
 'reniass': {'reniassance': []},
 'renibu': {'renibus': []},
 'renic': {'renice': [], 'renicing': []},
 'renick': {'renicke': ['renicker'], 'renicks': []},
 'renicke': ['renicker'],
 'renicknam': {'renicknamed': []},
 'renicolida': {'renicolidae': []},
 'reniculelloid': {'reniculelloides': []},
 'reniculu': {'reniculus': []},
 'renid': {'renident': []},
 'reniden': {'renidens': []},
 'renident': {'renidentes': []},
 'renie': {'reniee': []},
 'reniebla': {'renieblas': []},
 'reniedi': {'reniedy': []},
 'reniegu': {'reniegues': []},
 'reniemb': {'reniember': ['reniembered']},
 'reniember': ['reniembered'],
 'reniement': {'reniements': []},
 'renier': {'reniere': ['reniered'], 'reniers': []},
 'reniere': ['reniered'],
 'renieri': {'renieris': []},
 'renierit': {'renierite': []},
 'renifl': {'renifle': ['renifler']},
 'renifle': ['renifler'],
 'reniflemen': {'reniflemens': []},
 'renifleur': {'renifleurs': []},
 'reniform': {'reniforme': ['reniformes']},
 'reniforme': ['reniformes'],
 'reniformi': {'reniformis': []},
 'reniformibu': {'reniformibus': []},
 'renig': {'reniged': [], 'reniger': [], 'renigged': [], 'renigging': []},
 'renihu': {'renihue': []},
 'reniind': {'reniinding': []},
 'renik': {'reniker': []},
 'renild': {'renilde': []},
 'renillida': {'renillidae': []},
 'renin': ['renine', 'reninism'],
 'reninaldosteron': {'reninaldosterone': []},
 'reninangiotens': {'reninangiotension': []},
 'renind': {'reninded': [], 'reninds': []},
 'renindepend': {'renindependent': []},
 'reninem': {'reninemic': []},
 'rening': {'reninger': []},
 'reninlik': {'reninlike': []},
 'reninmedi': {'reninmediated': []},
 'reninproduc': {'reninproducing': []},
 'reninsecret': {'reninsecreting': []},
 'reninsubstr': {'reninsubstrate': []},
 'renion': {'renions': []},
 'reniov': {'reniove': ['renioved']},
 'reniove': ['renioved'],
 'renipustulatu': {'renipustulatus': []},
 'reniqu': {'renique': []},
 'reniri': {'renirie': []},
 'renirn': {'renirned': []},
 'reniss': {'renissance': []},
 'renit': {'renite': ['renitent', 'renitence', 'renitency']},
 'renite': ['renitent', 'renitence', 'renitency'],
 'reniten': {'renitens': []},
 'renitent': {'renitente': ['renitentes']},
 'renitente': ['renitentes'],
 'renitenti': {'renitentis': []},
 'renitentibu': {'renitentibus': []},
 'reniti': {'renity': []},
 'reniu': {'renius': []},
 'renj': {'renjing': []},
 'renji': {'renjie': []},
 'renk': {'renke': ['renked', 'renkes'], 'renking': [], 'renks': []},
 'renke': ['renked', 'renkes'],
 'renken': {'renkens': []},
 'renker': {'renkers': []},
 'renkin': {'renkins': []},
 'renkt': {'renkte': []},
 'renl': {'renle': ['renles', 'renled'], 'renling': ['renlings'], 'renls': []},
 'renlac': {'renlace': ['renlaced']},
 'renlace': ['renlaced'],
 'renle': ['renles', 'renled'],
 'renler': {'renlered': []},
 'renli': {'renlied': [], 'renly': []},
 'renling': ['renlings'],
 'renliti': {'renlity': []},
 'renliz': {'renlize': []},
 'renlli': {'renlly': []},
 'renm': {'renme': [], 'renming': []},
 'renman': {'renmans': []},
 'renmant': {'renmants': []},
 'renminchubansh': {'renminchubanshe': []},
 'renmor': {'renmore': []},
 'renn': {'renne': ['rennes', 'renneli'], 'renns': []},
 'renna': {'rennae': ['rennaes']},
 'rennae': ['rennaes'],
 'rennai': {'rennais': []},
 'rennais': {'rennaisance': []},
 'rennaiss': {'rennaissance': []},
 'rennak': {'rennaker': []},
 'rennal': {'rennall': ['rennalls'], 'rennals': []},
 'rennall': ['rennalls'],
 'rennant': {'rennants': []},
 'rennard': {'rennards': []},
 'rennc': {'renncs': []},
 'renne': {'rennee': []},
 'renneck': {'rennecke': ['rennecker']},
 'rennecke': ['rennecker'],
 'rennedi': {'rennedy': []},
 'rennek': {'renneke': ['renneker']},
 'renneke': ['renneker'],
 'rennel': {'rennell': ['rennells'], 'rennels': []},
 'rennelf': {'rennelfs': []},
 'rennell': ['rennells'],
 'rennelles': {'rennellese': []},
 'rennelp': {'rennelps': []},
 'rennelt': {'rennelts': []},
 'rennend': {'rennende': []},
 'rennenkampf': {'rennenkampfs': []},
 'rennepont': {'renneponts': []},
 'renner': {'rennere': [], 'renners': []},
 'rennertel': {'rennerteller': []},
 'rennesl': {'rennesle': []},
 'rennet': ['renneted',
            'rennetic',
            'renneting',
            'rennetted',
            'rennetting',
            'rennetability'],
 'renneth': {'rennethe': []},
 'rennetlik': {'rennetlike': []},
 'rennett': {'rennette': []},
 'rennev': {'renneval': []},
 'rennevil': {'renneville': []},
 'renngass': {'renngasse': []},
 'rennhof': {'rennhofer': []},
 'renni': {'rennie': ['rennies'], 'rennis': [], 'renny': []},
 'rennial': {'rennials': []},
 'rennibist': {'rennibister': []},
 'rennick': {'rennicke': [], 'rennicks': []},
 'rennie': ['rennies'],
 'rennig': {'renniger': []},
 'rennilas': {'rennilase': []},
 'rennin': {'rennin': []},
 'renning': {'renninge': ['renninger', 'renningers']},
 'renninge': ['renninger', 'renningers'],
 'renninlik': {'renninlike': []},
 'rennion': {'rennions': []},
 'rennit': {'rennite': ['rennited'], 'rennitic': []},
 'rennite': ['rennited'],
 'rennk': {'rennke': []},
 'rennl': {'rennle': []},
 'rennnciat': {'rennnciation': []},
 'renno': {'rennoe': [], 'rennos': []},
 'rennol': {'rennolls': []},
 'rennold': {'rennolds': []},
 'rennov': {'rennovate': ['rennovated'],
            'rennovating': [],
            'rennovation': ['rennovations']},
 'rennovate': ['rennovated'],
 'rennovation': ['rennovations'],
 'rennsala': {'rennsalaer': []},
 'rennsdal': {'rennsdale': []},
 'rennsela': {'rennselaer': ['rennselaers']},
 'rennselaer': ['rennselaers'],
 'rennselaervil': {'rennselaerville': []},
 'rennssela': {'rennsselaer': []},
 'rennstreck': {'rennstrecke': []},
 'rennsymphoni': {'rennsymphonie': []},
 'rennt': {'rennte': []},
 'rennthier': {'rennthiers': []},
 'renntier': {'renntiere': [], 'renntiers': []},
 'rennyhil': {'rennyhill': []},
 'rennyng': {'rennynge': []},
 'reno': ['renoe'],
 'renobal': {'renobales': []},
 'renobl': {'renoble': []},
 'renoceptor': {'renoceptors': []},
 'renocol': {'renocolic': []},
 'renocort': {'renocortical': []},
 'renodaeu': {'renodaeus': []},
 'renodeu': {'renodeus': []},
 'renodlad': {'renodlade': []},
 'renogastr': {'renogastric': []},
 'renogi': {'renogiation': []},
 'renogram': {'renograms': []},
 'renograph': {'renographic': []},
 'renographi': {'renography': []},
 'renoi': {'renoie': [], 'renois': []},
 'renoimc': {'renoimce': []},
 'renointestin': {'renointestinal': []},
 'renoir': ['renoire'],
 'renoiresqu': {'renoiresque': []},
 'renoirt': {'renoirte': []},
 'renoit': {'renoites': []},
 'renol': {'renoll': [], 'renols': []},
 'renold': {'renolde': [], 'renolds': []},
 'renoldn': {'renoldner': []},
 'renolv': {'renolved': []},
 'renom': {'renomalization': [], 'renome': ['renomed'], 'renommed': []},
 'renomad': {'renomadization': []},
 'renombr': {'renombre': ['renombres']},
 'renombrado': {'renombrados': []},
 'renombre': ['renombres'],
 'renome': {'renomee': []},
 'renomedullari': {'renomedullary': []},
 'renomegali': {'renomegaly': []},
 'renomin': {'renominalization': [],
             'renominate': ['renominated', 'renominates'],
             'renominating': [],
             'renomination': ['renominations']},
 'renominate': ['renominated', 'renominates'],
 'renomination': ['renominations'],
 'renomln': {'renomlnation': []},
 'renomm': {'renommation': [], 'renomme': ['renommer', 'renommes']},
 'renomme': {'renommee': ['renommees']},
 "renomme'": {"renomme'e": []},
 'renommee': ['renommees'],
 'renommi': {'renommie': []},
 'renommiert': {'renommierte': ['renommierter']},
 'renommierte': ['renommierter'],
 'renon': {'renone': ['renones'], 'renons': []},
 'renonc': {'renoncant': ['renoncants'],
            'renonce': ['renoncer',
                        'renoncent',
                        'renoncement',
                        'renoncements']},
 'renoncai': {'renoncaient': []},
 'renoncant': ['renoncants'],
 'renonce': ['renoncer', 'renoncent', 'renoncement', 'renoncements'],
 'renoncer': {'renoncerent': []},
 'renoncerai': {'renonceraient': []},
 'renonceron': {'renoncerons': []},
 'renonci': {'renonciation': ['renonciations']},
 'renonciation': ['renonciations'],
 'renoncon': {'renoncons': []},
 'renoncul': {'renoncule': ['renoncules']},
 'renonculace': {'renonculacees': []},
 'renoncule': ['renoncules'],
 'renone': ['renones'],
 'renonn': {'renonnalization': [], 'renonnalized': []},
 'renonnc': {'renonnce': ['renonnced']},
 'renonnce': ['renonnced'],
 'renoparenchym': {'renoparenchymal': []},
 'renopericardi': {'renopericardial': []},
 'renoport': {'renoportal': []},
 'renopriv': {'renoprival': []},
 'renoprotect': {'renoprotection': [], 'renoprotective': []},
 'renor': {'renoral': []},
 'renoren': {'renorenal': []},
 'renorm': {'renormal': ['renormalize',
                         'renormalized',
                         'renormalizes',
                         'renormalizing',
                         'renormalization',
                         'renormalizations'],
            'renormed': [],
            'renorming': []},
 'renormal': ['renormalize',
              'renormalized',
              'renormalizes',
              'renormalizing',
              'renormalization',
              'renormalizations'],
 'renormalis': {'renormalisability': [],
                'renormalisable': [],
                'renormalisation': ['renormalisations'],
                'renormalise': ['renormalises', 'renormalised'],
                'renormalising': []},
 'renormalisation': ['renormalisations'],
 'renormalise': ['renormalises', 'renormalised'],
 'renormaliz': {'renormalizability': [], 'renormalizable': []},
 'renormallz': {'renormallzation': [], 'renormallzed': []},
 'renormalon': {'renormalons': []},
 'renort': {'renorted': [], 'renorts': []},
 'renos': {'renosed': []},
 'renospark': {'renosparks': []},
 'renosplen': {'renosplenic': []},
 'renost': {'renoster': []},
 'renosterbo': {'renosterbos': []},
 'renot': {'renotate': ['renotated'],
           'renotating': [],
           'renotation': ['renotations'],
           'renote': ['renoted'],
           'renoticed': [],
           'renotion': []},
 'renotate': ['renotated'],
 'renotation': ['renotations'],
 'renotch': {'renotched': [], 'renotching': []},
 'renote': ['renoted'],
 'renotic': {'renotice': []},
 'renotier': {'renotiere': []},
 'renotif': {'renotification': []},
 'renotifi': {'renotified': [], 'renotify': []},
 'renotrop': {'renotropic': []},
 'renotroph': {'renotrophic': []},
 'renott': {'renotte': []},
 'renou': {'renoue': [], 'renous': []},
 'renouar': {'renouare': []},
 'renouard': {'renouards': []},
 'renouat': {'renouation': []},
 'renouc': {'renouce': ['renouced'], 'renoucing': []},
 'renouce': ['renouced'],
 'renouf': {'renoufs': []},
 'renoum': {'renoume': ['renoumed', 'renoumes']},
 'renoume': ['renoumed', 'renoumes'],
 'renoun': {'renoune': ['renouned', 'renouneing']},
 'renounc': {'renounce': ['renouncer',
                          'renounced',
                          'renounces',
                          'renouncers',
                          'renounceing',
                          'renouncement',
                          'renounceable'],
             'renouncing': ['renouncings']},
 'renounce': {'renouncee': []},
 'renounci': {'renounciation': []},
 'renouncing': ['renouncings'],
 'renoune': {'renounee': ['renouneed']},
 'renounee': ['renouneed'],
 'renouno': {'renounoe': ['renounoed']},
 'renounoe': ['renounoed'],
 'renouns': {'renounsed': []},
 'renoureter': {'renoureteral': []},
 'renourish': {'renourished': [], 'renourishing': [], 'renourishment': []},
 'renouuc': {'renouuce': []},
 'renouue': {'renouuee': []},
 'renouuel': {'renouueller': []},
 'renouvel': {'renouvelable': ['renouvelables'],
              'renouvelant': [],
              'renouvele': ['renouveler', 'renouveles'],
              'renouvellant': [],
              'renouvelle': ['renouveller',
                             'renouvelles',
                             'renouvellent',
                             'renouvellement',
                             'renouvellements']},
 'renouvelable': ['renouvelables'],
 'renouvelai': {'renouvelaient': []},
 'renouvele': {'renouvelee': ['renouvelees']},
 'renouvelee': ['renouvelees'],
 'renouveler': {'renouvelerent': []},
 'renouvelle': {'renouvellee': ['renouvellees']},
 'renouvellee': ['renouvellees'],
 'renouvelon': {'renouvelons': []},
 'renouvi': {'renouvier': []},
 'renov': {'renovable': ['renovables'],
           'renoval': [],
           'renovant': [],
           'renovate': ['renovated', 'renovates'],
           'renovating': [],
           'renovation': ['renovational'],
           'renovative': [],
           'renovator': [],
           'renove': ['renover', 'renoves', 'renoved', 'renovent'],
           'renoving': []},
 'renova': {'renovas': []},
 'renovabi': {'renovabis': []},
 'renovable': ['renovables'],
 'renovacion': {'renovaciones': []},
 'renovada': {'renovadas': []},
 'renovado': {'renovados': []},
 'renovador': {'renovadores': []},
 'renovadora': {'renovadoras': []},
 'renoval': {'renovales': [], 'renovalles': []},
 'renovamu': {'renovamus': []},
 'renovan': {'renovans': []},
 'renovanda': {'renovandae': []},
 'renovandi': {'renovandis': []},
 'renovant': {'renovante': ['renovantes']},
 'renovante': ['renovantes'],
 'renovar': {'renovare': ['renovared']},
 'renovare': ['renovared'],
 'renovars': {'renovarse': []},
 'renovass': {'renovasse': []},
 'renovat': {'renovater': ['renovaters']},
 'renovata': {'renovatae': []},
 'renovate': ['renovated', 'renovates'],
 'renovater': ['renovaters'],
 'renovateur': {'renovateurs': []},
 'renovati': {'renovatis': []},
 'renovatingli': {'renovatingly': []},
 'renovation': {'renovatione': ['renovationes'], 'renovationism': []},
 'renovatione': ['renovationes'],
 'renovationi': {'renovationis': []},
 'renovationist': {'renovationists': []},
 'renovatori': {'renovatory': []},
 'renovatu': {'renovatus': []},
 'renovavei': {'renovaveis': []},
 'renovdvei': {'renovdveis': []},
 'renove': {'renovee': ['renovees']},
 'renovee': ['renovees'],
 'renovel': {'renovell': []},
 'renoviert': {'renovierte': []},
 'renovu': {'renovue': []},
 'renow': {'renowal': [], 'renowed': [], 'renowes': []},
 'renowen': {'renowened': []},
 'renowm': {'renowme': ['renowmed']},
 'renowme': ['renowmed'],
 'renown': ['renowne',
            'renowned',
            'renownes',
            'renowner',
            'renowning',
            'renowners'],
 'renownc': {'renownce': ['renownced'], 'renowncing': []},
 'renownce': ['renownced'],
 'renownedli': {'renownedly': []},
 'renowu': {'renowued': []},
 'renpen': {'renpenning': []},
 'renq': {'renqing': []},
 'renr': {'renrative': [], 'renre': ['renred'], 'renrs': []},
 'renre': ['renred'],
 'renreit': {'renreiter': []},
 'renres': {'renresent': ['renresents',
                          'renresented',
                          'renresenting',
                          'renresentative',
                          'renresentatives']},
 'renresent': {'renresentation': []},
 'renri': {'renry': []},
 'renrint': {'renrinted': []},
 'rens': {'rense': ['rensed', 'renses'], 'rensing': []},
 'rensael': {'rensaeler': [], 'rensaeller': []},
 'rensaela': {'rensaelaer': []},
 'rensaiss': {'rensaissance': []},
 'rensal': {'rensaleer': []},
 'rensala': {'rensalaer': []},
 'rensalla': {'rensallaer': []},
 'rensberg': {'rensberger': [], 'rensbergs': []},
 'rensburg': {'rensburger': [], 'rensburgs': []},
 'renscign': {'renscignements': []},
 'rense': ['rensed', 'renses'],
 'renseela': {'renseelaer': []},
 'renseign': {'renseignant': [],
              'renseigne': ['renseignes',
                            'renseigner',
                            'renseignent',
                            'renseignement',
                            'renseignements'],
              'renseignments': []},
 'renseigna': {'renseignas': []},
 'renseigne': {'renseignee': ['renseignees']},
 'renseignee': ['renseignees'],
 'renseignemen': {'renseignemens': []},
 'rensel': {'renseller': []},
 'rensela': {'renselaer': ['renselaers']},
 'renselaer': ['renselaers'],
 'rensella': {'rensellaer': ['rensellaers']},
 'rensellaer': ['rensellaers'],
 'rensembl': {'rensemble': []},
 'rensenberg': {'rensenberger': []},
 'rensenhous': {'rensenhouse': []},
 'renshal': {'renshall': []},
 'renshaw': {'renshawe': [], 'renshaws': []},
 'rensi': {'rensie': [], 'rensis': [], 'rensy': []},
 'rensim': {'rensimer': []},
 'rension': {'rensions': []},
 'rensk': {'renske': []},
 'rensker': {'renskers': []},
 'renski': {'rensky': []},
 'renslad': {'renslade': []},
 'renslaer': {'renslaers': []},
 'rensn': {'rensning': []},
 'renson': {'rensonable': [], 'rensoning': [], 'rensons': []},
 'renss': {'rensse': []},
 'renssael': {'renssaeler': []},
 'renssaela': {'renssaelaer': []},
 'renssala': {'renssalaer': ['renssalaers']},
 'renssalaer': ['renssalaers'],
 'rensseal': {'renssealer': []},
 'rensseala': {'renssealaer': []},
 'renssel': {'rensseler': []},
 'renssela': {'rensselaer': ['rensselaers']},
 'rensselaer': ['rensselaers'],
 'rensselaerit': {'rensselaerite': []},
 'rensselaervil': {'rensselaerville': []},
 'renssella': {'renssellaer': ['renssellaers']},
 'renssellaer': ['renssellaers'],
 'renssels': {'rensselser': []},
 'renstierna': {'renstiernas': []},
 'rensu': {'rensus': []},
 'rensuk': {'rensuke': []},
 'renswoud': {'renswoude': []},
 'rent': ['rente', 'rented', 'renting', 'rentative'],
 'renta': {'rentas': []},
 'rentabilidad': {'rentabilidade': []},
 'rentabilis': {'rentabilisation': [], 'rentabiliser': []},
 'rentabilit': {'rentabilite': []},
 'rentabl': {'rentability': [], 'rentable': ['rentables', 'rentabler']},
 'rentable': ['rentables', 'rentabler'],
 'rentag': {'rentage': []},
 'rental': ['rentale',
            'rentall',
            'rentalls',
            'rentaller',
            'rentalled',
            'rentallers'],
 'rentalh': {'rentalhousing': []},
 'rentali': {'rentalis': []},
 'rentalpurchas': {'rentalpurchase': []},
 'rentbear': {'rentbearing': []},
 'rentbook': {'rentbooks': []},
 'rentboy': {'rentboys': []},
 'rentcharg': {'rentcharge': ['rentcharger', 'rentcharges']},
 'rentcharge': ['rentcharger', 'rentcharges'],
 'rentcollect': {'rentcollecting': [], 'rentcollection': []},
 'rentcollector': {'rentcollectors': []},
 'rentcontrol': {'rentcontrolled': []},
 'rentcreat': {'rentcreating': []},
 'rentday': {'rentdays': []},
 'rente': {'rentee': ['rentees']},
 'rentearn': {'rentearning': []},
 'rentee': ['rentees'],
 'renteharg': {'renteharge': []},
 'rentekamm': {'rentekammer': []},
 'rentel': {'rentell': []},
 'rentenalt': {'rentenalter': []},
 'rentenbrief': {'rentenbriefe': []},
 'rentenc': {'rentence': []},
 'rentengiit': {'rentengiiter': []},
 'rentengutsvertrag': {'rentengutsvertrage': []},
 'renteni': {'renteniers': []},
 'rentenkapitalismu': {'rentenkapitalismus': []},
 'rentenmark': {'rentenmarks': []},
 'rentent': {'rentention': [], 'rententive': []},
 'rententheori': {'rententheorie': []},
 'rentenversicherungstrag': {'rentenversicherungstrager': []},
 'renter': ['renteral', 'rentered'],
 'rentero': {'renteros': []},
 'renteroccupi': {'renteroccupied': []},
 'rentfre': {'rentfree': []},
 'rentfro': {'rentfroe': []},
 'rentgather': {'rentgatherer': ['rentgatherers']},
 'rentgatherer': ['rentgatherers'],
 'rentgener': {'rentgenerating': []},
 'renth': {'renthe': [], 'renths': []},
 'renthes': {'rentheses': []},
 'renthesi': {'renthesis': []},
 'renthi': {'renthy': []},
 'renthold': {'rentholders': []},
 'renti': {'rentie': [], 'rentis': [], 'renty': ['rentys']},
 'rential': {'rentially': [], 'rentials': []},
 'rentiat': {'rentiate': ['rentiated'], 'rentiating': [], 'rentiation': []},
 'rentiate': ['rentiated'],
 'rentibu': {'rentibus': []},
 'rentic': {'rentice': ['rentices']},
 'rentice': ['rentices'],
 'rentiel': {'rentielles': []},
 'rentier': ['rentiere', 'rentieres', 'rentierism'],
 'rentierjagerlag': {'rentierjagerlager': []},
 'rentiesvil': {'rentiesville': []},
 'rentigni': {'rentigny': []},
 'rentii': {'rentiis': []},
 'rentil': {'rentilation': []},
 'rentin': {'rentinal': [], 'rentine': ['rentines']},
 'rentincom': {'rentincome': []},
 'rentine': ['rentines'],
 'rention': {'rentioned': [], 'rentions': []},
 'rentista': {'rentistas': []},
 'rentiu': {'rentius': []},
 'rentkamm': {'rentkammer': []},
 'rentl': {'rentle': []},
 'rentli': {'rently': []},
 'rentlik': {'rentlike': []},
 'rentling': {'rentlinger': []},
 'rentmast': {'rentmaster': []},
 'rentmeest': {'rentmeester': ['rentmeesters']},
 'rentmeester': ['rentmeesters'],
 'rentmeist': {'rentmeister': []},
 'rentner': {'rentners': []},
 'rentnri': {'rentnry': []},
 'rento': {'rentos': []},
 'rentokil': {'rentokill': []},
 'renton': {'rentone': [], 'rentons': []},
 'rentor': {'rentors': []},
 'rentowel': {'rentowels': []},
 'rentpay': {'rentpayer': ['rentpayers'], 'rentpaying': []},
 'rentpayer': ['rentpayers'],
 'rentproduc': {'rentproducing': []},
 'rentr': {'rentre': ['rentres']},
 'rentrai': {'rentrais': []},
 'rentrais': {'rentraising': []},
 'rentrant': {'rentrants': []},
 'rentrat': {'rentrates': []},
 'rentre': {'rentree': ['rentrees']},
 "rentre'": {"rentre'e": []},
 'rentreceiv': {'rentreceiver': ['rentreceivers'], 'rentreceiving': []},
 'rentreceiver': ['rentreceivers'],
 'rentreduct': {'rentreduction': []},
 'rentree': ['rentrees'],
 'rentrepris': {'rentreprise': []},
 'rentrer': {'rentrerent': []},
 'rentrerai': {'rentreraient': []},
 'rentreron': {'rentrerons': []},
 'rentri': {'rentrie': [], 'rentry': []},
 'rentricl': {'rentricle': []},
 'rentrion': {'rentrions': []},
 'rentrol': {'rentroll': ['rentrolls']},
 'rentroll': ['rentrolls'],
 'rentron': {'rentrons': []},
 'rents': {'rentse': []},
 'rentscharg': {'rentscharge': []},
 'rentschler': {'rentschlers': []},
 'rentseek': {'rentseekers': [], 'rentseeking': []},
 'rentservic': {'rentservice': []},
 'rentshar': {'rentsharing': []},
 'rentstabil': {'rentstabilized': []},
 'rentsubsid': {'rentsubsidized': []},
 'rentsuppl': {'rentsupplement': []},
 'rentt': {'renttes': [], 'rentts': []},
 'rentth': {'rentthe': []},
 'rentual': {'rentually': []},
 'rentucki': {'rentucky': []},
 'rentur': {'renture': ['rentured']},
 'renture': ['rentured'],
 'renturi': {'renturies': [], 'rentury': []},
 'rentway': {'rentways': []},
 'renty': ['rentys'],
 'rentyield': {'rentyielding': []},
 'rentzel': {'rentzell': []},
 'rentzeperi': {'rentzeperis': []},
 'rentzepi': {'rentzepis': []},
 'renu': {'renue': ['renues', 'renued'], 'renuing': [], 'renus': []},
 'renua': {'renuas': []},
 'renubl': {'renublic': []},
 'renuci': {'renuciation': []},
 'renucl': {'renucleate': ['renucleated'], 'renucleation': []},
 'renucleate': ['renucleated'],
 'renue': ['renues', 'renued'],
 'renuen': {'renuens': []},
 'renuent': {'renuente': ['renuentes']},
 'renuente': ['renuentes'],
 'renuentibu': {'renuentibus': []},
 'renuer': {'renuere': []},
 'renuerf': {'renuerfer': []},
 'renuers': {'renuerse': []},
 'renuest': {'renuested': []},
 'renuev': {'renueve': []},
 'renuevo': {'renuevos': []},
 'renui': {'renuie': [], 'renuis': []},
 'renuimu': {'renuimus': []},
 'renuir': {'renuire': ['renuired', 'renuires', 'renuirements']},
 'renuire': ['renuired', 'renuires', 'renuirements'],
 'renuiss': {'renuisse': []},
 'renukachowdhuri': {'renukachowdhury': []},
 'renul': {'renule': ['renules']},
 'renule': ['renules'],
 'renult': {'renults': []},
 'renum': {'renumerative': []},
 'renumb': {'renumber': ['renumbers',
                         'renumbered',
                         'renumbering',
                         'renumberings']},
 'renumber': ['renumbers', 'renumbered', 'renumbering', 'renumberings'],
 'renumer': {'renumerate': ['renumerated'],
             'renumerating': [],
             'renumeration': ['renumerations']},
 'renumerate': ['renumerated'],
 'renumeration': ['renumerations'],
 'renummi': {'renummy': []},
 'renun': {'renunication': []},
 'renunc': {'renuncation': [],
            'renunce': ['renunces', 'renunced'],
            'renuncing': []},
 'renunce': ['renunces', 'renunced'],
 'renunci': {'renunciable': ['renunciables'],
             'renunciant': ['renunciants'],
             'renunciate': ['renunciated', 'renunciates'],
             'renunciating': [],
             'renunciation': [],
             'renunciative': [],
             'renunciator': ['renunciators'],
             'renuncie': ['renuncient']},
 'renuncia': {'renuncias': []},
 'renunciable': ['renunciables'],
 'renunciamo': {'renunciamos': []},
 'renunciamu': {'renunciamus': []},
 'renuncian': {'renuncians': []},
 'renunciant': {'renunciante': ['renunciantes']},
 'renunciante': ['renunciantes'],
 'renunciar': {'renunciare': []},
 'renunciass': {'renunciasse': []},
 'renunciate': ['renunciated', 'renunciates'],
 'renunciation': {'renunciatione': []},
 'renunciationi': {'renunciationis': []},
 'renunciator': ['renunciators'],
 'renunciatori': {'renunciatory': []},
 'renunciatu': {'renunciatus': []},
 'renunciavimu': {'renunciavimus': []},
 'renuncie': ['renuncient'],
 'renuncieti': {'renuncietis': []},
 'renunei': {'renuneiation': []},
 'renuner': {'renuneration': []},
 'renunici': {'renuniciation': []},
 'renunoi': {'renunoiation': []},
 'renunti': {'renuntiant': [],
             'renuntiate': [],
             'renuntiation': [],
             'renuntient': []},
 'renuntiamu': {'renuntiamus': []},
 'renuntian': {'renuntians': []},
 'renuntiant': {'renuntiante': ['renuntiantes']},
 'renuntiante': ['renuntiantes'],
 'renuntiar': {'renuntiare': ['renuntiarent']},
 'renuntiare': ['renuntiarent'],
 'renuntiass': {'renuntiasse': []},
 'renuntiation': {'renuntiatione': []},
 'renuntiationi': {'renuntiationis': []},
 'renuntiationibu': {'renuntiationibus': []},
 'renuntiatu': {'renuntiatus': []},
 'renuou': {'renuous': []},
 'renuoy': {'renuoye': ['renuoyer']},
 'renuoye': ['renuoyer'],
 'renur': {'renure': []},
 'renurtur': {'renurtured': []},
 'renut': {'renutation': []},
 'renutrit': {'renutrition': []},
 'renval': {'renvall': []},
 'renver': {'renvers': []},
 'renverron': {'renverrons': []},
 'renvers': {'renversal': [],
             'renversant': [],
             'renverse': ['renversed',
                          'renverser',
                          'renverses',
                          'renversent',
                          'renversement',
                          'renversements'],
             'renversing': []},
 'renversai': {'renversaient': []},
 'renversant': {'renversante': []},
 'renverse': {'renversee': ['renversees']},
 'renversee': ['renversees'],
 'renverser': {'renverserent': []},
 'renverson': {'renversons': []},
 'renvil': {'renville': ['renvilles']},
 'renville': ['renvilles'],
 'renvironn': {'renvironnement': []},
 'renvoi': {'renvoie': [], 'renvois': []},
 'renvois': {'renvoise': []},
 'renvoiz': {'renvoize': []},
 'renvoy': {'renvoyant': [],
            'renvoye': ['renvoyer', 'renvoyes', 'renvoyent'],
            'renvoying': []},
 'renvoyai': {'renvoyaient': []},
 'renvoye': {'renvoyee': ['renvoyees']},
 'renvoyee': ['renvoyees'],
 'renvoyer': {'renvoyerent': []},
 'renvoyon': {'renvoyons': []},
 'renvyl': {'renvyle': []},
 'renw': {'renwed': []},
 'renwal': {'renwall': []},
 'renwel': {'renwell': []},
 'renwick': {'renwicks': []},
 'reny': {'renye': []},
 'renyg': {'renyger': []},
 'renyngh': {'renynghe': []},
 'renyold': {'renyolds': []},
 'renyu': {'renyue': []},
 'renz': {'renze': []},
 'renzaprid': {'renzapride': []},
 'renzei': {'renzeis': []},
 'renzi': {'renzie': ['renzied'], 'renzis': [], 'renzy': []},
 'renzie': ['renzied'],
 'renziedli': {'renziedly': []},
 'reo': {'reos': []},
 'reoain': {'reoained': []},
 'reoair': {'reoaired': [], 'reoairs': []},
 'reoali': {'reoalis': []},
 'reoall': {'reoalled': [], 'reoalling': [], 'reoalls': []},
 'reobarl': {'reobarle': []},
 'reobjectif': {'reobjectification': []},
 'reobjectifi': {'reobjectified': [], 'reobjectify': []},
 'reoblig': {'reobligate': ['reobligated'], 'reobligation': []},
 'reobligate': ['reobligated'],
 'reobliter': {'reobliteration': []},
 'reobserv': {'reobservation': ['reobservations'],
              'reobserve': ['reobserved'],
              'reobserving': []},
 'reobservation': ['reobservations'],
 'reobserve': ['reobserved'],
 'reobstruct': {'reobstruction': []},
 'reobtain': {'reobtaine': ['reobtained'], 'reobtaining': [], 'reobtains': []},
 'reobtaine': ['reobtained'],
 'reoc': {'reocs': []},
 'reocclud': {'reocclude': ['reoccluded'], 'reoccluding': []},
 'reocclude': ['reoccluded'],
 'reocclus': {'reocclusion': ['reocclusions']},
 'reocclusion': ['reocclusions'],
 'reoccnpi': {'reoccnpied': []},
 'reoccup': {'reoccupancy': [],
             'reoccupants': [],
             'reoccupation': ['reoccupations'],
             'reoccuper': []},
 'reoccupation': ['reoccupations'],
 'reoccupi': {'reoccupied': [],
              'reoccupiers': [],
              'reoccupies': [],
              'reoccupy': ['reoccupying']},
 'reoccupl': {'reoccupled': []},
 'reoccupy': ['reoccupying'],
 'reoccur': {'reoccurance': [],
             'reoccured': [],
             'reoccurence': ['reoccurences'],
             'reoccuring': [],
             'reoccurred': [],
             'reoccurring': [],
             'reoccurs': []},
 'reoccurence': ['reoccurences'],
 'reoccurr': {'reoccurrance': [], 'reoccurrence': ['reoccurrences']},
 'reoccurrence': ['reoccurrences'],
 'reoceupi': {'reoceupied': []},
 'reocgnit': {'reocgnition': []},
 'reocgniz': {'reocgnized': []},
 'reoch': {'reoched': [], 'reoches': [], 'reoching': []},
 'reociv': {'reocived': []},
 'reocrd': {'reocrded': [], 'reocrds': []},
 'reoction': {'reoctions': []},
 'reoctiv': {'reoctive': []},
 'reoctob': {'reoctober': []},
 'reocur': {'reocurring': []},
 'reocurr': {'reocurrence': []},
 'reod': {'reode': [], 'reoding': ['reodings'], 'reods': []},
 'reoder': {'reodered': [], 'reoders': []},
 'reodi': {'reody': []},
 'reodili': {'reodily': []},
 'reoding': ['reodings'],
 'reodor': {'reodorants': [], 'reodorization': []},
 'reoeal': {'reoealed': []},
 'reoeat': {'reoeated': []},
 'reoeatedli': {'reoeatedly': []},
 'reoecup': {'reoecupation': []},
 'reoecupi': {'reoecupied': [], 'reoecupy': []},
 'reoed': {'reoede': ['reoeded'], 'reoeding': []},
 'reoede': ['reoeded'],
 'reoeipt': {'reoeipts': []},
 'reoeir': {'reoeire': ['reoeired']},
 'reoeire': ['reoeired'],
 'reoeit': {'reoeited': []},
 'reoeiv': {'reoeive': ['reoeives', 'reoeived'], 'reoeiving': []},
 'reoeive': ['reoeives', 'reoeived'],
 'reoeiver': {'reoeivers': []},
 'reoel': {'reoels': []},
 'reoelpt': {'reoelpts': []},
 'reoelr': {'reoelred': []},
 'reoelv': {'reoelve': ['reoelved'], 'reoelving': []},
 'reoelve': ['reoelved'],
 'reoentanc': {'reoentance': []},
 'reoentli': {'reoently': []},
 'reoeptacl': {'reoeptacle': []},
 'reoeptiv': {'reoeptive': []},
 'reoeptor': {'reoeptors': []},
 'reoess': {'reoesses': []},
 'reoetit': {'reoetition': []},
 'reoew': {'reoewed': []},
 'reof': {'reofs': []},
 'reoffenc': {'reoffence': ['reoffences']},
 'reoffence': ['reoffences'],
 'reoffend': {'reoffended': [],
              'reoffender': ['reoffenders'],
              'reoffending': [],
              'reoffends': []},
 'reoffender': ['reoffenders'],
 'reoffens': {'reoffense': ['reoffenses']},
 'reoffense': ['reoffenses'],
 'reoffer': {'reoffered': [], 'reoffering': ['reofferings'], 'reoffers': []},
 'reoffering': ['reofferings'],
 'reoffic': {'reofficered': []},
 'reogan': {'reoganization': ['reoganizations'], 'reoganize': ['reoganized']},
 'reoganis': {'reoganisation': [], 'reoganised': []},
 'reoganization': ['reoganizations'],
 'reoganize': ['reoganized'],
 'reognis': {'reognise': ['reognised']},
 'reognise': ['reognised'],
 'reognit': {'reognition': []},
 'reogniz': {'reognize': ['reognized']},
 'reognize': ['reognized'],
 'reogran': {'reogranization': []},
 'reogranis': {'reogranisation': []},
 'reograph': {'reographed': [], 'reographic': []},
 'reographi': {'reography': []},
 'reoherch': {'reoherches': []},
 'reoheroh': {'reoherohes': []},
 'reoht': {'reohts': []},
 'reoi': {'reois': []},
 'reoiev': {'reoieved': []},
 'reoil': {'reoiled': [], 'reoiling': []},
 'reoion': {'reoions': []},
 'reoip': {'reoipe': ['reoipes']},
 'reoipe': ['reoipes'],
 'reoiproc': {'reoiprocal': []},
 'reoister': {'reoistered': []},
 'reoit': {'reoite': ['reoited', 'reoites'], 'reoiting': []},
 'reoitat': {'reoitation': []},
 'reoite': ['reoited', 'reoites'],
 'reoiu': {'reoius': []},
 'reokon': {'reokoned': [], 'reokoning': []},
 'reol': {'reole': ['reoles']},
 'reolac': {'reolace': ['reolaced', 'reolacement']},
 'reolace': ['reolaced', 'reolacement'],
 'reolaim': {'reolaimed': []},
 'reole': ['reoles'],
 'reoli': {'reolied': [], 'reolies': [], 'reoly': []},
 'reoliti': {'reolity': []},
 'reoll': {'reolle': []},
 'reollect': {'reollection': []},
 'reolli': {'reolly': []},
 'reolog': {'reologi': ['reological'], 'reology': []},
 'reologi': ['reological'],
 'reologisch': {'reologische': []},
 'reolu': {'reolus': []},
 'reolut': {'reolution': ['reolutions']},
 'reolution': ['reolutions'],
 'reolutionari': {'reolutionary': []},
 'reolv': {'reolved': []},
 'reom': {'reome': [], 'reoms': []},
 'reomaens': {'reomaense': []},
 'reomensi': {'reomensis': []},
 'reommend': {'reommendation': ['reommendations'], 'reommended': []},
 'reommendation': ['reommendations'],
 'reon': {'reone': [], 'reons': []},
 'reonanc': {'reonance': []},
 'reoncili': {'reonciliation': []},
 'reond': {'reonde': []},
 'reonent': {'reonentation': []},
 'reonforc': {'reonforced': []},
 'reonli': {'reonly': []},
 'reons': {'reonse': []},
 'reonsibl': {'reonsibility': []},
 'reonstruct': {'reonstruction': []},
 'reoocupi': {'reoocupied': []},
 'reoognia': {'reoogniaed': []},
 'reoognie': {'reoognieed': []},
 'reoognii': {'reoogniied': []},
 'reoognis': {'reoognise': ['reoognises', 'reoognised'], 'reoognising': []},
 'reoognise': ['reoognises', 'reoognised'],
 'reoognit': {'reoognition': []},
 'reoogniz': {'reoognizable': [],
              'reoognize': ['reoognized', 'reoognizes'],
              'reoognizing': []},
 'reoognize': ['reoognized', 'reoognizes'],
 'reoognls': {'reoognlsed': []},
 'reoognlz': {'reoognlze': ['reoognlzed']},
 'reoognlze': ['reoognlzed'],
 'reooiv': {'reooive': ['reooived']},
 'reooive': ['reooived'],
 'reoollect': {'reoollected': [], 'reoollection': ['reoollections']},
 'reoollection': ['reoollections'],
 'reoolleot': {'reoolleotion': ['reoolleotions']},
 'reoolleotion': ['reoolleotions'],
 'reoolut': {'reoolution': []},
 'reoombin': {'reoombination': []},
 'reoommend': {'reoommendation': ['reoommendations'],
               'reoommended': [],
               'reoommending': [],
               'reoommends': []},
 'reoommendation': ['reoommendations'],
 'reoomnend': {'reoomnended': []},
 'reoompenc': {'reoompence': []},
 'reooncil': {'reooncile': ['reoonciled']},
 'reooncile': ['reoonciled'],
 'reoonmend': {'reoonmended': []},
 'reoonnoiss': {'reoonnoissance': []},
 'reoonnoit': {'reoonnoitering': []},
 'reoonoil': {'reoonoile': ['reoonoiled']},
 'reoonoile': ['reoonoiled'],
 'reoonsid': {'reoonsider': []},
 'reoonstitut': {'reoonstitution': []},
 'reoonstruot': {'reoonstruotion': []},
 'reoontli': {'reoontly': []},
 'reoord': {'reoorde': ['reoorded'], 'reoording': [], 'reoords': []},
 'reoorde': ['reoorded'],
 'reoort': {'reoorted': [], 'reoorting': [], 'reoorts': []},
 'reoount': {'reoounted': []},
 'reoours': {'reoourse': []},
 'reoov': {'reooved': []},
 'reoover': {'reoovered': []},
 'reooveri': {'reoovery': []},
 'reop': {'reope': []},
 'reopacif': {'reopacification': []},
 'reopen': {'reopenable': [],
            'reopened': [],
            'reopener': ['reopeners'],
            'reopening': ['reopenings'],
            'reopens': []},
 'reopend': {'reopended': []},
 'reopener': ['reopeners'],
 'reopening': ['reopenings'],
 'reoper': {'reoperate': ['reoperates', 'reoperated'],
            'reoperating': [],
            'reoperation': ['reoperations'],
            'reoperative': []},
 'reoperate': ['reoperates', 'reoperated'],
 'reoperation': {'reoperationalize': []},
 'reophacida': {'reophacidae': []},
 'reophor': {'reophore': ['reophores']},
 'reophore': ['reophores'],
 'reopi': {'reopie': []},
 'reopl': {'reople': []},
 'reopon': {'reoponed': []},
 'reoppos': {'reoppose': ['reopposed']},
 'reoppose': ['reopposed'],
 'reoprt': {'reoprted': [], 'reoprts': []},
 'reoptim': {'reoptimization': ['reoptimizations'],
             'reoptimize': ['reoptimized', 'reoptimizes'],
             'reoptimizing': []},
 'reoptimis': {'reoptimisation': [],
               'reoptimise': ['reoptimised'],
               'reoptimising': []},
 'reoptimise': ['reoptimised'],
 'reoptimization': ['reoptimizations'],
 'reoptimize': ['reoptimized', 'reoptimizes'],
 'reor': {'reore': [], 'reors': []},
 'reoral': {'reoralization': []},
 'reorchestr': {'reorchestrate': ['reorchestrated', 'reorchestrates'],
                'reorchestrating': [],
                'reorchestration': ['reorchestrations']},
 'reorchestrate': ['reorchestrated', 'reorchestrates'],
 'reorchestration': ['reorchestrations'],
 'reord': {'reorde': ['reorded'], 'reording': [], 'reords': []},
 'reordain': {'reordained': [], 'reordaining': [], 'reordains': []},
 'reorde': ['reorded'],
 'reorder': ['reordered', 'reordering', 'reorderable'],
 'reordin': {'reordination': ['reordinations']},
 'reordination': ['reordinations'],
 'reoreat': {'reoreation': ['reoreational']},
 'reoreation': ['reoreational'],
 'reores': {'reoresent': ['reoresents',
                          'reoresented',
                          'reoresenting',
                          'reoresentative',
                          'reoresentatives']},
 'reoresent': {'reoresentation': ['reoresentations']},
 'reoresentation': ['reoresentations'],
 'reorg': {'reorge': [], 'reorgs': []},
 'reorgamz': {'reorgamzation': []},
 'reorgan': {'reorganization': [],
             'reorganize': ['reorganized',
                            'reorganizes',
                            'reorganizer',
                            'reorganizers'],
             'reorganizing': []},
 'reorgani': {'reorganiation': [], 'reorganis': []},
 'reorganiazt': {'reorganiaztion': []},
 'reorganis': {'reorganisant': [],
               'reorganisation': ['reorganisational'],
               'reorganise': ['reorganises',
                              'reorganiser',
                              'reorganised',
                              'reorganisers',
                              'reorganisering'],
               'reorganising': []},
 'reorganisati': {'reorganisatie': []},
 'reorganisation': ['reorganisational'],
 'reorganise': {'reorganisee': ['reorganisees']},
 'reorganisee': ['reorganisees'],
 'reorganist': {'reorganistion': []},
 'reorganit': {'reorganites': []},
 'reorganiz': {'reorganizable': [], 'reorganizational': []},
 'reorganizationist': {'reorganizationists': []},
 'reorganize': ['reorganized', 'reorganizes', 'reorganizer', 'reorganizers'],
 'reorganizt': {'reorganiztion': []},
 'reorganz': {'reorganzation': []},
 'reorganzi': {'reorganziation': [], 'reorganzied': []},
 'reorgnis': {'reorgnisation': [], 'reorgnised': []},
 'reorgniz': {'reorgnization': [], 'reorgnized': []},
 'reori': {'reory': []},
 'reoricnt': {'reoricntation': []},
 'reoriem': {'reoriemation': []},
 'reorien': {'reorienation': []},
 'reorient': {'reorientable': [],
              'reorientalized': [],
              'reorientate': ['reorientated', 'reorientates'],
              'reorientating': [],
              'reorientation': ['reorientational'],
              'reorientative': [],
              'reoriente': ['reorienter', 'reoriented'],
              'reorienting': [],
              'reoriention': [],
              'reorients': []},
 'reorientate': ['reorientated', 'reorientates'],
 'reorientation': ['reorientational'],
 'reoriente': ['reorienter', 'reoriented'],
 'reorigin': {'reoriginate': ['reoriginated', 'reoriginates'],
              'reoriginating': [],
              'reorigination': []},
 'reoriginate': ['reoriginated', 'reoriginates'],
 'reorint': {'reorinted': []},
 'reorl': {'reorle': []},
 'reorm': {'reorms': []},
 'reornament': {'reornamented': []},
 'reoroduc': {'reoroduced': []},
 'reoroduct': {'reoroduction': []},
 'reoross': {'reorossed': [], 'reorossing': []},
 'reort': {'reorted': [], 'reorts': []},
 'reorthogon': {'reorthogonalization': [],
                'reorthogonalize': ['reorthogonalized']},
 'reorthogonalize': ['reorthogonalized'],
 'reorthonorm': {'reorthonormalization': []},
 'reoru': {'reorus': []},
 'reoruari': {'reoruary': []},
 'reoruit': {'reoruited': [],
             'reoruiting': [],
             'reoruitment': [],
             'reoruits': []},
 'reorystal': {'reorystallization': ['reorystallizations'],
               'reorystallized': []},
 'reorystallis': {'reorystallisation': [], 'reorystallised': []},
 'reorystallization': ['reorystallizations'],
 'reosiv': {'reosived': []},
 'reoson': {'reosonable': [], 'reosons': []},
 'reosonobl': {'reosonoble': []},
 'reossif': {'reossification': []},
 'reossifi': {'reossified': [], 'reossifies': [], 'reossify': []},
 'reostablish': {'reostablishment': []},
 'reosurc': {'reosurces': []},
 'reot': {'reote': ['reoted'], 'reots': []},
 'reotangl': {'reotangle': []},
 'reote': ['reoted'],
 'reother': {'reothers': []},
 'reotifi': {'reotified': [], 'reotify': []},
 'reotitud': {'reotitude': []},
 'reotli': {'reotly': []},
 'reotori': {'reotory': []},
 'reotyp': {'reotype': ['reotyped', 'reotypes'],
            'reotypical': [],
            'reotyping': []},
 'reotype': ['reotyped', 'reotypes'],
 'reou': {'reous': []},
 'reouc': {'reouce': ['reouced'], 'reoucing': []},
 'reouce': ['reouced'],
 'reouenci': {'reouency': []},
 'reouest': {'reouested': [], 'reouesting': [], 'reouests': []},
 'reouir': {'reouire': ['reouires', 'reouired'], 'reouiring': []},
 'reouire': ['reouires', 'reouired'],
 'reouirement': {'reouirements': []},
 'reoulat': {'reoulation': ['reoulations']},
 'reoulation': ['reoulations'],
 'reoulr': {'reoulred': []},
 'reoult': {'reoults': []},
 'reoulu': {'reoulus': []},
 'reour': {'reoured': [], 'reourred': [], 'reourring': []},
 'reourc': {'reource': ['reources']},
 'reource': ['reources'],
 'reoutat': {'reoutation': []},
 'reoutfit': {'reoutfitted': [], 'reoutfitting': []},
 'reoutlin': {'reoutline': ['reoutlined']},
 'reoutline': ['reoutlined'],
 'reouvertur': {'reouverture': []},
 'reov': {'reove': ['reoved']},
 'reovali': {'reovalis': []},
 'reove': ['reoved'],
 'reover': {'reovered': []},
 'reoveri': {'reovery': []},
 'reovir': {'reoviral': []},
 'reovirida': {'reoviridae': []},
 'reovirion': {'reovirions': []},
 'reoviru': {'reovirus': []},
 'reovirus': {'reovirus': []},
 'reoviruslik': {'reoviruslike': []},
 'reovlut': {'reovlution': []},
 'reown': {'reowned': [], 'reowning': []},
 'rep': ['repped', 'repping'],
 "rep'i": {"rep'y": []},
 "rep'r": {"rep're": []},
 "rep't": {"rep'ts": []},
 'repa': {'repas': []},
 'repaat': {'repaated': []},
 'repabl': {'repablic': []},
 'repac': {'repace': ['repaced', 'repacement'], 'repacing': [], 'repacity': []},
 'repace': ['repaced', 'repacement'],
 'repaci': {'repacious': []},
 'repacif': {'repacification': []},
 'repacifi': {'repacified': [], 'repacify': []},
 'repack': {'repacked': [],
            'repacker': ['repackers'],
            'repacking': ['repackings'],
            'repacks': []},
 'repackag': {'repackage': ['repackager',
                            'repackages',
                            'repackaged',
                            'repackagers'],
              'repackaging': ['repackagings']},
 'repackage': ['repackager', 'repackages', 'repackaged', 'repackagers'],
 'repackaging': ['repackagings'],
 'repacker': ['repackers'],
 'repacking': ['repackings'],
 'repacon': {'repacons': []},
 'repad': {'repadded': [], 'repadding': []},
 'repaf': {'repaffed': [], 'repaffing': [], 'repafs': []},
 'repafl': {'repafled': [], 'repafling': []},
 'repag': {'repage': ['repaged'], 'repaging': []},
 'repagan': {'repaganization': [], 'repaganize': ['repaganized']},
 'repaganize': ['repaganized'],
 'repage': ['repaged'],
 'repagin': {'repaginate': ['repaginated', 'repaginates'],
             'repaginating': [],
             'repagination': []},
 'repaginate': ['repaginated', 'repaginates'],
 'repaglinid': {'repaglinide': []},
 'repaguli': {'repagulis': []},
 'repai': {'repaie': ['repaied'], 'repais': []},
 'repaid': {'repaide': []},
 'repaie': ['repaied'],
 'repaii': {'repaiied': [], 'repaiiing': [], 'repaiis': []},
 'repain': {'repained': []},
 'repaint': {'repaintable': [],
             'repainted': [],
             'repainter': ['repainters'],
             'repainting': ['repaintings'],
             'repaints': []},
 'repainter': ['repainters'],
 'repainting': ['repaintings'],
 'repaintmanag': {'repaintmanager': []},
 'repair': ['repaire',
            'repairer',
            'repaires',
            'repaired',
            'repairent',
            'repairing',
            'repairings',
            'repaireing',
            'repairment',
            'repairable',
            'repairative',
            'repairation',
            'repairables',
            'repairations',
            'repairability'],
 'repairdefect': {'repairdefective': []},
 'repairdefici': {'repairdeficient': []},
 'repairi': {'repairier': [], 'repairis': []},
 'repairing': {'repairinge': []},
 'repairingth': {'repairingthe': []},
 'repairosom': {'repairosome': []},
 'repairpeopl': {'repairpeople': []},
 'repairperson': {'repairpersons': []},
 'repairshop': {'repairshops': []},
 'repairth': {'repairthe': []},
 'repairtim': {'repairtime': []},
 'repaiss': {'repaissant': [], 'repaissent': []},
 'repaistr': {'repaistre': []},
 'repait': {'repaited': [], 'repaiting': [], 'repaits': []},
 'repaitr': {'repaitre': []},
 'repal': {'repale': ['repalers'], 'repalle': [], 'repalli': []},
 'repalc': {'repalce': ['repalced', 'repalcement']},
 'repalce': ['repalced', 'repalcement'],
 'repale': ['repalers'],
 'repalp': {'repalpate': ['repalpated'], 'repalpation': []},
 'repalpate': ['repalpated'],
 'repalr': {'repalrs': []},
 'repan': {'repanned': [], 'repanning': [], 'repans': []},
 'repanc': {'repancies': [], 'repancy': []},
 'repand': {'repandant': [],
            'repande': ['repandent'],
            'repandous': [],
            'repands': []},
 'repandai': {'repandaient': []},
 'repande': ['repandent'],
 'repanden': {'repandens': []},
 'repandi': {'repandis': []},
 'repandir': {'repandirent': []},
 'repandli': {'repandly': []},
 'repandoi': {'repandoient': []},
 'repandr': {'repandre': []},
 'repandu': {'repandue': ['repandues'], 'repandus': []},
 'repandue': ['repandues'],
 'repanel': {'repaneled': [], 'repanelled': []},
 'repans': {'repanse': []},
 'repap': {'repaper': ['repapers', 'repapered', 'repapering']},
 'repaper': ['repapers', 'repapered', 'repapering'],
 'repapi': {'repapis': []},
 'repar': {'reparability': [],
           'reparable': ['reparables'],
           'reparably': [],
           'reparant': [],
           'reparate': ['reparated', 'reparately'],
           'reparating': [],
           'reparation': ['reparational'],
           'reparative': ['reparatively', 'reparativeness'],
           'reparator': [],
           'repare': ['repared',
                      'reparer',
                      'repares',
                      'reparent',
                      'reparents',
                      'repareing',
                      'reparented',
                      'reparenting'],
           'reparing': [],
           'repars': []},
 'repara': {'reparas': []},
 'reparabil': {'reparabile': []},
 'reparabili': {'reparabilis': []},
 'reparable': ['reparables'],
 'reparacion': {'reparacione': ['reparaciones'], 'reparacions': []},
 'reparacione': ['reparaciones'],
 'reparacioni': {'reparacionis': []},
 'reparacionibu': {'reparacionibus': []},
 'reparacioun': {'reparaciouns': []},
 'reparacon': {'reparacons': []},
 'reparacyon': {'reparacyons': []},
 'reparada': {'reparadas': []},
 'reparado': {'reparados': []},
 'reparagraph': {'reparagraphed': [], 'reparagraphing': []},
 'reparaiss': {'reparaissant': [], 'reparaisse': ['reparaissent']},
 'reparaisse': ['reparaissent'],
 'reparaitr': {'reparaitre': []},
 'reparameter': {'reparameterization': ['reparameterizations'],
                 'reparameterize': ['reparameterized', 'reparameterizes'],
                 'reparameterizing': []},
 'reparameteris': {'reparameterisation': ['reparameterisations'],
                   'reparameterise': ['reparameterised'],
                   'reparameterising': []},
 'reparameterisation': ['reparameterisations'],
 'reparameterise': ['reparameterised'],
 'reparameterization': ['reparameterizations'],
 'reparameterize': ['reparameterized', 'reparameterizes'],
 'reparametr': {'reparametrization': ['reparametrizations'],
                'reparametrize': ['reparametrized'],
                'reparametrizing': []},
 'reparametris': {'reparametrisation': ['reparametrisations']},
 'reparametrisation': ['reparametrisations'],
 'reparametrization': ['reparametrizations'],
 'reparametrize': ['reparametrized'],
 'reparamu': {'reparamus': []},
 'reparan': {'reparans': []},
 'reparanda': {'reparandae': [], 'reparandas': []},
 'reparandi': {'reparandis': []},
 'reparandisqu': {'reparandisque': []},
 'reparandu': {'reparandus': []},
 'reparaphras': {'reparaphrase': []},
 'reparar': {'reparare': []},
 'reparars': {'repararse': []},
 'reparata': {'reparatae': []},
 'reparate': ['reparated', 'reparately'],
 'reparateur': {'reparateurs': []},
 'reparati': {'reparatie': [], 'reparatis': []},
 'reparation': {'reparatione': ['reparationes', 'reparationer']},
 'reparatione': ['reparationes', 'reparationer'],
 'reparationesqu': {'reparationesque': []},
 'reparationi': {'reparationis': []},
 'reparationibu': {'reparationibus': []},
 'reparationist': {'reparationists': []},
 'reparationsfrag': {'reparationsfrage': []},
 'reparationsproblem': {'reparationsproblems': []},
 'reparatioun': {'reparatioune': []},
 'reparative': ['reparatively', 'reparativeness'],
 'reparatori': {'reparatory': []},
 'reparatric': {'reparatrice': ['reparatrices']},
 'reparatrice': ['reparatrices'],
 'reparatu': {'reparatus': []},
 'reparcel': {'reparceled': [],
              'reparceling': [],
              'reparcellation': [],
              'reparcelled': [],
              'reparcelling': []},
 'repard': {'reparded': [], 'reparding': [], 'repards': []},
 'repare': {'reparee': ['reparees']},
 'reparee': ['reparees'],
 'reparenthes': {'reparentheses': []},
 'reparentnotifi': {'reparentnotify': []},
 'reparer': {'reparere': []},
 'repari': {'reparied': [], 'reparis': []},
 'repariert': {'reparierte': []},
 'repark': {'reparked': [], 'reparking': []},
 'reparl': {'reparle': ['reparler']},
 'reparle': ['reparler'],
 'reparleron': {'reparlerons': []},
 'reparlimiento': {'reparlimientos': []},
 'reparo': {'reparos': []},
 'reparoistr': {'reparoistre': []},
 'reparoitr': {'reparoitre': []},
 'reparol': {'reparole': ['reparoled']},
 'reparole': ['reparoled'],
 'repars': {'reparse': ['reparsed', 'reparses'], 'reparsing': []},
 'reparse': ['reparsed', 'reparses'],
 'repart': {'repartant': [],
            'reparte': ['reparted', 'repartes', 'repartent'],
            'reparting': [],
            'repartion': [],
            'repartment': [],
            'reparts': []},
 'repartai': {'repartaient': []},
 'repartamiento': {'repartamientos': []},
 'reparte': {'repartee': ['reparteed', 'reparteeing']},
 'repartee': ['reparteed', 'reparteeing'],
 'reparti': {'repartiation': [],
             'repartie': ['reparties'],
             'repartiment': [],
             'repartis': [],
             'reparty': []},
 'reparticion': {'reparticiones': []},
 'reparticip': {'reparticipation': []},
 'repartico': {'reparticoes': []},
 'reparticular': {'reparticularized': []},
 'repartida': {'repartidas': []},
 'repartido': {'repartidos': []},
 'repartidola': {'repartidolas': []},
 'repartidor': {'repartidores': []},
 'repartie': ['reparties'],
 'repartiendos': {'repartiendose': []},
 'reparties': {'repartiese': []},
 'repartimento': {'repartimentos': []},
 'repartimicnto': {'repartimicntos': []},
 'repartimienlo': {'repartimienlos': []},
 'repartimiento': {'repartimientos': []},
 'repartir': {'repartirent': []},
 'repartirla': {'repartirlas': []},
 'repartirlo': {'repartirlos': []},
 'repartirs': {'repartirse': []},
 'repartiss': {'repartissant': [], 'repartissent': []},
 'repartissai': {'repartissaient': []},
 'repartit': {'repartition': ['repartitions',
                              'repartitional',
                              'repartitioned',
                              'repartitioning']},
 'repartiteur': {'repartiteurs': []},
 'repartition': ['repartitions',
                 'repartitional',
                 'repartitioned',
                 'repartitioning'],
 'repartn': {'repartner': ['repartnered', 'repartnering']},
 'repartner': ['repartnered', 'repartnering'],
 'reparto': {'repartos': []},
 'reparton': {'repartons': []},
 'repartri': {'repartriate': ['repartriated'], 'repartriation': []},
 'repartriate': ['repartriated'],
 'reparur': {'reparurent': []},
 'repas': {'repase': []},
 'repasi': {'repasied': [], 'repasy': []},
 'repask': {'repaske': []},
 'repaski': {'repasky': []},
 'repasl': {'repasled': []},
 'repaso': {'repasos': []},
 'repass': {'repassant': [],
            'repasse': ['repassed', 'repasser', 'repasses', 'repassent'],
            'repassing': ['repassings']},
 'repassag': {'repassage': ['repassaged']},
 'repassage': ['repassaged'],
 'repasse': ['repassed', 'repasser', 'repasses', 'repassent'],
 'repasser': {'repasserent': []},
 'repasseus': {'repasseuse': ['repasseuses']},
 'repasseuse': ['repasseuses'],
 'repassi': {'repassy': []},
 'repassing': ['repassings'],
 'repassiv': {'repassivate': ['repassivated', 'repassivates'],
              'repassivating': [],
              'repassivation': []},
 'repassivate': ['repassivated', 'repassivates'],
 'repast': ['repaste', 'repasted', 'repasting'],
 'repasteur': {'repasteurization': [], 'repasteurize': ['repasteurized']},
 'repasteurize': ['repasteurized'],
 'repastin': {'repastination': []},
 'repastur': {'repasture': []},
 'repat': {'repatation': [],
           'repate': ['repated', 'repatent', 'repatented', 'repatenting'],
           'repating': [],
           'repation': [],
           'repats': []},
 'repatch': {'repatched': [], 'repatching': []},
 'repate': ['repated', 'repatent', 'repatented', 'repatenting'],
 'repatedli': {'repatedly': []},
 'repatholog': {'repathologize': []},
 'repati': {'repatient': []},
 'repatin': {'repatinated': [], 'repatination': []},
 'repatit': {'repatition': []},
 'repatn': {'repatnation': []},
 'repatr': {'repatration': [], 'repatrs': []},
 'repatri': {'repatriability': [],
             'repatriable': ['repatriables'],
             'repatriants': [],
             'repatriate': ['repatriated'],
             'repatriating': [],
             'repatriation': [],
             'repatriators': [],
             'repatriement': [],
             'repatriering': [],
             'repatries': []},
 'repatriable': ['repatriables'],
 'repatriado': {'repatriados': []},
 'repatriar': {'repatriare': []},
 'repatriarch': {'repatriarchalization': []},
 'repatriat': {'repatriatable': []},
 'repatriate': {'repatriatees': []},
 'repatriot': {'repatriots': []},
 'repatron': {'repatronize': []},
 'repatronag': {'repatronage': []},
 'repattem': {'repatteming': []},
 'repattern': {'repatterned': [],
               'repatterning': ['repatternings'],
               'repatterns': []},
 'repatterning': ['repatternings'],
 'repatti': {'repattiation': []},
 'repau': {'repaus': []},
 'repav': {'repave': ['repaves', 'repaved', 'repavement', 'repavements'],
           'repaving': ['repavings'],
           'repavment': ['repavments']},
 'repave': ['repaves', 'repaved', 'repavement', 'repavements'],
 'repaving': ['repavings'],
 'repavment': ['repavments'],
 'repawn': {'repawned': []},
 'repawt': {'repawted': []},
 'repay': {'repayability': [],
           'repayable': [],
           'repayal': [],
           'repaye': ['repayed',
                      'repayer',
                      'repayers',
                      'repayeing',
                      'repayement'],
           'repaying': [],
           'repayment': [],
           'repays': []},
 'repaybl': {'repayble': []},
 'repayd': {'repayde': []},
 'repaye': ['repayed', 'repayer', 'repayers', 'repayeing', 'repayement'],
 'repayment': {'repaymente': []},
 'repayr': {'repayre': ['repayred', 'repayrer', 'repayres', 'repayreing'],
            'repayring': []},
 'repayre': ['repayred', 'repayrer', 'repayres', 'repayreing'],
 'repayring': {'repayringe': []},
 'repayth': {'repayther': []},
 'repb': {'repbed': [], 'repbes': []},
 "repb'": {"repb'ed": []},
 'repbes': {'repbesentatives': []},
 'repbr': {'repbre': []},
 'repbrt': {'repbrted': [], 'repbrts': []},
 'repbul': {'repbulic': []},
 'repc': {'repce': [], 'repcs': []},
 'repcat': {'repcatable': [], 'repcated': []},
 'repcn': {'repcns': []},
 'repcopl': {'repcopled': []},
 'repcrfus': {'repcrfusion': []},
 'repcrt': {'repcrted': [], 'repcrts': []},
 'repctit': {'repctition': []},
 'repder': {'repdered': []},
 'repdrt': {'repdrted': []},
 'repe': {'repeative': [],
          'reped': [],
          'repee': ['repees', 'repeed'],
          'repelied': [],
          'repes': [],
          'reping': []},
 'repea': {'repeaed': []},
 "repea'": {"repea'ed": []},
 'repeadedli': {'repeadedly': []},
 'repeadli': {'repeadly': []},
 'repeaf': {'repeafed': []},
 'repeai': {'repeaied': []},
 'repeal': ['repeale',
            'repealed',
            'repealer',
            'repealled',
            'repealers',
            'repealing',
            'repealling',
            'repealable',
            'repealment',
            'repealability'],
 'repealedli': {'repealedly': []},
 'repealist': {'repealists': []},
 'repear': {'repeared': [], 'repearing': [], 'repears': []},
 'repearedli': {'repearedly': []},
 'repeasant': {'repeasantization': []},
 'repeat': ['repeate',
            'repeated',
            'repeates',
            'repeater',
            'repeator',
            'repeation',
            'repeating',
            'repeatted',
            'repeately',
            'repeators',
            'repeatable',
            'repeatible',
            'repeatably',
            'repeatered',
            'repeatative',
            'repeatation',
            'repeatables',
            'repeatibility',
            'repeatability',
            'repeatableness',
            'repeatabilities'],
 'repeatabilti': {'repeatabilty': []},
 'repeatabl': {'repeatablity': []},
 'repeatahil': {'repeatahility': []},
 'repeatahl': {'repeatahle': []},
 'repeatbloom': {'repeatblooming': []},
 'repeatcolumn': {'repeatcolumns': []},
 'repeatcontain': {'repeatcontaining': []},
 'repeatdirect': {'repeatdirection': []},
 'repeatdli': {'repeatdly': []},
 'repeateadli': {'repeateadly': []},
 'repeated': {'repeatedely': [], 'repeatedness': []},
 'repeatedi': {'repeatedy': []},
 'repeatedli': {'repeatedly': []},
 'repeatedmeasur': {'repeatedmeasure': ['repeatedmeasures',
                                        'repeatedmeasurement',
                                        'repeatedmeasurements']},
 'repeatedmeasure': ['repeatedmeasures',
                     'repeatedmeasurement',
                     'repeatedmeasurements'],
 'repeatednot': {'repeatednote': []},
 'repeatedth': {'repeatedthe': []},
 'repeatedti': {'repeatedty': []},
 'repeatercommandeventarg': {'repeatercommandeventargs': []},
 'repeatflow': {'repeatflowering': []},
 'repeatidli': {'repeatidly': []},
 'repeatingli': {'repeatingly': []},
 'repeatingrifl': {'repeatingrifle': []},
 'repeatingth': {'repeatingthe': []},
 'repeatit': {'repeatition': [], 'repeatitive': []},
 'repeatkey': {'repeatkeys': []},
 'repeatli': {'repeatly': []},
 'repeatmask': {'repeatmasker': []},
 'repeatodli': {'repeatodly': []},
 'repeatpurchas': {'repeatpurchase': []},
 'repeatth': {'repeatthe': []},
 'repech': {'repeche': []},
 'repechag': {'repechage': []},
 'repeck': {'repecked': [], 'repecking': []},
 'repect': {'repectability': [],
            'repectable': [],
            'repected': [],
            'repectful': ['repectfully'],
            'repecting': [],
            'repective': ['repectively'],
            'repects': []},
 'repectful': ['repectfully'],
 'repective': ['repectively'],
 'reped': {'repede': []},
 'repedar': {'repedare': []},
 'repee': ['repees', 'repeed'],
 'repeel': {'repeeled': [], 'repeeling': []},
 'repees': {'repeesentatives': []},
 'repeesent': {'repeesentation': []},
 'repeet': {'repeeted': [], 'repeeting': []},
 'repeetedli': {'repeetedly': []},
 'repeg': {'repegged': [], 'repegging': []},
 'repeindr': {'repeindre': []},
 'repeint': {'repeinte': ['repeintes', 'repeinted'], 'repeints': []},
 'repeinte': ['repeintes', 'repeinted'],
 'repeir': {'repeire': []},
 'repeit': {'repeited': [], 'repeition': []},
 'repeiv': {'repeive': ['repeived']},
 'repeive': ['repeived'],
 'repel': {'repele': ['repeled', 'repeler', 'repelent'],
           'repeling': [],
           'repell': ['repells',
                      'repelle',
                      'repelled',
                      'repeller',
                      'repelles',
                      'repellers',
                      'repellent',
                      'repelling',
                      'repellant',
                      'repellance',
                      'repellings',
                      'repellency',
                      'repellancy',
                      'repellence',
                      'repellable',
                      'repellently',
                      'repellences',
                      'repellencies'],
           'repels': []},
 'repela': {'repelaer': []},
 'repelcot': {'repelcote': []},
 'repele': ['repeled', 'repeler', 'repelent'],
 'repelent': {'repelente': ['repelentes']},
 'repelente': ['repelentes'],
 'repelit': {'repelition': []},
 'repelita': {'repelitas': []},
 'repell': ['repells',
            'repelle',
            'repelled',
            'repeller',
            'repelles',
            'repellers',
            'repellent',
            'repelling',
            'repellant',
            'repellance',
            'repellings',
            'repellency',
            'repellancy',
            'repellence',
            'repellable',
            'repellently',
            'repellences',
            'repellencies'],
 'repella': {'repellas': []},
 'repellantli': {'repellantly': []},
 'repellen': {'repellens': []},
 'repellenda': {'repellendas': []},
 'repellendi': {'repellendis': []},
 'repellendo': {'repellendos': []},
 'repellendu': {'repellendus': []},
 'repellent': {'repellente': []},
 'repellentibu': {'repellentibus': []},
 'repellentlook': {'repellentlooking': []},
 'repeller': {'repellere': []},
 'repellet': {'repelleted': [], 'repelleting': [], 'repelletized': []},
 'repelli': {'repellis': []},
 'repellimu': {'repellimus': []},
 'repelling': {'repellingness': []},
 'repellingli': {'repellingly': []},
 'repellit': {'repellite': []},
 'repellor': {'repellors': []},
 'repen': {'repene': [],
           'repening': [],
           'repenned': [],
           'repenning': [],
           'repens': []},
 'repencil': {'repenciled': []},
 'repend': {'rependant': [], 'repende': [], 'repends': []},
 'rependamu': {'rependamus': []},
 'rependen': {'rependens': []},
 'repender': {'rependere': []},
 'rependi': {'rependis': []},
 'rependr': {'rependre': []},
 'repenetr': {'repenetrate': ['repenetrated', 'repenetrates'],
              'repenetrating': [],
              'repenetration': []},
 'repenetrate': ['repenetrated', 'repenetrates'],
 'repenl': {'repenled': []},
 'repens': {'repensant': [], 'repense': ['repenser']},
 'repense': {'repensee': []},
 'repent': {'repentable': [],
            'repentance': [],
            'repentancies': [],
            'repentant': ['repentants'],
            'repente': ['repented',
                        'repenter',
                        'repentes',
                        'repenters',
                        'repentent',
                        'repentence',
                        'repentently',
                        'repentences'],
            'repentful': [],
            'repenting': ['repentings'],
            'repentive': [],
            'repents': []},
 'repentac': {'repentace': []},
 'repentan': {'repentans': []},
 'repentane': {'repentanee': []},
 'repentano': {'repentanoe': []},
 'repentant': {'repentante': ['repentantes']},
 'repentante': ['repentantes'],
 'repentantli': {'repentantly': []},
 'repentauc': {'repentauce': []},
 'repentaunc': {'repentaunce': []},
 'repente': {'repentees': []},
 'repentedli': {'repentedly': []},
 'repenti': {'repentie': ['repenties'], 'repentis': []},
 'repentibu': {'repentibus': []},
 'repentie': ['repenties'],
 'repentigni': {'repentigny': ['repentignys']},
 'repentigny': ['repentignys'],
 'repentin': {'repentine': []},
 'repentina': {'repentinae': [], 'repentinas': []},
 'repentinament': {'repentinamente': []},
 'repentinc': {'repentince': []},
 'repenting': ['repentings'],
 'repentingli': {'repentingly': []},
 'repentini': {'repentinis': []},
 'repentino': {'repentinos': []},
 'repentinu': {'repentinus': []},
 'repentir': {'repentirs': []},
 'repentira': {'repentiras': []},
 'repentista': {'repentistas': []},
 'repenton': {'repentons': []},
 'repentyng': {'repentynge': []},
 'repeopl': {'repeople': ['repeoples', 'repeopled'], 'repeopling': []},
 'repeople': ['repeoples', 'repeopled'],
 'repeot': {'repeoted': []},
 'repept': {'repeptization': [], 'repeptize': ['repeptized']},
 'repeptize': ['repeptized'],
 'reper': {'reperable': ['reperables'],
           'reperant': [],
           'reperation': ['reperations'],
           'repere': ['reperer',
                      'reperes',
                      'reperent',
                      'reperence',
                      'reperences'],
           'reperiti': ['reperitis'],
           'repers': []},
 'reperable': ['reperables'],
 'reperag': {'reperage': ['reperages']},
 'reperage': ['reperages'],
 'reperation': ['reperations'],
 'reperatori': {'reperatory': []},
 'reperc': {'reperceive': ['reperceives']},
 'reperceiv': {'reperceived': [], 'reperceiving': []},
 'reperceive': ['reperceives'],
 'repercentag': {'repercentaged': []},
 'repercept': {'reperception': ['reperceptions']},
 'reperception': ['reperceptions'],
 'reperch': {'reperched': []},
 'repercol': {'repercolated': [], 'repercolation': []},
 'repercu': {'repercus': []},
 'repercurs': {'repercursions': []},
 'repercus': {'repercusion': ['repercusions']},
 'repercusion': {'repercusiones': []},
 'repercuss': {'repercussed': [],
               'repercusses': [],
               'repercussing': [],
               'repercussion': [],
               'repercussive': ['repercussives', 'repercussively']},
 'repercussa': {'repercussae': []},
 'repercussion': {'repercussione': ['repercussiones']},
 'repercussionari': {'repercussionary': []},
 'repercussione': ['repercussiones'],
 'repercussionibu': {'repercussionibus': []},
 'repercussive': ['repercussives', 'repercussively'],
 'repercusso': {'repercussoes': []},
 'repercusss': {'repercusssions': []},
 'repercussu': {'repercussus': []},
 'repercut': {'repercutant': [],
              'repercute': ['repercuter', 'repercuted', 'repercutent'],
              'repercutions': []},
 'repercute': {'repercutee': []},
 'repere': {'reperee': ['reperees']},
 'reperee': ['reperees'],
 'repereri': {'repereris': []},
 'reperes': {'reperesent': ['reperesents',
                            'reperesented',
                            'reperesenting',
                            'reperesentative',
                            'reperesentatives']},
 'reperesent': {'reperesentation': []},
 'repereuss': {'repereussions': []},
 'reperfect': {'reperfected': [], 'reperfecting': [], 'reperfection': []},
 'reperfiis': {'reperfiision': []},
 'reperfor': {'reperforate': ['reperforated'],
              'reperforating': [],
              'reperforation': [],
              'reperforator': ['reperforators']},
 'reperforate': ['reperforated'],
 'reperforator': ['reperforators'],
 'reperform': {'reperformance': ['reperformances'],
               'reperformed': [],
               'reperforming': [],
               'reperforms': []},
 'reperformance': ['reperformances'],
 'reperfus': {'reperfusate': [],
              'reperfuse': ['reperfuses', 'reperfused'],
              'reperfusing': [],
              'reperfusion': ['reperfusions']},
 'reperfuse': ['reperfuses', 'reperfused'],
 'reperfusion': ['reperfusions'],
 'reperfusioninduc': {'reperfusioninduced': []},
 'reperi': {'reperiant': [], 'reperient': [], 'reperies': [], 'reperis': []},
 'reperia': {'reperias': []},
 'reperiamu': {'reperiamus': []},
 'reperibil': {'reperibile': []},
 'reperieb': {'reperiebant': []},
 'reperiebamu': {'reperiebamus': []},
 'reperiemu': {'reperiemus': []},
 'reperien': {'reperiens': []},
 'reperienda': {'reperiendae': []},
 'reperiendi': {'reperiendis': []},
 'reperient': {'reperientes': []},
 'reperieti': {'reperietis': []},
 'reperimu': {'reperimus': []},
 'reperiod': {'reperiodization': [], 'reperiodize': [], 'reperiodizing': []},
 'reperir': {'reperire': ['reperirent']},
 'reperire': ['reperirent'],
 'reperiss': {'reperisse': ['reperissent']},
 'reperisse': ['reperissent'],
 'reperissemqu': {'reperissemque': []},
 'reperit': {'reperite': [], 'reperition': ['reperitions'], 'reperitive': []},
 'reperiti': ['reperitis'],
 'reperition': ['reperitions'],
 'reperiton': {'reperitonealization': [],
               'reperitonealize': ['reperitonealized'],
               'reperitonealizing': [],
               'reperitonization': []},
 'reperitonealize': ['reperitonealized'],
 'reperitqu': {'reperitque': []},
 'reperm': {'repermeation': []},
 'repermeabil': {'repermeabilization': []},
 'repermit': {'repermitted': []},
 'reperoir': {'reperoire': []},
 'reperouss': {'reperoussions': []},
 'repers': {'repersent': ['repersents',
                          'repersented',
                          'repersenting',
                          'repersentative',
                          'repersentatives']},
 'repersent': {'repersentation': ['repersentations']},
 'repersentation': ['repersentations'],
 'reperson': {'repersonalization': [],
              'repersonalize': ['repersonalized'],
              'repersonalizing': [],
              'repersons': []},
 'repersonalis': {'repersonalisation': []},
 'repersonalize': ['repersonalized'],
 'repersonif': {'repersonification': []},
 'repersonifi': {'repersonified': []},
 'repersuad': {'repersuade': ['repersuaded']},
 'repersuade': ['repersuaded'],
 'repert': {'repertation': [], 'reperte': ['reperted'], 'reperts': []},
 'reperta': {'repertae': [], 'repertas': []},
 'reperte': ['reperted'],
 'reperti': {'repertis': []},
 'reperting': {'repertinger': []},
 'repertior': {'repertiore': []},
 'reperto': {'repertos': []},
 'repertoir': {'repertoire': [], 'repertoirs': []},
 'repertoit': {'repertoite': ['repertoites']},
 'repertoite': ['repertoites'],
 'repertor': {'repertore': ['repertores'],
              'repertorization': [],
              'repertorize': ['repertorized'],
              'repertorizing': []},
 'repertore': ['repertores'],
 'repertori': {'repertorial': ['repertorially'],
               'repertorie': ['repertorier', 'repertoried'],
               'repertory': []},
 'repertorial': ['repertorially'],
 'repertorie': {'repertoriee': ['repertoriees']},
 'repertoriee': ['repertoriees'],
 'repertorio': {'repertorios': []},
 'repertoris': {'repertorisation': [], 'repertorising': []},
 'repertorium': {'repertoriums': []},
 'repertorize': ['repertorized'],
 'reperts': {'repertse': []},
 'repertu': {'repertus': []},
 'repertus': {'repertusion': []},
 'reperus': {'reperusal': ['reperusals'],
             'reperuse': ['reperused', 'reperuses'],
             'reperusing': []},
 'reperusal': ['reperusals'],
 'reperuse': ['reperused', 'reperuses'],
 'repes': {'repesent': ['repesents',
                        'repesented',
                        'repesenting',
                        'repesentative',
                        'repesentatives']},
 'repese': {'repeseed': []},
 'repesent': {'repesentation': ['repesentations']},
 'repesentation': ['repesentations'],
 'repess': {'repession': []},
 'repest': {'repested': []},
 'repestedli': {'repestedly': []},
 'repet': {'repetable': [],
           'repetance': [],
           'repetant': [],
           'repetation': [],
           'repetative': [],
           'repete': ['repetes', 'repeter', 'repeted', 'repetent', 'repetence'],
           'repetibility': [],
           'repetible': [],
           'repeting': [],
           'repetion': ['repetions'],
           'repetiti': ['repetitis'],
           'repetive': ['repetively', 'repetiveness'],
           'repetivity': []},
 'repeta': {'repetas': []},
 'repetab': {'repetabs': []},
 'repetabilit': {'repetabilite': []},
 'repetai': {'repetaient': [], 'repetais': []},
 'repetamu': {'repetamus': []},
 'repetatqu': {'repetatque': []},
 'repete': {'repetee': ['repetees']},
 'repeteadli': {'repeteadly': []},
 'repeteb': {'repetebant': []},
 'repetedli': {'repetedly': []},
 'repetee': ['repetees'],
 'repetemu': {'repetemus': []},
 'repeten': {'repetens': []},
 'repetend': {'repetends': []},
 'repetenda': {'repetendae': [], 'repetendas': []},
 'repetendi': {'repetendis': []},
 'repetendu': {'repetendus': []},
 'repetent': {'repetente': ['repetentes']},
 'repetente': ['repetentes'],
 'repetenti': {'repetentis': []},
 'repetentibu': {'repetentibus': []},
 'repeter': {'repetere': ['repeterent']},
 'repetere': ['repeterent'],
 'repeteron': {'repeterons': []},
 'repetet': {'repetetion': [], 'repetetive': ['repetetively']},
 'repetetive': ['repetetively'],
 'repeti': {'repetis': []},
 'repeticion': {'repeticiones': [], 'repeticions': []},
 'repetico': {'repeticoes': []},
 'repetida': {'repetidas': []},
 'repetidament': {'repetidamente': []},
 'repetido': {'repetidos': []},
 'repetidor': {'repetidores': []},
 'repetimo': {'repetimos': []},
 'repetimu': {'repetimus': []},
 'repetion': ['repetions'],
 'repetirs': {'repetirse': []},
 'repetiss': {'repetisse': []},
 'repetisti': {'repetistis': []},
 'repetit': {'repetitative': [],
             'repetite': [],
             'repetition': ['repetitional', 'repetitioned', 'repetitioning'],
             'repetitive': ['repetitives', 'repetitively', 'repetitiveness'],
             'repetitivity': [],
             'repetitous': []},
 'repetita': {'repetitae': [], 'repetitas': []},
 'repetitaqu': {'repetitaque': []},
 'repetiteur': {'repetiteurs': []},
 'repetiti': {'repetitie': [],
              'repetitiou': ['repetitious',
                             'repetitiously',
                             'repetitiousness']},
 'repetitif': {'repetitifs': []},
 'repetition': {'repetitione': ['repetitiones']},
 'repetitionari': {'repetitionary': []},
 'repetitioncompuls': {'repetitioncompulsion': []},
 'repetitione': ['repetitiones'],
 'repetitioni': {'repetitionis': []},
 'repetitionibu': {'repetitionibus': []},
 'repetitionr': {'repetitionrate': []},
 'repetitiou': ['repetitious', 'repetitiously', 'repetitiousness'],
 'repetitit': {'repetitition': ['repetititions'], 'repetititive': []},
 'repetitition': ['repetititions'],
 'repetititv': {'repetititve': []},
 'repetitiva': {'repetitivas': []},
 'repetitive': ['repetitives', 'repetitively', 'repetitiveness'],
 'repetitivemot': {'repetitivemotion': []},
 'repetitivit': {'repetitivite': []},
 'repetitivo': {'repetitivos': []},
 'repetito': {'repetitos': []},
 'repetiton': {'repetitons': []},
 'repetitor': {'repetitores': [], 'repetitors': []},
 'repetitori': {'repetitory': []},
 'repetitu': {'repetitus': []},
 'repetituru': {'repetiturus': []},
 'repetitv': {'repetitve': []},
 'repetive': ['repetively', 'repetiveness'],
 'repetizion': {'repetizione': []},
 'repetoi': {'repetoient': []},
 'repetoir': {'repetoire': ['repetoires']},
 'repetoire': ['repetoires'],
 'repeton': {'repetons': []},
 'repetori': {'repetory': []},
 'repettico': {'repetticoated': []},
 'repetunda': {'repetundae': []},
 'repetundi': {'repetundis': []},
 'repeu': {'repeues': [], 'repeus': []},
 'repeupl': {'repeuple': ['repeupler', 'repeuplement']},
 'repeuple': ['repeupler', 'repeuplement'],
 'repeut': {'repeutance': [], 'repeuted': []},
 'repew': {'repewed': [], 'repewing': []},
 'repf': {'repfeds': []},
 'repfcat': {'repfcation': []},
 'repfi': {'repfied': [], 'repfy': []},
 'repfoot': {'repfooter': []},
 'repg': {'repges': []},
 'repgow': {'repgowe': []},
 'reph': {'rephe': ['rephed', 'rephes']},
 "reph'": {"reph'ed": []},
 'repha': {'rephaeli': []},
 'rephaim': {'rephaims': []},
 'rephait': {'rephaite': ['rephaites']},
 'rephaite': ['rephaites'],
 'rephas': {'rephase': ['rephases', 'rephased', 'rephasement'],
            'rephasing': []},
 'rephase': ['rephases', 'rephased', 'rephasement'],
 'rephe': ['rephed', 'rephes'],
 'rephead': {'repheader': []},
 'rephi': {'rephy': []},
 'rephonemic': {'rephonemicization': [], 'rephonemicized': []},
 'rephonolog': {'rephonologization': [], 'rephonologized': []},
 'rephosphor': {'rephosphorization': [], 'rephosphorized': []},
 'rephosphoryl': {'rephosphorylate': ['rephosphorylated', 'rephosphorylates'],
                  'rephosphorylating': [],
                  'rephosphorylation': []},
 'rephosphorylate': ['rephosphorylated', 'rephosphorylates'],
 'rephotograph': {'rephotographed': [],
                  'rephotographic': [],
                  'rephotographing': [],
                  'rephotographs': []},
 'rephotographi': {'rephotography': []},
 'rephras': {'rephrasable': [],
             'rephrasal': ['rephrasals'],
             'rephrase': ['rephrases', 'rephrased'],
             'rephrasing': []},
 'rephrasal': ['rephrasals'],
 'rephrase': ['rephrases', 'rephrased'],
 'repi': {'repie': ['repied', 'repies'], 'repis': [], 'repy': []},
 'repiac': {'repiace': ['repiaced', 'repiacement'], 'repiacing': []},
 'repiace': ['repiaced', 'repiacement'],
 'repibl': {'repiblic': []},
 'repic': {'repice': []},
 'repick': {'repicked': [], 'repicking': []},
 'repicki': {'repicky': []},
 'repickl': {'repickled': []},
 'repicroc': {'repicrocal': []},
 'repictur': {'repicture': ['repictured'], 'repicturing': []},
 'repicture': ['repictured'],
 'repid': {'repide': [], 'repidity': [], 'repids': []},
 'repidgin': {'repidginization': [], 'repidginized': []},
 'repidli': {'repidly': []},
 'repids': {'repidsed': [], 'repidsion': [], 'repidsive': []},
 'repie': ['repied', 'repies'],
 'repiec': {'repiece': ['repieced'], 'repiecing': []},
 'repiece': ['repieced'],
 'repierc': {'repierce': ['repierced'], 'repiercing': []},
 'repierce': ['repierced'],
 'repies': {'repiesent': ['repiesents',
                          'repiesented',
                          'repiesenting',
                          'repiesentative',
                          'repiesentatives']},
 'repiesent': {'repiesentation': ['repiesentations']},
 'repiesentation': ['repiesentations'],
 'repig': {'repigment': ['repigments', 'repigmented', 'repigmenting']},
 'repigment': {'repigmentation': []},
 'repii': {'repiied': [], 'repiies': []},
 'repiibl': {'repiiblic': []},
 'repiiblica': {'repiiblicas': []},
 'repiibliqu': {'repiiblique': []},
 'repiic': {'repiication': []},
 'repiint': {'repiinted': []},
 'repiit': {'repiitation': []},
 'repil': {'repile': ['repiles', 'repiled'], 'repiling': []},
 'repile': ['repiles', 'repiled'],
 'repim': {'repime': []},
 'repimu': {'repimus': []},
 'repin': {'repine': ['repiner',
                      'repines',
                      'repined',
                      'repiners',
                      'repineing',
                      'repinement'],
           'repining': ['repinings'],
           'repinned': [],
           'repinning': [],
           'repins': []},
 'repine': ['repiner',
            'repines',
            'repined',
            'repiners',
            'repineing',
            'repinement'],
 'repining': ['repinings'],
 'repiningli': {'repiningly': []},
 'repinski': {'repinsky': []},
 'repint': {'repinted': []},
 'repioduc': {'repioduced': []},
 'repioduct': {'repioduction': []},
 'repion': {'repions': []},
 'repip': {'repipe': ['repiped'], 'repiping': []},
 'repipe': ['repiped'],
 'repipet': {'repipetting': []},
 'repiqu': {'repique': ['repiques', 'repiqued', 'repiquer', 'repiqueing']},
 'repiquag': {'repiquage': ['repiquages']},
 'repiquage': ['repiquages'],
 'repique': ['repiques', 'repiqued', 'repiquer', 'repiqueing'],
 'repir': {'repiration': ['repirations'], 'repire': []},
 'repiration': ['repirations'],
 'repiratori': {'repiratory': []},
 'repisa': {'repisas': []},
 'repisod': {'repisodic': []},
 'repit': {'repitation': [], 'repite': ['repites'], 'repition': ['repitions']},
 'repita': {'repitas': []},
 'repitch': {'repitched': [], 'repitching': []},
 'repite': ['repites'],
 'repiti': {'repitious': []},
 'repitiendos': {'repitiendose': []},
 'repities': {'repitiese': []},
 'repition': ['repitions'],
 'repitit': {'repitition': ['repititions'], 'repititive': []},
 'repititi': {'repititious': []},
 'repitition': ['repititions'],
 'repitl': {'repitles': []},
 'repjac': {'repjace': ['repjaced']},
 'repjace': ['repjaced'],
 'repji': {'repjied': [], 'repjy': []},
 'repk': {'repke': ['repked']},
 'repkat': {'repkation': []},
 'repkc': {'repkce': ['repkced']},
 'repkce': ['repkced'],
 'repke': ['repked'],
 'repkes': {'repkesentatives': []},
 'repkov': {'repkover': []},
 'repl': {'reple': ['reples', 'repled'], 'repls': []},
 "repl'": {"repl'ed": []},
 'repla': {'replaed': [], 'replaeing': []},
 'replac': {'replacability': [],
            'replacable': [],
            'replacant': [],
            'replace': ['replaces',
                        'replacer',
                        'replaced',
                        'replacers',
                        'replacent',
                        'replaceing',
                        'replacement',
                        'replaceable',
                        'replaceables',
                        'replaceability'],
            'replacing': [],
            'replacive': ['replacives'],
            'replacment': ['replacments']},
 'replace': {'replacee': ['replacees', 'replaceed']},
 'replacea': {'replaceaent': []},
 'replaceal': {'replaceall': []},
 'replacedbi': {'replacedby': []},
 'replacedth': {'replacedthe': []},
 'replacee': ['replacees', 'replaceed'],
 'replacefil': {'replacefiles': []},
 'replacem': {'replacemant': [], 'replaceme': ['replacemer']},
 'replaceme': ['replacemer'],
 'replacementstr': {'replacementstring': []},
 'replacen': {'replacenent': []},
 'replacenod': {'replacenode': []},
 'replacepkg': {'replacepkgs': []},
 'replacerang': {'replacerange': []},
 'replaceselect': {'replaceselection': []},
 'replacesth': {'replacesthe': []},
 'replacestr': {'replacestring': []},
 'replaceth': {'replacethe': []},
 'replacingth': {'replacingthe': []},
 'replacit': {'replacitent': []},
 'replacive': ['replacives'],
 'replacment': ['replacments'],
 'replae': {'replaee': ['replaeed']},
 'replaee': ['replaeed'],
 'replag': {'replagal': []},
 'replait': {'replaited': [], 'replaiting': []},
 'replan': {'replane': ['replaned'],
            'replaning': [],
            'replanned': [],
            'replanning': ['replannings'],
            'replans': []},
 'replane': ['replaned'],
 'replanish': {'replanished': []},
 'replank': {'replanked': [], 'replanking': []},
 'replann': {'replanner': []},
 'replanning': ['replannings'],
 'replanski': {'replansky': []},
 'replant': {'replantable': [],
             'replantation': ['replantations'],
             'replanted': [],
             'replanter': ['replanters'],
             'replanting': ['replantings'],
             'replants': []},
 'replantation': ['replantations'],
 'replanter': ['replanters'],
 'replanting': ['replantings'],
 'replao': {'replaoe': ['replaoes', 'replaoed'], 'replaoing': []},
 'replaoe': ['replaoes', 'replaoed'],
 'replar': {'replare': ['replared']},
 'replare': ['replared'],
 'replas': {'replased': [], 'replasing': []},
 'replast': {'replaster': ['replasters',
                           'replastered',
                           'replastering',
                           'replasterings']},
 'replaster': ['replasters', 'replastered', 'replastering', 'replasterings'],
 'replastic': {'replasticized': []},
 'replat': {'replate': ['replated', 'replates'],
            'replating': ['replatings'],
            'replats': [],
            'replatted': [],
            'replatting': []},
 'replate': ['replated', 'replates'],
 'replatin': {'replatinized': [], 'replatinizing': []},
 'replating': ['replatings'],
 'replatrag': {'replatrage': []},
 'replav': {'replaved': []},
 'replay': ['replayer',
            'replayed',
            'replaying',
            'replayings',
            'replayable',
            'replayability'],
 'replc': {'replced': []},
 'repldtrag': {'repldtrage': []},
 'reple': ['reples', 'repled'],
 'repleac': {'repleaced': []},
 'replead': {'repleaded': [],
             'repleader': ['repleaders'],
             'repleading': [],
             'repleads': []},
 'repleader': ['repleaders'],
 'repleal': {'replealed': []},
 'repleat': {'repleate': ['repleated'], 'repleating': []},
 'repleate': ['repleated'],
 'replec': {'replece': ['repleced', 'replecement']},
 'repleccioun': {'replecciouns': []},
 'replece': ['repleced', 'replecement'],
 'replect': {'replections': []},
 'repledg': {'repledge': ['repledges', 'repledged'], 'repledging': []},
 'repledge': {'repledgee': []},
 'replegars': {'replegarse': []},
 'replegi': {'replegiation': []},
 'replegiar': {'replegiare': []},
 'replen': {'replens': []},
 'replend': {'replendent': []},
 'replenessh': {'replenesshed': []},
 'replenifh': {'replenifhed': []},
 'replenish': {'replenishability': [],
               'replenishable': [],
               'replenishe': ['replenished',
                              'replenisher',
                              'replenishes',
                              'replenishers'],
               'replenishing': ['replenishings'],
               'replenishment': []},
 'replenishe': ['replenished', 'replenisher', 'replenishes', 'replenishers'],
 'replenishing': ['replenishings'],
 'replensh': {'replenshing': []},
 'replent': {'replente': []},
 'replentibu': {'replentibus': []},
 'replenysh': {'replenyshed': []},
 'replenyss': {'replenyssed': []},
 'replenyssh': {'replenysshed': []},
 'repler': {'replere': []},
 'replet': {'replete': ['repletes',
                        'repleter',
                        'repleted',
                        'repletely',
                        'repleteness'],
            'repleting': [],
            'repletion': [],
            'repletive': ['repletively'],
            'replets': []},
 'repleta': {'repletae': [], 'repletas': []},
 'replete': ['repletes', 'repleter', 'repleted', 'repletely', 'repleteness'],
 'repleti': {'repletis': []},
 'repletion': {'repletione': []},
 'repletive': ['repletively'],
 'repleto': {'repletos': []},
 'repletu': {'repletus': []},
 'replever': {'replevere': []},
 'replevi': {'repleviable': [],
             'replevied': [],
             'replevies': [],
             'replevy': ['replevying']},
 'replevin': {'replevined': [], 'replevins': []},
 'replevis': {'replevisable': [], 'replevised': []},
 'replevy': ['replevying'],
 'replf': {'replfed': []},
 'repli': {'replie': ['replied', 'replieds'],
           'replis': [],
           'reply': ['replyed', 'replying', 'replyings']},
 'repliant': {'repliants': []},
 'replic': {'replicability': [],
            'replicable': [],
            'replicably': [],
            'replicant': ['replicants'],
            'replicate': ['replicated', 'replicates'],
            'replicating': [],
            'replication': ['replicational'],
            'replicative': ['replicatively'],
            'replicator': ['replicators'],
            'replice': [],
            'replics': []},
 'replica': ['replicase'],
 'replicabiliri': {'replicabiliry': []},
 'replicahil': {'replicahility': []},
 'replican': {'replicans': []},
 'replicant': {'replicantes': []},
 'replicapl': {'replicaplated': [], 'replicaplating': []},
 'replicar': {'replicare': ['replicared'], 'replicars': []},
 'replicare': ['replicared'],
 'replicas': {'replica': ['replicase']},
 'replicat': {'replicatability': [], 'replicatable': []},
 'replicatament': {'replicatamente': []},
 'replicate': ['replicated', 'replicates'],
 'replicati': {'replicatis': []},
 'replication': {'replicatione': ['replicationes']},
 'replicationcompet': {'replicationcompetent': []},
 'replicationdefect': {'replicationdefective': []},
 'replicationdefici': {'replicationdeficient': []},
 'replicationdepend': {'replicationdependent': []},
 'replicatione': ['replicationes'],
 'replicationibu': {'replicationibus': []},
 'replicationincompet': {'replicationincompetent': []},
 'replicationselect': {'replicationselective': []},
 'replicative': ['replicatively'],
 'replicator': ['replicators'],
 'replicatori': {'replicatory': []},
 'replicazion': {'replicazione': []},
 'replich': {'repliche': []},
 'replici': {'replicis': []},
 'replicon': {'repliconation': [], 'replicons': []},
 'replict': {'repliction': []},
 'replid': {'replide': []},
 'replie': {'repliee': ['repliees']},
 'replieat': {'replieation': []},
 'repliedth': {'repliedthe': []},
 'repliee': ['repliees'],
 'repliegu': {'repliegue': ['repliegues']},
 'repliegue': ['repliegues'],
 'replier': {'replierent': [], 'repliers': []},
 'replight': {'replighted': []},
 'replik': {'replikation': []},
 'replil': {'repliles': []},
 'repling': {'replinger': []},
 'replinish': {'replinished': []},
 'repliqu': {'repliquant': [],
             'replique': ['repliques', 'repliquer', 'repliquent']},
 'replique': ['repliques', 'repliquer', 'repliquent'],
 'replisom': {'replisome': ['replisomes']},
 'replisome': ['replisomes'],
 'replitas': {'replitase': []},
 'replj': {'repljed': []},
 'repll': {'replled': [], 'replles': []},
 'replli': {'replly': []},
 'replnc': {'replnced': []},
 'reploc': {'replocator': [], 'reploce': ['reploced']},
 'reploce': ['reploced'],
 'replog': {'reploge': []},
 'replogl': {'replogle': ['replogles']},
 'replogle': ['replogles'],
 'replong': {'replonge': ['replonger']},
 'replonge': ['replonger'],
 'replot': {'reploted': [],
            'replotment': [],
            'replots': [],
            'replotted': [],
            'replotting': ['replottings']},
 'replotting': ['replottings'],
 'replough': {'reploughed': [], 'reploughing': ['reploughings']},
 'reploughing': ['reploughings'],
 'replow': {'replowed': [], 'replowing': []},
 'reploy': {'reployed': [], 'reployer': []},
 'replr': {'replre': []},
 'replt': {'replted': []},
 'replubl': {'replublic': []},
 'repluc': {'repluced': []},
 'replug': {'replugged': [], 'replugging': []},
 'replum': {'replume': ['replumed'], 'repluming': []},
 'replumb': {'replumbed': [], 'replumbing': []},
 'replume': ['replumed'],
 'replund': {'replundered': []},
 'replung': {'replunge': ['replunged', 'replunges'], 'replunging': []},
 'replunge': ['replunged', 'replunges'],
 'replur': {'repluralization': []},
 'replus': {'repluse': ['replused'], 'replusion': [], 'replusive': []},
 'repluse': ['replused'],
 'replv': {'replving': []},
 'reply': {'replye': ['replyes']},
 'replyal': {'replyall': []},
 'replyd': {'replyde': []},
 'replye': ['replyes'],
 'replyi': {'replyis': []},
 'replywa': {'replywas': []},
 'repm': {'repmed': []},
 'repmduc': {'repmduced': []},
 'repmduct': {'repmduction': []},
 'repn': {'repne': [], 'repns': []},
 'repnblic': {'repnblication': []},
 'repnblican': {'repnblicans': []},
 'repnbliqu': {'repnblique': []},
 'repnblish': {'repnblished': []},
 'repndiat': {'repndiate': ['repndiated', 'repndiates'],
              'repndiating': [],
              'repndiation': []},
 'repndiate': ['repndiated', 'repndiates'],
 'repngnanc': {'repngnance': []},
 'repnin': {'repnine': [], 'repnins': []},
 'repnls': {'repnlsed': []},
 'repnnl': {'repnnled': []},
 'repnnt': {'repnnted': [], 'repnnts': []},
 'repnrt': {'repnrted': []},
 'repnt': {'repnte': ['repnted']},
 'repntat': {'repntation': []},
 'repnte': ['repnted'],
 'repo': {'repoe': ['repoed'], 'repoing': [], 'repos': []},
 'repoa': {'repoae': []},
 'repoal': {'repoaled': []},
 'repoat': {'repoated': []},
 'repoatedli': {'repoatedly': []},
 'repobl': {'repoblic': []},
 'repoblacion': {'repoblaciones': []},
 'repoblador': {'repobladores': []},
 'repobt': {'repobts': []},
 'repocket': {'repocketed': [], 'repocketing': [], 'repockets': []},
 'repoduc': {'repoduce': ['repoduced']},
 'repoduce': ['repoduced'],
 'repoduct': {'repoduction': [], 'repoductive': []},
 'repoe': {'repoee': []},
 'repoet': {'repoets': []},
 'repof': {'repofe': ['repofes', 'repofed'], 'repofing': []},
 'repofe': ['repofes', 'repofed'],
 'repofit': {'repofited': []},
 'repofitori': {'repofitories': [], 'repofitory': []},
 'repogl': {'repogle': []},
 'repoi': {'repoie': [], 'repois': []},
 'repoin': {'repoined': []},
 'repoint': {'repointed': [], 'repointing': [], 'repoints': []},
 'repoir': {'repoire': []},
 'repois': {'repoise': ['repoised']},
 'repoise': ['repoised'],
 'repoison': {'repoisoned': [], 'repoisoning': []},
 'repoit': {'repoited': [], 'repoiter': [], 'repoiting': [], 'repoits': []},
 'repokt': {'repokts': []},
 'repol': {'repole': ['repoled'],
           'repoling': [],
           'repoll': ['repolls', 'repolled', 'repolling']},
 'repolar': {'repolarization': ['repolarizations'],
             'repolarize': ['repolarizes', 'repolarized'],
             'repolarizing': []},
 'repolaris': {'repolarisation': [],
               'repolarise': ['repolarised', 'repolarises'],
               'repolarising': []},
 'repolarise': ['repolarised', 'repolarises'],
 'repolarization': ['repolarizations'],
 'repolarize': ['repolarizes', 'repolarized'],
 'repole': ['repoled'],
 'repolish': {'repolished': [],
              'repolishes': [],
              'repolishing': ['repolishings']},
 'repolishing': ['repolishings'],
 'repolit': {'repolitization': []},
 'repolitic': {'repoliticalization': [],
               'repoliticization': [],
               'repoliticize': ['repoliticized', 'repoliticizes'],
               'repoliticizing': []},
 'repoliticis': {'repoliticisation': [],
                 'repoliticise': ['repoliticised'],
                 'repoliticising': []},
 'repoliticise': ['repoliticised'],
 'repoliticize': ['repoliticized', 'repoliticizes'],
 'repoll': ['repolls', 'repolled', 'repolling'],
 'repollo': {'repollos': []},
 'repolon': {'repolonization': []},
 'repolymer': {'repolymerization': [],
               'repolymerize': ['repolymerizes', 'repolymerized'],
               'repolymerizing': []},
 'repolymeris': {'repolymerisation': []},
 'repolymerize': ['repolymerizes', 'repolymerized'],
 'repon': {'reponant': [],
           'repone': ['reponed', 'reponer', 'repones'],
           'reponing': [],
           'repons': []},
 'repona': {'reponas': []},
 'reponc': {'reponce': []},
 'repond': {'repondant': ['repondants'],
            'reponde': ['reponded',
                        'reponder',
                        'repondent',
                        'reponders',
                        'repondents',
                        'repondered'],
            'reponding': [],
            'reponds': []},
 'repondai': {'repondaient': [], 'repondais': []},
 'repondant': ['repondants'],
 'reponde': ['reponded',
             'reponder',
             'repondent',
             'reponders',
             'repondents',
             'repondered'],
 'reponder': {'reponderance': []},
 'repondi': {'repondis': []},
 'repondim': {'repondimes': []},
 'repondion': {'repondions': []},
 'repondir': {'repondirent': []},
 'repondit': {'repondites': []},
 'repondoi': {'repondoient': []},
 'repondon': {'repondons': []},
 'repondr': {'repondre': []},
 'repondrai': {'repondraient': [], 'repondrais': []},
 'repondroi': {'repondrois': []},
 'repondron': {'repondrons': []},
 'repondu': {'repondue': ['repondues'], 'repondus': []},
 'repondue': ['repondues'],
 'repone': ['reponed', 'reponer', 'repones'],
 'reponen': {'reponens': []},
 'reponendi': {'reponendis': []},
 'reponent': {'reponentes': []},
 'reponer': {'reponere': ['reponerent']},
 'reponere': ['reponerent'],
 'reponers': {'reponerse': []},
 'reponf': {'reponfe': []},
 'reponi': {'reponis': []},
 'reponimu': {'reponimus': []},
 'repons': {'reponsable': [],
            'reponse': ['reponses'],
            'reponsibilities': [],
            'reponsibility': [],
            'reponsible': [],
            'reponsive': ['reponsiveness'],
            'reponsivity': []},
 'reponsc': {'reponscs': []},
 'reponse': ['reponses'],
 'reponsive': ['reponsiveness'],
 'repool': {'repooled': []},
 'repopul': {'repopulate': ['repopulated', 'repopulates'],
             'repopulating': [],
             'repopulation': ['repopulations'],
             'repopulator': ['repopulators']},
 'repopular': {'repopularization': [],
               'repopularize': ['repopularized'],
               'repopularizing': []},
 'repopularis': {'repopularised': []},
 'repopularize': ['repopularized'],
 'repopulate': ['repopulated', 'repopulates'],
 'repopulation': ['repopulations'],
 'repopulationist': {'repopulationists': []},
 'repopulator': ['repopulators'],
 'repor': {'repore': ['repored'], 'reporred': [], 'repors': []},
 "repor'": {"repor'ed": []},
 'reporc': {'reporced': [], 'reporcs': []},
 'repord': {'reporded': []},
 'reporduc': {'reporduce': ['reporduced']},
 'reporduce': ['reporduced'],
 'reporduct': {'reporduction': ['reporductions'], 'reporductive': []},
 'reporduction': ['reporductions'],
 'repore': ['repored'],
 'reporet': {'reporeted': []},
 'reporf': {'reporfed': [], 'reporfs': []},
 'repori': {'reporied': [], 'reporis': []},
 'reporl': {'reporled': [], 'reporling': [], 'reporls': []},
 'reporm': {'repormation': []},
 'reporoduc': {'reporoduced': []},
 'reporr': {'reporrer': ['reporrers'], 'reporrs': []},
 'reporredli': {'reporredly': []},
 'reporrer': ['reporrers'],
 'report': ['reporte',
            'reporter',
            'reported',
            'reportes',
            'reportant',
            'reporting',
            'reportive',
            'reportent',
            'reportate',
            'reportted',
            'reportator',
            'reportably',
            'reportable',
            'reportative',
            'reportively',
            'reportables',
            'reportation',
            'reportatives',
            'reportability'],
 "report'l": {"report'll": []},
 'reporta': {'reportas': []},
 'reportada': {'reportadas': []},
 'reportado': {'reportados': []},
 'reportag': {'reportage': []},
 'reportagen': {'reportagens': []},
 'reportaj': {'reportaje': ['reportajes']},
 'reportaje': ['reportajes'],
 'reportamu': {'reportamus': []},
 'reportan': {'reportans': []},
 'reportant': {'reportantes': []},
 'reportar': {'reportare': ['reportarent']},
 'reportare': ['reportarent'],
 'reportari': {'reportarie': [], 'reportary': []},
 'reportass': {'reportasse': []},
 'reportation': {'reportationes': []},
 'reportaturu': {'reportaturus': []},
 'reportback': {'reportbacks': []},
 'reportbi': {'reportby': []},
 'reportcr': {'reportcreator': []},
 'reporte': {'reportee': ['reportees']},
 'reported': {'reportedness': []},
 'reporteda': {'reportedas': []},
 'reportedbi': {'reportedby': []},
 'reportedinth': {'reportedinthe': []},
 'reportedli': {'reportedly': []},
 'reportedth': {'reportedthe': []},
 'reportee': ['reportees'],
 'reportei': {'reporteis': []},
 "reporter'": {"reporter's": []},
 'reporterag': {'reporterage': []},
 'reportergen': {'reportergene': []},
 'reporteri': {'reporterial': []},
 'reporterli': {'reporterly': []},
 'reporterlik': {'reporterlike': []},
 'reporternew': {'reporternews': []},
 'reportero': {'reporteros': []},
 'reporterphotograph': {'reporterphotographer': []},
 'reporterresearch': {'reporterresearcher': []},
 "reporters'l": {"reporters'll": []},
 'reportership': {'reporterships': []},
 'reportersourc': {'reportersource': []},
 'reportes': {'reportese': []},
 'reporteth': {'reportethe': []},
 'reporteti': {'reportetis': []},
 'reporteur': {'reporteurs': []},
 'reportev': {'reportevent': []},
 'reportf': {'reportfs': []},
 'reportfil': {'reportfile': []},
 'reportgener': {'reportgenerating': [], 'reportgeneration': []},
 'reporth': {'reporther': ['reporthers']},
 'reporther': ['reporthers'],
 'reporti': {'reportial': [], 'reportis': []},
 'reportin': {'reportins': []},
 'reporting': {'reportinge': []},
 'reportingli': {'reportingly': []},
 'reportingth': {'reportingthe': []},
 'reportli': {'reportly': []},
 'reportlik': {'reportlike': []},
 'reportnam': {'reportname': []},
 'reportofth': {'reportofthe': []},
 'reportoir': {'reportoire': []},
 'reporton': {'reportons': []},
 'reportonth': {'reportonthe': []},
 'reportori': {'reportorial': ['reportorially'], 'reportory': []},
 'reportorial': ['reportorially'],
 'reportray': {'reportrayal': [], 'reportrayed': []},
 'reportserv': {'reportserver': []},
 'reportsourc': {'reportsource': []},
 'reportstatu': {'reportstatus': []},
 'reportt': {'reportts': []},
 'reportth': {'reportthe': []},
 'reportview': {'reportviewer': []},
 'reportwa': {'reportwas': []},
 'reportwrit': {'reportwriter': [], 'reportwriting': []},
 'reporyj': {'reporyje': []},
 'repos': {'reposal': ['reposals'],
           'reposant': [],
           'repose': ['reposed',
                      'reposer',
                      'reposers',
                      'reposent',
                      'reposeing',
                      'reposeful',
                      'reposefully',
                      'reposefulness'],
           'reposing': [],
           'repositi': ['repositis']},
 'reposai': {'reposaient': [], 'reposais': []},
 'reposal': ['reposals'],
 'reposan': {'reposans': []},
 'reposant': {'reposante': ['reposantes']},
 'reposante': ['reposantes'],
 'reposcer': {'reposcere': ['reposcerent']},
 'reposcere': ['reposcerent'],
 'reposd': {'reposde': []},
 'repose': {'reposee': []},
 'reposed': {'reposedness': []},
 'reposedli': {'reposedly': []},
 'reposerai': {'reposerais': []},
 'reposeron': {'reposerons': []},
 'reposess': {'reposessed': [], 'reposession': []},
 'reposianu': {'reposianus': []},
 'reposing': {'reposinge': []},
 'reposingli': {'reposingly': []},
 'reposit': {'reposite': ['reposited'],
             'repositing': [],
             'reposition': ['repositional', 'repositioned', 'repositioning'],
             'reposits': []},
 'reposita': {'repositae': [], 'repositas': []},
 'repositari': {'repositaries': [], 'repositary': []},
 'reposite': ['reposited'],
 'repositi': ['repositis'],
 'reposition': {'repositionable': [], 'repositioner': ['repositioners']},
 'repositioner': ['repositioners'],
 'repositionn': {'repositionnement': [], 'repositionner': []},
 'repositiori': {'repositiories': []},
 'reposito': {'repositos': []},
 'repositoir': {'repositoires': []},
 'repositon': {'repositones': []},
 'repositor': {'repositors': []},
 'repositori': {'repositorie': [], 'repository': []},
 'repositorio': {'repositorios': []},
 'repositoti': {'repositoties': [], 'repositoty': []},
 'repositu': {'repositus': []},
 'reposo': {'reposos': []},
 'reposoir': {'reposoires': [], 'reposoirs': []},
 'reposon': {'reposons': []},
 'reposs': {'repossed': [], 'reposses': []},
 'reposses': {'repossesed': [], 'repossesion': []},
 'repossess': {'repossessable': [],
               'repossesse': ['repossessed', 'repossesses'],
               'repossessing': [],
               'repossession': []},
 'repossesse': ['repossessed', 'repossesses'],
 'repossessor': {'repossessors': []},
 'repost': {'reposte': ['reposted'],
            'reposting': ['repostings'],
            'reposts': []},
 'reposta': {'repostae': [], 'repostas': []},
 'reposte': ['reposted'],
 'repostero': {'reposteros': []},
 'reposti': {'repostis': []},
 'reposting': ['repostings'],
 'reposto': {'repostos': []},
 'repostpon': {'repostponed': []},
 'repostu': {'repostus': []},
 'repostul': {'repostulate': ['repostulated']},
 'repostulate': ['repostulated'],
 'repostur': {'reposture': ['repostured'], 'reposturing': []},
 'reposture': ['repostured'],
 'reposuimu': {'reposuimus': []},
 'reposuiss': {'reposuisse': []},
 'reposur': {'reposure': []},
 'repot': {'repotation': [],
           'repote': ['repoter', 'repoted'],
           'repots': [],
           'repotted': [],
           'repotting': ['repottings']},
 'repote': ['repoter', 'repoted'],
 'repotitori': {'repotitory': []},
 'repotr': {'repotred': []},
 'repott': {'repotts': []},
 'repotting': ['repottings'],
 'repou': {'repous': []},
 'repouil': {'repouille': []},
 'repouli': {'repoulis': []},
 'repound': {'repounded': [], 'repounding': []},
 'repour': {'repoured': [], 'repouring': []},
 'repous': {'repouse': []},
 'repouse': {'repousee': []},
 'repouss': {'repoussant': ['repoussants'],
             'repousse': ['repousses', 'repoussed', 'repousser', 'repoussent']},
 'repoussag': {'repoussage': []},
 'repoussai': {'repoussaient': [], 'repoussais': []},
 'repoussant': {'repoussante': ['repoussantes']},
 'repoussante': ['repoussantes'],
 'repousse': {'repoussee': ['repoussees', 'repousseed']},
 'repoussee': ['repoussees', 'repousseed'],
 'repousser': {'repousserent': []},
 'repoussoir': {'repoussoirs': []},
 'repousson': {'repoussons': []},
 'repow': {'repower': ['repowers', 'repowered', 'repowering']},
 'repowd': {'repowder': ['repowdered', 'repowdering']},
 'repowder': ['repowdered', 'repowdering'],
 'repower': ['repowers', 'repowered', 'repowering'],
 'repp': ['reppe', 'reppes'],
 'reppa': {'reppas': []},
 'reppel': {'reppell': []},
 'reppeli': {'reppelier': []},
 'repperg': {'repperger': []},
 'repperi': {'repperies': []},
 'repperimu': {'repperimus': []},
 'repperir': {'repperire': []},
 'repperiss': {'repperisse': []},
 'reppert': {'repperts': []},
 'reppi': {'reppis': [], 'reppy': []},
 'reppit': {'reppitation': []},
 'reppl': {'repple': []},
 'reppling': {'repplinger': []},
 'repport': {'repported': [], 'repports': []},
 'repprais': {'reppraisal': []},
 'reppres': {'reppresent': ['reppresents',
                            'reppresented',
                            'reppresenting',
                            'reppresentative',
                            'reppresentatives']},
 'reppresent': {'reppresentation': []},
 'reppress': {'reppression': [], 'reppressive': []},
 'repproach': {'repproachment': []},
 'repproch': {'repprochement': []},
 'repprt': {'repprted': [], 'repprts': []},
 'repps': {'reppse': []},
 'repqrt': {'repqrted': [], 'repqrts': []},
 'repr': {'repre': ['repres', 'repred'], 'repring': [], 'reprs': []},
 'repract': {'repracticed': [], 'repracticing': []},
 'repractic': {'repractice': []},
 'repractis': {'repractised': [], 'repractising': []},
 'repraduc': {'repraduced': []},
 'repraes': {'repraesentative': []},
 'repraesent': {'repraesentant': [],
                'repraesentation': [],
                'repraesentent': []},
 'repraesentab': {'repraesentabant': []},
 'repraesentan': {'repraesentans': []},
 'repraesentant': {'repraesentante': ['repraesentantes']},
 'repraesentante': ['repraesentantes'],
 'repraesentanti': {'repraesentantis': []},
 'repraesentantibu': {'repraesentantibus': []},
 'repraesentar': {'repraesentare': []},
 'repraesentata': {'repraesentatae': []},
 'repraesentati': {'repraesentatis': []},
 'repraesentation': {'repraesentatione': ['repraesentationes']},
 'repraesentatione': ['repraesentationes'],
 'repraesentationi': {'repraesentationis': []},
 'repraesenter': {'repraesenterer': []},
 'reprais': {'repraisal': ['repraisals']},
 'repraisal': ['repraisals'],
 'reprandr': {'reprandre': []},
 'repras': {'reprasent': ['reprasented', 'reprasentative', 'reprasentatives']},
 'reprasent': {'reprasentant': [], 'reprasentation': ['reprasentations']},
 'reprasentantenhau': {'reprasentantenhaus': []},
 'reprasentation': ['reprasentations'],
 'reprasentativ': {'reprasentativer': []},
 'reprasentier': {'reprasentiere': []},
 'reprasentierend': {'reprasentierende': []},
 'reprasentiert': {'reprasentierte': []},
 'reprat': {'reprated': []},
 'repraz': {'reprazent': []},
 'reprc': {'reprcs': []},
 'reprccipit': {'reprccipitated': [], 'reprccipitation': []},
 'reprcfent': {'reprcfented': []},
 'reprcsent': {'reprcsentable': [],
               'reprcsentation': [],
               'reprcsentative': ['reprcsentatives'],
               'reprcsente': ['reprcsented'],
               'reprcsents': []},
 'reprcsentative': ['reprcsentatives'],
 'reprcsente': ['reprcsented'],
 'reprd': {'reprded': [], 'reprding': []},
 'reprdsent': {'reprdsentant': ['reprdsentants'],
               'reprdsentation': [],
               'reprdsentative': [],
               'reprdsente': ['reprdsenter']},
 'reprdsentant': ['reprdsentants'],
 'reprdsente': ['reprdsenter'],
 'reprduc': {'reprduced': []},
 'repre': {'repree': ['repreed']},
 'repreach': {'repreached': [], 'repreaches': [], 'repreaching': []},
 'repreaent': {'repreaentation': [],
               'repreaentative': ['repreaentatives'],
               'repreaented': [],
               'repreaenting': [],
               'repreaents': []},
 'repreaentative': ['repreaentatives'],
 'repreat': {'repreated': [], 'repreating': []},
 'repreatedli': {'repreatedly': []},
 'reprebi': {'repreby': []},
 'reprec': {'reprecent': ['reprecented']},
 'reprecent': ['reprecented'],
 'reprecipit': {'reprecipitable': [],
                'reprecipitate': ['reprecipitated', 'reprecipitates'],
                'reprecipitating': [],
                'reprecipitation': ['reprecipitations']},
 'reprecipitate': ['reprecipitated', 'reprecipitates'],
 'reprecipitation': ['reprecipitations'],
 'reprecuss': {'reprecussion': ['reprecussions']},
 'reprecussion': ['reprecussions'],
 'repredict': {'repredicted': []},
 'repreduc': {'repreduced': []},
 'repreduct': {'repreduction': []},
 'repree': ['repreed'],
 'repreeent': {'repreeentation': [],
               'repreeentative': ['repreeentatives'],
               'repreeente': ['repreeented'],
               'repreeenting': [],
               'repreeents': []},
 'repreeentative': {'repreeentativee': []},
 'repreeente': ['repreeented'],
 'repreeipit': {'repreeipitated': []},
 'repreend': {'repreender': []},
 'repreent': {'repreentation': [],
              'repreentative': ['repreentatives'],
              'repreented': [],
              'repreenting': [],
              'repreents': []},
 'repreentative': ['repreentatives'],
 'repreesnt': {'repreesnted': []},
 'repreev': {'repreeve': []},
 'repref': {'reprefe': ['reprefent',
                        'reprefents',
                        'reprefented',
                        'reprefenting',
                        'reprefentative',
                        'reprefentatives'],
            'repreffed': [],
            'repreffing': [],
            'reprefs': []},
 'reprefcnt': {'reprefcnted': []},
 'reprefe': ['reprefent',
             'reprefents',
             'reprefented',
             'reprefenting',
             'reprefentative',
             'reprefentatives'],
 'reprefent': {'reprefentation': ['reprefentations'],
               'reprefente': ['reprefenter']},
 'reprefentation': ['reprefentations'],
 'reprefente': ['reprefenter'],
 'reprefl': {'reprefled': []},
 'reprehen': {'reprehens': []},
 'reprehend': {'reprehendable': [],
               'reprehendant': [],
               'reprehende': ['reprehended',
                              'reprehender',
                              'reprehendent',
                              'reprehenders'],
               'reprehending': [],
               'reprehends': []},
 'reprehenda': {'reprehendas': []},
 'reprehende': ['reprehended', 'reprehender', 'reprehendent', 'reprehenders'],
 'reprehenden': {'reprehendens': []},
 'reprehendendi': {'reprehendendis': []},
 'reprehendendu': {'reprehendendus': []},
 'reprehender': {'reprehendere': ['reprehenderent']},
 'reprehendere': ['reprehenderent'],
 'reprehenderi': {'reprehenderis': []},
 'reprehendi': {'reprehendis': []},
 'reprehendimu': {'reprehendimus': []},
 'reprehendit': {'reprehendite': []},
 'reprehenf': {'reprehenfible': []},
 'reprehens': {'reprehensibility': [],
               'reprehensible': ['reprehensibles', 'reprehensibleness'],
               'reprehensibly': [],
               'reprehension': [],
               'reprehensive': ['reprehensively', 'reprehensiveness']},
 'reprehensibil': {'reprehensibile': ['reprehensibiles']},
 'reprehensibile': ['reprehensibiles'],
 'reprehensibili': {'reprehensibilis': []},
 'reprehensible': ['reprehensibles', 'reprehensibleness'],
 'reprehensihl': {'reprehensihle': []},
 'reprehension': {'reprehensione': ['reprehensiones']},
 'reprehensione': ['reprehensiones'],
 'reprehensioni': {'reprehensionis': []},
 'reprehensionibu': {'reprehensionibus': []},
 'reprehensive': ['reprehensively', 'reprehensiveness'],
 'reprehensor': {'reprehensores': []},
 'reprehensori': {'reprehensory': []},
 'reprehensu': {'reprehensus': []},
 'reprehent': {'reprehention': []},
 'repreient': {'repreientation': [],
               'repreientative': ['repreientatives'],
               'repreiented': [],
               'repreienting': [],
               'repreients': []},
 'repreientative': ['repreientatives'],
 'repreint': {'repreinted': []},
 'repreit': {'repreited': []},
 'repreiv': {'repreive': ['repreives', 'repreived']},
 'repreive': ['repreives', 'repreived'],
 'reprej': {'reprejented': []},
 'reprel': {'reprelent': ['reprelents',
                          'reprelented',
                          'reprelenting',
                          'reprelentatives']},
 'reprelent': {'reprelentation': []},
 'repremand': {'repremanded': [], 'repremanding': []},
 'repren': {'reprenant': [], 'reprenent': [], 'reprens': []},
 'reprenai': {'reprenaient': [], 'reprenais': []},
 'reprend': {'reprende': ['reprender', 'reprendes'], 'reprends': []},
 'reprenda': {'reprendas': []},
 'reprende': ['reprender', 'reprendes'],
 'reprender': {'reprendere': []},
 'reprendr': {'reprendre': []},
 'reprendrai': {'reprendraient': [], 'reprendrais': []},
 'reprendron': {'reprendrons': []},
 'repreneur': {'repreneurs': []},
 'repreneuri': {'repreneurial': []},
 'reprenion': {'reprenions': []},
 'reprenn': {'reprenne': ['reprennent']},
 'reprenne': ['reprennent'],
 'reprenon': {'reprenons': []},
 'reprens': {'reprensent': ['reprensents',
                            'reprensented',
                            'reprensenting',
                            'reprensentative',
                            'reprensentatives'],
             'reprensible': [],
             'reprension': []},
 'reprensent': {'reprensentation': []},
 'reprensi': {'reprensis': []},
 'reprension': {'reprensiones': []},
 'reprent': {'reprentation': ['reprentations'],
             'reprentative': ['reprentatives'],
             'reprented': [],
             'reprenting': [],
             'reprents': []},
 'reprentation': ['reprentations'],
 'reprentative': ['reprentatives'],
 'repreoent': {'repreoented': []},
 'repreoipit': {'repreoipitated': []},
 'reprep': {'reprepped': [], 'reprepping': []},
 'reprepar': {'repreparation': [],
              'reprepare': ['reprepared'],
              'repreparing': []},
 'reprepare': ['reprepared'],
 'reprepres': {'reprepresent': ['reprepresented',
                                'reprepresenting',
                                'reprepresentative',
                                'reprepresentatives']},
 'reprepresent': {'reprepresentation': []},
 'reprer': {'reprerent': ['reprerents',
                          'reprerented',
                          'reprerenting',
                          'reprerentatives']},
 'reprercuss': {'reprercussions': []},
 'reprerent': {'reprerentation': []},
 'repreres': {'repreresentatives': [], 'repreresented': []},
 'repres': {'represant': ['represants',
                          'represanted',
                          'represanting',
                          'represantative',
                          'represantatives'],
            'represe': ['represer',
                        'represent',
                        'represence',
                        'represents',
                        'represeated',
                        'represented',
                        'represeating',
                        'representeds',
                        'representing',
                        'representted',
                        'representings',
                        'representting',
                        'representative',
                        'representativity',
                        'representatively',
                        'representativeness'],
            'represion': [],
            'represive': []},
 'represa': {'represas': []},
 'represail': {'represaille': ['represailles']},
 'represaille': ['represailles'],
 'represalia': {'represalias': []},
 'represalii': {'represaliis': []},
 'represant': {'represantation': ['represantations'], 'represante': []},
 'represantation': ['represantations'],
 'represcnt': {'represcntable': [],
               'represcntation': [],
               'represcntative': ['represcntatives'],
               'represcnted': [],
               'represcnts': []},
 'represcntative': ['represcntatives'],
 'represcrib': {'represcribe': ['represcribed'], 'represcribing': []},
 'represcribe': ['represcribed'],
 'represe': ['represer',
             'represent',
             'represence',
             'represents',
             'represeated',
             'represented',
             'represeating',
             'representeds',
             'representing',
             'representted',
             'representings',
             'representting',
             'representative',
             'representativity',
             'representatively',
             'representativeness'],
 'represeat': {'represeatation': [], 'represeatatives': [], 'represeats': []},
 'represem': {'represemation': ['represemations'],
              'represemative': ['represematives'],
              'represemed': [],
              'represeming': [],
              'represems': []},
 'represemation': ['represemations'],
 'represemative': ['represematives'],
 'represen': {'represenation': ['represenations', 'represenational'],
              'represenative': ['represenatives'],
              'represened': [],
              'represening': [],
              'represens': []},
 "represen'": {"represen'ed": []},
 'represenat': {'represenatation': [], 'represenatative': ['represenatatives']},
 'represenatative': ['represenatatives'],
 'represenation': ['represenations', 'represenational'],
 'represenative': ['represenatives'],
 'represenc': {'represenced': []},
 'represend': {'represended': []},
 'represenf': {'represenfed': []},
 'represeni': {'represeniation': [],
               'represeniative': ['represeniatives'],
               'represenied': [],
               'represeniing': [],
               'represenis': []},
 'represeniative': ['represeniatives'],
 'represenl': {'represenlation': [],
               'represenlative': ['represenlatives'],
               'represenled': [],
               'represenling': [],
               'represenls': []},
 'represenlative': ['represenlatives'],
 'represenr': {'represenration': ['represenrations', 'represenrational'],
               'represenrative': ['represenratives'],
               'represenred': [],
               'represenring': [],
               'represenrs': []},
 'represenration': ['represenrations', 'represenrational'],
 'represenrative': ['represenratives'],
 'represens': {'represensation': ['represensations'],
               'represensative': ['represensatives'],
               'represensed': [],
               'represensible': []},
 'represensation': ['represensations'],
 'represensative': ['represensatives'],
 'represent': {'representability': [],
               'representable': ['representables'],
               'represental': [],
               'representance': [],
               'representant': ['representants'],
               'representate': ['representated', 'representates'],
               'representating': [],
               'representation': ['representational', 'representationally'],
               'representator': ['representators'],
               'represente': ['representes',
                              'representer',
                              'representers',
                              'representent',
                              'representented'],
               'represention': ['representions', 'representional'],
               'representive': ['representives',
                                'representively',
                                'representiveness'],
               'representivity': [],
               'representment': ['representments'],
               'representou': []},
 'representa': {'representaive': ['representaives'], 'representas': []},
 'representable': ['representables'],
 'representacion': {'representacional': [],
                    'representaciones': [],
                    'representacions': []},
 'representacioni': {'representacionis': []},
 'representaco': {'representacoes': []},
 'representada': {'representadas': []},
 'representado': {'representados': []},
 'representadon': {'representadons': []},
 'representadv': {'representadve': ['representadves']},
 'representadve': ['representadves'],
 'representaf': {'representafives': []},
 'representai': {'representaient': [],
                 'representaiive': ['representaiives'],
                 'representais': []},
 'representaiion': {'representaiions': []},
 'representaiive': ['representaiives'],
 'representaion': {'representaions': []},
 'representaiton': {'representaitons': []},
 'representaitv': {'representaitve': ['representaitves']},
 'representaitve': ['representaitves'],
 'representaive': ['representaives'],
 'represental': {'representalive': ['representalives'], 'representall': []},
 'representalion': {'representalions': []},
 'representalive': ['representalives'],
 'representam': {'representames': []},
 'representamen': {'representamens': []},
 'representamo': {'representamos': []},
 'representan': {'representans': []},
 'representant': {'representante': ['representanter', 'representantes'],
                  'representantion': [],
                  'representantive': ['representantives']},
 'representante': ['representanter', 'representantes'],
 'representantibu': {'representantibus': []},
 'representantive': ['representantives'],
 'representanv': {'representanve': ['representanves']},
 'representanve': ['representanves'],
 'representar': {'representare': [], 'representarive': ['representarives']},
 'representarion': {'representarions': []},
 'representarive': ['representarives'],
 'representarl': {'representarle': []},
 'representars': {'representarse': []},
 'representas': {'representase': []},
 'representass': {'representasse': []},
 'representat': {'representatation': ['representatations'],
                 'representatative': ['representatatives'],
                 'representatic': []},
 'representata': {'representataive': ['representataives']},
 'representataive': ['representataives'],
 'representatation': ['representatations'],
 'representatative': ['representatatives'],
 'representate': ['representated', 'representates'],
 'representath': {'representathe': []},
 'representati': {'representatie': ['representaties'],
                  'representatiou': ['representatious']},
 'representatic': {'representatice': ['representatices']},
 'representatice': ['representatices'],
 'representatie': ['representaties'],
 'representatiev': {'representatieve': []},
 'representatif': {'representatifs': []},
 'representation': {'representationalism': ['representationalisms'],
                    'representationality': [],
                    'representatione': ['representationes'],
                    'representationism': []},
 'representationalism': ['representationalisms'],
 'representationalist': {'representationalistic': [],
                         'representationalists': []},
 'representatione': ['representationes'],
 'representationi': {'representationis': []},
 'representationindepend': {'representationindependent': []},
 'representationist': {'representationists': []},
 'representationofth': {'representationofthe': []},
 'representatiou': ['representatious'],
 'representatir': {'representatire': ['representatires']},
 'representatire': ['representatires'],
 'representatit': {'representatite': ['representatites'],
                   'representatitives': []},
 'representatite': ['representatites'],
 'representatitv': {'representatitve': ['representatitves']},
 'representatitve': ['representatitves'],
 'representatiu': {'representatiue': ['representatiues']},
 'representatiue': ['representatiues'],
 'representativ': {'representativness': [], 'representativs': []},
 'representativa': {'representativas': []},
 'representativc': {'representativcs': []},
 'representative': {'representativee': []},
 'representativeag': {'representativeagent': []},
 'representativedemocrat': {'representativedemocratic': []},
 'representativen': {'representativenes': []},
 'representatives': {'representativesness': []},
 'representativi': {'representativies': []},
 'representatividad': {'representatividade': []},
 'representativit': {'representativite': []},
 'representativo': {'representativos': []},
 'representatiy': {'representatiye': ['representatiyes']},
 'representatiye': ['representatiyes'],
 'representatlon': {'representatlons': []},
 'representatlv': {'representatlve': ['representatlves']},
 'representatlve': ['representatlves'],
 'representaton': {'representatons': []},
 'representator': ['representators'],
 'representatrv': {'representatrve': []},
 'representatton': {'representattons': []},
 'representattv': {'representattve': ['representattves']},
 'representattve': ['representattves'],
 'representatv': {'representatve': ['representatves']},
 'representatve': ['representatves'],
 'representatvi': {'representatvie': ['representatvies']},
 'representatvie': ['representatvies'],
 'representauv': {'representauves': []},
 'representav': {'representave': ['representaves']},
 'representave': ['representaves'],
 'represente': {'representee': ['representees']},
 'represented': {'representedness': []},
 'representeda': {'representedas': []},
 'representedbi': {'representedby': []},
 'representedbyth': {'representedbythe': []},
 'representedth': {'representedthe': []},
 'representee': ['representees'],
 'representer': {'representere': ['representerer', 'representerent']},
 'representera': {'representeras': []},
 'representerad': {'representerade': ['representerades']},
 'representerade': ['representerades'],
 'representerai': {'representeraient': []},
 'representerand': {'representerande': []},
 'representere': ['representerer', 'representerent'],
 'representerend': {'representerende': []},
 'representeron': {'representerons': []},
 'representert': {'representerte': []},
 'representet': {'representetion': [], 'representetive': ['representetives']},
 'representetive': ['representetives'],
 'representin': {'representine': []},
 'representing': {'representinge': []},
 'representingth': {'representingthe': []},
 'represention': ['representions', 'representional'],
 'representit': {'representitive': ['representitives', 'representitiveness']},
 'representitive': ['representitives', 'representitiveness'],
 'representive': ['representives', 'representively', 'representiveness'],
 'representment': ['representments'],
 'representnt': {'representntion': []},
 'representoi': {'representoient': []},
 'representon': {'representons': []},
 'representor': {'representors': []},
 'representot': {'representotion': [], 'representotive': []},
 'representst': {'representstion': [], 'representstive': ['representstives']},
 'representsth': {'representsthe': []},
 'representstive': ['representstives'],
 'representt': {'representtation': ['representtations'],
                'representtative': ['representtatives'],
                'representtion': [],
                'representtive': ['representtives']},
 'representtation': ['representtations'],
 'representtative': ['representtatives'],
 'representth': {'representthe': []},
 'representtive': ['representtives'],
 'representyng': {'representynge': []},
 'represeot': {'represeoted': []},
 'represept': {'represepted': []},
 'represert': {'represerted': []},
 'represerv': {'represerved': []},
 'represes': {'represesent': ['represesents', 'represesented']},
 'represesent': {'represesentation': []},
 'represess': {'represession': []},
 'represet': {'represetation': [],
              'represetative': ['represetatives'],
              'represeted': [],
              'represeting': [],
              'represets': []},
 'represetative': ['represetatives'],
 'represetn': {'represetned': []},
 'represeut': {'represeutation': ['represeutations'],
               'represeutative': ['represeutatives'],
               'represeuted': [],
               'represeuting': [],
               'represeuts': []},
 'represeutation': ['represeutations'],
 'represeutative': ['represeutatives'],
 'represion': {'represiones': []},
 'represiva': {'represivas': []},
 'represivo': {'represivos': []},
 'represj': {'represje': []},
 'represnet': {'represnetation': [],
               'represnetatives': [],
               'represneted': [],
               'represnets': []},
 'represnt': {'represntation': ['represntations'],
              'represntative': ['represntatives'],
              'represnted': [],
              'represnting': [],
              'represnts': []},
 'represntation': ['represntations'],
 'represntative': ['represntatives'],
 'represont': {'represonted': [], 'represonts': []},
 'repress': {'repressable': [],
             'repressal': [],
             'repressant': ['repressants'],
             'represse': ['represses',
                          'repressed',
                          'represser',
                          'repressent',
                          'repressents',
                          'repressented',
                          'repressenting',
                          'repressentative',
                          'repressentatives'],
             'repressibility': [],
             'repressible': [],
             'repressing': ['repressings'],
             'repression': [],
             'repressive': ['repressives', 'repressively', 'repressiveness']},
 'repressali': {'repressalie': []},
 'repressalia': {'repressalias': []},
 'repressalii': {'repressaliis': []},
 'repressant': ['repressants'],
 'repressaqu': {'repressaque': []},
 'represse': ['represses',
              'repressed',
              'represser',
              'repressent',
              'repressents',
              'repressented',
              'repressenting',
              'repressentative',
              'repressentatives'],
 'repressed': {'repressedness': []},
 'repressedli': {'repressedly': []},
 'repressedmemori': {'repressedmemory': []},
 'repressent': {'repressentation': []},
 'repressi': {'repressie': []},
 'repressif': {'repressifs': []},
 'repressing': {'repressinge': []},
 'repressingli': {'repressingly': []},
 'repression': {'repressional': [], 'repressione': [], 'repressionism': []},
 'repressionari': {'repressionary': []},
 'repressionist': {'repressionists': []},
 'repressionsensit': {'repressionsensitization': []},
 'repressiv': {'repressiver': []},
 'repressive': ['repressives', 'repressively', 'repressiveness'],
 'repressiveinspir': {'repressiveinspirational': []},
 'repressnt': {'repressntation': [],
               'repressntative': ['repressntatives'],
               'repressnted': [],
               'repressnts': []},
 'repressntative': ['repressntatives'],
 'repressor': {'repressor': []},
 'repressorbind': {'repressorbinding': []},
 'repressori': {'repressory': []},
 'repressoroper': {'repressoroperator': []},
 'represss': {'represssed': [],
              'represssion': ['represssions'],
              'represssive': []},
 'represssion': ['represssions'],
 'repressu': {'repressus': []},
 'repressur': {'repressure': ['repressured'],
               'repressuring': [],
               'repressurization': [],
               'repressurize': ['repressurizes', 'repressurized'],
               'repressurizing': []},
 'repressure': ['repressured'],
 'repressuris': {'repressurisation': [], 'repressurise': ['repressurised']},
 'repressurise': ['repressurised'],
 'repressurize': ['repressurizes', 'repressurized'],
 'represt': {'represtation': [],
             'represtatives': [],
             'represtented': [],
             'represting': []},
 'repret': {'repretable': [],
            'repretation': [],
            'repretative': ['repretatives'],
            'repreted': [],
            'repretent': ['repretents',
                          'repretented',
                          'repretenting',
                          'repretentative',
                          'repretentatives'],
            'repretion': []},
 'repretative': ['repretatives'],
 'repretent': {'repretentation': []},
 'repreth': {'reprethe': []},
 'repretit': {'repretition': []},
 'repretoir': {'repretoire': []},
 'repreu': {'repreue': ['repreued']},
 'repreue': ['repreued'],
 'reprev': {'reprevable': [], 'repreve': ['repreved']},
 'repreve': ['repreved'],
 'reprez': {'reprezentative': [], 'reprezented': [], 'reprezenting': []},
 'reprezent': {'reprezentant': [], 'reprezentate': [], 'reprezentation': []},
 'reprezentatywn': {'reprezentatywne': []},
 'reprezentowan': {'reprezentowane': []},
 'reprezentowani': {'reprezentowany': []},
 'reprezentuj': {'reprezentuje': []},
 'repri': {'repris': [], 'repry': []},
 'repriat': {'repriated': []},
 'repric': {'reprice': ['repriced', 'reprices'], 'repricing': ['repricings']},
 'reprice': ['repriced', 'reprices'],
 'repricing': ['repricings'],
 'reprief': {'repriefe': []},
 'repriev': {'reprieval': ['reprievals'],
             'reprieve': ['reprieved'],
             'reprieving': []},
 'reprieval': ['reprievals'],
 'reprieve': ['reprieved'],
 'reprif': {'reprifal': ['reprifals'], 'reprifes': []},
 'reprifal': ['reprifals'],
 'repril': {'repriles': []},
 'reprim': {'reprimant': [],
            'reprime': ['reprimed', 'reprimes', 'reprimer'],
            'repriming': []},
 'reprimam': {'reprimames': []},
 'reprimand': ['reprimande',
               'reprimanded',
               'reprimander',
               'reprimandes',
               'reprimanders',
               'reprimanding',
               'reprimandable'],
 'reprimandingli': {'reprimandingly': []},
 'reprime': {'reprimee': ['reprimees']},
 'reprimee': ['reprimees'],
 'reprimen': {'reprimens': []},
 'reprimend': {'reprimended': []},
 'reprimenda': {'reprimendas': []},
 'reprimendi': {'reprimendis': []},
 'reprimendo': {'reprimendos': []},
 'reprimer': {'reprimere': []},
 'reprimi': {'reprimis': []},
 'reprimida': {'reprimidas': []},
 'reprimido': {'reprimidos': []},
 'reprimitiv': {'reprimitivization': []},
 'reprin': {'reprined': [], 'reprins': []},
 'reprini': {'reprinied': []},
 'reprinl': {'reprinled': [], 'reprinls': []},
 'reprinr': {'reprinred': []},
 'reprins': {'reprinse': ['reprinses']},
 'reprinse': ['reprinses'],
 'reprint': ['reprinte',
             'reprinted',
             'reprinter',
             'reprinting',
             'reprinters',
             'reprintable'],
 'reprintedbi': {'reprintedby': []},
 'repriorit': {'reprioritization': ['reprioritizations'],
               'reprioritize': ['reprioritized', 'reprioritizes'],
               'reprioritizing': []},
 'reprioritis': {'reprioritisation': [],
                 'reprioritise': ['reprioritised'],
                 'reprioritising': []},
 'reprioritise': ['reprioritised'],
 'reprioritization': ['reprioritizations'],
 'reprioritize': ['reprioritized', 'reprioritizes'],
 'repriot': {'reprioted': []},
 'reprir': {'reprirent': []},
 'repris': {'reprisable': [],
            'reprisal': [],
            'reprise': ['reprised', 'repriser', 'reprises', 'reprisented'],
            'reprising': []},
 'reprisa': {'reprisas': []},
 'reprisai': {'reprisais': []},
 'reprisail': {'reprisailles': []},
 'reprisal': {'reprisall': ['reprisalls']},
 'reprisall': ['reprisalls'],
 'reprise': ['reprised', 'repriser', 'reprises', 'reprisented'],
 'reprisent': {'reprisentant': ['reprisentants'],
               'reprisentation': ['reprisentations'],
               'reprisente': ['reprisenter']},
 'reprisentant': ['reprisentants'],
 'reprisentation': ['reprisentations'],
 'reprisente': ['reprisenter'],
 'repristin': {'repristinate': ['repristinated', 'repristinates'],
               'repristinating': [],
               'repristination': ['repristinations'],
               'repristinization': []},
 'repristinate': ['repristinated', 'repristinates'],
 'repristination': ['repristinations'],
 'reprit': {'reprites': []},
 'repriu': {'repriue': []},
 'repriut': {'repriuted': []},
 'repriv': {'reprive': ['reprived', 'reprives']},
 'reprivat': {'reprivatization': ['reprivatizations'],
              'reprivatize': ['reprivatized'],
              'reprivatizing': []},
 'reprivatis': {'reprivatisation': [],
                'reprivatise': ['reprivatised'],
                'reprivatising': []},
 'reprivatise': ['reprivatised'],
 'reprivatization': ['reprivatizations'],
 'reprivatize': ['reprivatized'],
 'reprive': ['reprived', 'reprives'],
 'reprivileg': {'reprivilege': ['reprivileged'], 'reprivileging': []},
 'reprivilege': ['reprivileged'],
 'reprivit': {'reprivitization': []},
 'repriz': {'reprizal': ['reprizals'],
            'reprize': ['reprized', 'reprizes'],
            'reprizing': []},
 'reprizal': {'reprizall': ['reprizalls']},
 'reprizall': ['reprizalls'],
 'reprize': ['reprized', 'reprizes'],
 'reprlnt': {'reprlnted': []},
 'reprmt': {'reprmted': [], 'reprmts': []},
 'repro': {'repros': []},
 'reproach': ['reproache',
              'reproacher',
              'reproached',
              'reproaching',
              'reproachful',
              'reproachable',
              'reproachably',
              'reproachings',
              'reproachment',
              'reproachments',
              'reproachfully',
              'reproachability',
              'reproachfulness'],
 'reproachful': {'reproachfull': []},
 'reproachingli': {'reproachingly': []},
 'reproachless': {'reproachlessness': []},
 'reproaeh': {'reproaehed': [], 'reproaehes': []},
 'reproaoh': {'reproaohed': []},
 'reprob': {'reprobable': [],
            'reprobance': [],
            'reprobant': [],
            'reprobate': ['reprobated', 'reprobateness'],
            'reprobating': [],
            'reprobation': [],
            'reprobative': [],
            'reprobator': ['reprobators'],
            'reprobe': ['reprobes', 'reprobed'],
            'reprobing': ['reprobings']},
 'reprobaci': {'reprobacy': []},
 'reprobado': {'reprobados': []},
 'reprobamu': {'reprobamus': []},
 'reproban': {'reprobans': []},
 'reprobar': {'reprobare': []},
 'reprobat': {'reprobats': []},
 'reprobata': {'reprobatae': [], 'reprobatas': []},
 'reprobate': ['reprobated', 'reprobateness'],
 'reprobati': {'reprobatis': []},
 'reprobation': {'reprobatione': ['reprobationes']},
 'reprobatione': ['reprobationes'],
 'reprobationi': {'reprobationis': []},
 'reprobato': {'reprobatos': []},
 'reprobator': ['reprobators'],
 'reprobatori': {'reprobatory': []},
 'reprobatu': {'reprobatus': []},
 'reprobe': ['reprobes', 'reprobed'],
 'reprobi': {'reprobis': []},
 'reprobing': ['reprobings'],
 'reproblemat': {'reproblematization': [],
                 'reproblematize': ['reproblematized', 'reproblematizes'],
                 'reproblematizing': []},
 'reproblematis': {'reproblematised': []},
 'reproblematize': ['reproblematized', 'reproblematizes'],
 'reprobo': {'reprobos': []},
 'reprobr': {'reprobrate': ['reprobrated']},
 'reprobrate': ['reprobrated'],
 'reprobu': {'reprobus': []},
 'reproc': {'reprocity': []},
 'reprocess': {'reprocessability': [],
               'reprocessable': [],
               'reprocessed': [],
               'reprocesses': [],
               'reprocessible': [],
               'reprocessing': ['reprocessings']},
 'reprocessing': ['reprocessings'],
 'reprocessor': {'reprocessors': []},
 'reproch': {'reprochable': [],
             'reprochant': [],
             'reproche': ['reprocher',
                          'reproches',
                          'reproched',
                          'reprochent',
                          'reprocheful'],
             'reprochful': ['reprochfully'],
             'reproching': []},
 'reprochai': {'reprochaient': [], 'reprochais': []},
 'reproche': {'reprochee': ['reprochees']},
 'reprochee': ['reprochees'],
 'reprocheful': {'reprochefull': []},
 'reprocherai': {'reprocherais': []},
 'reprochful': {'reprochfull': []},
 'reprochi': {'reprochier': []},
 'reprochoi': {'reprochoient': []},
 'reprochon': {'reprochons': []},
 'reprock': {'reprocke': []},
 'reproclaim': {'reproclaimed': [], 'reproclaiming': []},
 'reproclam': {'reproclamation': []},
 'reprocur': {'reprocure': ['reprocured', 'reprocurement', 'reprocurements'],
              'reprocuring': []},
 'reprocure': ['reprocured', 'reprocurement', 'reprocurements'],
 'reprocuss': {'reprocussions': []},
 'reprod': {'reprods': []},
 'reprodm': {'reprodmed': []},
 'reprodnc': {'reprodnce': ['reprodnced']},
 'reprodnce': ['reprodnced'],
 'reprodnct': {'reprodnction': []},
 'reprodoc': {'reprodoced': []},
 'reprodu': {'reprodued': [], 'reprodueibility': []},
 'reproduc': {'reproducability': [],
              'reproducable': [],
              'reproducably': [],
              'reproducation': [],
              'reproduce': ['reproducer',
                            'reproduced',
                            'reproduces',
                            'reproduceably',
                            'reproduceable',
                            'reproduceability'],
              'reproducibility': [],
              'reproducible': ['reproducibles'],
              'reproducibly': [],
              'reproducing': [],
              'reproducive': []},
 'reproduccion': {'reproducciones': []},
 'reproduce': ['reproducer',
               'reproduced',
               'reproduces',
               'reproduceably',
               'reproduceable',
               'reproduceability'],
 'reproducebl': {'reproducebility': []},
 'reproducedbi': {'reproducedby': []},
 'reproduceerbar': {'reproduceerbare': []},
 'reproducer': {'reproducere': []},
 'reproducibil': {'reproducibile': []},
 'reproducibili': {'reproducibily': []},
 'reproducibiliri': {'reproducibiliry': []},
 'reproducibilti': {'reproducibilty': []},
 'reproducibl': {'reproduciblity': []},
 'reproducible': ['reproducibles'],
 'reproducida': {'reproducidas': []},
 'reproducido': {'reproducidos': []},
 'reproducihil': {'reproducihility': []},
 'reproducihl': {'reproducihle': []},
 'reproducimo': {'reproducimos': []},
 'reproducirs': {'reproducirse': []},
 'reproduclbl': {'reproduclbly': []},
 'reproduco': {'reproducoes': []},
 'reproduct': {'reproductability': [],
               'reproducted': [],
               'reproductibility': [],
               'reproductible': ['reproductibles'],
               'reproducting': [],
               'reproduction': ['reproductional'],
               'reproductive': ['reproductives',
                                'reproductively',
                                'reproductiveness'],
               'reproductivities': [],
               'reproductivity': [],
               'reproducts': []},
 'reproducteur': {'reproducteurs': []},
 'reproducti': {'reproductie': []},
 'reproductibilit': {'reproductibilite': []},
 'reproductible': ['reproductibles'],
 'reproductif': {'reproductifs': []},
 'reproduction': {'reproductionism': []},
 'reproductionist': {'reproductionists': []},
 'reproductionqu': {'reproductionquality': []},
 'reproductionrel': {'reproductionrelated': []},
 'reproductiva': {'reproductivas': []},
 'reproductive': ['reproductives', 'reproductively', 'reproductiveness'],
 'reproductiveag': {'reproductiveage': ['reproductiveaged']},
 'reproductiveage': ['reproductiveaged'],
 'reproductiveright': {'reproductiverights': []},
 'reproductivo': {'reproductivos': []},
 'reproductlon': {'reproductlons': []},
 'reproductlv': {'reproductlve': []},
 'reproductor': {'reproductores': []},
 'reproductora': {'reproductoras': []},
 'reproductori': {'reproductory': []},
 'reproductric': {'reproductrice': ['reproductrices']},
 'reproductrice': ['reproductrices'],
 'reproductv': {'reproductve': []},
 'reprodudbl': {'reprodudbility': []},
 'reprodue': {'reproduee': ['reprodueed']},
 'reproduee': ['reprodueed'],
 'reproduet': {'reproduetion': ['reproduetions'], 'reproduetive': []},
 'reproduetion': ['reproduetions'],
 'reprodui': {'reproduis': []},
 'reproduir': {'reproduire': []},
 'reproduiron': {'reproduirons': []},
 'reproduis': {'reproduisant': [], 'reproduise': ['reproduisent']},
 'reproduisai': {'reproduisaient': []},
 'reproduise': ['reproduisent'],
 'reproduison': {'reproduisons': []},
 'reproduit': {'reproduite': ['reproduites'], 'reproduits': []},
 'reproduite': ['reproduites'],
 'reprodukcij': {'reprodukcije': []},
 'reprodukt': {'reproduktion': ['reproduktions'], 'reproduktive': []},
 'reprodukti': {'reproduktie': []},
 'reproduktion': ['reproduktions'],
 'reproduktionsbiologi': {'reproduktionsbiologie': []},
 'reproduktionsprozess': {'reproduktionsprozesses': []},
 'reproduktionsr': {'reproduktionsrate': []},
 'reproduktionstypu': {'reproduktionstypus': []},
 'reproduktiv': {'reproduktiver': []},
 'reproduo': {'reproduoe': ['reproduoed'],
              'reproduoibility': [],
              'reproduoible': []},
 'reproduoe': ['reproduoed'],
 'reproduot': {'reproduotion': []},
 'reprodur': {'reprodured': []},
 'reprodut': {'reprodution': [], 'reprodutive': []},
 'reprodutivo': {'reprodutivos': []},
 'reprodutor': {'reprodutores': []},
 'reproduzido': {'reproduzidos': []},
 'reproduzierbar': {'reproduzierbare': ['reproduzierbarer']},
 'reproduzierbare': ['reproduzierbarer'],
 'reproduzierend': {'reproduzierende': []},
 'reproduziert': {'reproduzierte': []},
 'reproduzion': {'reproduzione': []},
 'reproeh': {'reproehe': []},
 'reprof': {'reprofe': ['reprofes']},
 'reprofe': ['reprofes'],
 'reprofession': {'reprofessionalization': [],
                  'reprofessionalize': ['reprofessionalized'],
                  'reprofessionalizing': []},
 'reprofessionalis': {'reprofessionalisation': []},
 'reprofessionalize': ['reprofessionalized'],
 'reprofil': {'reprofile': ['reprofiled'], 'reprofiling': []},
 'reprofile': ['reprofiled'],
 'reprogenet': {'reprogenetic': ['reprogenetics']},
 'reprogenetic': ['reprogenetics'],
 'reprografi': {'reprografie': []},
 'reprografisch': {'reprografischer': []},
 'reprogram': {'reprogramable': [],
               'reprogramed': [],
               'reprograming': [],
               'reprogrammed': [],
               'reprogramming': ['reprogrammings'],
               'reprograms': []},
 'reprogramm': {'reprogrammability': [],
                'reprogrammable': [],
                'reprogramme': ['reprogrammes', 'reprogrammer']},
 'reprogramme': ['reprogrammes', 'reprogrammer'],
 'reprogramming': ['reprogrammings'],
 'reprograph': {'reprographers': [],
                'reprographic': ['reprographics',
                                 'reprographical',
                                 'reprographically']},
 'reprographc': {'reprographcs': []},
 'reprographi': {'reprographie': ['reprographies'], 'reprography': []},
 'reprographic': ['reprographics', 'reprographical', 'reprographically'],
 'reprographie': ['reprographies'],
 'reprographisch': {'reprographischer': []},
 'reproh': {'reprohate': ['reprohated'], 'reprohation': []},
 'reprohate': ['reprohated'],
 'reprohibit': {'reprohibited': []},
 'reproject': {'reprojected': [],
               'reprojecting': [],
               'reprojection': ['reprojections'],
               'reprojects': []},
 'reprojection': ['reprojections'],
 'reprolaps': {'reprolapse': []},
 'reprolifer': {'reproliferation': []},
 'reprolin': {'reproline': []},
 'repromis': {'repromised': []},
 'repromission': {'repromissiones': []},
 'repromissioni': {'repromissionis': []},
 'repromitter': {'repromittere': []},
 'repromot': {'repromote': ['repromoted'],
              'repromoting': [],
              'repromotion': []},
 'repromote': ['repromoted'],
 'reprompt': {'reprompted': [], 'reprompting': [], 'reprompts': []},
 'repromulg': {'repromulgate': ['repromulgated'],
               'repromulgating': [],
               'repromulgation': []},
 'repromulgate': ['repromulgated'],
 'repronounc': {'repronounce': ['repronounced'], 'repronouncing': []},
 'repronounce': ['repronounced'],
 'repronunci': {'repronunciation': []},
 'reproof': ['reproofe', 'reproofes', 'reproofed', 'reproofing'],
 'reproou': {'reprooue': ['reprooued'], 'reproouing': []},
 'reproouct': {'reproouction': []},
 'reprooue': ['reprooued'],
 'reproov': {'reproof': [],
             'reproove': ['reprooved', 'reproovers'],
             'reprooving': []},
 'reproove': ['reprooved', 'reproovers'],
 'reprop': {'repropped': []},
 'repropag': {'repropagate': ['repropagated'],
              'repropagating': [],
              'repropagation': []},
 'repropagate': ['repropagated'],
 'reproperti': {'reproperty': []},
 'reproport': {'reproportion': ['reproportions',
                                'reproportioned',
                                'reproportioning']},
 'reproportion': {'reproportionation': []},
 'repropos': {'reproposal': ['reproposals'],
              'repropose': ['reproposed', 'reproposes'],
              'reproposing': []},
 'reproposal': ['reproposals'],
 'repropose': ['reproposed', 'reproposes'],
 'reproposit': {'reproposition': []},
 'repros': {'reprosent': ['reprosented']},
 'reprosecut': {'reprosecute': ['reprosecuted'],
                'reprosecuting': [],
                'reprosecution': ['reprosecutions']},
 'reprosecute': ['reprosecuted'],
 'reprosecution': ['reprosecutions'],
 'reprosent': ['reprosented'],
 'reprospect': {'reprospective': []},
 'reprot': {'reproted': [], 'reprots': []},
 'reprotect': {'reprotected': [], 'reprotecting': [], 'reprotection': []},
 'reproth': {'reprothe': []},
 'reproton': {'reprotonate': ['reprotonated', 'reprotonates'],
              'reprotonation': []},
 'reprotonate': ['reprotonated', 'reprotonates'],
 'reprotrus': {'reprotrusion': []},
 'reprou': {'reproue': ['reproued'], 'reprouing': []},
 'reprouabl': {'reprouable': []},
 'reprouch': {'reprouche': []},
 'reprouct': {'reprouction': []},
 'reproue': ['reproued'],
 'reprouf': {'reproufe': [], 'reproufs': []},
 'reprouv': {'reprouve': ['reprouver', 'reprouves']},
 'reprouve': {'reprouvee': ['reprouvees']},
 'reprouvee': ['reprouvees'],
 'reprov': {'reprovable': [],
            'reprovably': [],
            'reproval': [],
            'reprove': ['reproved',
                        'reproves',
                        'reprover',
                        'reproveing',
                        'reprovement',
                        'reproveable'],
            'reproving': ['reprovings']},
 'reprove': ['reproved',
             'reproves',
             'reprover',
             'reproveing',
             'reprovement',
             'reproveable'],
 'reprovid': {'reprovide': ['reprovided'], 'reproviding': []},
 'reprovide': ['reprovided'],
 'reproving': ['reprovings'],
 'reprovingli': {'reprovingly': []},
 'reprovis': {'reprovision': ['reprovisions',
                              'reprovisioned',
                              'reprovisioning']},
 'reprovision': ['reprovisions', 'reprovisioned', 'reprovisioning'],
 'reprovok': {'reprovoke': ['reprovoked']},
 'reprovoke': ['reprovoked'],
 'reprsent': {'reprsentation': ['reprsentations'],
              'reprsentative': ['reprsentatives'],
              'reprsented': [],
              'reprsenting': [],
              'reprsents': []},
 'reprsentation': ['reprsentations'],
 'reprsentative': ['reprsentatives'],
 'reprsesent': {'reprsesentant': []},
 'reprt': {'reprted': [], 'reprts': []},
 'reprtnt': {'reprtnted': []},
 'repruf': {'reprufe': []},
 'reprun': {'repruned': []},
 'reps': {'repse': []},
 'repsat': {'repsated': []},
 'repsect': {'repsected': [], 'repsective': ['repsectively'], 'repsects': []},
 'repsective': ['repsectively'],
 'repselv': {'repselver': []},
 'repsent': {'repsentation': [],
             'repsentative': ['repsentatives'],
             'repsented': [],
             'repsenting': [],
             'repsents': []},
 'repsentative': ['repsentatives'],
 'repses': {'repsesent': ['repsesented', 'repsesentatives']},
 'repsesent': {'repsesentation': []},
 'repsi': {'repsys': []},
 'repsiratori': {'repsiratory': []},
 'repsold': {'repsolds': []},
 'repsond': {'repsonded': [], 'repsondents': []},
 'repsons': {'repsonse': ['repsonses'],
             'repsonsibilities': [],
             'repsonsibility': [],
             'repsonsible': [],
             'repsonsive': []},
 'repsonse': ['repsonses'],
 'repstit': {'repstition': []},
 'rept': {'reptative': [], 'repte': ['reptes', 'repted'], 'repts': []},
 'reptac': {'reptace': ['reptaced', 'reptacement']},
 'reptace': ['reptaced', 'reptacement'],
 'reptan': {'reptans': []},
 'reptant': {'reptante': ['reptantes']},
 'reptante': ['reptantes'],
 'reptantesqu': {'reptantesque': []},
 'reptantian': {'reptantians': []},
 'reptar': {'reptare': []},
 'reptat': {'reptate': ['reptates'],
            'reptating': [],
            'reptation': ['reptations', 'reptational']},
 'reptate': ['reptates'],
 'reptation': ['reptations', 'reptational'],
 'repte': ['reptes', 'repted'],
 'reptei': {'repteis': []},
 'repten': {'reptens': []},
 'reptes': {'reptesent': ['reptesents',
                          'reptesented',
                          'reptesenting',
                          'reptesentative',
                          'reptesentatives']},
 'reptesent': {'reptesentation': []},
 'repth': {'repthe': []},
 'repti': {'reptied': [], 'repty': ['reptying']},
 'reptibl': {'reptiblic': []},
 'reptic': {'reptication': []},
 'reptil': {'reptile': [], 'reptilic': [], 'reptils': []},
 'reptilas': {'reptilase': []},
 'reptilelik': {'reptilelike': []},
 'reptilemamm': {'reptilemammal': []},
 'reptili': {'reptilious': [], 'reptilis': []},
 'reptilian': {'reptilian': []},
 'reptilianlik': {'reptilianlike': []},
 'reptiliari': {'reptiliary': []},
 'reptilibu': {'reptilibus': []},
 'reptilicu': {'reptilicus': []},
 'reptilienei': {'reptilieneies': []},
 'reptilienfond': {'reptilienfonds': []},
 'reptilifer': {'reptiliferous': []},
 'reptiliomorph': {'reptiliomorphs': []},
 'reptilivoru': {'reptilivorus': []},
 'reptiloid': {'reptiloids': []},
 'reptinr': {'reptinred': []},
 'reptint': {'reptinted': []},
 'reptis': {'reptisals': []},
 'reptit': {'reptition': ['reptitions'], 'reptitive': []},
 'reptiti': {'reptitious': ['reptitiously']},
 'reptition': ['reptitions'],
 'reptitious': ['reptitiously'],
 'reptll': {'reptlles': []},
 'reptn': {'reptns': []},
 'reptoduc': {'reptoduce': ['reptoduced']},
 'reptoduce': ['reptoduced'],
 'reptoduct': {'reptoduction': [], 'reptoductive': []},
 'reptoid': {'reptoids': []},
 'reptomyc': {'reptomyces': []},
 'repton': {'reptons': []},
 'reptonian': {'reptonians': []},
 'reptuat': {'reptuation': []},
 'reptur': {'repture': ['reptured']},
 'repture': ['reptured'],
 'reptut': {'reptutation': []},
 'repty': ['reptying'],
 'reptyl': {'reptyle': ['reptyles']},
 'reptyle': ['reptyles'],
 'repu': {'repue': ['repued', 'repues'], 'repus': []},
 'repuat': {'repuation': []},
 'repub': {'repube': [], 'repubic': ['repubics'], 'repubs': []},
 "repub'": {"repub'ic": []},
 'repubbcan': {'repubbcans': []},
 'repubbl': {'repubblic': []},
 'repubblican': {'repubblicane': []},
 'repubblich': {'repubbliche': []},
 'repubcan': {'repubcans': []},
 'repubf': {'repubfic': []},
 'repubhc': {'repubhcs': []},
 'repubhcan': {'repubhcans': []},
 'repubhqu': {'repubhque': []},
 'repubhsh': {'repubhshed': []},
 'repubi': {'repubiic': []},
 'repubic': ['repubics'],
 'repubican': {'repubicans': []},
 'repubiiqu': {'repubiique': []},
 'repubiish': {'repubiished': []},
 'republ': {'republi': ['republic',
                        'republis',
                        'republies',
                        'republical',
                        'republication']},
 'republi': {'republie': ['republieation']},
 'republiah': {'republiahed': []},
 'republian': {'republians': []},
 'republiau': {'republiaue': []},
 'republic': {'republice': [],
              'republicism': [],
              'republicize': ['republicized']},
 'republica': {'republicae': [], 'republicas': []},
 'republicad': {'republicade': []},
 'republicain': {'republicaine': ['republicaines'], 'republicains': []},
 'republicaine': ['republicaines'],
 'republican': ['republicane',
                'republicaner',
                'republicanize',
                'republicanism',
                'republicanized',
                'republicanizing',
                'republicanization'],
 'republicana': {'republicanas': []},
 'republicanappoint': {'republicanappointed': []},
 'republicanback': {'republicanbacked': []},
 'republicancontrol': {'republicancontrolled': []},
 'republicandemocrat': {'republicandemocratic': [], 'republicandemocrats': []},
 'republicandomin': {'republicandominated': []},
 'republicanis': {'republicanisation': [],
                  'republicanise': ['republicanised'],
                  'republicanising': []},
 'republicanise': ['republicanised'],
 'republicanism': {'republicanisme': []},
 'republicanist': {'republicanists': []},
 'republicanl': {'republicanled': []},
 'republicanlean': {'republicanleaning': []},
 'republicanli': {'republicanly': []},
 'republicanliber': {'republicanliberal': []},
 'republicanmind': {'republicanminded': []},
 'republicano': {'republicanos': []},
 'republicanori': {'republicanoriented': []},
 'republicanparti': {'republicanparty': []},
 'republicanprogress': {'republicanprogressive': []},
 'republicansponsor': {'republicansponsored': []},
 'republicanu': {'republicanus': []},
 'republicati': {'republicatiou': []},
 'republicau': {'republicaus': []},
 'republich': {'republiche': []},
 'republici': {'republicis': []},
 'republician': {'republicians': []},
 'republicize': ['republicized'],
 'republick': {'republicke': ['republickes'], 'republicks': []},
 'republicke': ['republickes'],
 'republicki': {'republicky': []},
 'republicqu': {'republicque': []},
 'republicrat': {'republicrats': []},
 'republicu': {'republicus': []},
 'republicwa': {'republicwas': []},
 'republicwid': {'republicwide': []},
 'republie': ['republieation'],
 'republiean': {'republieans': []},
 'republifh': {'republifhed': []},
 'republifli': {'republiflied': []},
 'republigu': {'republigue': []},
 'republiih': {'republiihed': []},
 'republik': {'republike': ['republikes']},
 'republika': {'republikas': []},
 'republikan': {'republikaner': ['republikaners'], 'republikans': []},
 'republikaner': ['republikaners'],
 'republikanisch': {'republikanische': ['republikanischer',
                                        'republikanisches']},
 'republikanische': ['republikanischer', 'republikanisches'],
 'republikanismu': {'republikanismus': []},
 'republike': ['republikes'],
 'republikeins': {'republikeinse': []},
 'republiki': {'republiky': []},
 'republikin': {'republikins': []},
 'republilh': {'republilhed': []},
 'republio': {'republios': []},
 'republiou': {'republioue': []},
 'republiqn': {'republiqne': []},
 'republiqu': {'republique': ['republiques']},
 'republique': ['republiques'],
 'republiqueta': {'republiquetas': []},
 'republisb': {'republisbed': []},
 'republish': {'republishable': [],
               'republished': [],
               'republisher': ['republishers'],
               'republishes': [],
               'republishing': []},
 'republisher': ['republishers'],
 'republisli': {'republislied': []},
 'republisti': {'republistied': []},
 'republlc': {'republlcs': []},
 'republlqu': {'republlque': []},
 'republlsh': {'republlshed': []},
 'republocrat': {'republocrats': []},
 'republtqu': {'republtque': []},
 'repubt': {'repubtic': []},
 'repubtiqu': {'repubtique': []},
 'repubucan': {'repubucans': []},
 'repubuqu': {'repubuque': []},
 'repuc': {'repucer': []},
 'repucer': {'repuceration': []},
 'repucl': {'repuclic': []},
 'repud': {'repudation': [], 'repudicated': [], 'repudication': []},
 'repudi': {'repudiability': [],
            'repudiable': [],
            'repudiant': [],
            'repudiate': ['repudiates', 'repudiated'],
            'repudiating': [],
            'repudiation': [],
            'repudiative': [],
            'repudiator': ['repudiators'],
            'repudie': ['repudies', 'repudier', 'repudient']},
 'repudia': {'repudias': []},
 'repudiab': {'repudiabant': []},
 'repudiamu': {'repudiamus': []},
 'repudiandu': {'repudiandus': []},
 'repudiant': {'repudiantes': []},
 'repudiar': {'repudiare': ['repudiared']},
 'repudiare': ['repudiared'],
 'repudiass': {'repudiasse': []},
 'repudiat': {'repudiatable': []},
 'repudiate': {'repudiatee': []},
 'repudiati': {'repudiatis': []},
 'repudiatingli': {'repudiatingly': []},
 'repudiationist': {'repudiationists': []},
 'repudiator': ['repudiators'],
 'repudiatori': {'repudiatory': []},
 'repudiatu': {'repudiatus': []},
 'repudie': {'repudiee': []},
 'repudiemu': {'repudiemus': []},
 'repudii': {'repudiis': []},
 'repudl': {'repudlic': []},
 'repue': ['repued', 'repues'],
 'repuel': {'repuelic': []},
 'repuerascen': {'repuerascens': []},
 'repuerascer': {'repuerascere': []},
 'repuest': {'repuested': []},
 'repuesta': {'repuestas': []},
 'repuesto': {'repuestos': []},
 'repug': {'repugance': [], 'repugant': []},
 'repugn': {'repugnance': [],
            'repugnancies': [],
            'repugnancy': [],
            'repugnant': ['repugnants'],
            'repugnates': [],
            'repugne': ['repugned', 'repugner', 'repugnes', 'repugnent'],
            'repugning': [],
            'repugns': []},
 'repugna': {'repugnas': []},
 'repugnac': {'repugnace': []},
 'repugnaci': {'repugnacy': []},
 'repugnai': {'repugnaient': []},
 'repugnan': {'repugnans': []},
 'repugnanci': {'repugnancie': []},
 'repugnane': {'repugnanee': []},
 'repugnano': {'repugnanoe': []},
 'repugnant': {'repugnante': ['repugnantes']},
 'repugnante': ['repugnantes'],
 'repugnanti': {'repugnantis': []},
 'repugnantia': {'repugnantiae': []},
 'repugnantibu': {'repugnantibus': []},
 'repugnantii': {'repugnantiis': []},
 'repugnantli': {'repugnantly': []},
 'repugnar': {'repugnare': ['repugnarent']},
 'repugnare': ['repugnarent'],
 'repugnatori': {'repugnatorial': [], 'repugnatory': []},
 'repugnauc': {'repugnauce': []},
 'repugnaunc': {'repugnaunce': []},
 'repugne': ['repugned', 'repugner', 'repugnes', 'repugnent'],
 'repugnemu': {'repugnemus': []},
 'repugu': {'repuguance': [], 'repuguant': []},
 'repuhl': {'repuhlic': ['repuhlics', 'repuhlication']},
 'repuhli': {'repuhlie': []},
 'repuhlic': ['repuhlics', 'repuhlication'],
 'repuhlican': {'repuhlicanism': [], 'repuhlicans': []},
 'repuhliqu': {'repuhlique': []},
 'repuhlish': {'repuhlished': []},
 'repuiat': {'repuiation': []},
 'repuir': {'repuire': ['repuires', 'repuired', 'repuirement', 'repuirements']},
 'repuire': ['repuires', 'repuired', 'repuirement', 'repuirements'],
 'repuis': {'repuised': []},
 'repuk': {'repuke': ['repuked']},
 'repuke': ['repuked'],
 'repul': {'repulation': [],
           'repule': ['repuled'],
           'repulic': [],
           'repulled': [],
           'repulles': [],
           'repulling': [],
           'repuls': []},
 'repulb': {'repulbic': []},
 'repulc': {'repulce': []},
 'repule': ['repuled'],
 'repulf': {'repulfe': ['repulfed'], 'repulfing': [], 'repulfive': []},
 'repulfe': ['repulfed'],
 'repulican': {'repulicans': []},
 'repuliss': {'repulisse': []},
 'repullul': {'repullulate': [], 'repullulation': []},
 'repulp': {'repulpability': [],
            'repulpable': [],
            'repulped': [],
            'repulper': ['repulpers'],
            'repulping': []},
 'repulper': ['repulpers'],
 'repuls': {'repulse': ['repulsed', 'repulser', 'repulsers'],
            'repulsing': [],
            'repulsion': [],
            'repulsive': ['repulsives', 'repulsively', 'repulsiveness']},
 'repulsa': {'repulsae': [], 'repulsas': []},
 'repulsant': {'repulsantes': []},
 'repulse': ['repulsed', 'repulser', 'repulsers'],
 'repulsi': {'repulsis': []},
 'repulsif': {'repulsifs': []},
 'repulsion': {'repulsional': [], 'repulsione': []},
 'repulsioninduct': {'repulsioninduction': []},
 'repulsiss': {'repulsisse': []},
 'repulsivc': {'repulsivcness': []},
 'repulsive': ['repulsives', 'repulsively', 'repulsiveness'],
 'repulsivelook': {'repulsivelooking': []},
 'repulsivo': {'repulsivos': []},
 'repulso': {'repulsos': []},
 'repulsor': {'repulsors': []},
 'repulsorlift': {'repulsorlifts': []},
 'repulss': {'repulsse': []},
 'repulsu': {'repulsus': []},
 'repult': {'repults': []},
 'repulver': {'repulverized': []},
 'repum': {'repumic': []},
 'repump': {'repumped': [], 'repumper': [], 'repumping': []},
 'repunch': {'repunched': [], 'repunches': [], 'repunching': []},
 'repunctu': {'repunctuate': ['repunctuates', 'repunctuated'],
              'repunctuating': [],
              'repunctuation': []},
 'repunctuate': ['repunctuates', 'repunctuated'],
 'repunctur': {'repuncture': ['repunctured'], 'repuncturing': []},
 'repuncture': ['repunctured'],
 'repunish': {'repunished': []},
 'repunt': {'repunte': []},
 'repuol': {'repuolic': []},
 'repupl': {'repuplic': []},
 'repur': {'repurable': [], 'repuration': ['repurations'], 'repured': []},
 'repuration': ['repurations'],
 'repurchas': {'repurchasable': [],
               'repurchase': ['repurchaser', 'repurchased', 'repurchasers'],
               'repurchasing': []},
 'repurchase': ['repurchaser', 'repurchased', 'repurchasers'],
 'repurcus': {'repurcusions': []},
 'repurcuss': {'repurcussion': ['repurcussions']},
 'repurcussion': ['repurcussions'],
 'repurg': {'repurgation': [], 'repurged': [], 'repurging': []},
 'repurgar': {'repurgare': []},
 'repurgata': {'repurgatae': []},
 'repurgati': {'repurgatis': []},
 'repurgation': {'repurgatione': []},
 'repurgatu': {'repurgatus': []},
 'repurif': {'repurification': []},
 'repurifi': {'repurified': [], 'repurifies': [], 'repurify': ['repurifying']},
 'repurify': ['repurifying'],
 'repurl': {'repurlic': []},
 'repurlican': {'repurlicans': []},
 'repurpos': {'repurposable': [],
              'repurpose': ['repurposes', 'repurposed'],
              'repurposing': []},
 'repurpose': ['repurposes', 'repurposed'],
 'repurt': {'repurted': []},
 'repus': {'repuse': []},
 'repush': {'repushed': []},
 'reput': {'reputability': [],
           'reputable': ['reputables', 'reputableness'],
           'reputably': [],
           'reputant': [],
           'reputate': ['reputated'],
           'reputation': ['reputational', 'reputationally'],
           'reputative': ['reputatively'],
           'repute': ['reputer', 'reputed', 'reputent'],
           'reputing': [],
           'repution': [],
           'reputting': []},
 'reputa': {'reputas': []},
 'reputab': {'reputabant': []},
 'reputabimu': {'reputabimus': []},
 'reputable': ['reputables', 'reputableness'],
 'reputacion': {'reputaciones': []},
 'reputada': {'reputadas': []},
 'reputado': {'reputados': []},
 'reputahl': {'reputahle': []},
 'reputak': {'reputake': []},
 'reputamu': {'reputamus': []},
 'reputan': {'reputans': []},
 'reputandu': {'reputandus': []},
 'reputant': {'reputantes': []},
 'reputantibu': {'reputantibus': []},
 'reputar': {'reputare': ['reputarent']},
 'reputare': ['reputarent'],
 'reputaremu': {'reputaremus': []},
 'reputars': {'reputarse': []},
 'reputat': {'reputatation': [], 'reputatic': []},
 'reputate': ['reputated'],
 'reputati': {'reputatie': [], 'reputatiou': [], 'reputatis': []},
 'reputation': {'reputatione': []},
 'reputationa': {'reputationas': []},
 'reputationalist': {'reputationalists': []},
 'reputationbas': {'reputationbased': []},
 'reputationbuild': {'reputationbuilding': []},
 'reputationi': {'reputationis': []},
 'reputationrel': {'reputationrelated': []},
 'reputative': ['reputatively'],
 'reputatu': {'reputatus': []},
 'reputavimu': {'reputavimus': []},
 'reputazion': {'reputazione': []},
 'repute': {'reputee': ['reputees']},
 'reputedli': {'reputedly': []},
 'reputee': ['reputees'],
 'reputemu': {'reputemus': []},
 'reputet': {'reputetion': []},
 'reputeti': {'reputetis': []},
 'reputi': {'reputiated': []},
 'reputit': {'reputition': []},
 'reputnt': {'reputntion': []},
 'reputti': {'reputtied': [], 'reputty': ['reputtying']},
 'reputty': ['reputtying'],
 'reputut': {'reputution': []},
 'reputyt': {'reputytion': []},
 'repuuiqu': {'repuuique': []},
 'repuw': {'repuwic': []},
 'repvbliqu': {'repvblique': []},
 'repyn': {'repyne': ['repyned'], 'repyning': []},
 'repyne': ['repyned'],
 'repyt': {'repytation': []},
 'req': {'reqs': []},
 "req't": {"req'ts": []},
 'reqair': {'reqaire': ['reqaired', 'reqaires']},
 'reqaire': ['reqaired', 'reqaires'],
 'reqard': {'reqarded': [], 'reqarding': [], 'reqards': []},
 'reqe': {'reqing': []},
 'reqeir': {'reqeired': []},
 'reqeiv': {'reqeive': ['reqeived']},
 'reqeive': ['reqeived'],
 'reqenc': {'reqency': []},
 'reqent': {'reqently': []},
 'reqest': {'reqested': [], 'reqesting': [], 'reqests': []},
 'reqiiest': {'reqiiested': []},
 'reqiiir': {'reqiiire': ['reqiiired', 'reqiiires', 'reqiiirements'],
             'reqiiiring': []},
 'reqiiire': ['reqiiired', 'reqiiires', 'reqiiirements'],
 'reqiir': {'reqiire': ['reqiired']},
 'reqiire': ['reqiired'],
 'reqim': {'reqime': ['reqimes']},
 'reqime': ['reqimes'],
 'reqinr': {'reqinre': ['reqinred', 'reqinres', 'reqinrements']},
 'reqinre': ['reqinred', 'reqinres', 'reqinrements'],
 'reqion': {'reqional': [], 'reqions': []},
 'reqir': {'reqire': ['reqired', 'reqires', 'reqirement', 'reqirements'],
           'reqiring': []},
 'reqire': ['reqired', 'reqires', 'reqirement', 'reqirements'],
 'reqist': {'reqister': ['reqistered']},
 'reqister': ['reqistered'],
 'reqistr': {'reqistration': []},
 'reqiur': {'reqiure': ['reqiures', 'reqiured', 'reqiurement', 'reqiurements'],
            'reqiuring': []},
 'reqiure': ['reqiures', 'reqiured', 'reqiurement', 'reqiurements'],
 'reqjir': {'reqjired': []},
 'reqmr': {'reqmre': ['reqmres', 'reqmred']},
 'reqmre': ['reqmres', 'reqmred'],
 'reqmrement': {'reqmrements': []},
 'reqmt': {'reqmts': []},
 'reqnesen': {'reqnesens': []},
 'reqnest': {'reqnested': [], 'reqnesting': [], 'reqnests': []},
 'reqnir': {'reqnire': ['reqnires', 'reqnired', 'reqnirement', 'reqnirements'],
            'reqniring': []},
 'reqnire': ['reqnires', 'reqnired', 'reqnirement', 'reqnirements'],
 'reqnisit': {'reqnisite': ['reqnisites'], 'reqnisition': []},
 'reqnisite': ['reqnisites'],
 'reqnlr': {'reqnlred': []},
 'reqoest': {'reqoested': []},
 'reqoir': {'reqoire': ['reqoired', 'reqoires', 'reqoirements']},
 'reqoire': ['reqoired', 'reqoires', 'reqoirements'],
 'reqress': {'reqression': []},
 'reqrir': {'reqrired': []},
 'reqsir': {'reqsired': []},
 'reqt': {'reqts': []},
 'reqtiir': {'reqtiire': ['reqtiires', 'reqtiired']},
 'reqtiire': ['reqtiires', 'reqtiired'],
 'requ': {'reque': ['reques'], 'requs': []},
 "requ'r": {"requ're": []},
 'requa': {'requaed': [], 'requas': []},
 'requalif': {'requalification': ['requalifications']},
 'requalifi': {'requalified': [],
               'requalifies': [],
               'requalify': ['requalifying']},
 'requalification': ['requalifications'],
 'requalify': ['requalifying'],
 'requant': {'requantization': [],
             'requantize': ['requantized', 'requantizer'],
             'requantizing': []},
 'requantifi': {'requantified': []},
 'requantize': ['requantized', 'requantizer'],
 'requart': {'requartered': []},
 'requat': {'requate': []},
 'requcsen': {'requcsens': []},
 'requcst': {'requcsted': []},
 'reque': {'requee': ['requeed']},
 'requeat': {'requeated': [], 'requeating': [], 'requeats': []},
 'requee': ['requeed'],
 'requeen': {'requeened': [], 'requeening': []},
 'requeet': {'requeeted': []},
 'requefen': {'requefens': []},
 'requefl': {'requefled': []},
 'requeft': {'requefted': [], 'requefting': [], 'requefts': []},
 'requeist': {'requeisted': [], 'requeisting': [], 'requeists': []},
 'requeisti': {'requeistis': []},
 'requeit': {'requeited': []},
 'requeleyn': {'requeleyne': []},
 'requelm': {'requelme': []},
 'requen': {'requens': []},
 'requenc': {'requence': ['requences'], 'requencies': [], 'requency': []},
 'requence': ['requences'],
 'requench': {'requenched': [], 'requenching': []},
 'requendi': {'requendy': []},
 'requent': {'requentation': [], 'requented': [], 'requently': []},
 'requer': {'requerant': ['requerants'], 'requere': ['requered', 'requerer']},
 'requerant': {'requerante': ['requerantes']},
 'requerante': ['requerantes'],
 'requere': ['requered', 'requerer'],
 'requerent': {'requerente': []},
 'requeri': {'requeried': [],
             'requeries': [],
             'requeriment': ['requeriments'],
             'requery': ['requerying']},
 'requerida': {'requeridas': []},
 'requerido': {'requeridos': []},
 'requeriment': ['requeriments'],
 'requerimento': {'requerimentos': []},
 'requerimiento': {'requerimientos': []},
 'requerimo': {'requerimos': []},
 'requeroi': {'requeroient': []},
 'requeron': {'requerons': []},
 'requerr': {'requerrant': [], 'requerre': []},
 'requerron': {'requerrons': []},
 'requery': ['requerying'],
 'reques': {'requesed': []},
 'requescen': {'requescens': []},
 'requescn': {'requescns': []},
 'requesen': {'requesenes': [], 'requesens': []},
 'requesi': {'requesied': [], 'requesis': []},
 'requesit': {'requesite': []},
 'requesl': {'requesled': [], 'requesls': []},
 'requeson': {'requesones': []},
 'requesr': {'requesred': [], 'requesrs': []},
 'request': ['requeste',
             'requestes',
             'requested',
             'requester',
             'requestive',
             'requesting',
             'requestion',
             'requestable',
             'requestives',
             'requestions',
             'requestioned',
             'requestioning'],
 'requesta': {'requestas': []},
 'requestdispatch': {'requestdispatcher': []},
 'requeste': {'requestee': ['requestees']},
 'requestee': ['requestees'],
 'requestencod': {'requestencoding': []},
 'requestfocu': {'requestfocus': []},
 'requesthandl': {'requesthandler': []},
 'requesthead': {'requestheaders': []},
 'requesti': {'requestis': []},
 'requesting': {'requestinge': []},
 'requestingth': {'requestingthe': []},
 'requestnamespac': {'requestnamespace': []},
 'requestopt': {'requestoptional': []},
 'requestor': {'requestors': []},
 'requestprocess': {'requestprocessing': []},
 'requestrefus': {'requestrefuse': []},
 'requestrepli': {'requestreply': []},
 'requestrespons': {'requestresponse': []},
 'requestscop': {'requestscope': []},
 'requestth': {'requestthe': []},
 'requesttyp': {'requesttype': []},
 'requestwa': {'requestwas': []},
 'requet': {'requete': ['requeted', 'requetes'],
            'requets': [],
            'requetted': []},
 'requete': ['requeted', 'requetes'],
 'requeti': {'requetis': []},
 'requett': {'requette': []},
 'requeu': {'requeue': ['requeued', 'requeues'], 'requeuing': []},
 'requeue': ['requeued', 'requeues'],
 'requfr': {'requfre': ['requfred']},
 'requfre': ['requfred'],
 'requh': {'requhe': ['requhed', 'requhements']},
 "requh'": {"requh'ed": []},
 'requhe': ['requhed', 'requhements'],
 'requht': {'requhtements': []},
 'requi': {'requie': ['requies', 'requied'], 'requis': []},
 "requi'": {"requi'ed": []},
 'requiait': {'requiaite': []},
 'requib': {'requibed': []},
 'requic': {'requiced': []},
 'requicken': {'requickened': [], 'requickening': [], 'requickens': []},
 'requie': {'requieed': []},
 'requiebro': {'requiebros': []},
 'requiem': ['requieme'],
 'requiement': {'requiements': []},
 'requiemqu': {'requiemque': []},
 'requiequ': {'requieque': []},
 'requier': {'requierant': [],
             'requiere': ['requieres',
                          'requiered',
                          'requierent',
                          'requierement',
                          'requierements'],
             'requiering': [],
             'requierments': [],
             'requiers': []},
 'requiere': ['requieres',
              'requiered',
              'requierent',
              'requierement',
              'requierements'],
 'requiesc': {'requiescal': [],
              'requiescant': [],
              'requiesce': ['requiescent', 'requiescence']},
 'requiesca': {'requiescas': []},
 'requiescamu': {'requiescamus': []},
 'requiescat': {'requiescat': []},
 'requiesce': ['requiescent', 'requiescence'],
 'requiescen': {'requiescens': []},
 'requiescer': {'requiescere': []},
 'requiescit': {'requiescite': []},
 'requiesqu': {'requiesque': []},
 'requiess': {'requiesse': []},
 'requiet': {'requiete': []},
 'requieti': {'requietis': []},
 'requievimu': {'requievimus': []},
 'requieviss': {'requievisse': []},
 'requif': {'requife': ['requifed']},
 'requife': ['requifed'],
 'requifit': {'requifite': ['requifites'], 'requifition': ['requifitions']},
 'requifite': ['requifites'],
 'requifition': ['requifitions'],
 'requii': {'requiie': ['requiied', 'requiies'], 'requiiing': []},
 'requiie': ['requiied', 'requiies'],
 'requiiement': {'requiiements': []},
 'requiiit': {'requiiite': []},
 'requilibr': {'requilibration': []},
 'requilit': {'requilite': []},
 'requiment': {'requiments': []},
 'requin': {'requined': [], 'requins': []},
 'requint': {'requinte': []},
 'requinto': {'requintos': []},
 'requip': {'requipment': [], 'requipped': []},
 'requir': {'requirable': [],
            'requirant': [],
            'require': ['required',
                        'requires',
                        'requirer',
                        'requirent',
                        'requirers',
                        'requireds',
                        'requirents',
                        'requireent',
                        'requireing',
                        'requireents',
                        'requirement'],
            'requiring': ['requirings'],
            'requiritis': [],
            'requirment': ['requirments'],
            'requirred': [],
            'requirs': []},
 'requira': {'requiraments': [], 'requiras': []},
 'requiramu': {'requiramus': []},
 'requiran': {'requiranents': []},
 'requirati': {'requiratis': []},
 'requirc': {'requircments': [], 'requircs': []},
 'requird': {'requirde': []},
 'require': {'requiree': ['requireed']},
 'requirea': {'requireaent': ['requireaents']},
 'requireaent': ['requireaents'],
 'requireb': {'requirebant': []},
 'required': {'requirede': [], 'requiredness': []},
 'requiredbi': {'requiredby': []},
 'requiredd': {'requireddate': []},
 'requiredfieldvalid': {'requiredfieldvalidator': []},
 'requiredi': {'requiredis': []},
 'requiredreserv': {'requiredreserve': []},
 'requiredth': {'requiredthe': []},
 'requiree': ['requireed'],
 'requiref': {'requirefs': []},
 'requirei': {'requireients': []},
 'requirein': {'requireinents': []},
 'requireing': {'requireinge': []},
 'requireit': {'requireits': []},
 'requirel': {'requirelents': []},
 'requirem': {'requiremant': ['requiremants'], 'requireme': ['requiremer']},
 'requiremant': ['requiremants'],
 'requiremcnt': {'requiremcnts': []},
 'requireme': ['requiremer'],
 'requiremeat': {'requiremeats': []},
 'requiremem': {'requiremems': []},
 'requirememt': {'requirememts': []},
 'requiremen': {'requiremens': []},
 'requiremeni': {'requiremenis': []},
 'requiremenl': {'requiremenls': []},
 'requiremenr': {'requiremenrs': []},
 'requirement': {'requiremente': []},
 'requirementi': {'requirementis': []},
 'requirementsar': {'requirementsare': []},
 'requirementsgath': {'requirementsgathering': []},
 'requiremerit': {'requiremerits': []},
 'requiremert': {'requiremerts': []},
 'requiremet': {'requiremets': []},
 'requiremetn': {'requiremetns': []},
 'requiremeut': {'requiremeuts': []},
 'requiremnet': {'requiremnets': []},
 'requiremnt': {'requiremnts': []},
 'requiremont': {'requiremonts': []},
 'requiremsnt': {'requiremsnts': []},
 'requiremt': {'requiremts': []},
 'requiremtn': {'requiremtns': []},
 'requiremtnt': {'requiremtnts': []},
 'requiremu': {'requiremus': []},
 'requiren': {'requirenent': ['requirenents'],
              'requirenments': [],
              'requirens': []},
 'requirendi': {'requirendis': []},
 'requirendu': {'requirendus': []},
 'requirenent': ['requirenents'],
 'requireni': {'requirenients': []},
 'requirent': {'requirente': ['requirentes']},
 'requirente': ['requirentes'],
 'requirenti': {'requirentis': []},
 'requirentibu': {'requirentibus': []},
 'requireo': {'requireoents': []},
 'requirer': {'requirere': ['requirerent', 'requirerents']},
 'requirere': ['requirerent', 'requirerents'],
 'requirern': {'requirernent': ['requirernents']},
 'requirernent': ['requirernents'],
 'requiresquestionandansw': {'requiresquestionandanswer': []},
 'requiresth': {'requiresthe': []},
 'requiret': {'requirets': []},
 'requireth': {'requirethe': []},
 'requireti': {'requiretis': []},
 'requiri': {'requiried': [], 'requiries': [], 'requiris': []},
 'requiriendol': {'requiriendoles': []},
 'requiries': {'requiriese': []},
 'requirimiento': {'requirimientos': []},
 'requirimu': {'requirimus': []},
 'requiring': {'requiringe': []},
 'requiringth': {'requiringthe': []},
 'requirit': {'requirite': []},
 'requirment': ['requirments'],
 'requiro': {'requiros': []},
 'requis': {'requise': ['requised', 'requises'],
            'requision': ['requisioned'],
            'requisiti': ['requisitis', 'requisities']},
 'requise': ['requised', 'requises'],
 'requisicion': {'requisiciones': []},
 'requisil': {'requisile': []},
 'requision': ['requisioned'],
 'requisionist': {'requisionists': []},
 'requisir': {'requisire': []},
 'requisiss': {'requisisse': []},
 'requisit': {'requisite': ['requisited', 'requisitely', 'requisiteness'],
              'requisition': ['requisitional',
                              'requisitioned',
                              'requisitioning',
                              'requisitionings'],
              'requisitive': [],
              'requisits': []},
 'requisita': {'requisitae': [], 'requisitas': []},
 'requisitc': {'requisitcs': []},
 'requisite': ['requisited', 'requisitely', 'requisiteness'],
 'requisiti': {'requisitie': []},
 'requisition': {'requisitione': ['requisitiones',
                                  'requisitioner',
                                  'requisitioners']},
 'requisitionari': {'requisitionaries': [], 'requisitionary': []},
 'requisitione': ['requisitiones', 'requisitioner', 'requisitioners'],
 'requisitioni': {'requisitionis': []},
 'requisitionibu': {'requisitionibus': []},
 'requisitionist': {'requisitionists': []},
 'requisitionn': {'requisitionne': ['requisitionner', 'requisitionnes']},
 'requisitionnair': {'requisitionnaire': ['requisitionnaires']},
 'requisitionnaire': ['requisitionnaires'],
 'requisitionne': ['requisitionner', 'requisitionnes'],
 'requisito': {'requisitos': []},
 'requisitoir': {'requisitoire': ['requisitoires']},
 'requisitoire': ['requisitoires'],
 'requisiton': {'requisitoned': [], 'requisitons': []},
 'requisitori': {'requisitorial': [], 'requisitory': []},
 'requisitt': {'requisitte': []},
 'requisitu': {'requisitus': []},
 'requisivimu': {'requisivimus': []},
 'requisizion': {'requisizione': []},
 'requislt': {'requislte': []},
 'requist': {'requiste': ['requisted', 'requistes'],
             'requistion': ['requistions', 'requistioned', 'requistioning']},
 'requiste': ['requisted', 'requistes'],
 'requisti': {'requistie': ['requisties']},
 'requistie': ['requisties'],
 'requistion': ['requistions', 'requistioned', 'requistioning'],
 'requistit': {'requistite': []},
 'requisyt': {'requisyte': []},
 'requit': {'requitable': [],
            'requital': [],
            'requite': ['requites',
                        'requited',
                        'requiter',
                        'requiters',
                        'requitement',
                        'requitements'],
            'requiting': [],
            'requitted': [],
            'requitting': []},
 'requital': {'requitall': []},
 'requite': ['requites',
             'requited',
             'requiter',
             'requiters',
             'requitement',
             'requitements'],
 'requitemenr': {'requitemenrs': []},
 'requiti': {'requity': []},
 'requitt': {'requittal': []},
 'requittal': {'requittall': []},
 'requjr': {'requjre': ['requjred']},
 'requjre': ['requjred'],
 'requk': {'requke': ['requkes', 'requked', 'requkements']},
 'requke': ['requkes', 'requked', 'requkements'],
 'requl': {'requlate': ['requlated'],
           'requlating': [],
           'requlation': ['requlations']},
 'reqular': {'reqularity': []},
 'reqularli': {'reqularly': []},
 'requlate': ['requlated'],
 'requlation': ['requlations'],
 'requlatori': {'requlatory': []},
 'requlr': {'requlre': ['requlres', 'requlred', 'requlrement', 'requlrements'],
            'requlring': []},
 'requlre': ['requlres', 'requlred', 'requlrement', 'requlrements'],
 'requlsit': {'requlsite': []},
 'requlslt': {'requlslte': []},
 'reqult': {'requlte': []},
 'requn': {'requne': ['requned', 'requnes']},
 'requne': ['requned', 'requnes'],
 'requost': {'requosted': []},
 'requot': {'requotation': ['requotations'],
            'requote': ['requotes', 'requoted'],
            'requoting': []},
 'requotation': ['requotations'],
 'requote': ['requotes', 'requoted'],
 'requr': {'requre': ['requred', 'requres', 'requrement', 'requrements'],
           'requring': [],
           'requrred': []},
 'requre': ['requred', 'requres', 'requrement', 'requrements'],
 'requrest': {'requrested': []},
 'requri': {'requrie': ['requried', 'requries', 'requriement', 'requriements'],
            'requriments': []},
 'requrie': ['requried', 'requries', 'requriement', 'requriements'],
 'requrr': {'requrre': ['requrres', 'requrrements']},
 'requrre': ['requrres', 'requrrements'],
 'requrt': {'requrted': []},
 'requs': {'reqused': []},
 'requsit': {'requsite': ['requsites'], 'requsition': ['requsitions']},
 'requsite': ['requsites'],
 'requsition': ['requsitions'],
 'requsst': {'requssted': []},
 'requst': {'requsted': [], 'requstes': [], 'requsting': [], 'requsts': []},
 'requt': {'requted': []},
 'requtr': {'requtre': ['requtred', 'requtres', 'requtrement', 'requtrements']},
 'requtre': ['requtred', 'requtres', 'requtrement', 'requtrements'],
 'requu': {'requue': ['requued']},
 'requue': ['requued'],
 'requv': {'requved': []},
 'requw': {'requwed': []},
 'requy': {'requyer': []},
 'requyr': {'requyre': ['requyred', 'requyres', 'requyreing'], 'requyring': []},
 'requyre': ['requyred', 'requyres', 'requyreing'],
 'requyri': {'requyris': []},
 'requyring': {'requyringe': []},
 'requysit': {'requysite': []},
 'requysyt': {'requysyte': []},
 'requyt': {'requyte': ['requyted'], 'requyting': []},
 'requyte': ['requyted'],
 'reqvi': {'reqvies': []},
 'reqviir': {'reqviire': ['reqviired']},
 'reqviire': ['reqviired'],
 'reqvir': {'reqvired': []},
 'reqwr': {'reqwred': []},
 'rer': {'rerful': [], 'rerred': [], 'rers': []},
 'rera': {'rerae': [], 'reras': []},
 'reraain': {'reraained': []},
 'rerac': {'rerace': [], 'reracity': []},
 'reraci': {'reracialization': [], 'reracialized': []},
 'rerack': {'reracked': [], 'reracking': []},
 'reract': {'reraction': []},
 'reradi': {'reradiate': ['reradiated', 'reradiates'],
            'reradiating': [],
            'reradiation': ['reradiations'],
            'reradiative': [],
            'reradiator': ['reradiators']},
 'reradiate': ['reradiated', 'reradiates'],
 'reradiation': ['reradiations'],
 'reradiator': ['reradiators'],
 'reradic': {'reradicalization': [], 'reradicalize': ['reradicalized']},
 'reradicalize': ['reradicalized'],
 'rerag': {'rerage': ['rerages']},
 'rerage': ['rerages'],
 'rerail': {'rerailed': [], 'rerailer': ['rerailers'], 'rerailing': []},
 'rerailer': ['rerailers'],
 'rerain': {'rerained': [], 'reraining': [], 'rerains': []},
 'rerais': {'reraise': ['reraises', 'reraised', 'reraiser'], 'reraising': []},
 'reraise': ['reraises', 'reraised', 'reraiser'],
 'rerak': {'reraked': [], 'reraking': []},
 'reral': {'rerall': []},
 'rerali': {'reraliation': []},
 'rerandom': {'rerandomization': [],
              'rerandomize': ['rerandomized'],
              'rerandomizing': []},
 'rerandomize': ['rerandomized'],
 'rerank': {'reranked': [], 'reranking': ['rerankings'], 'reranks': []},
 'reranking': ['rerankings'],
 'reraov': {'reraoved': []},
 'rerard': {'rerardation': [], 'rerarded': [], 'rerarding': []},
 'rerat': {'rerate': ['rerates', 'rerated'],
           'rerating': ['reratings'],
           'reration': ['rerations']},
 'rerate': ['rerates', 'rerated'],
 'reratif': {'reratification': []},
 'reratifi': {'reratified': [], 'reratify': []},
 'rerating': ['reratings'],
 'reration': {'rerationalization': [], 'rerationalize': ['rerationalized']},
 'rerationalize': ['rerationalized'],
 'rerb': {'rerbs': []},
 'rerby': {'rerbye': []},
 'rerc': {'rerce': ['rerces']},
 'rercdo': {'rercdos': []},
 'rerce': ['rerces'],
 'rerceiv': {'rerceived': []},
 'rercentag': {'rercentage': []},
 'rerch': {'rerched': []},
 'rerci': {'rercy': []},
 'rercsbi': {'rercsby': []},
 'rerd': {'rerde': ['rerded'], 'rerding': [], 'rerds': []},
 'rerde': ['rerded'],
 'rerdel': {'rerdell': []},
 'rerder': {'rerdered': []},
 'rerdili': {'rerdily': []},
 'rerdur': {'rerdure': []},
 'rere': {'rered': [], 'reree': [], 'rerely': [], 'reres': [], 'rering': []},
 'rereach': {'rereached': []},
 'rereact': {'rereaction': []},
 'reread': {'rereadability': [],
            'rereadable': [],
            'rereader': ['rereaders'],
            'rereading': ['rereadings'],
            'rereads': []},
 'rereader': ['rereaders'],
 'rereading': ['rereadings'],
 'rereadmiral': {'rereadmirall': []},
 'rereal': {'rerealed': [],
            'rerealization': [],
            'rerealized': [],
            'rereals': []},
 'reream': {'rereaming': []},
 'rerearch': {'rerearches': []},
 'rereat': {'rereated': []},
 'rerebr': {'rerebral': []},
 'rerebrac': {'rerebrace': []},
 'rerec': {'rereceive': ['rereceives'], 'rerecently': []},
 'rerecal': {'rerecalled': []},
 'rereceipt': {'rereceipts': []},
 'rereceiv': {'rereceived': [], 'rereceiving': []},
 'rereceive': ['rereceives'],
 'rerecept': {'rereception': []},
 'rerecogn': {'rerecognize': ['rerecognized']},
 'rerecognit': {'rerecognition': []},
 'rerecognize': ['rerecognized'],
 'rerecord': {'rerecordable': [],
              'rerecorded': [],
              'rerecording': ['rerecordings'],
              'rerecords': []},
 'rerecording': ['rerecordings'],
 'rerecov': {'rerecovered': []},
 'rerecoveri': {'rerecovery': []},
 'rerecruit': {'rerecruited': [], 'rerecruiting': [], 'rerecruitment': []},
 'rerecurr': {'rerecurrence': []},
 'reredo': {'reredoes': [], 'reredos': []},
 'reredort': {'reredorter': ['reredorters']},
 'reredorter': ['reredorters'],
 'reredos': ['reredosse'],
 'reredoss': {'reredos': ['reredosse']},
 'rereduc': {'rereduce': ['rereduced'], 'rereducing': []},
 'rereduce': ['rereduced'],
 'rereduct': {'rereduction': []},
 'rereel': {'rereeled': [], 'rereeling': []},
 'reref': {'rerefence': [], 'rerefer': ['rereferred', 'rereferring']},
 'rerefer': {'rereference': []},
 'rereferenc': {'rereferenced': []},
 'rereferr': {'rereferral': []},
 'rerefin': {'rerefined': [], 'rerefining': []},
 'rereflect': {'rereflected': [],
               'rereflecting': [],
               'rereflection': ['rereflections']},
 'rereflection': ['rereflections'],
 'rereform': {'rereformed': []},
 'rerefus': {'rerefused': []},
 'reregard': {'reregarded': [], 'reregarding': []},
 'reregist': {'reregister': ['reregisters', 'reregistered', 'reregistering']},
 'reregister': ['reregisters', 'reregistered', 'reregistering'],
 'reregistr': {'reregistration': ['reregistrations']},
 'reregistration': ['reregistrations'],
 'reregistri': {'reregistry': []},
 'reregul': {'reregulate': ['reregulated', 'reregulates'],
             'reregulating': [],
             'reregulation': ['reregulations']},
 'reregulate': ['reregulated', 'reregulates'],
 'reregulation': ['reregulations'],
 'reregulatori': {'reregulatory': []},
 'rerehears': {'rerehearse': ['rerehearsed'], 'rerehearsing': []},
 'rerehearse': ['rerehearsed'],
 'rereiv': {'rereive': ['rereives', 'rereiver', 'rereived'], 'rereiving': []},
 'rereive': ['rereives', 'rereiver', 'rereived'],
 'rereject': {'rerejected': []},
 'rerel': {'rerelate': ['rerelated'],
           'rerelating': [],
           'rerelation': ['rerelations'],
           'rerell': [],
           'rerels': []},
 'rerelate': ['rerelated'],
 'rerelation': ['rerelations'],
 'rereleas': {'rerelease': ['rereleases', 'rereleased'], 'rereleasing': []},
 'rerelease': ['rereleases', 'rereleased'],
 'rereliev': {'rerelieved': []},
 'rereligi': {'rereligious': []},
 'reremain': {'reremained': [], 'reremaining': [], 'reremains': []},
 'reremaind': {'reremainder': []},
 'reremark': {'reremarkable': [],
              'reremarkably': [],
              'reremarked': [],
              'reremarks': []},
 'rerememb': {'reremember': ['reremembered', 'reremembering']},
 'reremember': ['reremembered', 'reremembering'],
 'rerement': {'rerements': []},
 'reremic': {'reremice': []},
 'reremind': {'rereminded': []},
 'reremoni': {'reremony': []},
 'reremous': {'reremouse': []},
 'reremov': {'reremoval': [], 'reremove': ['reremoved']},
 'reremove': ['reremoved'],
 'rerenc': {'rerence': ['rerences']},
 'rerence': ['rerences'],
 'rerend': {'rerender': ['rerenders',
                         'rerendered',
                         'rerendering',
                         'rerenderings']},
 'rerender': ['rerenders', 'rerendered', 'rerendering', 'rerenderings'],
 'rerenew': {'rerenewed': []},
 'rereng': {'rerenge': []},
 'rerenn': {'rerenne': []},
 'rerent': {'rerental': [],
            'rerented': [],
            'rerenting': [],
            'rerention': [],
            'rerently': [],
            'rerents': []},
 'rerenu': {'rerenue': ['rerenues']},
 'rerenue': ['rerenues'],
 'rerep': {'rerepealed': [], 'rerepeated': [], 'rerepeating': []},
 'rerepair': {'rerepaired': []},
 'rerepl': {'rereplicate': [], 'rereplication': []},
 'rereplac': {'rereplaced': [], 'rereplacement': []},
 'rerepli': {'rereplied': []},
 'rereport': {'rereported': [], 'rereporting': [], 'rereports': []},
 'rerepres': {'rerepresent': ['rerepresents',
                              'rerepresented',
                              'rerepresenting',
                              'rerepresentative']},
 'rerepresent': {'rerepresentation': ['rerepresentations']},
 'rerepresentation': ['rerepresentations'],
 'rerepress': {'rerepressed': [], 'rerepression': []},
 'rereprint': {'rereprinted': []},
 'rereproduc': {'rereproduced': []},
 'rerept': {'rereption': []},
 'rerequest': {'rerequested': [], 'rerequesting': [], 'rerequests': []},
 'rerequir': {'rerequire': ['rerequired',
                            'rerequires',
                            'rerequirement',
                            'rerequirements'],
              'rerequiring': []},
 'rerequire': ['rerequired', 'rerequires', 'rerequirement', 'rerequirements'],
 'rerequisit': {'rerequisite': ['rerequisites']},
 'rerequisite': ['rerequisites'],
 'rerer': {'rerere': ['rerered', 'rererence', 'rererences'],
           'rererred': [],
           'rerers': []},
 'rerere': {'rereree': []},
 'rerers': {'rererse': ['rerersed']},
 'rererse': ['rerersed'],
 'rererv': {'rererve': ['rererved']},
 'rererve': ['rererved'],
 'reres': {'reresent': ['reresents',
                        'reresented',
                        'reresenting',
                        'reresentative',
                        'reresentatives']},
 'reresbi': {'reresby': ['reresbys']},
 'reresby': ['reresbys'],
 'reresect': {'reresection': []},
 'reresembl': {'reresemblance': []},
 'reresent': {'reresentation': []},
 'rereserv': {'rereserved': [], 'rereserves': []},
 'rereshi': {'rereshy': []},
 'reresist': {'reresistance': []},
 'reresolut': {'reresolution': []},
 'reresolv': {'reresolve': ['reresolved'], 'reresolving': []},
 'reresolve': ['reresolved'],
 'reresourc': {'reresources': []},
 'rerespect': {'rerespecting': [], 'rerespective': ['rerespectively']},
 'rerespective': ['rerespectively'],
 'rerespons': {'reresponse': [], 'reresponsibility': [], 'reresponsible': []},
 'reress': {'reression': []},
 'rerestor': {'rerestoration': [], 'rerestored': []},
 'rerestrict': {'rerestricted': []},
 'reresult': {'reresulted': [], 'reresulting': [], 'reresults': []},
 'reresum': {'reresumed': []},
 'reresupp': {'reresupper': []},
 'reretain': {'reretained': []},
 'reretir': {'reretired': []},
 'rereturn': {'rereturned': [], 'rereturning': [], 'rereturns': []},
 'rerev': {'rerevealed': [], 'rereveals': []},
 'rerevers': {'rereversal': [], 'rereversed': []},
 'rereview': {'rereviewed': [], 'rereviewing': [], 'rereviews': []},
 'rerevis': {'rerevised': [], 'rerevising': [], 'rerevision': ['rerevisions']},
 'rerevision': ['rerevisions'],
 'rerevolutionari': {'rerevolutionary': []},
 'rereward': {'rerewarde': []},
 'rerewrit': {'rerewriting': []},
 'rerfer': {'rerference': []},
 'rerform': {'rerformance': [], 'rerformed': []},
 'rerg': {'rerge': []},
 'rerhap': {'rerhaps': []},
 'rerherch': {'rerherches': []},
 'rerhink': {'rerhinking': []},
 'rerhov': {'rerhoved': []},
 'reri': {'rerie': ['reries'], 'reris': [], 'rery': ['rerying']},
 'reric': {'rericence': []},
 'rericht': {'rerichte': []},
 'rerid': {'reride': ['rerider', 'rerides', 'reridered'], 'reriding': []},
 'reride': ['rerider', 'rerides', 'reridered'],
 'rerie': ['reries'],
 'reriei': {'rerieie': []},
 'reriew': {'reriewed': [], 'reriews': []},
 'rerifi': {'rerified': [], 'rerify': []},
 'rerifl': {'rerifled': []},
 'rerig': {'rerigged': [], 'rerigging': []},
 'reright': {'rerighting': [], 'rerights': []},
 'rerigoniu': {'rerigonius': []},
 'rerili': {'rerily': []},
 'rerin': {'rerined': []},
 'rering': {'reringing': []},
 'rerino': {'rerinoic': []},
 'rerins': {'rerinse': ['rerinsed'], 'rerinsing': []},
 'rerinse': ['rerinsed'],
 'rerint': {'rerinted': []},
 'reriod': {'reriods': []},
 'rerion': {'rerional': [], 'rerions': []},
 'reriou': {'rerious': []},
 'rerir': {'rerire': ['rerired', 'rerirement'], 'reriring': []},
 'rerire': ['rerired', 'rerirement'],
 'reris': {'rerise': ['rerised'], 'rerising': [], 'rerision': []},
 'rerise': ['rerised'],
 'rerist': {'reristance': []},
 'rerit': {'rerited': [], 'reritement': [], 'rerits': []},
 'rerita': {'reritas': []},
 'reritati': {'reritatis': []},
 'reriti': {'rerity': []},
 'reritu': {'reritualization': []},
 'reriv': {'rerival': [], 'rerive': ['rerived']},
 'rerive': ['rerived'],
 'rerivet': {'reriveted': []},
 'rerk': {'rerks': []},
 'rerkshir': {'rerkshire': []},
 'rerl': {'rerle': ['rerled']},
 'rerle': ['rerled'],
 'rerlect': {'rerlected': [], 'rerlection': []},
 'rerli': {'rerly': []},
 'rerlli': {'rerlly': []},
 'rerm': {'rermed': [], 'rermes': [], 'rerms': []},
 'rerman': {'rermanent': [], 'rermans': []},
 'rermani': {'rermany': []},
 'rermi': {'rermie': []},
 'rermin': {'rerminal': ['rerminals'], 'rerminating': [], 'rermination': []},
 'rerminal': ['rerminals'],
 'rerminar': {'rerminare': ['rerminared']},
 'rerminare': ['rerminared'],
 'rerminolog': {'rerminology': []},
 'rermiss': {'rermission': []},
 'rern': {'rerne': ['rerned'], 'rerning': [], 'rerns': []},
 'rernadott': {'rernadotte': []},
 'rernain': {'rernained': [], 'rernaining': [], 'rernains': []},
 'rernaind': {'rernainder': []},
 'rernark': {'rernarkable': [],
             'rernarkably': [],
             'rernarked': [],
             'rernarks': []},
 'rerne': ['rerned'],
 'rernedi': {'rernedies': [], 'rernedy': []},
 'rernemb': {'rernember': ['rernembered']},
 'rernember': ['rernembered'],
 'rerni': {'rernie': [], 'rerny': []},
 'rernic': {'rernice': []},
 'rernind': {'rerninded': [],
             'rerninder': [],
             'rerninding': [],
             'rerninds': []},
 'rerninisc': {'rerniniscence': ['rerniniscences'],
               'rerniniscent': ['rerniniscently']},
 'rerniniscence': ['rerniniscences'],
 'rerniniscent': ['rerniniscently'],
 'rernment': {'rernments': []},
 'rernot': {'rernote': []},
 'rernov': {'rernoval': [], 'rernove': ['rernoved'], 'rernoving': []},
 'rernove': ['rernoved'],
 'rero': {'reros': []},
 'reroast': {'reroasted': [], 'reroasting': []},
 'rerob': {'rerobe': ['rerobed'], 'rerobing': []},
 'rerobe': ['rerobed'],
 'rerog': {'rerogative': ['rerogatives']},
 'rerogative': ['rerogatives'],
 'rerogn': {'rerognize': ['rerognized']},
 'rerognit': {'rerognition': []},
 'rerognize': ['rerognized'],
 'rerok': {'reroked': []},
 'rerol': {'reroll': ['rerolls',
                      'rerolle',
                      'reroller',
                      'rerolled',
                      'rerolling',
                      'rerollers',
                      'rerollable']},
 'reroll': ['rerolls',
            'rerolle',
            'reroller',
            'rerolled',
            'rerolling',
            'rerollers',
            'rerollable'],
 'rerolnt': {'rerolntion': []},
 'rerolut': {'rerolution': ['rerolutions']},
 'rerolution': ['rerolutions'],
 'rerolutionari': {'rerolutionary': []},
 'rerolv': {'rerolve': ['rerolved']},
 'rerolve': ['rerolved'],
 'reromantic': {'reromanticizing': []},
 'rerommend': {'rerommended': []},
 'reronstruct': {'reronstruction': []},
 'reroof': {'reroofed': [], 'reroofing': []},
 'reroot': {'rerooted': [], 'rerooting': [], 'reroots': []},
 'rerord': {'rerorded': [], 'rerording': [], 'rerords': []},
 'rerorm': {'rerorms': []},
 'rerort': {'rerorted': [], 'rerorts': []},
 'rerot': {'rerotated': [], 'rerotation': []},
 'rerou': {'rerous': []},
 'reround': {'rerounded': [], 'rerounding': []},
 'rerourc': {'rerources': []},
 'rerout': {'reroutable': [],
            'reroute': ['rerouted', 'reroutes', 'rerouteing'],
            'rerouting': ['reroutings']},
 'reroute': ['rerouted', 'reroutes', 'rerouteing'],
 'rerouting': ['reroutings'],
 'rerov': {'rerove': ['reroved', 'rerover', 'rerovered']},
 'rerove': ['reroved', 'rerover', 'rerovered'],
 'reroveri': {'rerovery': []},
 'rerpect': {'rerpective': ['rerpectively']},
 'rerpective': ['rerpectively'],
 'rerpiir': {'rerpiired': []},
 'rerpons': {'rerponse': []},
 'rerr': {'rerre': []},
 'rerrac': {'rerrace': []},
 'rerrain': {'rerraining': []},
 'rerreat': {'rerreating': []},
 'rerri': {'rerrie': [], 'rerry': []},
 'rerriain': {'rerriained': [], 'rerriaining': []},
 'rerribl': {'rerrible': [], 'rerribly': []},
 'rerriev': {'rerrieval': [], 'rerrieve': ['rerrieved']},
 'rerrieve': ['rerrieved'],
 'rerrif': {'rerrific': []},
 'rerrifi': {'rerrified': []},
 'rerritori': {'rerritorial': [], 'rerritories': [], 'rerritory': []},
 'rerrmant': {'rerrmants': []},
 'rerror': {'rerrorism': []},
 'rerrospect': {'rerrospective': ['rerrospectively']},
 'rerrospective': ['rerrospectively'],
 'rerrov': {'rerrove': ['rerroved']},
 'rerrove': ['rerroved'],
 'rers': {'rerse': ['rerses', 'rersed']},
 'rersat': {'rersation': []},
 'rerse': ['rerses', 'rersed'],
 'rerserv': {'rerserve': []},
 'rersion': {'rersions': []},
 'rersiti': {'rersity': []},
 'rerson': {'rersonal': [], 'rersons': []},
 'rersourc': {'rersources': []},
 'rersu': {'rersus': []},
 'rert': {'rerte': ['rerted'], 'rerts': []},
 'rertainli': {'rertainly': []},
 'rertainti': {'rertainty': []},
 'rerte': ['rerted'],
 'rertebr': {'rertebral': []},
 'rerti': {'rerty': []},
 'rertiari': {'rertiary': []},
 'rertibl': {'rertible': []},
 'rertic': {'rertical': ['rertically']},
 'rertical': ['rertically'],
 'rertiev': {'rertieval': []},
 'rertifi': {'rertified': [], 'rertifying': []},
 'rertil': {'rertility': []},
 'rertitori': {'rertitory': []},
 'rertitoti': {'rertitotial': [], 'rertitoties': [], 'rertitoty': []},
 'rertor': {'rertored': []},
 'rertu': {'rertue': []},
 'reru': {'rerue': []},
 'rerub': {'rerubbed': []},
 'rerubl': {'rerublic': []},
 'rerug': {'reruge': []},
 'reruge': {'rerugees': []},
 'reruir': {'reruire': ['reruired']},
 'reruire': ['reruired'],
 'reruit': {'reruited': [], 'reruitment': []},
 'rerult': {'rerults': []},
 'rerum': {'rerumed': [], 'rerums': []},
 'rerumqu': {'rerumque': []},
 'rerun': ['rerunning'],
 'reruptur': {'rerupture': ['reruptures', 'reruptured']},
 'rerupture': ['reruptures', 'reruptured'],
 'rerur': {'reruralization': []},
 'rerurn': {'rerurne': ['rerurned'], 'rerurning': [], 'rerurns': []},
 'rerurne': ['rerurned'],
 'rerus': {'reruse': ['rerused']},
 'reruse': ['rerused'],
 'rerv': {'rerve': ['rerved', 'rerves']},
 'rervant': {'rervants': []},
 'rerve': ['rerved', 'rerves'],
 'rervic': {'rervice': ['rervices']},
 'rervice': ['rervices'],
 'rervou': {'rervous': []},
 'rery': ['rerying'],
 'rerybodi': {'rerybody': []},
 'reryon': {'reryone': []},
 'reryth': {'rerything': []},
 'res': ['resse', 'ressed', 'ressing', 'ressings'],
 'resa': {'resas': []},
 'resabio': {'resabios': []},
 'resaca': {'resacas': []},
 'resacetophenon': {'resacetophenone': []},
 'resack': {'resacked': [], 'resacking': []},
 'resacr': {'resacralization': [],
            'resacralize': ['resacralized', 'resacralizes'],
            'resacralizing': []},
 'resacralis': {'resacralisation': [],
                'resacralise': ['resacralised'],
                'resacralising': []},
 'resacralise': ['resacralised'],
 'resacralize': ['resacralized', 'resacralizes'],
 'resacrif': {'resacrificed': []},
 'resacril': {'resacrilization': []},
 'resad': {'resadence': []},
 'resaddl': {'resaddle': ['resaddled'], 'resaddling': []},
 'resaddle': ['resaddled'],
 'resadiy': {'resadiye': []},
 'resai': {'resais': []},
 'resaignar': {'resaignare': []},
 'resail': {'resailed': [], 'resailing': []},
 'resain': {'resained': []},
 'resaiv': {'resaive': ['resaived']},
 'resaive': ['resaived'],
 'resal': {'resalability': [],
           'resalable': [],
           'resale': ['resaler', 'resalers', 'resaleable', 'resaleability']},
 'resale': ['resaler', 'resalers', 'resaleable', 'resaleability'],
 'resalepric': {'resaleprice': []},
 'resalin': {'resalination': [], 'resalinization': []},
 'resalt': {'resalte': ['resalted'], 'resalting': [], 'resalts': []},
 'resalte': ['resalted'],
 'resalut': {'resalute': ['resaluted'], 'resaluting': [], 'resalution': []},
 'resalute': ['resaluted'],
 'resalv': {'resalve': ['resalved']},
 'resalve': ['resalved'],
 'resam': {'resame': []},
 'resambl': {'resamble': ['resambles']},
 'resamble': ['resambles'],
 'resampl': {'resample': ['resamples', 'resampler', 'resampled'],
             'resampling': ['resamplings']},
 'resample': ['resamples', 'resampler', 'resampled'],
 'resampling': ['resamplings'],
 'resan': {'resanation': []},
 'resanct': {'resanctioned': []},
 'resanctif': {'resanctification': []},
 'resanctifi': {'resanctified': [],
                'resanctifies': [],
                'resanctify': ['resanctifying']},
 'resanctify': ['resanctifying'],
 'resand': {'resande': ['resanded'], 'resanding': []},
 'resande': ['resanded'],
 'resanit': {'resanitized': []},
 'resaon': {'resaonable': [], 'resaonably': [], 'resaons': []},
 'resar': {'resare': []},
 'resarch': {'resarcher': ['resarchers'], 'resarches': []},
 'resarcher': ['resarchers'],
 'resarcir': {'resarcire': []},
 'resarcirs': {'resarcirse': []},
 'resard': {'resarded': [], 'resarding': [], 'resards': []},
 'resariu': {'resarius': []},
 'resarlu': {'resarlus': []},
 'resartn': {'resartns': []},
 'resartti': {'resarttis': []},
 'resartu': {'resartus': []},
 'resarv': {'resarve': ['resarved', 'resarves']},
 'resarve': ['resarved', 'resarves'],
 'resason': {'resasonable': [], 'resasonably': [], 'resasons': []},
 'resat': {'resate': []},
 'resatel': {'resatellization': []},
 'resatisfact': {'resatisfaction': []},
 'resatisfi': {'resatisfied': [], 'resatisfy': ['resatisfying']},
 'resatisfy': ['resatisfying'],
 'resatur': {'resaturants': [],
             'resaturate': ['resaturates', 'resaturated'],
             'resaturating': [],
             'resaturation': []},
 'resaturate': ['resaturates', 'resaturated'],
 'resau': {'resaue': ['resaued']},
 'resaue': ['resaued'],
 'resaur': {'resaurant': ['resaurants']},
 'resaurant': ['resaurants'],
 'resaurc': {'resaurces': []},
 'resav': {'resave': ['resaves', 'resaved'], 'resaving': []},
 'resavag': {'resavage': []},
 'resavanj': {'resavanje': []},
 'resave': ['resaves', 'resaved'],
 'resavour': {'resavouring': []},
 'resaw': {'resawed': [], 'resawing': [], 'resaws': []},
 'resay': {'resaying': [], 'resays': []},
 'resayv': {'resayve': []},
 'resbal': {'resbale': []},
 'resbaudi': {'resbaudis': []},
 'resbi': {'resby': []},
 'resblut': {'resblution': []},
 'resblv': {'resblved': []},
 'resbridg': {'resbridger': []},
 'resburc': {'resburces': []},
 'resburi': {'resbury': []},
 'resbyteri': {'resbytery': []},
 'resbyterian': {'resbyterianism': [], 'resbyterians': []},
 'resc': {'resce': ['resced', 'resces'], 'rescing': []},
 'rescal': {'rescalable': [],
            'rescale': ['rescaled', 'rescales'],
            'rescaling': ['rescalings'],
            'rescalli': [],
            'rescals': []},
 'rescale': ['rescaled', 'rescales'],
 'rescaling': ['rescalings'],
 'rescan': {'rescanned': [], 'rescanning': [], 'rescans': []},
 'rescanier': {'rescaniere': []},
 'rescap': {'rescape': ['rescapes'], 'rescaps': []},
 'rescape': ['rescapes'],
 'rescar': {'rescare': []},
 'rescarch': {'rescarches': []},
 'rescat': {'rescate': ['rescates', 'rescated'], 'rescating': []},
 'rescatada': {'rescatadas': []},
 'rescatado': {'rescatados': []},
 'rescatador': {'rescatadores': []},
 'rescate': ['rescates', 'rescated'],
 'rescatista': {'rescatistas': []},
 'rescatt': {'rescatter': ['rescattered', 'rescattering', 'rescatterings']},
 'rescatter': ['rescattered', 'rescattering', 'rescatterings'],
 'rescaui': {'rescauied': []},
 'resce': ['resced', 'resces'],
 'rescebiamo': {'rescebiamos': []},
 'resceiv': {'resceived': []},
 'rescen': {'rescens': []},
 'rescenc': {'rescence': ['rescences']},
 'rescence': ['rescences'],
 'rescens': {'rescension': ['rescensions']},
 'rescension': ['rescensions'],
 'rescent': {'rescented': [], 'rescently': [], 'rescents': []},
 'resceptacl': {'resceptacle': []},
 'rescess': {'rescession': []},
 'resceyu': {'resceyue': ['resceyued']},
 'resceyue': ['resceyued'],
 'resceyv': {'resceyve': ['resceyved']},
 'resceyve': ['resceyved'],
 'resch': {'resche': ['resches', 'resched'], 'resching': [], 'reschs': []},
 'resche': ['resches', 'resched'],
 'reschedul': {'reschedulable': [],
               'reschedule': ['rescheduled',
                              'rescheduler',
                              'reschedules',
                              'reschedulers',
                              'reschedulement'],
               'rescheduling': ['reschedulings']},
 'reschedule': ['rescheduled',
                'rescheduler',
                'reschedules',
                'reschedulers',
                'reschedulement'],
 'rescheduling': ['reschedulings'],
 'reschemat': {'reschematization': [], 'reschematize': []},
 'reschenthal': {'reschenthaler': []},
 'rescher': {'reschers': []},
 'rescherch': {'rescherche': ['rescherches']},
 'rescherche': ['rescherches'],
 'reschk': {'reschke': []},
 'reschli': {'reschly': []},
 'reschni': {'reschny': []},
 'reschofski': {'reschofsky': []},
 'reschool': {'reschooled': [], 'reschooling': []},
 'reschovski': {'reschovsky': []},
 'reschylu': {'reschylus': []},
 'resci': {'rescis': []},
 'rescib': {'rescibe': []},
 'rescibido': {'rescibidos': []},
 'rescienc': {'rescience': []},
 'rescieri': {'rescieris': []},
 'rescin': {'rescined': [], 'resciniti': []},
 'rescind': {'rescindable': [],
             'rescinded': [],
             'rescinder': ['rescinders'],
             'rescindible': [],
             'rescinding': ['rescindings'],
             'rescindment': [],
             'rescinds': []},
 'rescinden': {'rescindens': []},
 'rescinder': {'rescindere': []},
 'rescindi': {'rescindis': []},
 'rescindimu': {'rescindimus': []},
 'rescinding': ['rescindings'],
 'rescinnamin': {'rescinnamine': []},
 'rescir': {'rescire': []},
 'rescis': {'rescision': []},
 'resciss': {'rescissible': [], 'rescission': []},
 'rescission': {'rescissional': [], 'rescissione': []},
 'rescissionari': {'rescissionary': []},
 'rescissori': {'rescissory': []},
 'resciu': {'rescius': []},
 'resclut': {'resclution': []},
 'resclv': {'resclved': []},
 'rescn': {'rescne': ['rescned']},
 'rescne': ['rescned'],
 'resco': {'rescoe': ['rescoes'], 'rescos': []},
 'rescobi': {'rescobie': []},
 'rescoe': ['rescoes'],
 'rescogitan': {'rescogitans': []},
 'rescoldo': {'rescoldos': []},
 'rescons': {'resconse': []},
 'resconstruct': {'resconstruction': []},
 'rescop': {'rescope': ['rescoped'], 'rescoping': []},
 'rescope': ['rescoped'],
 'rescopi': {'rescopy': []},
 'rescor': {'rescore': ['rescored', 'rescores'], 'rescoring': ['rescorings']},
 'rescore': ['rescored', 'rescores'],
 'rescorifi': {'rescorified': [], 'rescorify': []},
 'rescoring': ['rescorings'],
 'rescorlawagn': {'rescorlawagner': []},
 'rescou': {'rescous': []},
 'rescount': {'rescounter': ['rescounters']},
 'rescounter': ['rescounters'],
 'rescour': {'rescoured': []},
 'rescourc': {'rescource': ['rescources']},
 'rescource': ['rescources'],
 'rescours': {'rescourse': []},
 'rescouss': {'rescousse': []},
 'rescow': {'rescowe': ['rescowed']},
 'rescowe': ['rescowed'],
 'rescrambl': {'rescramble': ['rescrambled'], 'rescrambling': []},
 'rescramble': ['rescrambled'],
 'rescrap': {'rescrape': ['rescraped'], 'rescraping': []},
 'rescrape': ['rescraped'],
 'rescratch': {'rescratched': []},
 'rescreen': {'rescreened': [],
              'rescreening': ['rescreenings'],
              'rescreens': []},
 'rescreening': ['rescreenings'],
 'rescrew': {'rescrewed': [], 'rescrewing': []},
 'rescrib': {'rescribe': ['rescribed', 'rescribes'], 'rescribing': []},
 'rescriba': {'rescribas': []},
 'rescribati': {'rescribatis': []},
 'rescribe': ['rescribed', 'rescribes'],
 'rescribendi': {'rescribendis': []},
 'rescriber': {'rescribere': []},
 'rescripsimu': {'rescripsimus': []},
 'rescripsiss': {'rescripsisse': []},
 'rescript': ['rescripted',
              'rescription',
              'rescriptive',
              'rescripting',
              'rescriptings',
              'rescriptions'],
 'rescripti': {'rescriptis': []},
 'rescripto': {'rescriptos': []},
 'rescriptu': {'rescriptus': []},
 'rescrit': {'rescrits': []},
 'rescrpin': {'rescrpine': []},
 'rescrub': {'rescrubbed': [], 'rescrubbing': []},
 'rescrutin': {'rescrutinize': ['rescrutinized'], 'rescrutinizing': []},
 'rescrutini': {'rescrutiny': []},
 'rescrutinis': {'rescrutinised': []},
 'rescrutinize': ['rescrutinized'],
 'rescrv': {'rescrve': ['rescrved']},
 'rescrve': ['rescrved'],
 'rescrved': {'rescrvedness': []},
 'resction': {'resctions': []},
 'rescu': {'rescue': ['rescued', 'rescueing'],
           'rescuing': ['rescuings'],
           'rescus': []},
 'rescuabl': {'rescuability': [], 'rescuable': []},
 'rescucit': {'rescucitation': []},
 'rescudos': {'rescudose': []},
 'rescue': {'rescuee': ['rescuees']},
 'rescuee': ['rescuees'],
 'rescueparti': {'rescueparty': []},
 'rescuer': {'rescuer': []},
 'rescuing': ['rescuings'],
 'resculpt': {'resculpted': [], 'resculpting': [], 'resculpts': []},
 'resculptur': {'resculpture': ['resculptured'], 'resculpturing': []},
 'resculpture': ['resculptured'],
 'rescur': {'rescure': ['rescurer', 'rescured', 'rescurers'], 'rescuring': []},
 'rescurc': {'rescurces': []},
 'rescure': ['rescurer', 'rescured', 'rescurers'],
 'rescus': {'rescusants': [], 'rescused': []},
 'rescuscit': {'rescuscitate': ['rescuscitated'], 'rescuscitation': []},
 'rescuscitate': ['rescuscitated'],
 'rescusit': {'rescusitate': ['rescusitated'], 'rescusitation': []},
 'rescusitate': ['rescusitated'],
 'rescuyng': {'rescuynge': []},
 'resd': {'resde': [], 'resding': ['resdings'], 'resds': []},
 'resdect': {'resdective': ['resdectively'], 'resdects': []},
 'resdective': ['resdectively'],
 'resdenc': {'resdence': []},
 'resdent': {'resdents': []},
 'resdenti': {'resdential': []},
 'resder': {'resders': []},
 'resdess': {'resdessness': []},
 'resdessli': {'resdessly': []},
 'resdi': {'resdy': []},
 'resdili': {'resdily': []},
 'resding': ['resdings'],
 'resdistribut': {'resdistribution': []},
 'resdlt': {'resdlts': []},
 'resdond': {'resdondents': []},
 'resdons': {'resdonse': ['resdonses'],
             'resdonsibilities': [],
             'resdonsibility': [],
             'resdonsible': []},
 'resdonse': ['resdonses'],
 'resdt': {'resdts': []},
 'resdu': {'resdue': []},
 'resdurc': {'resdurces': []},
 'rese': {'res': ['resee',
                  'resed',
                  'resees',
                  'resing',
                  'reseed',
                  'reseeds',
                  'resings',
                  'reseeing']},
 'reseabl': {'reseable': ['reseables']},
 'reseable': ['reseables'],
 'reseach': {'reseached': [],
             'reseacher': ['reseachers'],
             'reseaches': [],
             'reseaching': []},
 'reseacher': ['reseachers'],
 'reseaich': {'reseaichers': [], 'reseaiches': []},
 'reseal': {'resealability': [],
            'resealable': [],
            'resealed': [],
            'resealing': [],
            'reseals': []},
 'reseam': {'reseamed': []},
 'researc': {'researce': []},
 'researcb': {'researcbes': []},
 'research': ['researche',
              'researched',
              'researcher',
              'researching',
              'researchful',
              'researchable',
              'researchings',
              'researchability'],
 'researcha': {'researchas': []},
 'researchact': {'researchaction': [], 'researchactive': []},
 'researchassoci': {'researchassociation': []},
 'researchatmospher': {'researchatmospheres': []},
 'researchbas': {'researchbased': []},
 'researchcent': {'researchcenter': []},
 'researchcentr': {'researchcentre': []},
 'researchcottrel': {'researchcottrell': []},
 'researchdemonstr': {'researchdemonstration': []},
 'researchderiv': {'researchderived': []},
 'researchdevelop': {'researchdevelopment': []},
 'researchdoctor': {'researchdoctorate': []},
 'researche': {'researchee': ['researchees']},
 'researchee': ['researchees'],
 'researcher': {'researcheres': []},
 'researchera': {'researcheras': []},
 'researcherdesign': {'researcherdesigned': []},
 'researcherparticip': {'researcherparticipant': []},
 'researcherpractition': {'researcherpractitioner': []},
 'researcherresearch': {'researcherresearched': []},
 'researchershav': {'researchershave': []},
 'researcherwrit': {'researcherwriter': []},
 'researchet': {'researchets': []},
 'researchfind': {'researchfindings': []},
 'researchfland': {'researchflanders': []},
 'researchfocus': {'researchfocused': []},
 'researchfund': {'researchfunding': []},
 'researchgener': {'researchgenerated': []},
 'researchgrad': {'researchgrade': []},
 'researchha': {'researchhas': []},
 'researchi': {'researchis': [], 'researchy': []},
 'researchinform': {'researchinformed': []},
 'researchinstitut': {'researchinstitute': []},
 'researchintens': {'researchintensive': []},
 'researchinterest': {'researchinterests': []},
 'researchist': {'researchists': []},
 'researchjourn': {'researchjournal': []},
 'researchl': {'researchled': []},
 'researchlik': {'researchlike': []},
 'researchlnstitut': {'researchlnstitute': []},
 'researchmethod': {'researchmethods': []},
 'researchmind': {'researchminded': []},
 'researchminded': {'researchmindedness': []},
 'researchori': {'researchoriented': []},
 'researchorient': {'researchorientated': []},
 'researchpap': {'researchpaper': ['researchpapers']},
 'researchpaper': ['researchpapers'],
 'researchpolici': {'researchpolicy': []},
 'researchpractic': {'researchpractice': []},
 'researchproduct': {'researchproduction': []},
 'researchprogramm': {'researchprogramme': []},
 'researchproject': {'researchprojects': []},
 'researchqu': {'researchquality': []},
 'researchquest': {'researchquestions': []},
 'researchrel': {'researchrelated': []},
 'researchreport': {'researchreports': []},
 'researchsupport': {'researchsupported': []},
 'researchteach': {'researchteaching': []},
 'researchtechnolog': {'researchtechnology': []},
 'researchtyp': {'researchtype': []},
 'researchvalid': {'researchvalidated': []},
 'researchwa': {'researchwas': []},
 'researchwar': {'researchware': []},
 'researchwis': {'researchwise': []},
 'researchwork': {'researchworker': ['researchworkers']},
 'researchworker': ['researchworkers'],
 'researcli': {'researclies': []},
 'researcn': {'researcner': ['researcners'], 'researcnes': []},
 'researcner': ['researcners'],
 'researeh': {'researehed': [],
              'researeher': ['researehers'],
              'researehes': [],
              'researehing': []},
 'researeher': ['researehers'],
 'researh': {'researhers': []},
 'researoh': {'researoher': ['researohers'], 'researohes': []},
 'researoher': ['researohers'],
 'researv': {'researve': ['researves', 'researved']},
 'researve': ['researves', 'researved'],
 'reseason': {'reseasonalized': [], 'reseasoned': [], 'reseasoning': []},
 'reseat': {'reseated': [],
            'reseater': [],
            'reseating': ['reseatings'],
            'reseats': []},
 'reseatch': {'reseatched': [],
              'reseatcher': ['reseatchers'],
              'reseatching': []},
 'reseatcher': ['reseatchers'],
 'reseating': ['reseatings'],
 'reseau': {'reseau': []},
 'reseav': {'reseave': ['reseaved']},
 'reseave': ['reseaved'],
 'resebi': {'reseby': []},
 'resebv': {'resebve': []},
 'resec': {'reseces': []},
 'resecant': {'resecantes': []},
 'resecanti': {'resecantis': []},
 'resecar': {'resecare': []},
 'reseco': {'resecos': []},
 'resecran': {'resecrans': []},
 'resecret': {'resecrete': ['resecreted'], 'resecretion': []},
 'resecrete': ['resecreted'],
 'resect': {'resectability': [],
            'resectable': [],
            'resected': [],
            'resectibility': [],
            'resecting': [],
            'resection': ['resectioned', 'resectional', 'resectioning'],
            'resective': ['resectively'],
            'resects': []},
 'resectabiliri': {'resectabiliry': []},
 'resecti': {'resectis': []},
 'resection': ['resectioned', 'resectional', 'resectioning'],
 'resectionist': {'resectionists': []},
 'resective': ['resectively'],
 'resector': {'resectors': []},
 'resectori': {'resectory': []},
 'resectoscop': {'resectoscope': ['resectoscopes'], 'resectoscopic': []},
 'resectoscope': ['resectoscopes'],
 'resecular': {'resecularization': [], 'resecularized': []},
 'resecur': {'resecure': ['resecured', 'resecures'], 'resecuring': []},
 'resecure': ['resecured', 'resecures'],
 'resecurit': {'resecuritization': []},
 'resed': {'resedated': [], 'resedation': [], 'resede': ['resedence']},
 'reseda': ['resedae'],
 'resedacea': {'resedaceae': []},
 'resedacec': {'resedacece': []},
 'resede': ['resedence'],
 'resedi': {'resediment': ['resediments', 'resedimented', 'resedimenting']},
 'resedifoliu': {'resedifolius': []},
 'resediment': {'resedimentation': []},
 'resediss': {'resedisse': []},
 'resedu': {'resedue': []},
 'reseed': {'reseeded': [],
            'reseeder': ['reseeders'],
            'reseeding': ['reseedings']},
 'reseeder': ['reseeders'],
 'reseeding': ['reseedings'],
 'reseek': {'reseeking': [], 'reseeks': []},
 'reseet': {'reseetion': []},
 'reseev': {'reseeve': ['reseeved']},
 'reseeve': ['reseeved'],
 'reseg': {'resegment': ['resegments', 'resegmented', 'resegmenting']},
 'resegment': {'resegmentation': []},
 'resegon': {'resegone': []},
 'resegreg': {'resegregate': ['resegregates', 'resegregated'],
              'resegregating': [],
              'resegregation': [],
              'resegregative': []},
 'resegregate': ['resegregates', 'resegregated'],
 'resegregationist': {'resegregationists': []},
 'reseh': {'reseher': []},
 'reseign': {'reseignements': []},
 'reseind': {'reseinded': []},
 'reseis': {'reseise': ['reseised']},
 'reseise': ['reseised'],
 'reseiv': {'reseivation': ['reseivations'],
            'reseive': ['reseived', 'reseives'],
            'reseiving': []},
 'reseivation': ['reseivations'],
 'reseive': ['reseived', 'reseives'],
 'reseiz': {'reseize': ['reseized'], 'reseizing': []},
 'reseize': ['reseized'],
 'reseizur': {'reseizure': []},
 'resekt': {'resektion': []},
 'resel': {'resele': ['reseler'],
           'resell': ['resells',
                      'reseller',
                      'resellers',
                      'reselling',
                      'resellable'],
           'resels': []},
 'resele': ['reseler'],
 'reselect': {'reselected': [],
              'reselecting': [],
              'reselection': ['reselections'],
              'reselects': []},
 'reselection': ['reselections'],
 'reseli': {'reselier': []},
 'resell': ['resells', 'reseller', 'resellers', 'reselling', 'resellable'],
 'reselt': {'reselts': []},
 'reselut': {'reselution': []},
 'reselv': {'reselved': []},
 'resem': {'reseme': ['resemed']},
 'resemant': {'resemantization': []},
 'resemantic': {'resemanticization': [],
                'resemanticize': ['resemanticized', 'resemanticizes'],
                'resemanticizing': []},
 'resemanticize': ['resemanticized', 'resemanticizes'],
 'resemb': {'resembance': [],
            'resembe': ['resembes', 'resembed'],
            'resembing': []},
 "resemb'": {"resemb'e": []},
 'resembal': {'resembalance': []},
 'resembe': ['resembes', 'resembed'],
 'resembel': {'resembeled': [], 'resembels': []},
 'resembi': {'resembiance': [], 'resembie': ['resembies'], 'resembiing': []},
 'resembie': ['resembies'],
 'resembl': {'resemblance': [],
             'resemblant': [],
             'resemble': ['resembled',
                          'resembles',
                          'resembler',
                          'resemblent',
                          'resemblers',
                          'resemblence',
                          'resembleing',
                          'resemblences',
                          'resembleance'],
             'resembli': ['resembling'],
             'resembls': [],
             'resembly': []},
 'resemblac': {'resemblace': []},
 'resemblag': {'resemblage': []},
 'resemblane': {'resemblanee': []},
 'resemblano': {'resemblanoe': ['resemblanoes']},
 'resemblanoe': ['resemblanoes'],
 'resemblauc': {'resemblauce': []},
 'resemblaunc': {'resemblaunce': ['resemblaunces']},
 'resemblaunce': ['resemblaunces'],
 'resemble': ['resembled',
              'resembles',
              'resembler',
              'resemblent',
              'resemblers',
              'resemblence',
              'resembleing',
              'resemblences',
              'resembleance'],
 'resemblesth': {'resemblesthe': []},
 'resembleth': {'resemblethe': []},
 'resembli': ['resembling'],
 'resembling': {'resemblinge': []},
 'resemblingli': {'resemblingly': []},
 'resemblingth': {'resemblingthe': []},
 'resemblnnc': {'resemblnnce': []},
 'resemblo': {'resemblos': []},
 'resembr': {'resembrance': []},
 'reseme': ['resemed'],
 'resemhl': {'resemhlance': ['resemhlances'],
             'resemhle': ['resemhles', 'resemhled'],
             'resemhling': []},
 'resemhlance': ['resemhlances'],
 'resemhle': ['resemhles', 'resemhled'],
 'resemiot': {'resemiotization': []},
 'reseml': {'resemlance': [], 'resemle': [], 'resemling': []},
 'resemol': {'resemolance': [], 'resemole': []},
 'resempl': {'resemple': ['resemples']},
 'resemple': ['resemples'],
 'resen': {'resenation': ['resenations'],
           'resene': ['resener', 'resened', 'resenes'],
           'resening': [],
           'resenment': [],
           'resens': []},
 "resen'": {"resen'e": ["resen'es", "resen'ed"]},
 "resen'e": ["resen'es", "resen'ed"],
 'resena': {'resenas': []},
 'resenada': {'resenadas': []},
 'resenado': {'resenados': []},
 'resenation': ['resenations'],
 'resenberg': {'resenberger': []},
 'resenbl': {'resenblance': [],
             'resenble': ['resenbled', 'resenbles'],
             'resenbling': []},
 'resenble': ['resenbled', 'resenbles'],
 'resenc': {'resence': []},
 'resend': {'resende': ['resendes'], 'resending': [], 'resends': []},
 'resende': ['resendes'],
 'resendiu': {'resendius': []},
 'resene': ['resener', 'resened', 'resenes'],
 'resenha': {'resenhas': []},
 'reseni': {'resenie': ['resenied']},
 'resenie': ['resenied'],
 'reseniu': {'resenius': []},
 'resenj': {'resenje': []},
 'resennn': {'resennnent': []},
 'resenr': {'resenre': ['resenred'], 'resenrment': []},
 'resenre': ['resenred'],
 'resens': {'resense': ['resensed'], 'resensing': []},
 'resense': ['resensed'],
 'resensit': {'resensitization': [],
              'resensitize': ['resensitizes', 'resensitized'],
              'resensitizing': []},
 'resensitis': {'resensitisation': [],
                'resensitise': ['resensitised'],
                'resensitising': []},
 'resensitise': ['resensitised'],
 'resensitize': ['resensitizes', 'resensitized'],
 'resent': {'resentable': [],
            'resentation': ['resentations', 'resentational'],
            'resentative': ['resentatives', 'resentativeness'],
            'resente': ['resenter',
                        'resented',
                        'resenters',
                        'resentence',
                        'resentement',
                        'resentences'],
            'resentful': ['resentfully', 'resentfulness'],
            'resenting': [],
            'resentive': [],
            'resently': [],
            'resentment': [],
            'resents': []},
 'resenta': {'resentaent': []},
 'resentation': ['resentations', 'resentational'],
 'resentative': ['resentatives', 'resentativeness'],
 'resente': ['resenter',
             'resented',
             'resenters',
             'resentence',
             'resentement',
             'resentences'],
 'resentenc': {'resentenced': [], 'resentencing': ['resentencings']},
 'resentencing': ['resentencings'],
 'resentful': ['resentfully', 'resentfulness'],
 'resenth': {'resenthal': []},
 'resenti': {'resentiment': ['resentiments']},
 'resentido': {'resentidos': []},
 'resentiment': ['resentiments'],
 'resentimiento': {'resentimientos': []},
 'resentingli': {'resentingly': []},
 'resentirs': {'resentirse': []},
 'resentn': {'resentnent': []},
 'resentrn': {'resentrnents': []},
 'resenun': {'resenunent': []},
 'reseorch': {'reseorchers': []},
 'reseourc': {'reseources': []},
 'resepar': {'reseparate': ['reseparates', 'reseparated'],
             'reseparating': [],
             'reseparation': []},
 'reseparate': ['reseparates', 'reseparated'],
 'resepct': {'resepctive': ['resepctively'], 'resepcts': []},
 'resepctive': ['resepctively'],
 'resepect': {'resepective': ['resepectively']},
 'resepective': ['resepectively'],
 'resept': {'reseption': []},
 'reseptor': {'reseptors': []},
 'resequ': {'resequence': ['resequences'], 'resequent': ['resequents']},
 'resequenc': {'resequenced': [], 'resequencer': [], 'resequencing': []},
 'resequence': ['resequences'],
 'resequent': ['resequents'],
 'resequest': {'resequester': ['resequestered']},
 'resequester': ['resequestered'],
 'resequestr': {'resequestration': []},
 'reser': {'reserable': [],
           'reserant': [],
           'reserate': [],
           'reseration': [],
           'resere': ['reseres', 'resered', 'reserence', 'reserences'],
           'resering': [],
           'reserred': [],
           'reserring': [],
           'resers': []},
 'resera': {'reseras': []},
 'reserach': {'reseracher': ['reserachers'], 'reseraches': []},
 'reseracher': ['reserachers'],
 'reseran': {'reserans': []},
 'reserar': {'reserare': []},
 'reserati': {'reseratis': []},
 'reseration': {'reseratione': []},
 'reseratu': {'reseratus': []},
 'reserc': {'reserce': ['reserced']},
 'reserce': ['reserced'],
 'reserch': {'reserche': ['reserches', 'resercher', 'reserchers']},
 'reserche': ['reserches', 'resercher', 'reserchers'],
 'resere': {'resereed': [], 'reserees': []},
 'reserect': {'reserection': []},
 'reseri': {'reserialize': ['reserialized'],
            'reserializing': [],
            'reseryed': []},
 'reserialize': ['reserialized'],
 'resernbl': {'resernblance': [], 'resernbles': []},
 'resero': {'reseroe': ['reseroed']},
 'reseroe': ['reseroed'],
 'reserp': {'reserpate': [], 'reserpic': []},
 'reserpin': {'reserpine': [],
              'reserpinization': [],
              'reserpinized': [],
              'reserpins': []},
 'reserpineinduc': {'reserpineinduced': []},
 'reserpinelik': {'reserpinelike': []},
 'reserpinetr': {'reserpinetreated': []},
 'reserpinis': {'reserpinised': []},
 'reserpln': {'reserplne': []},
 'reserpm': {'reserpme': []},
 'reserr': {'reserration': [], 'reserre': ['reserres', 'reserrer']},
 'reserre': ['reserres', 'reserrer'],
 'resers': {'reserse': ['resersed']},
 'reserse': ['resersed'],
 'resert': {'reserted': []},
 'resertl': {'resertlement': []},
 'reseru': {'reseruation': ['reseruations'],
            'reserue': ['reseruer', 'reserued', 'reserues'],
            'reseruing': []},
 'reseruamu': {'reseruamus': []},
 'reseruati': {'reseruatis': []},
 'reseruation': ['reseruations'],
 'reserue': ['reseruer', 'reserued', 'reserues'],
 'reserv': {'reservable': [],
            'reserval': [],
            'reservance': [],
            'reservant': [],
            'reservate': ['reservated'],
            'reservation': ['reservational'],
            'reservative': ['reservatives'],
            'reserve': ['reserver',
                        'reserved',
                        'reservers',
                        'reservent',
                        'reservered',
                        'reserveing'],
            'reserviced': [],
            'reservicing': [],
            'reserving': [],
            'reservs': []},
 'reserva': {'reservas': []},
 'reservacion': {'reservaciones': []},
 'reservacon': {'reservacons': []},
 'reservada': {'reservadas': []},
 'reservadament': {'reservadamente': []},
 'reservado': {'reservados': []},
 'reservai': {'reservaient': [], 'reservais': []},
 'reservamo': {'reservamos': []},
 'reservamu': {'reservamus': []},
 'reservan': {'reservans': []},
 'reservandos': {'reservandose': []},
 'reservant': {'reservantes': []},
 'reservar': {'reservare': []},
 'reservarion': {'reservarions': []},
 'reservars': {'reservarse': []},
 'reservass': {'reservasse': []},
 'reservata': {'reservatae': [], 'reservatas': []},
 'reservate': ['reservated'],
 'reservati': {'reservatis': []},
 'reservation': {'reservatione': ['reservationes', 'reservationer'],
                 'reservationism': []},
 'reservationbas': {'reservationbased': []},
 'reservatione': ['reservationes', 'reservationer'],
 'reservationi': {'reservationis': []},
 'reservationibu': {'reservationibus': []},
 'reservationist': {'reservationists': []},
 'reservationsonli': {'reservationsonly': []},
 'reservationwid': {'reservationwide': []},
 'reservative': ['reservatives'],
 'reservatlon': {'reservatlons': []},
 'reservato': {'reservatos': []},
 'reservaton': {'reservatons': []},
 'reservatori': {'reservatories': [], 'reservatory': []},
 'reservatorio': {'reservatorios': []},
 'reservatrecht': {'reservatrechte': []},
 'reservatu': {'reservatus': []},
 'reservavimu': {'reservavimus': []},
 'reserve': {'reservee': ['reservees']},
 'reservearme': {'reservearmee': []},
 'reservearmi': {'reservearmy': []},
 'reservebas': {'reservebased': []},
 'reservecurr': {'reservecurrency': []},
 'reserved': {'reservedness': []},
 'reservedli': {'reservedly': []},
 'reservednef': {'reservednefs': []},
 'reservedness': {'reservednesse': []},
 'reservee': ['reservees'],
 'reservefond': {'reservefonds': []},
 'reserveforc': {'reserveforce': []},
 'reservehold': {'reserveholding': []},
 'reservemateri': {'reservematerial': ['reservematerials']},
 'reservematerial': ['reservematerials'],
 'reservemu': {'reservemus': []},
 'reserveoffizi': {'reserveoffizier': ['reserveoffiziers']},
 'reserveoffizier': ['reserveoffiziers'],
 'reserverequir': {'reserverequirement': []},
 'reserveri': {'reservery': []},
 'reservestoff': {'reservestoffe': []},
 'reservetreasuri': {'reservetreasury': []},
 'reservic': {'reservice': ['reservices']},
 'reservice': ['reservices'],
 'reserviert': {'reservierte': []},
 'reserving': {'reservinge': []},
 'reservior': {'reserviors': []},
 'reservist': ['reserviste', 'reservistes'],
 'reservo': {'reservos': []},
 'reservoi': {'reservois': []},
 'reservoii': {'reservoiis': []},
 'reservoir': ['reservoire', 'reservoired', 'reservoires', 'reservoiring'],
 'reservoirinduc': {'reservoirinduced': []},
 'reservoit': {'reservoits': []},
 'reservon': {'reservons': []},
 'reservor': {'reservors': []},
 'reservorio': {'reservorios': []},
 'resery': {'reserye': ['reseryes']},
 'reserye': ['reseryes'],
 'resess': {'resession': []},
 'reset': ['reseted',
           'resetted',
           'reseting',
           'resetting',
           'resetable',
           'resettings',
           'resetability'],
 'resetarit': {'resetarits': []},
 'resetcont': {'resetcontent': []},
 'resetd': {'resetde': ['resetded', 'resetdement', 'resetdements'],
            'resetding': []},
 'resetde': ['resetded', 'resetdement', 'resetdements'],
 'resetev': {'resetevent': []},
 'resetiosflag': {'resetiosflags': []},
 'resetl': {'resetled': [], 'resetlement': []},
 'resetlog': {'resetlogs': []},
 'resett': {'resettability': [],
            'resettable': [],
            'resette': ['resetter', 'resetters']},
 'resettari': {'resettaris': []},
 'resette': ['resetter', 'resetters'],
 'resetti': {'resettied': [], 'resettiement': [], 'resettiers': []},
 'resettl': {'resettle': ['resettler',
                          'resettles',
                          'resettled',
                          'resettlers',
                          'resettlement'],
             'resettling': ['resettlings'],
             'resettlment': []},
 'resettle': {'resettlees': []},
 'resettlem': {'resettleme': []},
 'resettling': ['resettlings'],
 'resetv': {'resetve': ['resetved']},
 'resetve': ['resetved'],
 'reseu': {'reseue': ['reseued'], 'reseuing': []},
 'reseue': ['reseued'],
 'reseurc': {'reseurces': []},
 'reseut': {'reseutment': []},
 'resev': {'resevation': ['resevations'],
           'reseve': ['reseved', 'reseves', 'resevered']},
 'resevation': ['resevations'],
 'reseve': ['reseved', 'reseves', 'resevered'],
 'resever': {'reseveral': []},
 'resevoir': {'resevoirs': []},
 'resew': {'resewe': ['resewes', 'resewed'], 'resewing': [], 'resews': []},
 'resewe': ['resewes', 'resewed'],
 'reseyu': {'reseyue': []},
 'reseyv': {'reseyve': ['reseyved']},
 'reseyve': ['reseyved'],
 'resezion': {'resezione': []},
 'resf': {'resfs': []},
 'resfect': {'resfecting': []},
 'resfriado': {'resfriados': []},
 'resgard': {'resgarde': []},
 'resgat': {'resgate': ['resgates']},
 'resgate': ['resgates'],
 'resgesta': {'resgestae': []},
 'resgin': {'resgination': []},
 'resgist': {'resgistered': []},
 'resgistr': {'resgistration': []},
 'resguardada': {'resguardadas': []},
 'resguardado': {'resguardados': []},
 'resguardars': {'resguardarse': []},
 'resguardo': {'resguardos': []},
 'resguid': {'resguide': []},
 'resh': {'reshe': ['reshed'], 'reshing': [], 'reshness': []},
 'reshackl': {'reshackle': ['reshackled'], 'reshackling': []},
 'reshackle': ['reshackled'],
 'reshad': {'reshade': ['reshaded'], 'reshading': []},
 'reshade': ['reshaded'],
 'reshadi': {'reshadie': []},
 'reshadiy': {'reshadiye': []},
 'reshaft': {'reshafted': [], 'reshafting': []},
 'reshaiushche': {'reshaiushchee': []},
 'reshak': {'reshake': [], 'reshaking': []},
 'reshal': {'reshall': []},
 'reshap': {'reshapable': [],
            'reshape': ['reshaped',
                        'reshaper',
                        'reshapes',
                        'reshapers',
                        'reshapement'],
            'reshaping': ['reshapings']},
 'reshape': ['reshaped', 'reshaper', 'reshapes', 'reshapers', 'reshapement'],
 'reshaping': ['reshapings'],
 'reshar': {'reshare': ['reshared'], 'resharing': []},
 'reshare': ['reshared'],
 'resharpen': {'resharpenable': [],
               'resharpened': [],
               'resharpening': ['resharpenings'],
               'resharpens': []},
 'resharpening': ['resharpenings'],
 'reshav': {'reshave': ['reshaved']},
 'reshave': ['reshaved'],
 'reshe': {'reshee': ['resheed']},
 'reshear': {'resheared': [], 'reshearing': []},
 'resheath': {'resheathe': ['resheathed', 'resheathes'], 'resheathing': []},
 'resheathe': ['resheathed', 'resheathes'],
 'reshedul': {'resheduling': []},
 'reshee': ['resheed'],
 'resheet': {'resheeted': []},
 'reshef': {'reshefs': []},
 'reshelv': {'reshelve': ['reshelved', 'reshelves'], 'reshelving': []},
 'reshelve': ['reshelved', 'reshelves'],
 'resheni': {'reshenie': [], 'resheny': []},
 'resheniy': {'resheniye': []},
 'reshershi': {'reshershy': []},
 'resheti': {'reshety': []},
 'reshetk': {'reshetke': []},
 'reshevski': {'reshevsky': []},
 'reshi': {'reshis': []},
 'reshift': {'reshifted': [], 'reshifting': ['reshiftings'], 'reshifts': []},
 'reshifting': ['reshiftings'],
 'reshim': {'reshimmed': [], 'reshimming': []},
 'reshin': {'reshine': ['reshined']},
 'reshine': ['reshined'],
 'reshingl': {'reshingle': ['reshingled'], 'reshingling': []},
 'reshingle': ['reshingled'],
 'reship': {'reshipment': [], 'reshipped': [], 'reshipping': [], 'reships': []},
 'reshipp': {'reshipper': ['reshippers']},
 'reshipper': ['reshippers'],
 'reshir': {'reshire': []},
 'reshk': {'reshke': []},
 'reshli': {'reshly': []},
 'reshment': {'reshments': []},
 'resho': {'reshoe': ['reshoed', 'reshoeing']},
 'reshock': {'reshocked': []},
 'reshoe': ['reshoed', 'reshoeing'],
 'reshoot': {'reshooting': [], 'reshoots': []},
 'reshor': {'reshored': [], 'reshores': [], 'reshoring': []},
 'reshould': {'reshoulder': ['reshouldered', 'reshouldering']},
 'reshoulder': ['reshouldered', 'reshouldering'],
 'reshovel': {'reshoveled': []},
 'reshovski': {'reshovsky': []},
 'reshow': {'reshowed': [], 'reshowing': ['reshowings']},
 'reshowing': ['reshowings'],
 'reshpect': {'reshpectable': []},
 'reshpolici': {'reshpolicy': []},
 'reshred': {'reshredded': []},
 'reshtor': {'reshtore': []},
 'reshu': {'reshus': []},
 'reshuffi': {'reshuffiings': []},
 'reshuffl': {'reshuffle': ['reshuffled', 'reshuffler', 'reshufflement'],
              'reshuffling': []},
 'reshuffle': ['reshuffled', 'reshuffler', 'reshufflement'],
 'reshufh': {'reshufhings': []},
 'reshufil': {'reshufiling': []},
 'reshufl': {'reshuflle': ['reshuflled'], 'reshuflling': []},
 'reshuflle': ['reshuflled'],
 'reshum': {'reshume': []},
 'reshut': {'reshutting': []},
 'reshwat': {'reshwater': ['reshwaters']},
 'reshwater': ['reshwaters'],
 'resi': {'resie': ['resies', 'resied'],
          'resiing': [],
          'resis': [],
          'resy': []},
 'resia': {'resias': []},
 'resiaenc': {'resiaence': []},
 'resiak': {'resiake': []},
 'resialyl': {'resialylated': [], 'resialylation': []},
 'resianc': {'resiance': [], 'resiancy': []},
 'resiann': {'resianne': []},
 'resiant': {'resiants': []},
 'resiat': {'resiatance': [], 'resiatant': []},
 'resibl': {'resibility': []},
 'resiboi': {'resibois': []},
 'resibu': {'resibus': []},
 'resic': {'resical': []},
 'resicl': {'resicle': []},
 'resid': ['reside',
           'residal',
           'resider',
           'resided',
           'resides',
           'residing',
           'residers',
           'residant',
           'resident',
           'resideing',
           'residency',
           'residence',
           'residants',
           'resideant',
           'residance'],
 'resida': {'residae': []},
 'residai': {'residaient': []},
 'residan': {'residans': []},
 'residcnc': {'residcnce': []},
 'resideac': {'resideace': []},
 'resideb': {'residebant': []},
 'residem': {'residems': []},
 'residemi': {'residemial': []},
 'residen': {'residene': [], 'residens': []},
 'residenc': {'residenced': [], 'residencs': []},
 'residencebas': {'residencebased': []},
 'residencetim': {'residencetime': []},
 'residenci': {'residencial': ['residencials'], 'residencie': []},
 'residencia': {'residencias': []},
 'residenciai': {'residenciais': []},
 'residencial': {'residenciales': []},
 'residencygener': {'residencygeneral': []},
 'residend': {'residendal': []},
 'residene': {'residenee': ['residenees']},
 'residenee': ['residenees'],
 'resideni': {'residenial': [], 'residenis': []},
 'residenl': {'residenls': []},
 'residenli': {'residenlial': []},
 'resideno': {'residenoe': []},
 'residenr': {'residenre': [], 'residenrs': []},
 'residenri': {'residenrial': []},
 'residens': {'residense': []},
 'resident': {'residental': [],
              'residente': ['residenter', 'residentes', 'residenters']},
 'residentalien': {'residentaliens': []},
 'residentari': {'residentaries': [], 'residentary': []},
 'residentcontrol': {'residentcontrolled': []},
 'residente': ['residenter', 'residentes', 'residenters'],
 'residentgener': {'residentgeneral': []},
 'residenti': {'residential': ['residentials',
                               'residentially',
                               'residentiality',
                               'residentialism'],
               'residentie': ['residenties'],
               'residentis': []},
 'residentia': {'residentiae': []},
 'residential': ['residentials',
                 'residentially',
                 'residentiality',
                 'residentialism'],
 'residentialcar': {'residentialcare': []},
 'residentialcommerci': {'residentialcommercial': []},
 'residentiari': {'residentiaries': [], 'residentiary': []},
 'residentiaryship': {'residentiaryships': []},
 'residentibu': {'residentibus': []},
 'residentie': ['residenties'],
 'residentiel': {'residentielle': ['residentielles'], 'residentiels': []},
 'residentielle': ['residentielles'],
 'residentintrud': {'residentintruder': []},
 'residentori': {'residentoriented': []},
 'residentown': {'residentowned': []},
 'residentship': {'residentships': []},
 'residenu': {'residenual': []},
 'residenz': {'residenze': []},
 'residenzgaleri': {'residenzgalerie': []},
 'residenzial': {'residenziale': []},
 'residenzstadt': {'residenzstadte': []},
 'residenzstddt': {'residenzstddte': []},
 'residenzstrass': {'residenzstrasse': []},
 'residenztheat': {'residenztheater': []},
 'resider': {'residere': ['residerent']},
 'residere': ['residerent'],
 'resideremu': {'resideremus': []},
 'residerend': {'residerende': []},
 'residetqu': {'residetque': []},
 'resideuc': {'resideuce': []},
 'resideut': {'resideuts': []},
 'residew': {'residewe': []},
 'residi': {'residial': [], 'residis': []},
 'residier': {'residiere': []},
 'residiert': {'residierte': []},
 'residing': {'residinge': []},
 'residn': {'residnal': [], 'residne': []},
 'residonc': {'residonce': []},
 'residont': {'residonts': []},
 'residron': {'residronate': []},
 'residt': {'residtant': [], 'residted': [], 'residting': [], 'residts': []},
 'residu': {'residual': ['residually',
                         'residualism',
                         'residuality',
                         'residualize',
                         'residualness',
                         'residualized',
                         'residualizing',
                         'residualization'],
            'residuated': [],
            'residuation': [],
            'residue': ['residued'],
            'residuous': [],
            'residus': []},
 'residua': {'residuae': [], 'residuas': []},
 'residuai': {'residuais': []},
 'residuair': {'residuaire': ['residuaires']},
 'residuaire': ['residuaires'],
 'residual': {'residuale': ['residuales']},
 'residualbas': {'residualbased': []},
 'residuale': ['residuales'],
 'residualis': {'residualisation': [],
                'residualise': ['residualised'],
                'residualising': []},
 'residualise': ['residualised'],
 'residualist': {'residualistic': [], 'residualists': []},
 'residuar': {'residuarity': []},
 'residuari': {'residuaries': [], 'residuary': []},
 'residuc': {'residuces': []},
 'residue': ['residued'],
 'residuefre': {'residuefree': []},
 'residuel': {'residuelle': ['residuelles'], 'residuels': []},
 'residuelle': ['residuelles'],
 'residuespecif': {'residuespecific': []},
 'residui': {'residuis': []},
 'residuo': {'residuos': []},
 'residuos': {'residuosity': []},
 'residur': {'residures': []},
 'residuu': {'residuus': []},
 'residuum': {'residuum': []},
 'resie': ['resies', 'resied'],
 'resienc': {'resience': []},
 'resient': {'resiente': [], 'resients': []},
 'resienti': {'resiential': []},
 'resiet': {'resietance': []},
 'resiev': {'resieve': ['resieved'], 'resieving': []},
 'resieve': ['resieved'],
 'resift': {'resiftance': [], 'resifted': [], 'resifting': ['resiftings']},
 'resifting': ['resiftings'],
 'resig': {'resigation': []},
 'resight': {'resighted': [], 'resighting': ['resightings'], 'resights': []},
 'resighting': ['resightings'],
 'resign': {'resignal': ['resignaled', 'resignaling'],
            'resignant': [],
            'resignate': ['resignated'],
            'resignation': [],
            'resignative': [],
            'resigne': ['resignes',
                        'resigned',
                        'resigner',
                        'resignent',
                        'resigners'],
            'resigning': [],
            'resignment': [],
            'resigns': []},
 'resignacion': {'resignacione': []},
 'resignado': {'resignados': []},
 'resignal': {'resignalled': [], 'resignalling': []},
 'resignan': {'resignanation': []},
 'resignanti': {'resignantis': []},
 'resignar': {'resignare': []},
 'resignars': {'resignarse': []},
 'resignate': ['resignated'],
 'resignation': {'resignatione': ['resignationes'], 'resignationism': []},
 'resignatione': ['resignationes'],
 'resignationi': {'resignationis': []},
 'resignationibu': {'resignationibus': []},
 'resignationist': {'resignationists': []},
 'resignatori': {'resignatory': []},
 'resigne': {'resignee': ['resignees']},
 'resigned': {'resignedness': []},
 'resignedli': {'resignedly': []},
 'resignee': ['resignees'],
 'resigni': {'resigny': []},
 'resigniert': {'resignierte': []},
 'resignif': {'resignification': ['resignifications']},
 'resignifi': {'resignifiability': [],
               'resignifiable': [],
               'resignified': [],
               'resignifies': [],
               'resignify': ['resignifying']},
 'resignification': ['resignifications'],
 'resignify': ['resignifying'],
 'resigningli': {'resigningly': []},
 'resignit': {'resignition': []},
 'resignon': {'resignons': []},
 'resignt': {'resigntion': []},
 'resigu': {'resiguation': [], 'resigued': [], 'resiguing': [], 'resigus': []},
 'resiienc': {'resiience': []},
 'resiiienc': {'resiiience': []},
 'resiilt': {'resiilted': [], 'resiilting': [], 'resiilts': []},
 'resiime': {'resiimee': []},
 'resiimen': {'resiimenes': []},
 'resiit': {'resiitance': []},
 'resil': {'resile': ['resiled',
                      'resiles',
                      'resilent',
                      'resilency',
                      'resilence',
                      'resilement'],
           'resilicated': [],
           'resilication': [],
           'resiling': [],
           'resill': ['resille', 'resilled', 'resillence']},
 'resile': ['resiled',
            'resiles',
            'resilent',
            'resilency',
            'resilence',
            'resilement'],
 'resili': {'resilial': [],
            'resiliance': [],
            'resiliancy': [],
            'resiliant': [],
            'resiliate': ['resiliated'],
            'resiliation': [],
            'resilie': ['resilier',
                        'resilient',
                        'resiliency',
                        'resilience',
                        'resilients',
                        'resiliently']},
 'resiliate': ['resiliated'],
 'resilicif': {'resilicification': []},
 'resilie': ['resilier',
             'resilient',
             'resiliency',
             'resilience',
             'resilients',
             'resiliently'],
 'resilien': {'resiliens': []},
 'resilif': {'resilifer': []},
 'resiliomet': {'resiliometer': []},
 'resilir': {'resilire': []},
 'resilit': {'resilition': []},
 'resill': ['resille', 'resilled', 'resillence'],
 'resilli': {'resillience': [], 'resillient': []},
 'resilt': {'resilting': [], 'resilts': []},
 'resilv': {'resilver': ['resilvered', 'resilvering']},
 'resilver': ['resilvered', 'resilvering'],
 'resim': {'resime': []},
 'resimen': {'resimene': []},
 'resiml': {'resimler': []},
 'resimplif': {'resimplification': []},
 'resimplifi': {'resimplified': [], 'resimplify': []},
 'resimu': {'resimus': []},
 'resimul': {'resimulate': ['resimulated'],
             'resimulating': [],
             'resimulation': []},
 'resimulate': ['resimulated'],
 'resin': ['resine',
           'resiner',
           'resinic',
           'resined',
           'resines',
           'resining',
           'resinned',
           'resinate',
           'resinous',
           'resiners',
           'resinning',
           'resinates',
           'resinated',
           'resinance',
           'resination',
           'resinating',
           'resinement',
           'resinously',
           'resinements',
           'resinousness'],
 'resina': {'resinae': [], 'resinas': []},
 'resinac': {'resinaceous': []},
 'resinariu': {'resinarius': []},
 'resinbas': {'resinbased': []},
 'resinbond': {'resinbonded': []},
 'resinc': {'resince': []},
 'resincan': {'resincanals': []},
 'resinco': {'resincoated': []},
 'resincontain': {'resincontaining': []},
 'resinduct': {'resinducts': []},
 'resinembed': {'resinembedded': []},
 'resineus': {'resineuse': ['resineuses']},
 'resineuse': ['resineuses'],
 'resinfil': {'resinfilled': []},
 'resinform': {'resinforming': []},
 'resing': {'resinged': [], 'resinger': [], 'resinging': []},
 'resingular': {'resingularization': []},
 'resini': {'resiny': []},
 'resinic': {'resinicization': [], 'resinicize': []},
 'resinif': {'resinification': []},
 'resinifer': {'resiniferous': []},
 'resinifi': {'resinifiable': [],
              'resinified': [],
              'resinifies': [],
              'resinify': ['resinifying']},
 'resinify': ['resinifying'],
 'resinimpregn': {'resinimpregnated': []},
 'resinit': {'resinite': ['resinites']},
 'resinite': ['resinites'],
 'resink': {'resinking': []},
 'resinlik': {'resinlike': []},
 'resinmodifi': {'resinmodified': []},
 'resinogen': {'resinogenous': []},
 'resinographi': {'resinography': []},
 'resinoid': {'resinoid': []},
 'resinol': {'resinolic': [], 'resinols': []},
 'resinon': {'resinons': []},
 'resinosa': {'resinosae': []},
 'resinosi': {'resinosis': []},
 'resinosu': {'resinosus': []},
 'resinotannol': {'resinotannols': []},
 'resinouslook': {'resinouslooking': []},
 'resinproduc': {'resinproducing': []},
 'resins': {'resinse': []},
 'resinsc': {'resinscented': []},
 'resinsoak': {'resinsoaked': []},
 'resint': {'resinter': ['resintered', 'resintering']},
 'resinter': ['resintered', 'resintering'],
 'resintr': {'resintreated': []},
 'resinu': {'resinuous': []},
 'resioenc': {'resioence': []},
 'resioent': {'resioents': []},
 'resioenti': {'resioential': []},
 'resion': {'resional': [], 'resions': []},
 'resior': {'resioration': [], 'resiore': ['resiored']},
 'resiore': ['resiored'],
 'resiou': {'resioue': ['resioues']},
 'resioual': {'resiouals': []},
 'resioue': ['resioues'],
 'resipisc': {'resipiscant': [], 'resipisce': ['resipiscence']},
 'resipisce': ['resipiscence'],
 'resipiscen': {'resipiscens': []},
 'resipiscent': {'resipiscentes': []},
 'resipiscentia': {'resipiscentiae': []},
 'resipiscentibu': {'resipiscentibus': []},
 'resipiscer': {'resipiscere': ['resipiscerent']},
 'resipiscere': ['resipiscerent'],
 'resipiscit': {'resipiscite': []},
 'resipratori': {'resipratory': []},
 'resiproc': {'resiprocal': []},
 'resir': {'resired': []},
 'resiratori': {'resiratory': []},
 'resirict': {'resiricted': [], 'resirictions': []},
 'resirv': {'resirved': []},
 'resis': {'resisance': [], 'resisant': [], 'resised': [], 'resisivity': []},
 'resisd': {'resisdence': [], 'resisdents': []},
 'resisdessli': {'resisdessly': []},
 'resisf': {'resisfance': []},
 'resisi': {'resisiance': [], 'resisiant': []},
 'resisid': {'resisidence': []},
 'resisist': {'resisistance': []},
 'resisit': {'resisitance': [],
             'resisitant': [],
             'resisiting': [],
             'resisitive': [],
             'resisitivities': [],
             'resisitivity': []},
 'resisitv': {'resisitvity': []},
 'resisl': {'resislance': [], 'resislant': []},
 'resisr': {'resisrance': [], 'resisrant': [], 'resisred': []},
 'resisst': {'resisstance': []},
 'resissu': {'resissued': []},
 'resist': {'resistability': [],
            'resistable': [],
            'resistal': [],
            'resistance': [],
            'resistanci': ['resistancies'],
            'resistancy': [],
            'resistant': ['resistants'],
            'resistate': ['resistates'],
            'resiste': ['resister',
                        'resisted',
                        'resistes',
                        'resistent',
                        'resistered',
                        'resistency',
                        'resistence',
                        'resistently',
                        'resistences',
                        'resistencies'],
            'resistful': [],
            'resistibility': [],
            'resistible': ['resistibleness'],
            'resistibly': [],
            'resisting': ['resistings'],
            'resistive': ['resistives', 'resistively', 'resistiveness'],
            'resistivity': [],
            'resists': []},
 'resista': {'resistas': []},
 'resistaac': {'resistaace': []},
 'resistac': {'resistace': []},
 'resistahc': {'resistahce': []},
 'resistai': {'resistaient': []},
 'resistamu': {'resistamus': []},
 'resistan': {'resistane': [], 'resistans': []},
 'resistanc': {'resistancs': []},
 'resistancc': {'resistancce': []},
 'resistance': {'resistancee': []},
 'resistanceassoci': {'resistanceassociated': []},
 'resistancebreak': {'resistancebreaking': []},
 'resistancecapac': {'resistancecapacity': []},
 'resistancecapacit': {'resistancecapacitance': []},
 'resistancecoil': {'resistancecoils': []},
 'resistanceconf': {'resistanceconferring': []},
 'resistancecoupl': {'resistancecoupled': []},
 'resistancefre': {'resistancefree': []},
 'resistanceh': {'resistanceheated': [], 'resistanceheating': []},
 'resistanceinduc': {'resistanceinducing': []},
 'resistanceinduct': {'resistanceinductance': []},
 'resistancemeasur': {'resistancemeasuring': []},
 'resistancerel': {'resistancerelated': []},
 'resistancetemperatur': {'resistancetemperature': []},
 'resistancethermomet': {'resistancethermometer': []},
 'resistancetrain': {'resistancetrained': [], 'resistancetraining': []},
 'resistancetyp': {'resistancetype': []},
 'resistanceweld': {'resistancewelded': [], 'resistancewelding': []},
 'resistancewir': {'resistancewire': []},
 'resistanci': ['resistancies'],
 'resistane': {'resistanee': []},
 'resistano': {'resistanoe': [], 'resistanos': []},
 'resistanr': {'resistanre': []},
 'resistans': {'resistanse': []},
 'resistant': {'resistante': ['resistantes']},
 'resistante': ['resistantes'],
 'resistantia': {'resistantiae': []},
 'resistantli': {'resistantly': []},
 'resistarc': {'resistarce': []},
 'resistate': ['resistates'],
 'resistauc': {'resistauce': []},
 'resistaunc': {'resistaunce': []},
 'resistcnc': {'resistcnce': []},
 'resistco': {'resistcoated': []},
 'resistcr': {'resistcrs': []},
 'resistdi': {'resistdyed': []},
 'resiste': ['resister',
             'resisted',
             'resistes',
             'resistent',
             'resistered',
             'resistency',
             'resistence',
             'resistently',
             'resistences',
             'resistencies'],
 'resisteb': {'resistebant': []},
 'resisten': {'resistens': []},
 'resistencia': {'resistencias': []},
 'resistene': {'resistenee': []},
 'resisteno': {'resistenoe': []},
 'resistent': {'resistente': ['resistentes', 'resistenter']},
 'resistente': ['resistentes', 'resistenter'],
 'resistenti': {'resistentialism': [], 'resistentie': [], 'resistentis': []},
 'resistentia': {'resistentiae': [], 'resistentias': []},
 'resistentialist': {'resistentialists': []},
 'resistentibu': {'resistentibus': []},
 'resistentic': {'resistentice': []},
 'resistentis': {'resistentise': []},
 'resistenz': {'resistenze': []},
 'resister': {'resistere': ['resisterent']},
 'resisterai': {'resisteraient': []},
 'resistere': ['resisterent'],
 'resisti': {'resistis': []},
 'resistible': ['resistibleness'],
 'resistimo': {'resistimos': []},
 'resistimu': {'resistimus': []},
 'resistinc': {'resistince': []},
 'resisting': ['resistings'],
 'resistingli': {'resistingly': []},
 'resistingpow': {'resistingpower': []},
 'resistingth': {'resistingthe': []},
 'resistirs': {'resistirse': []},
 'resistit': {'resistite': []},
 'resistive': ['resistives', 'resistively', 'resistiveness'],
 'resistivecapacit': {'resistivecapacitive': []},
 'resistivit': {'resistivite': ['resistivites']},
 'resistivite': ['resistivites'],
 'resistivitytemperatur': {'resistivitytemperature': []},
 'resistivti': {'resistivty': []},
 'resistl': {'resistles': []},
 'resistlcssli': {'resistlcssly': []},
 'resistless': {'resistlesse': [], 'resistlessness': []},
 'resistlessli': {'resistlessly': []},
 'resistmc': {'resistmce': []},
 'resistnac': {'resistnace': []},
 'resistnc': {'resistnce': []},
 'resistnnc': {'resistnnce': []},
 'resistojet': {'resistojets': []},
 'resistol': {'resistols': []},
 'resistomet': {'resistometer': []},
 'resistometr': {'resistometric': []},
 'resistometri': {'resistometry': []},
 'resiston': {'resistons': []},
 'resistonc': {'resistonce': []},
 'resistor': {'resistor': []},
 'resistr': {'resistration': []},
 'resistsnc': {'resistsnce': []},
 'resistt': {'resisttance': []},
 'resistth': {'resistthe': []},
 'resistunc': {'resistunce': []},
 'resit': {'resitance': ['resitances'],
           'resitant': [],
           'resitation': [],
           'resite': ['resites', 'resited'],
           'resiting': ['resitings'],
           'resition': [],
           'resitive': [],
           'resitivities': [],
           'resitivity': [],
           'resits': [],
           'resitted': [],
           'resitting': ['resittings']},
 'resitance': ['resitances'],
 'resite': ['resites', 'resited'],
 'resith': {'resithe': []},
 'resiti': {'resitience': []},
 'resiting': ['resitings'],
 'resititut': {'resititution': []},
 'resitol': {'resitols': []},
 'resitor': {'resitors': []},
 'resitting': ['resittings'],
 'resitu': {'resituate': ['resituated', 'resituates'],
            'resituating': [],
            'resituation': [],
            'resituer': []},
 'resituate': ['resituated', 'resituates'],
 'resitut': {'resitution': []},
 'resiu': {'resius': []},
 'resiuou': {'resiuous': []},
 'resiv': {'resive': ['resived']},
 'resive': ['resived'],
 'resiz': {'resizability': [],
           'resizable': [],
           'resize': ['resized', 'resizer', 'resizes', 'resizeable'],
           'resizing': ['resizings']},
 'resize': ['resized', 'resizer', 'resizes', 'resizeable'],
 'resizebi': {'resizeby': []},
 'resizepalett': {'resizepalette': []},
 'resizing': ['resizings'],
 'resjiect': {'resjiecting': [],
              'resjiective': ['resjiectively'],
              'resjiects': []},
 'resjiective': ['resjiectively'],
 'resjions': {'resjionsibility': []},
 'resjlt': {'resjlts': []},
 'resjouiss': {'resjouissance': []},
 'resjstanc': {'resjstance': []},
 'resk': {'reske': ['resked', 'reskes'], 'resking': [], 'resks': []},
 'reskajeag': {'reskajeage': []},
 'reske': ['resked', 'reskes'],
 'resketch': {'resketched': [], 'resketching': []},
 'reskew': {'reskewe': ['reskewed']},
 'reskewe': ['reskewed'],
 'reski': {'reskied': [], 'resky': []},
 'reskil': {'reskill': ['reskilled', 'reskilling']},
 'reskill': ['reskilled', 'reskilling'],
 'reskim': {'reskimer': [], 'reskimmed': []},
 'reskin': {'reskinned': [], 'reskinning': []},
 'reskript': {'reskripte': []},
 'resku': {'reskue': ['reskued']},
 'reskue': ['reskued'],
 'reskym': {'reskymer': ['reskymers']},
 'reskymer': ['reskymers'],
 'resl': {'resle': ['resled'], 'resling': [], 'resls': []},
 'reslant': {'reslanted': [], 'reslanting': []},
 'reslat': {'reslate': ['reslated'], 'reslating': []},
 'reslate': ['reslated'],
 'reslaur': {'reslauration': []},
 'resldenc': {'resldence': ['resldences']},
 'resldence': ['resldences'],
 'resldeno': {'resldenoe': []},
 'resldent': {'resldents': []},
 'resldentl': {'resldentlal': []},
 'resldu': {'resldue': ['resldues']},
 'resldue': ['resldues'],
 'resle': ['resled'],
 'reslect': {'reslected': [],
             'reslecting': [],
             'reslection': ['reslections'],
             'reslects': []},
 'reslection': ['reslections'],
 'resleev': {'resleeved': [], 'resleeving': []},
 'resless': {'reslessness': []},
 'reslic': {'reslice': ['resliced'], 'reslicing': []},
 'reslice': ['resliced'],
 'reslienc': {'reslience': []},
 'resling': {'reslinging': []},
 'reslis': {'reslised': []},
 'reslist': {'reslistic': []},
 'resliti': {'reslity': []},
 'resliz': {'reslize': ['reslized']},
 'reslize': ['reslized'],
 'reslli': {'reslly': []},
 'resln': {'reslns': []},
 'reslop': {'resloped': [], 'resloping': []},
 'reslor': {'resloration': [], 'reslore': ['reslored']},
 'reslore': ['reslored'],
 'reslot': {'reslotted': []},
 'reslout': {'resloution': []},
 'reslov': {'reslove': ['resloved']},
 'reslove': ['resloved'],
 'reslrict': {'reslricted': [], 'reslriction': ['reslrictions']},
 'reslriction': ['reslrictions'],
 'reslstanc': {'reslstance': []},
 'reslstenc': {'reslstence': []},
 'reslster': {'reslsters': []},
 'reslurri': {'reslurried': [], 'reslurry': ['reslurrying']},
 'reslurry': ['reslurrying'],
 'reslut': {'resluted': [], 'resluting': [], 'reslution': [], 'resluts': []},
 'resm': {'resme': ['resmed'], 'resms': []},
 'resma': {'resmas': []},
 'resmbl': {'resmbles': [], 'resmbling': []},
 'resmblanc': {'resmblance': []},
 'resme': ['resmed'],
 'resmelt': {'resmelted': [], 'resmelting': []},
 'resmn': {'resmned': []},
 'resmok': {'resmoke': ['resmoked'], 'resmoking': []},
 'resmoke': ['resmoked'],
 'resmooth': {'resmoothed': [], 'resmoothing': []},
 'resmou': {'resmous': []},
 'resmudg': {'resmudged': []},
 'resn': {'resne': ['resnes'], 'resning': [], 'resns': []},
 'resnabl': {'resnable': []},
 'resnact': {'resnacted': []},
 'resnai': {'resnais': []},
 'resnap': {'resnapped': [], 'resnapping': []},
 'resnar': {'resnared': []},
 'resnatron': {'resnatrons': []},
 'resnay': {'resnaye': []},
 'resne': ['resnes'],
 'resnect': {'resnective': ['resnectively'], 'resnects': []},
 'resnective': ['resnectively'],
 'resnforc': {'resnforce': ['resnforced', 'resnforcement', 'resnforcements']},
 'resnforce': ['resnforced', 'resnforcement', 'resnforcements'],
 'resnick': {'resnicks': []},
 'resnicket': {'resnicketal': []},
 'resnicki': {'resnicky': []},
 'resnitski': {'resnitsky': []},
 'resnitzki': {'resnitzky': []},
 'resnizki': {'resnizky': []},
 'resnlt': {'resnlted': [], 'resnlting': [], 'resnlts': []},
 'resnm': {'resnme': ['resnmed']},
 'resnme': ['resnmed'],
 'resnons': {'resnonse': ['resnonses'],
             'resnonsibility': [],
             'resnonsible': []},
 'resnonse': ['resnonses'],
 'resnrrect': {'resnrrection': []},
 'resnub': {'resnubbed': []},
 'resnulliu': {'resnullius': []},
 'reso': {'resos': []},
 'resoak': {'resoaked': [], 'resoaking': []},
 'resoanc': {'resoance': []},
 'resoap': {'resoaped': [], 'resoaping': []},
 'resoarc': {'resoarces': []},
 'resoci': {'resocial': ['resocialize',
                         'resocialized',
                         'resocializes',
                         'resocializing',
                         'resocialization']},
 'resocial': ['resocialize',
              'resocialized',
              'resocializes',
              'resocializing',
              'resocialization'],
 'resocialis': {'resocialisation': [],
                'resocialise': ['resocialised'],
                'resocialising': []},
 'resocialise': ['resocialised'],
 'resod': {'resodded': [], 'resodding': []},
 'resoect': {'resoected': [],
             'resoecting': [],
             'resoective': ['resoectively'],
             'resoects': []},
 'resoective': ['resoectively'],
 'resoften': {'resoftened': [], 'resoftening': []},
 'resofut': {'resofution': []},
 'resofv': {'resofve': ['resofved']},
 'resofve': ['resofved'],
 'resogn': {'resognized': []},
 'resognit': {'resognition': []},
 'resoh': {'resohe': ['resohed'], 'resohing': []},
 'resohe': ['resohed'],
 'resohit': {'resohition': ['resohitions']},
 'resohition': ['resohitions'],
 'resohtt': {'resohttion': []},
 'resoiirc': {'resoiirces': []},
 'resoil': {'resoiled': [], 'resoiling': []},
 'resoind': {'resoinded': []},
 'resoipt': {'resoiption': []},
 'resoiratori': {'resoiratory': []},
 'resoit': {'resoited': []},
 'resoiut': {'resoiution': ['resoiutions']},
 'resoiution': ['resoiutions'],
 'resoiv': {'resoive': ['resoived', 'resoives'], 'resoiving': []},
 'resoive': ['resoived', 'resoives'],
 'resojut': {'resojution': []},
 'resojv': {'resojved': []},
 'resok': {'resoked': []},
 'resol': {'resolation': [],
           'resole': ['resoles', 'resoled'],
           'resoling': [],
           'resols': []},
 'resolc': {'resolced': []},
 'resold': {'resolder': ['resoldered', 'resoldering']},
 'resolder': ['resoldered', 'resoldering'],
 'resole': {'resoleed': []},
 'resolemn': {'resolemnized': []},
 'resoli': {'resolis': [], 'resolyed': [], 'resolying': []},
 'resolicit': {'resolicitation': [], 'resolicited': [], 'resoliciting': []},
 'resolidif': {'resolidification': []},
 'resolidifi': {'resolidified': [],
                'resolidifies': [],
                'resolidify': ['resolidifying']},
 'resolidify': ['resolidifying'],
 'resolit': {'resolite': []},
 'resoln': {'resolns': []},
 'resolnt': {'resolnte': [], 'resolntion': ['resolntions']},
 'resolntion': ['resolntions'],
 'resolo': {'resoloed': []},
 'resolot': {'resolotion': []},
 'resolov': {'resoloved': []},
 'resolr': {'resolre': ['resolred']},
 'resolre': ['resolred'],
 'resolt': {'resolte': ['resolted'],
            'resolting': [],
            'resoltion': [],
            'resolts': []},
 'resolte': ['resolted'],
 'resoltuion': {'resoltuions': []},
 'resolu': {'resoluation': [],
            'resolue': ['resolues', 'resolued'],
            'resoluing': [],
            'resolument': [],
            'resolus': []},
 'resolubil': {'resolubilization': [],
               'resolubilize': ['resolubilizes', 'resolubilized'],
               'resolubilizing': []},
 'resolubilis': {'resolubilisation': [], 'resolubilised': []},
 'resolubilit': {'resolubilite': []},
 'resolubilize': ['resolubilizes', 'resolubilized'],
 'resolubl': {'resolubility': [], 'resoluble': ['resolubles']},
 'resoluble': ['resolubles'],
 'resolucion': {'resoluciones': [], 'resolucions': []},
 'resoluco': {'resolucoes': []},
 'resolucon': {'resolucons': []},
 'resolue': ['resolues', 'resolued'],
 'resoluion': {'resoluions': []},
 'resolulion': {'resolulions': []},
 'resolult': {'resolultion': []},
 'resolulut': {'resolulution': ['resolulutions']},
 'resolulution': ['resolulutions'],
 'resolum': {'resolumes': []},
 'resolur': {'resolurely': [], 'resolurent': []},
 'resolurion': {'resolurions': []},
 'resolus': {'resolusion': []},
 'resolusi': {'resolusies': []},
 'resolut': {'resolute': ['resolutes',
                          'resoluted',
                          'resolutely',
                          'resoluteness'],
             'resolutic': [],
             'resoluting': [],
             'resolution': ['resolutional'],
             'resolutive': ['resolutives', 'resolutively']},
 'resoluta': {'resolutae': [], 'resolutas': []},
 'resolutament': {'resolutamente': []},
 'resolute': ['resolutes', 'resoluted', 'resolutely', 'resoluteness'],
 'resoluteli': {'resolutelie': []},
 'resolutelook': {'resolutelooking': []},
 'resoluti': {'resolutie': ['resoluties'],
              'resolutiou': ['resolutious'],
              'resolutis': []},
 'resolutie': ['resoluties'],
 'resolution': {'resolutione': ['resolutiones',
                                'resolutioner',
                                'resolutioners']},
 'resolutionari': {'resolutionary': []},
 'resolutionbas': {'resolutionbased': []},
 'resolutiondepend': {'resolutiondependent': []},
 'resolutione': ['resolutiones', 'resolutioner', 'resolutioners'],
 'resolutioni': {'resolutionis': []},
 'resolutionibu': {'resolutionibus': []},
 'resolutionindepend': {'resolutionindependent': []},
 'resolutionist': {'resolutionists': []},
 'resolutiou': ['resolutious'],
 'resolutissimu': {'resolutissimus': []},
 'resolutive': ['resolutives', 'resolutively'],
 'resolutivecomposit': {'resolutivecompositive': []},
 'resolutli': {'resolutly': []},
 'resolutlon': {'resolutlons': []},
 'resoluto': {'resolutos': []},
 'resolutoir': {'resolutoire': []},
 'resoluton': {'resolutons': []},
 'resolutori': {'resolutory': []},
 'resolutu': {'resolutus': []},
 'resoluzion': {'resoluzione': []},
 'resolv': {'resolvability': [],
            'resolvable': [],
            'resolvably': [],
            'resolvance': [],
            'resolvant': ['resolvants'],
            'resolvated': [],
            'resolvation': [],
            'resolve': ['resolved',
                        'resolver',
                        'resolvent',
                        'resolvers',
                        'resolveds',
                        'resolveing',
                        'resolveable',
                        'resolvement'],
            'resolvible': [],
            'resolving': [],
            'resolvs': []},
 'resolvai': {'resolvaient': []},
 'resolvant': ['resolvants'],
 'resolvas': {'resolvase': ['resolvases']},
 'resolvase': ['resolvases'],
 'resolve': ['resolved',
             'resolver',
             'resolvent',
             'resolvers',
             'resolveds',
             'resolveing',
             'resolveable',
             'resolvement'],
 'resolved': {'resolvedness': []},
 'resolvedli': {'resolvedly': []},
 'resolveent': {'resolveentity': []},
 'resolvemo': {'resolvemos': []},
 'resolven': {'resolvens': []},
 'resolvenda': {'resolvendas': []},
 'resolvendu': {'resolvendus': []},
 'resolver': {'resolvere': []},
 'resolverequestcach': {'resolverequestcache': []},
 'resolverla': {'resolverlas': []},
 'resolverlo': {'resolverlos': []},
 'resolvers': {'resolverse': []},
 'resolveth': {'resolvethe': []},
 'resolvi': {'resolvis': []},
 'resolvida': {'resolvidas': []},
 'resolvido': {'resolvidos': []},
 'resolvier': {'resolviere': []},
 'resolvimu': {'resolvimus': []},
 'resolvin': {'resolvins': []},
 'resolving': {'resolvinge': []},
 'resolvingpow': {'resolvingpower': []},
 'resolvingth': {'resolvingthe': []},
 'resolvon': {'resolvons': []},
 'resoly': {'resolye': ['resolyes']},
 'resolye': ['resolyes'],
 'resom': {'resome': ['resomer']},
 'resomat': {'resomatization': []},
 'resombl': {'resomblance': [], 'resomble': ['resombles'], 'resombling': []},
 'resomble': ['resombles'],
 'resomc': {'resomces': []},
 'resome': ['resomer'],
 'resommend': {'resommended': []},
 'reson': {'resonable': ['resonables', 'resonableness'],
           'resonably': [],
           'resonance': [],
           'resonancies': [],
           'resonancy': [],
           'resonant': ['resonants', 'resonanted', 'resonanting'],
           'resonate': ['resonates', 'resonated', 'resonately'],
           'resonating': [],
           'resonation': ['resonations'],
           'resonator': [],
           'resone': ['resoned', 'resones', 'resonent', 'resonence'],
           'resonicated': [],
           'resoning': ['resonings'],
           'resons': []},
 'resona': {'resonas': []},
 'resonab': {'resonabant': [], 'resonabely': []},
 'resonabil': {'resonabill': []},
 'resonabili': {'resonabilis': []},
 'resonabl': {'resonablement': []},
 'resonable': ['resonables', 'resonableness'],
 'resonac': {'resonace': ['resonaces']},
 'resonace': ['resonaces'],
 'resonan': {'resonans': []},
 'resonanac': {'resonanace': []},
 'resonancechamb': {'resonancechamber': []},
 'resonanceenhanc': {'resonanceenhanced': []},
 'resonancefrequ': {'resonancefrequency': []},
 'resonanceimag': {'resonanceimaging': []},
 'resonancelik': {'resonancelike': []},
 'resonancestabil': {'resonancestabilized': []},
 'resonancia': {'resonancias': []},
 'resonandi': {'resonandy': []},
 'resonane': {'resonanee': []},
 'resonano': {'resonanoe': []},
 'resonans': {'resonanse': []},
 'resonant': {'resonantal': [], 'resonante': ['resonantes']},
 'resonantcav': {'resonantcavity': []},
 'resonante': ['resonantes'],
 'resonantfrequ': {'resonantfrequency': []},
 'resonanti': {'resonantie': [], 'resonantis': []},
 'resonantibu': {'resonantibus': []},
 'resonantli': {'resonantly': []},
 'resonantor': {'resonantors': []},
 'resonanttunnel': {'resonanttunneling': []},
 'resonantval': {'resonantvalence': []},
 'resonanzkurv': {'resonanzkurve': []},
 'resonanztheori': {'resonanztheorie': []},
 'resonanztomographi': {'resonanztomographie': []},
 'resonar': {'resonare': ['resonares', 'resonared', 'resonarent']},
 'resonare': ['resonares', 'resonared', 'resonarent'],
 'resonat': {'resonater': []},
 'resonate': ['resonates', 'resonated', 'resonately'],
 'resonateur': {'resonateurs': []},
 'resonation': ['resonations'],
 'resonatori': {'resonatory': []},
 'resonauc': {'resonauce': []},
 'resonc': {'resonce': []},
 'resond': {'resonded': [], 'resondent': ['resondents'], 'resonding': []},
 'resondent': ['resondents'],
 'resone': ['resoned', 'resones', 'resonent', 'resonence'],
 'resonemu': {'resonemus': []},
 'resoni': {'resonis': []},
 'resoning': ['resonings'],
 'resonm': {'resonmed': []},
 'resonn': {'resonnance': ['resonnances'],
            'resonnant': ['resonnants'],
            'resonne': ['resonner', 'resonnent', 'resonnement']},
 'resonnai': {'resonnaient': []},
 'resonnance': ['resonnances'],
 'resonnant': {'resonnante': []},
 'resonne': ['resonner', 'resonnent', 'resonnement'],
 'resononc': {'resononce': []},
 'resonrc': {'resonrce': ['resonrces']},
 'resonrce': ['resonrces'],
 'resons': {'resonsance': [],
            'resonse': ['resonses'],
            'resonsibilities': [],
            'resonsibility': [],
            'resonsible': [],
            'resonsive': ['resonsiveness']},
 'resonse': ['resonses'],
 'resonsive': ['resonsiveness'],
 'resonsnc': {'resonsnce': []},
 'resonstruct': {'resonstruction': []},
 'resont': {'resontment': []},
 'resoom': {'resoomed': []},
 'resoond': {'resoonded': [], 'resoondent': ['resoondents']},
 'resoondent': ['resoondents'],
 'resoons': {'resoonse': ['resoonses'],
             'resoonsibilities': [],
             'resoonsibility': [],
             'resoonsible': []},
 'resoonse': ['resoonses'],
 'resoorc': {'resoorce': ['resoorces']},
 'resoorce': ['resoorces'],
 'resop': {'resopal': []},
 'resophag': {'resophageal': []},
 'resophagu': {'resophagus': []},
 'resophon': {'resophonic': []},
 'resopns': {'resopnse': [], 'resopnsibility': [], 'resopnsible': []},
 'resopons': {'resoponse': [], 'resoponsible': []},
 'resoprt': {'resoprtion': []},
 'resopt': {'resoption': []},
 'resor': {'resoration': ['resorations'],
           'resore': ['resored'],
           'resoring': [],
           'resorred': [],
           'resors': []},
 'resoration': ['resorations'],
 'resorb': {'resorbability': [],
            'resorbable': ['resorbables'],
            'resorbe': ['resorbes',
                        'resorbed',
                        'resorber',
                        'resorbent',
                        'resorbers',
                        'resorbents'],
            'resorbing': [],
            'resorbs': []},
 'resorbable': ['resorbables'],
 'resorbe': {'resorbee': ['resorbees']},
 'resorbee': ['resorbees'],
 'resorben': {'resorbens': []},
 'resorbiert': {'resorbierte': []},
 'resorbt': {'resorbtion': [], 'resorbtive': []},
 'resorc': {'resorce': ['resorces']},
 'resorce': ['resorces'],
 'resorcin': {'resorcinal': [], 'resorcinate': [], 'resorcine': []},
 'resorcinaren': {'resorcinarene': ['resorcinarenes']},
 'resorcinarene': ['resorcinarenes'],
 'resorcinol': ['resorcinolic'],
 'resorcinolformaldehyd': {'resorcinolformaldehyde': []},
 'resorcinoli': {'resorcinolis': []},
 'resorcycl': {'resorcyclic': []},
 'resorcyl': {'resorcylate': [], 'resorcylic': []},
 'resord': {'resorded': [], 'resords': []},
 'resore': ['resored'],
 'resorh': {'resorhed': []},
 'resori': {'resoried': []},
 'resorl': {'resorled': [], 'resorls': []},
 'resorm': {'resormation': [],
            'resormed': [],
            'resormer': ['resormers'],
            'resorming': []},
 'resormer': ['resormers'],
 'resorp': {'resorped': []},
 'resorpt': {'resorption': ['resorptional'], 'resorptive': []},
 'resorption': {'resorptione': []},
 'resors': {'resorse': []},
 'resort': ['resorte',
            'resorter',
            'resorted',
            'resortes',
            'resorting',
            'resortion',
            'resorters',
            'resortment',
            'resortings',
            'resortation'],
 'resorti': {'resortie': [], 'resortis': [], 'resorty': []},
 'resorting': {'resortinge': []},
 'resortiss': {'resortissants': []},
 'resortlik': {'resortlike': []},
 'resortstyl': {'resortstyle': []},
 'resorttyp': {'resorttype': []},
 'resortu': {'resortus': []},
 'resoruc': {'resoruce': ['resoruces']},
 'resoruce': ['resoruces'],
 'resorv': {'resorve': ['resorved', 'resorves']},
 'resorve': ['resorved', 'resorves'],
 'resorvoir': {'resorvoirs': []},
 'resosurc': {'resosurces': []},
 'resot': {'resotion': ['resotions']},
 'resotion': ['resotions'],
 'resotr': {'resotration': [], 'resotre': ['resotred']},
 'resotre': ['resotred'],
 'resotuc': {'resotuces': []},
 'resotut': {'resotution': ['resotutions']},
 'resotution': ['resotutions'],
 'resotv': {'resotve': ['resotved']},
 'resotve': ['resotved'],
 'resou': {'resoue': ['resoued'], 'resous': []},
 'resoubc': {'resoubces': []},
 'resouc': {'resouce': ['resouces', 'resouceful', 'resoucefulness']},
 'resouce': ['resouces', 'resouceful', 'resoucefulness'],
 'resoucr': {'resoucres': []},
 'resoud': {'resouding': []},
 'resoudr': {'resoudre': []},
 'resoudroi': {'resoudrois': []},
 'resoue': ['resoued'],
 'resouec': {'resoueces': []},
 'resoufc': {'resoufces': []},
 'resouic': {'resouice': ['resouices']},
 'resouice': ['resouices'],
 'resoul': {'resouled': []},
 'resouldr': {'resouldre': []},
 'resoult': {'resoultion': ['resoultions']},
 'resoultion': ['resoultions'],
 'resoulut': {'resoulution': []},
 'resoun': {'resounable': [], 'resoune': ['resounes'], 'resouns': []},
 'resound': {'resounde': ['resounded', 'resounder'],
             'resounding': ['resoundings'],
             'resounds': []},
 'resounde': ['resounded', 'resounder'],
 'resoundedli': {'resoundedly': []},
 'resoundi': {'resoundis': []},
 'resounding': ['resoundings'],
 'resoundingli': {'resoundingly': []},
 'resoundli': {'resoundly': []},
 'resoune': ['resounes'],
 'resour': {'resoure': ['resoures'], 'resours': []},
 'resourc': {'resource': ['resourced',
                          'resourcer',
                          'resourcers',
                          'resourceful',
                          'resourceness',
                          'resourcement',
                          'resourcefully',
                          'resourcefulness'],
             'resourcing': [],
             'resourcism': [],
             'resourcs': []},
 'resourca': {'resourcas': []},
 'resourcc': {'resourcces': [], 'resourccs': []},
 'resource': {'resourcee': ['resourcees']},
 'resourceabund': {'resourceabundant': []},
 'resourcealloc': {'resourceallocating': [], 'resourceallocation': []},
 'resourcebas': {'resourcebase': ['resourcebased']},
 'resourcebase': ['resourcebased'],
 'resourcebound': {'resourcebounded': []},
 'resourcebundl': {'resourcebundle': ['resourcebundles']},
 'resourcebundle': ['resourcebundles'],
 'resourcecent': {'resourcecenter': []},
 'resourceconsci': {'resourceconscious': []},
 'resourceconserv': {'resourceconservation': [], 'resourceconserving': []},
 'resourceconstrain': {'resourceconstrained': []},
 'resourceconsum': {'resourceconsuming': []},
 'resourceconsumpt': {'resourceconsumption': [], 'resourceconsumptive': []},
 'resourcedefici': {'resourcedeficient': []},
 'resourcedemand': {'resourcedemanding': []},
 'resourcedepend': {'resourcedependence': [],
                    'resourcedependency': [],
                    'resourcedependent': []},
 'resourcedeplet': {'resourcedepleting': [], 'resourcedepletion': []},
 'resourcedevelop': {'resourcedevelopment': []},
 'resourcedistribut': {'resourcedistribution': []},
 'resourcedrain': {'resourcedraining': []},
 'resourcee': ['resourcees'],
 'resourceeffici': {'resourceefficient': []},
 'resourceendow': {'resourceendowed': [], 'resourceendowment': []},
 'resourcefui': {'resourcefuiness': []},
 'resourceful': {'resourcefullness': []},
 'resourcefuln': {'resourcefulnes': []},
 'resourcegener': {'resourcegenerating': []},
 'resourcehold': {'resourceholding': []},
 'resourcehungri': {'resourcehungry': []},
 'resourceintens': {'resourceintensive': []},
 'resourceless': {'resourcelessness': []},
 'resourcelessli': {'resourcelessly': []},
 'resourcelifetim': {'resourcelifetime': []},
 'resourcelimit': {'resourcelimited': []},
 'resourcemanag': {'resourcemanagement': [], 'resourcemanager': []},
 'resourcemobil': {'resourcemobilization': []},
 'resourcenam': {'resourcename': []},
 'resourceori': {'resourceoriented': []},
 'resourceown': {'resourceowning': []},
 'resourceplan': {'resourceplanning': []},
 'resourceprocess': {'resourceprocessing': []},
 'resourceproduc': {'resourceproducing': []},
 'resourceproperti': {'resourceproperties': []},
 'resourceprovid': {'resourceproviding': []},
 'resourceread': {'resourcereader': []},
 'resourcerecoveri': {'resourcerecovery': []},
 'resourcerel': {'resourcerelated': []},
 'resources': {'resourcesful': ['resourcesfulness']},
 'resourcesar': {'resourcesare': []},
 'resourcesav': {'resourcesaving': []},
 'resourcesavail': {'resourcesavailable': []},
 'resourcesbas': {'resourcesbased': []},
 'resourcescarc': {'resourcescarce': []},
 'resourceseek': {'resourceseeking': []},
 'resourcesensit': {'resourcesensitive': []},
 'resourcesful': ['resourcesfulness'],
 'resourceshar': {'resourcesharing': []},
 'resourcesinclud': {'resourcesincluding': []},
 'resourcespecif': {'resourcespecific': []},
 'resourcesrel': {'resourcesrelated': []},
 'resourcestarv': {'resourcestarved': []},
 'resourcestr': {'resourcestring': []},
 'resourcetyp': {'resourcetype': []},
 'resourceus': {'resourceuse': [], 'resourceusing': []},
 'resourceutil': {'resourceutilization': []},
 'resourcewis': {'resourcewise': []},
 'resourcewrit': {'resourcewriter': []},
 'resourcist': {'resourcists': []},
 'resourco': {'resourcos': []},
 'resoure': {'resouree': ['resourees', 'resoureeful', 'resoureefulness']},
 'resourec': {'resoureces': [], 'resourecs': []},
 'resouree': ['resourees', 'resoureeful', 'resoureefulness'],
 'resouro': {'resouroe': ['resouroes']},
 'resouroe': ['resouroes'],
 'resourr': {'resourre': ['resourres']},
 'resourre': ['resourres'],
 'resours': {'resourse': ['resourses', 'resourseful', 'resoursefulness']},
 'resoursc': {'resoursces': []},
 'resourse': ['resourses', 'resourseful', 'resoursefulness'],
 'resourt': {'resourte': ['resourtes']},
 'resourte': ['resourtes'],
 'resousc': {'resousces': []},
 'resout': {'resoution': ['resoutions']},
 'resoutc': {'resoutce': ['resoutces']},
 'resoutce': ['resoutces'],
 'resoution': ['resoutions'],
 'resouud': {'resouuded': []},
 'resov': {'resove': ['resoved'], 'resoving': []},
 'resove': ['resoved'],
 'resovl': {'resovle': ['resovled']},
 'resovle': ['resovled'],
 'resovski': {'resovsky': []},
 'resow': {'resowed': [], 'resowing': ['resowings'], 'resows': []},
 'resowing': ['resowings'],
 'resp': {'respe': ['resped', 'respes', 'respeds'], 'resps': []},
 "resp'i": {"resp'y": []},
 "resp'li": {"resp'ly": []},
 'respa': {'respas': []},
 'respac': {'respace': ['respaced'], 'respacing': []},
 'respace': ['respaced'],
 'respact': {'respactable': [], 'respactive': ['respactively'], 'respacts': []},
 'respactive': ['respactively'],
 'respad': {'respaded': []},
 'respagn': {'respagne': []},
 'respaign': {'respaigne': []},
 'respair': {'respaire': []},
 'respal': {'respall': []},
 'respald': {'respalde': []},
 'respaldada': {'respaldadas': []},
 'respaldado': {'respaldados': []},
 'respaldo': {'respaldos': []},
 'respandr': {'respandre': []},
 'respans': {'respanse': [], 'respansibility': [], 'respansible': []},
 'respark': {'resparked': [], 'resparking': []},
 'respati': {'respatialization': [],
             'respatialize': ['respatialized'],
             'respatializing': []},
 'respatialis': {'respatialisation': []},
 'respatialize': ['respatialized'],
 'respawn': {'respawned': [], 'respawning': [], 'respawns': []},
 'respberri': {'respberries': []},
 'respcct': {'respccting': [], 'respccts': []},
 'respcctiv': {'respcctive': ['respcctively']},
 'respcctive': ['respcctively'],
 'respcet': {'respcets': []},
 'respcns': {'respcnse': []},
 'respcnsibl': {'respcnsibility': [], 'respcnsible': []},
 'respct': {'respcts': []},
 'respctabl': {'respctable': []},
 'respctiv': {'respctive': ['respctively']},
 'respctive': ['respctively'],
 'respdi': {'respdis': []},
 'respdns': {'respdnse': []},
 'respe': {'respee': []},
 'respeak': {'respeaking': []},
 'respeatedli': {'respeatedly': []},
 'respec': {'respecable': [],
            'respecful': ['respecfully'],
            'respecing': [],
            'respecive': ['respecively'],
            'respecs': []},
 'respecdv': {'respecdve': ['respecdvely']},
 'respecdve': ['respecdvely'],
 'respecful': ['respecfully'],
 'respeci': {'respeciable': [],
             'respecialization': [],
             'respecialize': ['respecialized'],
             'respecially': [],
             'respeciation': [],
             'respecied': [],
             'respeciing': [],
             'respeciive': ['respeciively'],
             'respecis': []},
 'respecialize': ['respecialized'],
 'respecif': {'respecification': ['respecifications']},
 'respecifi': {'respecified': [],
               'respecifies': [],
               'respecify': ['respecifying']},
 'respecification': ['respecifications'],
 'respecify': ['respecifying'],
 'respeciive': ['respeciively'],
 'respecit': {'respecitively': []},
 'respecitv': {'respecitve': ['respecitvely']},
 'respecitve': ['respecitvely'],
 'respecive': ['respecively'],
 'respeck': {'respeckable': [],
             'respecke': [],
             'respeckful': ['respeckfully'],
             'respecks': []},
 'respeckful': ['respeckfully'],
 'respeckt': {'respecktible': []},
 'respecl': {'respeclable': [],
             'respecled': [],
             'respeclful': ['respeclfully'],
             'respecling': [],
             'respeclive': ['respeclively'],
             'respecls': []},
 'respeclful': ['respeclfully'],
 'respeclive': ['respeclively'],
 'respecnv': {'respecnvely': []},
 'respecr': {'respecrability': [],
             'respecrable': [],
             'respecred': [],
             'respecrful': [],
             'respecrive': ['respecrively'],
             'respecrs': []},
 'respecrive': ['respecrively'],
 'respect': ['respecte',
             'respectes',
             'respecter',
             'respected',
             'respectal',
             'respectent',
             'respectant',
             'respection',
             'respective',
             'respecting',
             'respectful',
             'respectible',
             'respections',
             'respectable',
             'respectives',
             'respectably',
             'respectables',
             'respectfully',
             'respectively',
             'respectivity',
             'respectability',
             'respectibility',
             'respectiveness',
             'respectfulness',
             'respectableness'],
 'respecta': {'respectaable': [], 'respectas': []},
 'respectabihti': {'respectabihty': []},
 'respectabil': {'respectabilization': [],
                 'respectabilize': ['respectabilized'],
                 'respectabilizing': []},
 'respectabili': {'respectabilis': []},
 'respectabilis': {'respectabilise': []},
 'respectabilit': {'respectabilite': []},
 'respectabilize': ['respectabilized'],
 'respectabilti': {'respectabilty': []},
 'respectabl': {'respectabler': [], 'respectablity': [], 'respectablized': []},
 'respectablelook': {'respectablelooking': []},
 'respectables': {'respectablesized': []},
 'respectablesound': {'respectablesounding': []},
 'respectablil': {'respectablility': []},
 'respectablydress': {'respectablydressed': []},
 'respectacl': {'respectacle': []},
 'respectahil': {'respectahility': []},
 'respectahl': {'respectahle': []},
 'respectai': {'respectaient': [], 'respectais': []},
 'respectan': {'respectans': []},
 'respectant': {'respectantes': []},
 'respectaol': {'respectaole': []},
 'respectar': {'respectare': []},
 'respectbl': {'respectble': []},
 'respecte': {'respectee': ['respectees']},
 'respectedli': {'respectedly': []},
 'respectee': ['respectees'],
 'respecterai': {'respecteraient': []},
 'respecterbl': {'respecterble': []},
 'respecteron': {'respecterons': []},
 'respecteus': {'respecteuse': []},
 'respectev': {'respectevely': []},
 'respectfidli': {'respectfidly': []},
 'respectfnlli': {'respectfnlly': []},
 'respectfolli': {'respectfolly': []},
 'respectforth': {'respectforthe': []},
 'respectful': {'respectfull': []},
 'respectfuli': {'respectfuly': []},
 'respectfullli': {'respectfullly': []},
 'respecth': {'respecthe': ['respecthely']},
 'respecthe': ['respecthely'],
 'respecti': {'respectiely': [],
              'respectiful': ['respectifully'],
              'respectis': [],
              'respecty': []},
 'respectibu': {'respectibus': []},
 'respectic': {'respectice': ['respecticely']},
 'respectice': ['respecticely'],
 'respectiev': {'respectieve': []},
 'respectievelijk': {'respectievelijke': []},
 'respectievli': {'respectievly': []},
 'respectif': {'respectifs': []},
 'respectiful': ['respectifully'],
 'respectin': {'respectins': []},
 'respecting': {'respectinge': []},
 'respectingli': {'respectingly': []},
 'respectingth': {'respectingthe': []},
 'respectinspir': {'respectinspiring': []},
 'respectir': {'respectire': ['respectirely']},
 'respectire': ['respectirely'],
 'respectit': {'respectite': ['respectitely']},
 'respectite': ['respectitely'],
 'respectiu': {'respectiue': ['respectiuely']},
 'respectiue': ['respectiuely'],
 'respectiv': {'respectivement': [], 'respectivs': []},
 'respectiva': {'respectivae': [], 'respectivas': []},
 'respectivali': {'respectivaly': []},
 'respectivament': {'respectivamente': []},
 'respectivcli': {'respectivcly': []},
 "respective'i": {"respective'y": []},
 'respectivefi': {'respectivefy': []},
 'respectiveli': {'respectivelie': []},
 'respectivelli': {'respectivelly': []},
 'respectivelyth': {'respectivelythe': []},
 'respectiveri': {'respectivery': []},
 'respectiveti': {'respectivety': []},
 'respectivi': {'respectiviely': [], 'respectivis': []},
 'respectivili': {'respectivily': []},
 'respectivli': {'respectivly': []},
 'respectivo': {'respectivos': []},
 'respectiy': {'respectiye': ['respectiyely']},
 'respectiye': ['respectiyely'],
 'respectless': {'respectlesse': []},
 'respectlessli': {'respectlessly': []},
 'respectli': {'respectly': []},
 'respectlulli': {'respectlully': []},
 'respectlv': {'respectlve': ['respectlvely']},
 'respectlve': ['respectlvely'],
 'respecto': {'respectos': []},
 'respecton': {'respectons': []},
 'respector': {'respectors': []},
 'respectrv': {'respectrve': ['respectrvely']},
 'respectrve': ['respectrvely'],
 'respectsth': {'respectsthe': []},
 'respectsulli': {'respectsully': []},
 'respectt': {'respecttable': [], 'respecttive': ['respecttively']},
 'respectth': {'respectthe': []},
 'respecttive': ['respecttively'],
 'respecttoth': {'respecttothe': []},
 'respecttv': {'respecttve': ['respecttvely']},
 'respecttve': ['respecttvely'],
 'respectu': {'respectus': []},
 'respectueus': {'respectueuse': ['respectueuses', 'respectueusement']},
 'respectueuse': ['respectueuses', 'respectueusement'],
 'respectulli': {'respectully': []},
 'respectv': {'respectve': ['respectvely']},
 'respectve': ['respectvely'],
 'respectvi': {'respectviely': []},
 'respectworthi': {'respectworthiness': [], 'respectworthy': []},
 'respectyv': {'respectyvely': []},
 'respecuv': {'respecuvely': []},
 'respecv': {'respecvely': []},
 'respedl': {'respedls': []},
 'respedt': {'respedtable': [],
             'respedted': [],
             'respedtive': [],
             'respedts': []},
 'respeet': {'respeetability': [],
             'respeetable': [],
             'respeeted': [],
             'respeetful': ['respeetfully'],
             'respeeting': [],
             'respeetive': ['respeetively'],
             'respeets': []},
 'respeetful': ['respeetfully'],
 'respeetive': ['respeetively'],
 'respeft': {'respeftable': [],
             'respefted': [],
             'respefting': [],
             'respeftive': [],
             'respefts': []},
 'respeitabilidad': {'respeitabilidade': []},
 'respeitada': {'respeitadas': []},
 'respeitado': {'respeitados': []},
 'respeitant': {'respeitante': ['respeitantes']},
 'respeitante': ['respeitantes'],
 'respeito': {'respeitos': []},
 'respeitosament': {'respeitosamente': []},
 'respek': {'respeks': []},
 'respekt': {'respektable': [], 'respektive': [], 'respekts': []},
 'respektiert': {'respektierte': []},
 'respektlo': {'respektlos': []},
 'respektlos': {'respektloser': []},
 'respektvol': {'respektvoll': ['respektvolle']},
 'respektvoll': ['respektvolle'],
 'respel': {'respell': ['respells', 'respelled', 'respelling', 'respellings']},
 'respell': ['respells', 'respelled', 'respelling', 'respellings'],
 'respend': {'respendent': ['respendents'],
             'respending': ['respendings'],
             'respends': []},
 'respendent': ['respendents'],
 'respendi': {'respendial': []},
 'respending': ['respendings'],
 'respens': {'respense': ['respenses'],
             'respensibility': [],
             'respensible': []},
 'respense': ['respenses'],
 'respeot': {'respeotability': [],
             'respeotable': [],
             'respeote': ['respeoted'],
             'respeotful': ['respeotfully'],
             'respeoting': [],
             'respeotive': ['respeotively'],
             'respeots': []},
 'respeote': ['respeoted'],
 'respeotful': ['respeotfully'],
 'respeotive': ['respeotively'],
 'resper': {'resperation': [], 'respers': []},
 'resperd': {'resperdal': []},
 'respergen': {'respergens': []},
 'resperger': {'respergere': []},
 'respergin': {'respergine': []},
 'resperidon': {'resperidone': []},
 'resperin': {'resperine': []},
 'resperpin': {'resperpine': []},
 'respers': {'respersed': []},
 'respersi': {'respersis': []},
 'respersu': {'respersus': []},
 'respert': {'resperting': [], 'respertive': ['respertively'], 'resperts': []},
 'respertive': ['respertively'],
 'respest': {'respesting': [], 'respestive': ['respestively'], 'respests': []},
 'respestive': ['respestively'],
 'respet': {'respetable': ['respetables'],
            'respete': ['respeted'],
            'respetive': ['respetively'],
            'respets': []},
 'respetable': ['respetables'],
 'respetada': {'respetadas': []},
 'respetado': {'respetados': []},
 'respetamo': {'respetamos': []},
 'respetars': {'respetarse': []},
 'respete': ['respeted'],
 'respetive': ['respetively'],
 'respetl': {'respetling': []},
 'respeto': {'respetos': []},
 'respett': {'respettive': [], 'respetts': []},
 'respettivament': {'respettivamente': []},
 'respetuosament': {'respetuosamente': []},
 'respetuoso': {'respetuosos': []},
 'respi': {'respis': [], 'respy': []},
 'respiatori': {'respiatory': []},
 'respic': {'respice': []},
 'respicer': {'respicere': ['respicerent']},
 'respicere': ['respicerent'],
 'respici': {'respiciant': [],
             'respicient': [],
             'respicies': [],
             'respicis': []},
 'respicia': {'respicias': []},
 'respiciamu': {'respiciamus': []},
 'respicieb': {'respiciebant': []},
 'respicien': {'respiciens': []},
 'respiciendu': {'respiciendus': []},
 'respicient': {'respiciente': ['respicientes']},
 'respiciente': ['respicientes'],
 'respicienti': {'respicientis': []},
 'respicientibu': {'respicientibus': []},
 'respicimu': {'respicimus': []},
 'respicit': {'respicite': []},
 'respiciu': {'respicius': []},
 'respict': {'respictable': [],
             'respicted': [],
             'respictible': [],
             'respictively': [],
             'respicts': []},
 'respid': {'respide': []},
 'respihal': {'respihaler': []},
 'respiiat': {'respiiation': []},
 'respiiatori': {'respiiatory': []},
 'respik': {'respike': ['respiked'], 'respiking': []},
 'respike': ['respiked'],
 'respin': {'respinning': [], 'respins': []},
 'resping': {'respinge': ['respinger']},
 'respinge': ['respinger'],
 'respinger': {'respingere': []},
 'respins': {'respinse': []},
 'respint': {'respinte': []},
 'respir': {'respirability': [],
            'respirable': [],
            'respiral': [],
            'respirant': [],
            'respirate': ['respirated', 'respirates'],
            'respirating': [],
            'respiration': ['respirational'],
            'respirative': [],
            'respirator': [],
            'respire': ['respirer',
                        'respires',
                        'respired',
                        'respirers',
                        'respirent'],
            'respiring': []},
 'respira': {'respiraation': [], 'respiras': []},
 'respiracion': {'respiraciones': []},
 'respiradero': {'respiraderos': []},
 'respirai': {'respiraient': [], 'respirais': []},
 'respiralori': {'respiralory': []},
 'respiramo': {'respiramos': []},
 'respiran': {'respirans': []},
 'respirant': {'respirante': ['respirantes']},
 'respirante': ['respirantes'],
 'respiraori': {'respiraory': []},
 'respirar': {'respirare': []},
 'respirarori': {'respirarory': []},
 'respiratari': {'respiratary': []},
 'respirate': ['respirated', 'respirates'],
 'respirati': {'respiratiou': []},
 'respiration': {'respiratione': []},
 'respirationdefici': {'respirationdeficient': []},
 'respirationdepend': {'respirationdependent': []},
 'respirationi': {'respirationis': []},
 'respirationr': {'respirationrate': []},
 'respirationsorgan': {'respirationsorgane': []},
 'respirationstrakt': {'respirationstraktes': []},
 'respiratiori': {'respiratiory': []},
 'respiratoir': {'respiratoire': ['respiratoires']},
 'respiratoire': ['respiratoires'],
 'respiratordepend': {'respiratordependent': []},
 'respiratori': {'respiratorial': [],
                 'respiratorie': ['respiratories'],
                 'respiratory': []},
 'respiratoria': {'respiratoriae': [], 'respiratorias': []},
 'respiratorie': ['respiratories'],
 'respiratorili': {'respiratorily': []},
 'respiratorio': {'respiratorios': []},
 'respiratorisch': {'respiratorische': ['respiratorischer']},
 'respiratorische': ['respiratorischer'],
 'respiratoriu': {'respiratorius': []},
 'respiratorycent': {'respiratorycenter': []},
 'respiratorydefici': {'respiratorydeficient': []},
 'respiratorydepress': {'respiratorydepressant': [],
                        'respiratorydepression': []},
 'respiratorydiseas': {'respiratorydisease': []},
 'respiratoryfailur': {'respiratoryfailure': []},
 'respiratoryinduc': {'respiratoryinduced': []},
 'respiratoryinfect': {'respiratoryinfections': []},
 'respiratoryorgan': {'respiratoryorgans': []},
 'respiratoryr': {'respiratoryrate': []},
 'respiratoryrel': {'respiratoryrelated': []},
 'respiratoti': {'respiratoty': []},
 'respirazion': {'respirazione': []},
 'respircar': {'respircare': []},
 'respircel': {'respircell': []},
 'respirdi': {'respirdis': []},
 'respire': {'respiree': []},
 'respiremu': {'respiremus': []},
 'respireron': {'respirerons': []},
 'respiridon': {'respiridone': []},
 'respirion': {'respirions': []},
 'respiritori': {'respiritory': []},
 'respiritu': {'respiritualization': [],
               'respiritualize': ['respiritualized'],
               'respiritualizing': []},
 'respiritualis': {'respiritualisation': []},
 'respiritualize': ['respiritualized'],
 'respirm': {'respirmed': []},
 'respirocyt': {'respirocyte': ['respirocytes']},
 'respirocyte': ['respirocytes'],
 'respirofer': {'respirofermentative': []},
 'respirogen': {'respirogenic': []},
 'respirogram': {'respirograms': []},
 'respirolog': {'respirology': []},
 'respirologist': {'respirologists': []},
 'respiromet': {'respirometer': ['respirometers']},
 'respirometer': ['respirometers'],
 'respirometr': {'respirometric': ['respirometrically']},
 'respirometri': {'respirometry': []},
 'respirometric': ['respirometrically'],
 'respiron': {'respironics': [], 'respirons': []},
 'respirophas': {'respirophasic': []},
 'respiroviru': {'respirovirus': []},
 'respirovirus': {'respiroviruses': []},
 'respirtori': {'respirtory': []},
 'respit': {'respitation': [],
            'respite': ['respited'],
            'respiting': [],
            'respits': [],
            'respitted': []},
 'respitatori': {'respitatory': []},
 'respite': ['respited'],
 'respitori': {'respitory': []},
 'respitrac': {'respitrace': []},
 'resplandec': {'resplandece': ['resplandecer']},
 'resplandece': ['resplandecer'],
 'resplandecent': {'resplandecente': []},
 'resplandecient': {'resplandeciente': ['resplandecientes']},
 'resplandeciente': ['resplandecientes'],
 'resplandi': {'resplandy': []},
 'resplandissan': {'resplandissans': []},
 'resplandor': {'resplandores': []},
 'respled': {'respledent': []},
 'resplend': {'resplendance': [],
              'resplendant': [],
              'resplende': ['resplended',
                            'resplendent',
                            'resplendence',
                            'resplendency',
                            'resplendently'],
              'resplending': [],
              'resplends': []},
 'resplendantli': {'resplendantly': []},
 'resplende': ['resplended',
               'resplendent',
               'resplendence',
               'resplendency',
               'resplendently'],
 'resplenden': {'resplendens': []},
 'resplendendi': {'resplendendy': []},
 'resplendent': {'resplendente': []},
 'resplender': {'resplendere': []},
 'resplendiss': {'resplendissant': ['resplendissants'],
                 'resplendissement': [],
                 'resplendissent': []},
 'resplendissai': {'resplendissaient': []},
 'resplendissant': {'resplendissante': ['resplendissantes']},
 'resplendissante': ['resplendissantes'],
 'respli': {'resply': []},
 'resplic': {'resplice': ['respliced'], 'resplicing': []},
 'resplice': ['respliced'],
 'resplint': {'resplinted': [], 'resplinting': []},
 'resplit': {'resplits': [], 'resplitting': []},
 'resplratori': {'resplratory': []},
 'resplut': {'resplution': []},
 'resplv': {'resplved': []},
 'respndent': {'respndents': []},
 'respnns': {'respnnse': []},
 'respns': {'respnse': ['respnses']},
 'respnse': ['respnses'],
 'respnsibl': {'respnsibilities': [], 'respnsibility': [], 'respnsible': []},
 'respo': {'respos': []},
 'respoas': {'respoase': ['respoases'],
             'respoasibilities': [],
             'respoasibility': [],
             'respoasible': []},
 'respoase': ['respoases'],
 'respoct': {'respoctable': [],
             'respoctfully': [],
             'respocting': [],
             'respoctive': [],
             'respocts': []},
 'respod': {'respodent': ['respodents']},
 'respodent': ['respodents'],
 'respohs': {'respohse': []},
 'respok': {'respoke': []},
 'respom': {'respome': [], 'respomibility': []},
 'respoms': {'respomse': []},
 'respon': {'responance': [],
            'respone': ['respones',
                        'responed',
                        'responent',
                        'responents',
                        'responeible',
                        'responeibility'],
            'responibilities': [],
            'responibility': [],
            'responible': [],
            'respons': []},
 'respona': {'responae': ['responaes'],
             'responaibility': [],
             'responaible': []},
 'responae': ['responaes'],
 'responbl': {'responbilities': [], 'responbility': [], 'responble': []},
 'responc': {'responce': ['responces'],
             'responcibility': [],
             'responcible': []},
 'responce': ['responces'],
 'respond': {'respondability': [],
             'respondable': [],
             'respondance': [],
             'respondant': ['respondants'],
             'responde': ['responder',
                          'respondes',
                          'responded',
                          'respondent',
                          'respondency',
                          'respondence',
                          'respondeant',
                          'respondences',
                          'respondently',
                          'respondencies'],
             'respondibility': [],
             'respondible': [],
             'responding': ['respondings'],
             'responds': []},
 'responda': {'respondas': []},
 'respondai': {'respondaient': []},
 'respondant': ['respondants'],
 'respondcnc': {'respondcnce': []},
 'respondcr': {'respondcre': [], 'respondcrs': []},
 'respondd': {'responddents': []},
 'responde': {'respondee': ['respondees']},
 'respondea': {'respondeas': []},
 'respondeamu': {'respondeamus': []},
 'respondeati': {'respondeatis': []},
 'respondeb': {'respondebant': [], 'respondebitis': []},
 'respondebi': {'respondebis': []},
 'respondebimu': {'respondebimus': []},
 'respondee': ['respondees'],
 'respondemo': {'respondemos': []},
 'respondemu': {'respondemus': []},
 'responden': {'respondens': []},
 'respondend': {'respondends': []},
 'respondene': {'respondenee': []},
 'respondenr': {'respondenrs': []},
 'respondent': {'respondente': ['respondentes']},
 'respondente': ['respondentes'],
 'respondenti': {'respondentis': []},
 'respondentibu': {'respondentibus': []},
 'responder': {'respondere': ['responderes', 'responderent']},
 'respondere': ['responderes', 'responderent'],
 'responderemu': {'responderemus': []},
 'responderi': {'responderis': []},
 'responderl': {'responderle': []},
 'responderm': {'responderme': []},
 'respondert': {'responderte': []},
 'respondet': {'respondete': [], 'respondets': []},
 'respondi': {'respondis': [], 'respondy': []},
 'respondient': {'respondiente': []},
 'respondieronm': {'respondieronme': []},
 'respondies': {'respondiese': []},
 'respondimo': {'respondimos': []},
 'respondimu': {'respondimus': []},
 'responding': ['respondings'],
 'respondingli': {'respondingly': []},
 'respondir': {'respondirent': []},
 'respondiss': {'respondisse': ['respondissent']},
 'respondisse': ['respondissent'],
 'respondisti': {'respondistis': []},
 'respondnet': {'respondnets': []},
 'respondoi': {'respondoient': []},
 'respondr': {'respondre': []},
 'respondu': {'respondus': []},
 'respone': {'responee': ['responees']},
 'responee': ['responees'],
 'respones': {'responese': ['responeses']},
 'responese': ['responeses'],
 'responi': {'responie': [], 'responiibility': [], 'responiible': []},
 'responis': {'responisibility': [], 'responisible': []},
 'responisbl': {'responisbility': [], 'responisble': []},
 'respono': {'responoent': []},
 'responr': {'responre': []},
 'respons': {'responsabiliti': ['responsabilitis', 'responsabilities'],
             'responsability': [],
             'responsable': ['responsables'],
             'responsal': ['responsals'],
             'responsant': [],
             'response': ['responsed',
                          'responser',
                          'responsers',
                          'responsents',
                          'responseable',
                          'responseability'],
             'responsibiliti': ['responsibilitis'],
             'responsibility': [],
             'responsible': ['responsibles', 'responsibleness'],
             'responsibli': [],
             'responsibly': [],
             'responsing': [],
             'responsion': ['responsions'],
             'responsity': [],
             'responsive': ['responsives', 'responsively', 'responsiveness'],
             'responsivities': [],
             'responsivity': []},
 'responsa': {'responsae': [], 'responsas': []},
 'responsabil': {'responsabile': []},
 'responsabilidad': {'responsabilidade': ['responsabilidades']},
 'responsabilidade': ['responsabilidades'],
 'responsabilis': {'responsabilisation': [], 'responsabiliser': []},
 'responsabilit': {'responsabilitate': [],
                   'responsabilite': ['responsabilites']},
 'responsabilite': ['responsabilites'],
 'responsabiliti': ['responsabilitis', 'responsabilities'],
 'responsabilizars': {'responsabilizarse': []},
 'responsabl': {'responsablle': []},
 'responsable': ['responsables'],
 'responsablement': {'responsablemente': []},
 'responsal': {'responsale': ['responsales'], 'responsall': []},
 'responsale': ['responsales'],
 'responsali': {'responsalis': []},
 'responsaqu': {'responsaque': []},
 'responsar': {'responsare': []},
 'responsari': {'responsaries': [], 'responsary': []},
 'responsavei': {'responsaveis': []},
 'responsbiil': {'responsbiility': []},
 'responsbil': {'responsbile': []},
 'responsbl': {'responsbilities': [], 'responsbility': [], 'responsble': []},
 'responsc': {'responscs': []},
 'responsd': {'responsdents': []},
 'response': {'responsee': ['responsees']},
 'responsebas': {'responsebased': []},
 'responsebl': {'responsebility': []},
 'responsecent': {'responsecentered': []},
 'responsecod': {'responsecode': []},
 'responseconsequ': {'responseconsequence': []},
 'responseconting': {'responsecontingent': []},
 'responsecurv': {'responsecurve': ['responsecurves']},
 'responsecurve': ['responsecurves'],
 'responsedepend': {'responsedependence': [], 'responsedependent': []},
 'responsee': ['responsees'],
 'responseencod': {'responseencoding': []},
 'responsefrequ': {'responsefrequency': []},
 'responsefunct': {'responsefunction': []},
 'responsehead': {'responseheaders': []},
 'responsei': {'responseis': []},
 'responseindepend': {'responseindependent': []},
 'responselearn': {'responselearning': []},
 'responsenamespac': {'responsenamespace': []},
 'responseori': {'responseoriented': []},
 'responseoutcom': {'responseoutcome': []},
 'responsepattern': {'responsepatterns': []},
 'responseprevent': {'responseprevention': []},
 'responseproduc': {'responseproduced': []},
 'responser': {'responserate': []},
 'responserbl': {'responserbility': []},
 'responsereinforc': {'responsereinforcement': [], 'responsereinforcer': []},
 'responserel': {'responserelated': []},
 'responserespons': {'responseresponse': []},
 'responseselect': {'responseselection': []},
 'responsesequ': {'responsesequence': ['responsesequences']},
 'responsesequence': ['responsesequences'],
 'responsespecif': {'responsespecific': []},
 'responsestimulu': {'responsestimulus': []},
 'responsesurfac': {'responsesurface': []},
 'responsetim': {'responsetime': ['responsetimes']},
 'responsetime': ['responsetimes'],
 'responsetoth': {'responsetothe': []},
 'responsetyp': {'responsetype': []},
 'responsewa': {'responsewas': []},
 'responsi': {'responsie': [],
              'responsiity': [],
              'responsis': [],
              'responsys': []},
 'responsib': {'responsibe': [],
               'responsibibility': [],
               'responsibities': [],
               'responsibity': []},
 "responsib'": {"responsib'e": []},
 'responsibd': {'responsibdity': []},
 'responsibeel': {'responsibeelity': []},
 'responsibfl': {'responsibflity': []},
 'responsibi': {'responsibie': [], 'responsibiities': [], 'responsibiity': []},
 "responsibib'ti": {"responsibib'ty": []},
 'responsibibti': {'responsibibties': [], 'responsibibty': []},
 'responsibif': {'responsibifity': []},
 'responsibihti': {'responsibihties': [], 'responsibihty': []},
 'responsibii': {'responsibiiities': [], 'responsibiiity': []},
 'responsibiil': {'responsibiility': []},
 'responsibiilti': {'responsibiilty': []},
 'responsibil': {'responsibile': [],
                 'responsibilism': [],
                 'responsibilization': [],
                 'responsibilize': ['responsibilized'],
                 'responsibilizing': [],
                 'responsibillity': []},
 'responsibili': {'responsibilies': [],
                  'responsibiliity': [],
                  'responsibily': []},
 'responsibilid': {'responsibilides': []},
 'responsibilidad': {'responsibilidades': []},
 'responsibilii': {'responsibiliies': []},
 'responsibiliit': {'responsibiliites': []},
 'responsibilil': {'responsibilility': []},
 'responsibilili': {'responsibililies': [], 'responsibilily': []},
 'responsibililti': {'responsibililty': []},
 'responsibiliri': {'responsibiliries': [], 'responsibiliry': []},
 'responsibilis': {'responsibilisation': [],
                   'responsibilised': [],
                   'responsibilising': []},
 'responsibilit': {'responsibilite': ['responsibilites'],
                   'responsibilitics': [],
                   'responsibilitities': [],
                   'responsibilitity': []},
 'responsibilite': ['responsibilites'],
 'responsibiliti': {'responsibilitie': []},
 'responsibilitit': {'responsibilitites': []},
 'responsibilitybas': {'responsibilitybased': []},
 'responsibilityi': {'responsibilityis': []},
 'responsibilitytak': {'responsibilitytaking': []},
 'responsibiliu': {'responsibiliues': []},
 'responsibilize': ['responsibilized'],
 'responsibillti': {'responsibillties': [], 'responsibillty': []},
 'responsibilrti': {'responsibilrty': []},
 'responsibilti': {'responsibilties': [], 'responsibilty': []},
 'responsibiltii': {'responsibiltiies': []},
 'responsibiltti': {'responsibiltty': []},
 'responsibit': {'responsibitities': [], 'responsibitity': []},
 'responsibiuti': {'responsibiuties': [], 'responsibiuty': []},
 'responsibl': {'responsiblities': [],
                'responsiblity': [],
                'responsibllities': [],
                'responsibllity': [],
                'responsibls': []},
 'responsible': ['responsibles', 'responsibleness'],
 'responsibleforth': {'responsibleforthe': []},
 'responsiblelook': {'responsiblelooking': []},
 'responsibleparti': {'responsibleparty': []},
 'responsibli': {'responsibliity': []},
 'responsiblil': {'responsiblilities': [], 'responsiblility': []},
 'responsiblilti': {'responsiblilty': []},
 'responsiblllti': {'responsiblllty': []},
 'responsibllti': {'responsibllty': []},
 'responsibt': {'responsibte': []},
 'responsibtl': {'responsibtlity': []},
 'responsibu': {'responsibuities': [], 'responsibuity': []},
 'responsidil': {'responsidility': []},
 'responsihil': {'responsihilities': [], 'responsihility': []},
 'responsihl': {'responsihle': []},
 'responsihli': {'responsihly': []},
 'responsiibl': {'responsiiblity': []},
 'responsiil': {'responsiilities': [], 'responsiility': []},
 'responsil': {'responsile': [], 'responsilities': [], 'responsility': []},
 'responsilb': {'responsilbe': []},
 'responsilib': {'responsilibity': []},
 'responsilil': {'responsilility': []},
 'responsioil': {'responsioilities': [], 'responsioility': []},
 'responsiol': {'responsiole': []},
 'responsion': {'responsione': ['responsiones']},
 'responsione': ['responsiones'],
 'responsioni': {'responsionis': []},
 'responsionibu': {'responsionibus': []},
 'responsiril': {'responsirility': []},
 'responsis': {'responsisibility': []},
 'responsit': {'responsitivity': []},
 'responsitil': {'responsitility': []},
 'responsiv': {'responsivness': []},
 'responsivcli': {'responsivcly': []},
 'responsive': ['responsives', 'responsively', 'responsiveness'],
 'responsiven': {'responsivenes': []},
 'responsives': {'responsivesness': []},
 'responsiviri': {'responsiviry': []},
 'responsivist': {'responsivists': []},
 'responsivlti': {'responsivlty': []},
 'responslbl': {'responslbility': [], 'responslble': []},
 'responslblllti': {'responslblllty': []},
 'responslbllltl': {'responslbllltles': []},
 'responslv': {'responslve': [], 'responslvity': []},
 'responso': {'responsos': []},
 'responsori': {'responsorial': ['responsorials', 'responsorially'],
                'responsories': [],
                'responsory': []},
 'responsoria': {'responsoriae': []},
 'responsorial': {'responsoriale': []},
 'responsoriali': {'responsorialis': []},
 'responsorii': {'responsoriis': []},
 'responsorio': {'responsorios': []},
 'responsoriu': {'responsorius': []},
 'responss': {'responsse': [], 'responssible': []},
 'responstbl': {'responstbility': [], 'responstble': []},
 'responsu': {'responsus': []},
 'responsumqu': {'responsumque': []},
 'responsuro': {'responsuros': []},
 'responsuru': {'responsurus': []},
 'respont': {'respontable': [], 'responte': [], 'respontibility': []},
 'responth': {'responthe': []},
 'respool': {'respooled': [], 'respooling': []},
 'respoos': {'respoose': []},
 'resporatori': {'resporatory': []},
 'resporis': {'resporise': [], 'resporisibilities': [], 'resporisibility': []},
 'resporpt': {'resporption': []},
 'respors': {'resporse': [], 'resporsibility': [], 'resporsible': []},
 'resport': {'resported': [], 'resportion': [], 'resports': []},
 'respos': {'respose': ['resposes', 'resposed', 'resposeful'],
            'resposibilities': [],
            'resposibility': [],
            'resposible': [],
            'resposing': [],
            'resposive': ['resposiveness']},
 'respose': ['resposes', 'resposed', 'resposeful'],
 'resposit': {'resposition': ['respositioned', 'respositioning']},
 'resposition': ['respositioned', 'respositioning'],
 'respositori': {'respositories': [], 'respository': []},
 'resposive': ['resposiveness'],
 'resposn': {'resposne': ['resposnes'], 'resposnible': []},
 'resposne': ['resposnes'],
 'resposs': {'respossibility': [], 'respossible': []},
 'respost': {'respostes': []},
 'resposta': {'respostas': []},
 'respot': {'respotted': [], 'respotting': []},
 'respoud': {'respouded': []},
 'respoun': {'respouns': []},
 'respoundr': {'respoundre': []},
 'respous': {'respouse': ['respouses'],
             'respousibility': [],
             'respousible': []},
 'respouse': ['respouses'],
 'resppns': {'resppnse': []},
 'resppnsibl': {'resppnsibility': [], 'resppnsible': []},
 'resprain': {'resprained': []},
 'respratori': {'respratory': []},
 'respray': {'resprayed': [], 'respraying': [], 'resprays': []},
 'respread': {'respreading': [], 'respreads': []},
 'resprect': {'resprectively': []},
 'respres': {'respresent': ['respresents',
                            'respresented',
                            'respresenting',
                            'respresentative',
                            'respresentatives',
                            'respresentativeness']},
 'respresent': {'respresentation': ['respresentations', 'respresentational']},
 'respresentation': ['respresentations', 'respresentational'],
 'respress': {'respression': [], 'respressive': []},
 'respriat': {'respriation': []},
 'respriatori': {'respriatory': []},
 'respring': {'respringing': []},
 'resprinkl': {'resprinkled': []},
 'resprout': {'resprouted': [],
              'resprouter': ['resprouters'],
              'resprouting': [],
              'resprouts': []},
 'resprouter': ['resprouters'],
 'respsct': {'respscts': []},
 'respsctiv': {'respsctive': ['respsctively']},
 'respsctive': ['respsctively'],
 'respsons': {'respsonse': [], 'respsonsibility': [], 'respsonsible': []},
 'respt': {'respts': []},
 'respti': {'respty': []},
 'respu': {'respue': []},
 'respua': {'respuas': []},
 'respuamu': {'respuamus': []},
 'respubl': {'respublic': []},
 'respublica': {'respublicae': [], 'respublicas': []},
 'respublik': {'respublike': []},
 'respublikasi': {'respublikasy': []},
 'respubliki': {'respubliky': []},
 'respubliko': {'respublikos': []},
 'respueb': {'respuebant': []},
 'respuen': {'respuens': []},
 'respuendu': {'respuendus': []},
 'respuent': {'respuentes': []},
 'respuer': {'respuere': []},
 'respuesta': {'respuestas': []},
 'respui': {'respuis': []},
 'respuimu': {'respuimus': []},
 'respul': {'respules': []},
 'respuls': {'respulsion': [], 'respulsive': []},
 'respunch': {'respunchable': []},
 'respundr': {'respundre': []},
 'respurc': {'respurces': []},
 'resputt': {'resputtered': [], 'resputtering': []},
 'respyt': {'respyte': ['respyted']},
 'respyte': ['respyted'],
 'resqlv': {'resqlved': []},
 'resqu': {'resque': ['resques', 'resqued', 'resquely', 'resqueness']},
 'resquar': {'resquare': ['resquared'], 'resquaring': []},
 'resquare': ['resquared'],
 'resque': ['resques', 'resqued', 'resquely', 'resqueness'],
 'resquebrajars': {'resquebrajarse': []},
 'resqueez': {'resqueezed': []},
 'resquest': {'resquested': [], 'resquesting': []},
 'resquicio': {'resquicios': []},
 'resquir': {'resquired': []},
 'resqurc': {'resqurces': []},
 'resr': {'resred': [], 'resring': [], 'resrs': []},
 'resractori': {'resractory': []},
 'resrain': {'resrained': []},
 'resraur': {'resraurant': ['resraurants']},
 'resraurant': ['resraurants'],
 'resresh': {'resreshed': [],
             'resreshing': [],
             'resreshment': ['resreshments']},
 'resreshment': ['resreshments'],
 'resrev': {'resreve': []},
 'resrict': {'resricted': [], 'resriction': ['resrictions'], 'resrictive': []},
 'resriction': ['resrictions'],
 'resrless': {'resrlessness': []},
 'resrlt': {'resrlts': []},
 'resrons': {'resronse': []},
 'resror': {'resroration': [], 'resrored': []},
 'resrouc': {'resrouces': []},
 'resrudi': {'resrudied': []},
 'resrv': {'resrve': ['resrved', 'resrves']},
 'resrvat': {'resrvation': []},
 'resrve': ['resrved', 'resrves'],
 'resryl': {'resryled': []},
 'ress': {'res': ['resse', 'ressed', 'ressing', 'ressings']},
 'ressa': {'ressas': []},
 'ressac': {'ressacs': []},
 'ressag': {'ressage': []},
 'ressaisi': {'ressaisie': []},
 'ressaiv': {'ressaive': []},
 'ressaldar': {'ressaldars': []},
 'ressant': {'ressante': ['ressantes'], 'ressants': []},
 'ressante': ['ressantes'],
 'ressari': {'ressary': []},
 'ressass': {'ressasse': ['ressasser', 'ressassement']},
 'ressasse': ['ressasser', 'ressassement'],
 'ressau': {'ressaue': ['ressaued']},
 'ressaue': ['ressaued'],
 'ressault': {'ressaulted': [], 'ressaults': []},
 'ressaut': {'ressauts': []},
 'ressav': {'ressave': ['ressaved'], 'ressaving': []},
 'ressave': ['ressaved'],
 'ressayr': {'ressayre': []},
 'resseant': {'resseants': []},
 'ressect': {'ressected': [], 'ressection': []},
 'resseg': {'resseger': []},
 'ressegui': {'resseguie': ['resseguier']},
 'resseguie': ['resseguier'],
 'resseguro': {'resseguros': []},
 'ressel': {'resseler': [], 'ressell': [], 'ressels': []},
 'ressela': {'resselaer': []},
 'resselgass': {'resselgasse': []},
 'ressem': {'ressemer': []},
 'ressembl': {'ressemblance': ['ressemblances'],
              'ressemblant': ['ressemblants'],
              'ressemble': ['ressembles',
                            'ressembled',
                            'ressembler',
                            'ressemblent',
                            'ressemblement'],
              'ressembling': []},
 'ressemblai': {'ressemblaient': [], 'ressemblais': []},
 'ressemblan': {'ressemblans': []},
 'ressemblance': ['ressemblances'],
 'ressemblant': {'ressemblante': ['ressemblantes']},
 'ressemblante': ['ressemblantes'],
 'ressemble': ['ressembles',
               'ressembled',
               'ressembler',
               'ressemblent',
               'ressemblement'],
 'ressemblerai': {'ressembleraient': []},
 'ressembloi': {'ressembloient': []},
 'ressemblon': {'ressemblons': []},
 'ressen': {'ressens': []},
 'ressent': {'ressentant': [],
             'ressente': ['ressented', 'ressentent'],
             'ressentment': []},
 'ressentai': {'ressentaient': [], 'ressentais': []},
 'ressente': ['ressented', 'ressentent'],
 'ressenti': {'ressentie': ['ressenties', 'ressentient'],
              'ressentiment': ['ressentiments'],
              'ressentis': []},
 'ressentie': ['ressenties', 'ressentient'],
 'ressentimen': {'ressentimens': []},
 'ressentiment': ['ressentiments'],
 'ressentir': {'ressentirent': []},
 'ressentoi': {'ressentoient': []},
 'ressenton': {'ressentons': []},
 'ressequi': {'ressequie': []},
 'resser': {'resserer': [], 'ressers': []},
 'resserr': {'resserrant': [],
             'resserre': ['resserrer',
                          'resserres',
                          'resserrent',
                          'resserrement']},
 'resserre': {'resserree': ['resserrees']},
 'resserree': ['resserrees'],
 'ressettl': {'ressettlement': []},
 'resseyu': {'resseyue': []},
 'resseyv': {'resseyve': ['resseyved']},
 'resseyve': ['resseyved'],
 'ressi': {'ressie': [], 'ressy': []},
 'ressibl': {'ressible': []},
 'ressin': {'ressined': []},
 'ressing': {'ressinger': []},
 'ression': {'ressional': [], 'ressions': []},
 'ressist': {'ressistance': []},
 'ressit': {'ressitance': []},
 'ressiv': {'ressive': ['ressively', 'ressiveness'], 'ressivism': []},
 'ressive': ['ressively', 'ressiveness'],
 'ressli': {'ressly': []},
 'resslt': {'resslts': []},
 'ressmey': {'ressmeyer': []},
 'ressolut': {'ressolution': []},
 'ressolv': {'ressolved': []},
 'resson': {'ressonable': [],
            'ressonably': [],
            'ressonance': [],
            'ressone': [],
            'ressoning': [],
            'ressons': []},
 'ressonabil': {'ressonabill': []},
 'ressoni': {'ressonis': []},
 'ressor': {'ressors': []},
 'ressort': {'ressortant': [],
             'ressorte': ['ressorted', 'ressortent'],
             'ressorts': []},
 'ressortai': {'ressortaient': []},
 'ressorte': ['ressorted', 'ressortent'],
 'ressorti': {'ressortie': []},
 'ressortiss': {'ressortissant': ['ressortissants'], 'ressortissent': []},
 'ressortissant': {'ressortissante': ['ressortissantes']},
 'ressortissante': ['ressortissantes'],
 'ressouch': {'ressouche': []},
 'ressoud': {'ressouder': []},
 'ressoun': {'ressoune': []},
 'ressourc': {'ressource': ['ressources', 'ressourcer', 'ressourcement']},
 'ressourcc': {'ressourccs': []},
 'ressource': ['ressources', 'ressourcer', 'ressourcement'],
 'ressourcenallok': {'ressourcenallokation': []},
 'ressourcenmanag': {'ressourcenmanagement': []},
 'ressoure': {'ressourees': []},
 'ressouven': {'ressouvenant': []},
 'ressouvenir': {'ressouvenirs': []},
 'ressouvi': {'ressouvient': []},
 'ressouvien': {'ressouviens': []},
 'ressovski': {'ressovsky': []},
 'ressowski': {'ressowsky': []},
 'resspect': {'resspective': ['resspectively']},
 'resspective': ['resspectively'],
 'resspons': {'ressponse': [], 'ressponsibility': [], 'ressponsible': []},
 'ressrv': {'ressrve': []},
 'resstablish': {'resstablishment': []},
 'ressuag': {'ressuage': []},
 'ressucit': {'ressucite': []},
 'ressult': {'ressults': []},
 'ressur': {'ressure': ['ressured', 'ressures'],
            'ressuring': [],
            'ressurs': []},
 'ressure': ['ressured', 'ressures'],
 'ressurect': {'ressurected': [], 'ressurecting': [], 'ressurection': []},
 'ressurg': {'ressurgence': []},
 'ressurrect': {'ressurrected': [], 'ressurrecting': [], 'ressurrection': []},
 'ressurs': {'ressurser': []},
 'ressuscit': {'ressuscitant': [],
               'ressuscitate': ['ressuscitated'],
               'ressuscitation': [],
               'ressuscite': ['ressuscites', 'ressusciter', 'ressuscitent']},
 'ressuscitate': ['ressuscitated'],
 'ressuscite': {'ressuscitee': []},
 'ressusciterai': {'ressusciteraient': []},
 'ressusciteron': {'ressusciterons': []},
 'rest': ['reste',
          'restes',
          'rested',
          'restful',
          'resting',
          'restings',
          'restting',
          'restfully',
          'restfulness'],
 "rest'r": {"rest're": []},
 'resta': {'restas': []},
 'restab': {'restabant': []},
 'restabelec': {'restabelecer': []},
 'restabil': {'restabilization': ['restabilizations'],
              'restabilize': ['restabilizes', 'restabilized'],
              'restabilizing': []},
 'restabilis': {'restabilisation': [],
                'restabilise': ['restabilised'],
                'restabilising': []},
 'restabilise': ['restabilised'],
 'restabilization': ['restabilizations'],
 'restabilize': ['restabilizes', 'restabilized'],
 'restabl': {'restablization': [], 'restably': []},
 'restablec': {'restablece': ['restablecer']},
 'restablece': ['restablecer'],
 'restablecers': {'restablecerse': []},
 'restablish': {'restablished': [],
                'restablishes': [],
                'restablishing': [],
                'restablishment': []},
 'restabliss': {'restablissement': []},
 'restack': {'restacked': [], 'restacking': [], 'restacks': []},
 'restact': {'restactivity': []},
 'restaf': {'restaffed': [], 'restaffing': []},
 'restag': {'restage': ['restages', 'restaged'], 'restaging': ['restagings']},
 'restage': ['restages', 'restaged'],
 'restaging': ['restagings'],
 'restagn': {'restagnant': [], 'restagnates': [], 'restagnation': []},
 'restagnon': {'restagnone': []},
 'restai': {'restais': []},
 'restain': {'restained': [], 'restaining': [], 'restains': []},
 'restaint': {'restaints': []},
 'restak': {'restake': ['restaked'], 'restaking': []},
 'restake': ['restaked'],
 'restal': {'restall': []},
 'restalin': {'restalinization': []},
 'restam': {'restames': []},
 'restamp': {'restamped': [], 'restamping': [], 'restamps': []},
 'restan': {'restans': []},
 'restanc': {'restance': ['restances']},
 'restance': ['restances'],
 'restand': {'restanding': []},
 'restandard': {'restandardization': ['restandardizations'],
                'restandardize': ['restandardized'],
                'restandardizing': []},
 'restandardis': {'restandardisation': [], 'restandardise': ['restandardised']},
 'restandardise': ['restandardised'],
 'restandardization': ['restandardizations'],
 'restandardize': ['restandardized'],
 'restani': {'restany': []},
 'restanqu': {'restanques': []},
 'restanr': {'restanrant': ['restanrants'], 'restanration': []},
 'restanrant': ['restanrants'],
 'restant': {'restante': ['restantes'], 'restants': []},
 'restante': ['restantes'],
 'restantibu': {'restantibus': []},
 'restapl': {'restaple': ['restapled'], 'restapling': []},
 'restaple': ['restapled'],
 'restar': {'restarant': ['restarants'], 'restare': ['restared', 'restarent']},
 'restarant': ['restarants'],
 'restaraunt': {'restaraunts': []},
 'restarch': {'restarched': [], 'restarches': []},
 'restare': ['restared', 'restarent'],
 'restarebb': {'restarebbe': []},
 'restarl': {'restarle': []},
 'restarn': {'restarne': []},
 'restart': {'restartability': [],
             'restartable': [],
             'restarted': [],
             'restarter': [],
             'restarting': ['restartings'],
             'restarts': []},
 'restarting': ['restartings'],
 'restaru': {'restaruant': ['restaruants']},
 'restaruant': ['restaruants'],
 'restasi': {'restasis': []},
 'restass': {'restasse': ['restassent']},
 'restasse': ['restassent'],
 'restat': {'restatable': [],
            'restate': ['restater',
                        'restates',
                        'restated',
                        'restaters',
                        'restatement'],
            'restating': [],
            'restation': ['restationed', 'restationing'],
            'restatment': []},
 'restate': ['restater', 'restates', 'restated', 'restaters', 'restatement'],
 'restation': ['restationed', 'restationing'],
 'restauant': {'restauants': []},
 'restauar': {'restauarant': []},
 'restaud': {'restauds': []},
 'restaur': {'restaurant': ['restauranting'],
             'restaurate': [],
             'restauration': ['restaurations'],
             'restaurative': [],
             'restaurator': [],
             'restaure': ['restaured',
                          'restaurer',
                          'restaures',
                          'restaurent',
                          'restaurents',
                          'restaurering'],
             'restauring': [],
             'restaurs': []},
 'restaurac': {'restaurace': []},
 'restauracion': {'restauraciones': []},
 'restaurada': {'restauradas': []},
 'restaurado': {'restaurados': []},
 'restaurador': {'restauradores': []},
 'restauram': {'restaurames': []},
 'restauran': {'restaurans': []},
 'restauranda': {'restaurandae': []},
 'restaurandi': {'restaurandis': []},
 'restauranr': {'restauranrs': []},
 'restaurant': {'restaurante': ['restauranter',
                                'restaurantes',
                                'restauranteer',
                                'restauranteers']},
 'restaurante': ['restauranter',
                 'restaurantes',
                 'restauranteer',
                 'restauranteers'],
 'restauranteur': {'restauranteurs': []},
 'restaurantgo': {'restaurantgoers': []},
 'restaurantkeep': {'restaurantkeeper': ['restaurantkeepers']},
 'restaurantkeeper': ['restaurantkeepers'],
 'restaurantosauru': {'restaurantosaurus': []},
 'restaurantown': {'restaurantowner': []},
 'restaurantqu': {'restaurantquality': []},
 'restaurants': {'restaurantsized': []},
 'restaurantstyl': {'restaurantstyle': []},
 'restaurantsuppli': {'restaurantsupply': []},
 'restaurar': {'restaurare': []},
 'restaurass': {'restaurasse': []},
 'restaurat': {'restaurats': []},
 'restaurateur': {'restaurateur': []},
 'restaurateus': {'restaurateuse': []},
 'restaurati': {'restauratie': ['restauraties']},
 'restauratie': ['restauraties'],
 'restauration': {'restauratione': []},
 'restaurationi': {'restaurationis': []},
 'restaurationsepoch': {'restaurationsepoche': []},
 'restaurativ': {'restaurativer': []},
 'restaurator': {'restauratore': []},
 'restauratorisch': {'restauratorische': []},
 'restauratric': {'restauratrice': []},
 'restauratu': {'restauratus': []},
 'restauraunt': {'restauraunts': []},
 'restauraw': {'restauraws': []},
 'restaurazion': {'restaurazione': []},
 'restaure': {'restauree': ['restaurees']},
 'restauree': ['restaurees'],
 'restauriert': {'restaurierte': []},
 'restaut': {'restautant': ['restautants']},
 'restautant': ['restautants'],
 'restavek': {'restaveks': []},
 'restawhil': {'restawhile': []},
 'restawil': {'restawile': []},
 'restbestand': {'restbestande': []},
 'restbillet': {'restbillets': []},
 'restbreak': {'restbreaks': []},
 'restcamp': {'restcamps': []},
 'restcom': {'restcome': []},
 'restcur': {'restcure': ['restcures']},
 'restcure': ['restcures'],
 'restday': {'restdays': []},
 'restdenc': {'restdence': []},
 'restdent': {'restdents': []},
 'restdt': {'restdted': [], 'restdting': [], 'restdts': []},
 'reste': {'restee': ['restees']},
 'resteadi': {'resteadied': []},
 'resteal': {'restealing': []},
 'resteam': {'resteamed': [], 'resteaming': []},
 'resteclion': {'resteclions': []},
 'rested': {'restedness': []},
 'restee': ['restees'],
 'resteel': {'resteeled': []},
 'resteep': {'resteeped': [], 'resteeping': []},
 'resteign': {'resteigne': []},
 'restel': {'resteles': [], 'restell': ['restelle', 'restellism']},
 'restele': {'restelees': []},
 'restell': ['restelle', 'restellism'],
 'restemey': {'restemeyer': []},
 'resten': {'restene': []},
 'restencil': {'restenciled': []},
 'restenergi': {'restenergy': []},
 'restenos': {'restenose': ['restenoses', 'restenosed'], 'restenosing': []},
 'restenose': ['restenoses', 'restenosed'],
 'restenosi': {'restenosis': []},
 'restenot': {'restenotic': []},
 'restent': {'restenting': []},
 'restep': {'restepped': [], 'restepping': []},
 'rester': ['restered', 'resterent', 'resterant', 'resteration'],
 'restera': {'resteras': []},
 'resterai': {'resteraient': [], 'resterais': []},
 'resterand': {'resterande': []},
 'resterebb': {'resterebbe': []},
 'resterend': {'resterende': []},
 'resteril': {'resterilization': [],
              'resterilize': ['resterilizes', 'resterilized'],
              'resterilizing': []},
 'resterilis': {'resterilisation': [], 'resterilise': ['resterilised']},
 'resterilise': ['resterilised'],
 'resteriliz': {'resterilizable': []},
 'resterilize': ['resterilizes', 'resterilized'],
 'resterion': {'resterions': []},
 'resternotomi': {'resternotomy': []},
 'resteron': {'resterons': []},
 'resteth': {'restethe': []},
 'restf': {'restfs': []},
 'restfram': {'restframe': []},
 'restful': {'restfull': ['restfullness']},
 'restfull': ['restfullness'],
 'restgiv': {'restgiving': []},
 'resth': {'resthe': []},
 'resthet': {'resthetic': ['resthetics', 'resthetical']},
 'resthetic': {'restheticism': []},
 'restholm': {'restholme': []},
 'resthom': {'resthome': ['resthomes']},
 'resthome': ['resthomes'],
 'resthous': {'resthouse': ['resthouses']},
 'resthouse': ['resthouses'],
 'resthut': {'resthuts': []},
 'resti': {'restie': [], 'restiness': [], 'restis': [], 'resty': []},
 'restiacea': {'restiaceae': []},
 'restiacec': {'restiacece': []},
 'restiad': {'restiads': []},
 'restiain': {'restiained': [], 'restiaining': []},
 'restiaint': {'restiaints': []},
 'restibu': {'restibus': []},
 'restick': {'restickable': [], 'resticking': []},
 'restict': {'resticted': [],
             'resticting': [],
             'restiction': ['restictions'],
             'restictive': [],
             'resticts': []},
 'restiction': ['restictions'],
 'restierend': {'restierende': []},
 'restiess': {'restiessness': []},
 'restiessli': {'restiessly': []},
 'restif': {'restifs': []},
 'restifd': {'restifde': []},
 'restiff': {'restiffness': []},
 'restiffen': {'restiffened': []},
 'restifi': {'restified': [], 'restify': []},
 'restiform': {'restiforme': []},
 'restiformi': {'restiformis': []},
 'restig': {'restigation': [], 'restige': ['restiges']},
 'restige': ['restiges'],
 'restigi': {'restigious': []},
 'restigmat': {'restigmatization': [],
               'restigmatize': ['restigmatized'],
               'restigmatizing': []},
 'restigmatize': ['restigmatized'],
 'restigouch': {'restigouche': []},
 'restigoueh': {'restigouehe': []},
 'restiict': {'restiicted': [],
              'restiiction': ['restiictions'],
              'restiictive': []},
 'restiiction': ['restiictions'],
 'restil': {'restile': []},
 'restilt': {'restilts': []},
 'restim': {'restimated': []},
 'restimoni': {'restimonies': [], 'restimony': []},
 'restimul': {'restimulate': ['restimulated', 'restimulates'],
              'restimulating': [],
              'restimulation': ['restimulations'],
              'restimulative': [],
              'restimulator': ['restimulators']},
 'restimulate': ['restimulated', 'restimulates'],
 'restimulation': ['restimulations'],
 'restimulator': ['restimulators'],
 'restin': {'restine': [], 'restins': []},
 'restinclier': {'restincliere': []},
 'resting': {'restinge': []},
 'restinga': {'restingas': []},
 'restinghous': {'restinghouse': []},
 'restingli': {'restingly': []},
 'restingplac': {'restingplace': ['restingplaces']},
 'restingplace': ['restingplaces'],
 'restingpoint': {'restingpoints': []},
 'restingspor': {'restingspore': ['restingspores']},
 'restingspore': ['restingspores'],
 'restingst': {'restingstate': []},
 'restingstag': {'restingstage': []},
 'restingtim': {'restingtime': []},
 'restinguer': {'restinguere': []},
 'restinguimu': {'restinguimus': []},
 'restio': {'restios': []},
 'restioid': {'restioids': []},
 'restion': {'restiones': [], 'restions': []},
 'restionac': {'restionaceous': []},
 'restionacea': {'restionaceae': []},
 'restional': {'restionales': []},
 'restipul': {'restipulate': ['restipulated'],
              'restipulation': ['restipulations']},
 'restipulate': ['restipulated'],
 'restipulation': ['restipulations'],
 'restir': {'restirred': [], 'restirring': []},
 'restirct': {'restircted': [], 'restirction': ['restirctions']},
 'restirction': ['restirctions'],
 'restist': {'restistance': [], 'restistant': []},
 'restit': {'restite': ['restites'], 'restitic': []},
 'restitch': {'restitched': [], 'restitches': [], 'restitching': []},
 'restite': ['restites'],
 'restiter': {'restiterant': []},
 'restitiss': {'restitisse': []},
 'restitisti': {'restitistis': []},
 'restititut': {'restititution': []},
 'restitnt': {'restitntion': []},
 'restitu': {'restituant': [],
             'restitue': ['restituer',
                          'restitues',
                          'restituent',
                          'restituents'],
             'restituiti': [],
             'restitus': []},
 'restitua': {'restituas': []},
 'restituati': {'restituatis': []},
 'restitucion': {'restitucione': ['restituciones']},
 'restitucione': ['restituciones'],
 'restitue': {'restituee': ['restituees']},
 'restituee': ['restituees'],
 'restituemu': {'restituemus': []},
 'restituen': {'restituens': []},
 'restituenda': {'restituendae': [], 'restituendas': []},
 'restituendi': {'restituendis': []},
 'restituendo': {'restituendos': []},
 'restituendu': {'restituendus': []},
 'restituent': {'restituente': ['restituentes']},
 'restituente': ['restituentes'],
 'restituer': {'restituere': ['restituerent']},
 'restituere': ['restituerent'],
 'restitui': {'restituis': []},
 'restituido': {'restituidos': []},
 'restituimu': {'restituimus': []},
 'restituir': {'restituire': []},
 'restituirl': {'restituirle': []},
 'restituirs': {'restituirse': []},
 'restituisc': {'restituisce': []},
 'restituiss': {'restituisse': []},
 'restituit': {'restituite': []},
 'restituru': {'restiturus': []},
 'restitut': {'restitutable': [],
              'restitute': ['restitutes', 'restituted'],
              'restituting': [],
              'restitution': ['restitutional'],
              'restitutive': ['restitutively']},
 'restituta': {'restitutae': [], 'restitutas': []},
 'restitute': ['restitutes', 'restituted'],
 'restituti': {'restitutis': []},
 'restitution': {'restitutione': ['restitutiones'], 'restitutionism': []},
 'restitutionari': {'restitutionary': []},
 'restitutione': ['restitutiones'],
 'restitutioni': {'restitutionis': []},
 'restitutionibu': {'restitutionibus': []},
 'restitutionist': {'restitutionists': []},
 'restitutive': ['restitutively'],
 'restituto': {'restitutos': []},
 'restitutori': {'restitutory': []},
 'restitutu': {'restitutus': []},
 'restituturu': {'restituturus': []},
 'restituy': {'restituye': []},
 'restituzion': {'restituzione': []},
 'restitvti': {'restitvtis': []},
 'restiv': {'restival': [],
            'restive': ['restively', 'restiveness'],
            'restivity': []},
 'restive': ['restively', 'restiveness'],
 'restl': {'restle': ['restled', 'restles', 'restleness'], 'restling': []},
 'restle': {'restlees': []},
 'restlea': {'restleas': []},
 'restler': {'restlers': []},
 'restles': {'restlesness': []},
 'restlesli': {'restlesly': []},
 'restlesness': {'restlesnesse': []},
 'restless': {'restlesse': ['restlesseness'], 'restlessness': []},
 'restlesse': ['restlesseness'],
 'restlessli': {'restlessly': []},
 'restlessn': {'restlessnes': []},
 'restlessness': {'restlessnesse': []},
 'restlesss': {'restlesssness': []},
 'restlest': {'restlestness': []},
 'restlich': {'restliche': []},
 'restlo': {'restlos': []},
 'restlos': {'restlose': ['restloser']},
 'restlose': ['restloser'],
 'restmass': {'restmasses': []},
 'restmctur': {'restmcturing': []},
 'restment': {'restments': []},
 'restmor': {'restmore': []},
 'restnct': {'restncted': [], 'restncting': [], 'restncts': []},
 'restnction': {'restnctions': []},
 'restnctiv': {'restnctive': []},
 'restnet': {'restneted': []},
 'restnictur': {'restnicturing': []},
 'resto': {'restos': []},
 'restob': {'restobation': []},
 'restock': {'restocked': [], 'restocking': ['restockings'], 'restocks': []},
 'restocking': ['restockings'],
 'restoeat': {'restoeation': []},
 'restofth': {'restofthe': []},
 'restoi': {'restoie': ['restoied'], 'restoiing': []},
 'restoiat': {'restoiation': []},
 'restoie': ['restoied'],
 'restok': {'restoke': ['restoked'], 'restoking': []},
 'restoke': ['restoked'],
 'restoldu': {'restoldus': []},
 'reston': {'restone': ['restoned'], 'restonic': [], 'restons': []},
 'restone': ['restoned'],
 'restonian': {'restonians': []},
 'restop': {'restopped': []},
 'restopp': {'restopper': ['restoppered', 'restoppering']},
 'restopper': ['restoppered', 'restoppering'],
 'restor': {'restorability': [],
            'restorable': [],
            'restoral': ['restorals'],
            'restorance': [],
            'restorant': ['restorants'],
            'restorate': ['restorated'],
            'restorating': [],
            'restoration': ['restorational'],
            'restorative': ['restoratively', 'restorativeness'],
            'restorator': ['restorators'],
            'restore': ['restorer',
                        'restores',
                        'restored',
                        'restoreing',
                        'restorement',
                        'restorements'],
            'restoring': ['restorings'],
            'restors': []},
 'restora': {'restoraation': []},
 'restorag': {'restorage': []},
 'restoral': ['restorals'],
 'restorant': {'restorante': []},
 'restorate': ['restorated'],
 'restorateur': {'restorateurs': []},
 'restorati': {'restoratiou': []},
 'restoration': {'restorationer': ['restorationers'], 'restorationism': []},
 'restorationer': ['restorationers'],
 'restorationist': {'restorationists': []},
 'restoratiu': {'restoratiue': []},
 'restorative': ['restoratively', 'restorativeness'],
 'restorativejustic': {'restorativejustice': []},
 'restorator': ['restorators'],
 'restoratori': {'restoratory': []},
 'restord': {'restorde': []},
 'restore': {'restoree': []},
 'restorecrtmod': {'restorecrtmode': []},
 'restoredirectori': {'restoredirectory': []},
 'restorest': {'restorestate': []},
 'restoreth': {'restorethe': []},
 'restori': {'restoried': [], 'restory': ['restorying']},
 'restoring': {'restoringe': []},
 'restoringli': {'restoringly': []},
 'restoringth': {'restoringthe': []},
 'restorm': {'restormal': []},
 'restort': {'restortation': [],
             'restorted': [],
             'restorting': [],
             'restortion': []},
 'restory': ['restorying'],
 'restot': {'restotation': [], 'restote': ['restoted'], 'restoting': []},
 'restote': ['restoted'],
 'restoul': {'restoule': []},
 'restov': {'restoved': []},
 'restow': {'restowed': [], 'restowing': []},
 'restowag': {'restowage': []},
 'restpaus': {'restpause': ['restpauses']},
 'restpause': ['restpauses'],
 'restperiod': {'restperiods': []},
 'restplac': {'restplace': []},
 'restpr': {'restpre': ['restpred']},
 'restpre': ['restpred'],
 'restr': {'restring': ['restrings']},
 'restra': {'restraing': []},
 'restractur': {'restracturing': []},
 'restraict': {'restraicte': []},
 'restraighten': {'restraightened': [], 'restraightening': []},
 'restrain': {'restrainable': [],
              'restraine': ['restrained',
                            'restraines',
                            'restrainer',
                            'restraineing'],
              'restraining': ['restrainings'],
              'restrainment': [],
              'restrains': []},
 'restraindr': {'restraindre': []},
 'restraine': {'restrainee': []},
 'restrained': {'restrainedness': []},
 'restrainedli': {'restrainedly': []},
 'restraining': ['restrainings'],
 'restrainingli': {'restrainingly': []},
 'restrainst': {'restrainsts': []},
 'restraint': ['restrainte', 'restrainted', 'restraintes', 'restraintive'],
 'restraintfre': {'restraintfree': []},
 'restraintist': {'restraintists': []},
 'restrait': {'restraits': []},
 'restraiu': {'restraiued': []},
 'restralnt': {'restralnts': []},
 'restram': {'restramed': [], 'restraming': []},
 'restramt': {'restramts': []},
 'restran': {'restraning': []},
 'restrap': {'restrapped': [], 'restrapping': []},
 'restrat': {'restration': []},
 'restrateg': {'restrategize': ['restrategized'], 'restrategizing': []},
 'restrategize': ['restrategized'],
 'restratif': {'restratification': ['restratifications']},
 'restratifi': {'restratified': [],
                'restratifies': [],
                'restratify': ['restratifying']},
 'restratification': ['restratifications'],
 'restratify': ['restratifying'],
 'restraunt': {'restraunts': []},
 'restraur': {'restraurant': ['restraurants']},
 'restraurant': ['restraurants'],
 'restrayn': {'restrayne': ['restrayned'], 'restrayning': []},
 'restrayne': ['restrayned'],
 'restrayning': {'restrayninge': []},
 'restraynt': {'restraynte': []},
 'restrct': {'restrcted': []},
 'restrction': {'restrctions': []},
 'restreak': {'restreaked': [], 'restreaking': []},
 'restredistribut': {'restredistribution': []},
 'restreign': {'restreignant': [], 'restreigne': ['restreignent']},
 'restreigne': ['restreignent'],
 'restreignon': {'restreignons': []},
 'restrein': {'restreine': ['restreined']},
 'restreindr': {'restreindre': []},
 'restreine': ['restreined'],
 'restreint': {'restreinte': ['restreintes'], 'restreints': []},
 'restreinte': ['restreintes'],
 'restrengthen': {'restrengthened': [], 'restrengthening': []},
 'restrepo': {'restrepos': []},
 'restress': {'restressed': [], 'restresses': [], 'restressing': []},
 'restretch': {'restretched': [], 'restretching': []},
 'restreyn': {'restreyne': ['restreyned'], 'restreyning': []},
 'restreyne': ['restreyned'],
 'restri': {'restrie': [], 'restry': []},
 'restriant': {'restriants': []},
 'restribut': {'restribution': []},
 'restric': {'restricated': [],
             'restrication': [],
             'restriced': [],
             'restricing': [],
             'restricive': []},
 'restriccion': {'restriccione': ['restricciones']},
 'restriccione': ['restricciones'],
 'restricdon': {'restricdons': []},
 'restrici': {'restricied': []},
 'restriciion': {'restriciions': []},
 'restricion': {'restricions': []},
 'restricit': {'restriciting': [],
               'restricition': ['restricitions'],
               'restricitive': []},
 'restricition': ['restricitions'],
 'restriciton': {'restricitons': []},
 'restricitv': {'restricitve': []},
 'restricl': {'restricled': []},
 'restriclion': {'restriclions': []},
 'restricnon': {'restricnons': []},
 'restrico': {'restricoes': []},
 'restricr': {'restricred': []},
 'restricrion': {'restricrions': []},
 'restrict': {'restrictability': [],
              'restrictable': [],
              'restricte': ['restricted', 'restricter', 'restricters'],
              'restrictic': [],
              'restricting': [],
              'restriction': ['restrictional'],
              'restrictive': ['restrictives',
                              'restrictively',
                              'restrictiveness'],
              'restrictivity': [],
              'restricts': []},
 'restrictanonym': {'restrictanonymous': []},
 'restrictas': {'restrictase': ['restrictases']},
 'restrictase': ['restrictases'],
 'restricte': {'restrictee': ['restrictees']},
 'restricted': {'restrictedness': []},
 'restrictedact': {'restrictedactivity': []},
 'restrictedcircul': {'restrictedcirculation': []},
 'restrictedli': {'restrictedly': []},
 'restrictedrang': {'restrictedrange': []},
 'restrictedus': {'restricteduse': []},
 'restrictee': ['restrictees'],
 'restricti': {'restrictie': ['restricties', 'restrictied'],
               'restrictious': [],
               'restrictis': []},
 'restrictie': ['restricties', 'restrictied'],
 'restrictif': {'restrictifs': []},
 'restrictin': {'restrictins': []},
 'restrictingli': {'restrictingly': []},
 'restrictingth': {'restrictingthe': []},
 'restrictioa': {'restrictioas': []},
 'restriction': {'restrictione': ['restrictiones'], 'restrictionism': []},
 'restrictionari': {'restrictionary': []},
 'restrictione': ['restrictiones'],
 'restrictionenzym': {'restrictionenzyme': []},
 'restrictionfrag': {'restrictionfragment': []},
 'restrictioni': {'restrictionis': []},
 'restrictionibu': {'restrictionibus': []},
 'restrictionist': {'restrictionists': []},
 'restrictionmodif': {'restrictionmodification': []},
 'restrictionsit': {'restrictionsite': []},
 'restrictiv': {'restrictivement': [], 'restrictivism': []},
 'restrictiva': {'restrictivas': []},
 'restrictivcli': {'restrictivcly': []},
 'restrictive': ['restrictives', 'restrictively', 'restrictiveness'],
 'restrictivist': {'restrictivists': []},
 'restrictivo': {'restrictivos': []},
 'restrictli': {'restrictly': []},
 'restricton': {'restrictons': []},
 'restrictor': {'restrictors': []},
 'restrictori': {'restrictory': []},
 'restrictt': {'restricttion': ['restricttions']},
 'restrictth': {'restrictthe': []},
 'restricttion': ['restricttions'],
 'restrictu': {'restrictus': []},
 'restrictur': {'restricture': [], 'restricturing': []},
 'restrictv': {'restrictve': []},
 'restriet': {'restrieted': [],
              'restrieting': [],
              'restrietion': ['restrietions'],
              'restrietive': []},
 'restrietion': ['restrietions'],
 'restrik': {'restrike': ['restrikes'], 'restriking': ['restrikings']},
 'restrike': ['restrikes'],
 'restriking': ['restrikings'],
 'restriksjon': {'restriksjoner': []},
 'restrikt': {'restriktion': [], 'restriktive': []},
 'restriktion': {'restriktioner': []},
 'restriktiv': {'restriktiver': []},
 'restrinct': {'restrinction': []},
 'restring': {'restringe': ['restringent', 'restringents'], 'restringing': []},
 'restringe': ['restringent', 'restringents'],
 'restringer': {'restringere': []},
 'restringida': {'restringidas': []},
 'restringido': {'restringidos': []},
 'restringirs': {'restringirse': []},
 'restringit': {'restringite': []},
 'restriot': {'restrioted': [],
              'restrioting': [],
              'restriotion': ['restriotions'],
              'restriotive': [],
              'restriots': []},
 'restriotion': ['restriotions'],
 'restrip': {'restripe': ['restriped'],
             'restriping': [],
             'restripped': [],
             'restripping': []},
 'restripe': ['restriped'],
 'restrit': {'restrited': [], 'restrition': ['restritions'], 'restritive': []},
 'restrita': {'restritas': []},
 'restrition': ['restritions'],
 'restrito': {'restritos': []},
 'restritt': {'restrittive': []},
 'restriv': {'restrive': [], 'restriving': []},
 'restrizion': {'restrizione': []},
 'restrlct': {'restrlcted': []},
 'restrlctlon': {'restrlctlons': []},
 'restrok': {'restroke': ['restroked'], 'restroking': []},
 'restroke': ['restroked'],
 'restroom': {'restroom': []},
 'restropect': {'restropective': []},
 'restror': {'restroration': [], 'restrored': []},
 'restrospect': {'restrospection': [],
                 'restrospective': ['restrospectives', 'restrospectively'],
                 'restrospectivity': []},
 'restrospective': ['restrospectives', 'restrospectively'],
 'restrostern': {'restrosternal': []},
 'restrot': {'restrotation': []},
 'restrucmr': {'restrucmring': []},
 'restruct': {'restructed': [],
              'restructered': [],
              'restructing': [],
              'restruction': ['restructions'],
              'restructive': []},
 'restruction': ['restructions'],
 'restructu': {'restructuing': []},
 'restructur': {'restructurable': [],
                'restructural': ['restructuralized', 'restructuralization'],
                'restructuration': ['restructurations'],
                'restructure': ['restructured',
                                'restructures',
                                'restructurer',
                                'restructurers'],
                'restructuring': ['restructurings'],
                'restructurization': []},
 'restructural': ['restructuralized', 'restructuralization'],
 'restructuralis': {'restructuralisation': []},
 'restructuration': ['restructurations'],
 'restructure': {'restructuree': []},
 'restructuring': ['restructurings'],
 'restructuris': {'restructurisation': []},
 'restructut': {'restructuting': []},
 'restrv': {'restrved': []},
 'reststanc': {'reststance': []},
 'reststoff': {'reststoffe': []},
 'reststop': {'reststops': []},
 'restth': {'restthe': []},
 'restticr': {'restticred': []},
 'resttict': {'restticted': [],
              'restticting': [],
              'resttiction': ['resttictions'],
              'resttictive': [],
              'restticts': []},
 'resttiction': ['resttictions'],
 'resttim': {'resttime': []},
 'resttuctur': {'resttucture': []},
 'resttuctut': {'resttuctuting': []},
 'restuan': {'restuans': []},
 'restuar': {'restuarant': ['restuarants']},
 'restuarant': ['restuarants'],
 'restucco': {'restuccoed': []},
 'restuctur': {'restucture': [], 'restucturing': []},
 'restudi': {'restudied': [], 'restudies': [], 'restudy': ['restudying']},
 'restudy': ['restudying'],
 'restuf': {'restuffed': [], 'restuffing': []},
 'restul': {'restuls': []},
 'restult': {'restults': []},
 'restur': {'resturant': ['resturants']},
 'resturant': ['resturants'],
 'resturctur': {'resturcturing': []},
 'restutu': {'restutus': []},
 'restval': {'restvale': []},
 'restwel': {'restwell': []},
 'restyl': {'restyle': ['restyled', 'restyles'],
            'restyling': ['restylings'],
            'restylization': [],
            'restylized': []},
 'restylan': {'restylane': []},
 'restyle': ['restyled', 'restyles'],
 'restyling': ['restylings'],
 'restyng': {'restynge': []},
 'restyp': {'restype': []},
 'resu': {'resue': ['resued', 'resues'], 'resuing': [], 'resus': []},
 "resu't": {"resu'ts": []},
 'resua': {'resuae': ['resuaed']},
 'resuabl': {'resuable': []},
 'resuae': ['resuaed'],
 'resubdivid': {'resubdivide': ['resubdivided'], 'resubdividing': []},
 'resubdivide': ['resubdivided'],
 'resubdivis': {'resubdivision': ['resubdivisions']},
 'resubdivision': ['resubdivisions'],
 'resubdu': {'resubdue': ['resubdued']},
 'resubdue': ['resubdued'],
 'resubject': {'resubjected': [], 'resubjecting': [], 'resubjection': []},
 'resubjectif': {'resubjectification': []},
 'resubjectifi': {'resubjectify': []},
 'resubjectiv': {'resubjectivization': []},
 'resubjug': {'resubjugate': ['resubjugated'],
              'resubjugating': [],
              'resubjugation': []},
 'resubjugate': ['resubjugated'],
 'resublim': {'resublimated': [],
              'resublimation': [],
              'resublime': ['resublimed'],
              'resubliming': []},
 'resublime': ['resublimed'],
 'resubmerg': {'resubmerge': ['resubmerges', 'resubmerged', 'resubmergence'],
               'resubmerging': []},
 'resubmerge': ['resubmerges', 'resubmerged', 'resubmergence'],
 'resubmers': {'resubmersion': []},
 'resubmiss': {'resubmission': ['resubmissions']},
 'resubmission': ['resubmissions'],
 'resubmit': {'resubmits': [], 'resubmitted': [], 'resubmitting': []},
 'resubmitt': {'resubmittal': ['resubmittals']},
 'resubmittal': ['resubmittals'],
 'resubordin': {'resubordinate': ['resubordinated'],
                'resubordinating': [],
                'resubordination': []},
 'resubordinate': ['resubordinated'],
 'resubscrib': {'resubscribe': ['resubscribed'], 'resubscribing': []},
 'resubscribe': ['resubscribed'],
 'resubscript': {'resubscription': []},
 'resubstanti': {'resubstantiate': ['resubstantiated'], 'resubstantiation': []},
 'resubstantiate': ['resubstantiated'],
 'resubstitut': {'resubstitute': ['resubstituted'],
                 'resubstituting': [],
                 'resubstitution': []},
 'resubstitute': ['resubstituted'],
 'resuc': {'resuce': ['resuced']},
 'resuce': ['resuced'],
 'resucit': {'resucitate': ['resucitated'],
             'resucitating': [],
             'resucitation': [],
             'resucite': []},
 'resucitate': ['resucitated'],
 'resuct': {'resuction': ['resuctioning']},
 'resuction': ['resuctioning'],
 'resudu': {'resudual': [], 'resudues': []},
 'resue': ['resued', 'resues'],
 'resuelta': {'resueltas': []},
 'resueltament': {'resueltamente': []},
 'resuelto': {'resueltos': []},
 'resuelv': {'resuelve': ['resuelves']},
 'resuelve': ['resuelves'],
 'resuen': {'resuene': []},
 'resueri': {'resuerie': []},
 'resuess': {'resuessness': []},
 'resuf': {'resufal': ['resufals']},
 'resufal': ['resufals'],
 'resufc': {'resufcs': []},
 'resuff': {'resuffer': ['resuffering']},
 'resuffer': ['resuffering'],
 'resuft': {'resufts': []},
 'resug': {'resuge': []},
 'resugar': {'resugared': []},
 'resuge': {'resugee': ['resugees']},
 'resugee': ['resugees'],
 'resuggest': {'resuggested': []},
 'resuh': {'resuhant': [], 'resuhed': [], 'resuhing': [], 'resuhs': []},
 'resuict': {'resuicted': [], 'resuictions': []},
 'resuir': {'resuired': []},
 'resuirect': {'resuirection': []},
 'resuit': {'resuitant': [],
            'resuite': ['resuited'],
            'resuiting': [],
            'resuits': []},
 'resuite': ['resuited'],
 'resuitect': {'resuitection': []},
 'resujt': {'resujts': []},
 'resuk': {'resuked': [], 'resuking': [], 'resuks': []},
 'resul': {'resulant': [],
           'resulated': [],
           'resulation': ['resulations'],
           'resule': ['resules', 'resuled'],
           'resuling': [],
           'resull': ['resulls', 'resulled', 'resulling'],
           'resuls': []},
 'resulation': ['resulations'],
 'resulc': {'resulcs': []},
 'resule': ['resules', 'resuled'],
 'resulf': {'resulfs': []},
 'resulfur': {'resulfurized': []},
 'resulg': {'resulgent': []},
 'resuli': {'resulied': [], 'resuliing': [], 'resulis': []},
 'resuliyi': {'resuliyy': []},
 'resull': ['resulls', 'resulled', 'resulling'],
 'resullat': {'resullats': []},
 'resullt': {'resullts': []},
 'resulot': {'resulotion': []},
 'resulphur': {'resulphurized': []},
 'resulr': {'resulrant': [], 'resulred': [], 'resulring': [], 'resulrs': []},
 'resulst': {'resulsts': []},
 'result': ['resulte',
            'resulter',
            'resulted',
            'resultou',
            'resultes',
            'resultion',
            'resultent',
            'resultive',
            'resultant',
            'resultate',
            'resulting',
            'resultful',
            'resultals',
            'resultates',
            'resultancy',
            'resultings',
            'resultance',
            'resultated',
            'resultting',
            'resultances',
            'resultative',
            'resultfully',
            'resultatives',
            'resultfulness',
            'resultatively',
            'resultativity',
            'resultativeness'],
 'resulta': {'resultas': []},
 'resultado': {'resultados': []},
 'resultai': {'resultaient': [], 'resultais': []},
 'resultan': {'resultans': []},
 'resultant': {'resultante': ['resultantes']},
 'resultante': ['resultantes'],
 'resultantforc': {'resultantforce': []},
 'resultanti': {'resultantis': []},
 'resultantli': {'resultantly': []},
 'resultar': {'resultare': []},
 'resultas': {'resultase': []},
 'resultat': {'resultater': [], 'resultats': []},
 'resultaten': {'resultatene': [], 'resultatens': []},
 'resultatern': {'resultaterne': []},
 'resultati': {'resultaty': []},
 'resultatlo': {'resultatlos': []},
 'resultcod': {'resultcode': []},
 'resulte': {'resultee': ['resultees']},
 'resultee': ['resultees'],
 'resulteerd': {'resulteerde': []},
 'resultel': {'resultelements': []},
 'resulter': {'resultere': ['resulterer', 'resulterent']},
 'resulterad': {'resulterade': []},
 'resulterai': {'resulteraient': []},
 'resulterand': {'resulterande': []},
 'resultere': ['resulterer', 'resulterent'],
 'resultered': {'resulterede': []},
 'resulterend': {'resulterende': []},
 'resulteroi': {'resulteroient': []},
 'resultert': {'resulterte': []},
 'resultf': {'resultfs': []},
 'resultget': {'resultgetting': []},
 'resulti': {'resultis': [], 'resulty': []},
 'resultierend': {'resultierende': ['resultierender']},
 'resultierende': ['resultierender'],
 'resultiert': {'resultierte': []},
 'resultin': {'resultine': [], 'resultins': []},
 'resultingfromth': {'resultingfromthe': []},
 'resultinginth': {'resultinginthe': []},
 'resultingli': {'resultingly': []},
 'resultless': {'resultlessness': []},
 'resultlessli': {'resultlessly': []},
 'resultofth': {'resultofthe': []},
 'resultori': {'resultoriented': []},
 'resultorient': {'resultorientation': []},
 'resultproduc': {'resultproducing': []},
 'resultsar': {'resultsare': []},
 'resultsbas': {'resultsbased': []},
 'resultset': {'resultsets': []},
 'resultsetconcurr': {'resultsetconcurrency': []},
 'resultsettyp': {'resultsettype': []},
 'resultsfocus': {'resultsfocused': []},
 'resultshav': {'resultshave': []},
 'resultsobtain': {'resultsobtained': []},
 'resultsofth': {'resultsofthe': []},
 'resultsori': {'resultsoriented': []},
 'resultsorient': {'resultsorientation': []},
 'resultstr': {'resultstring': []},
 'resultswer': {'resultswere': []},
 'resultth': {'resultthe': []},
 'resulttyp': {'resulttype': []},
 'resultwa': {'resultwas': []},
 'resultwil': {'resultwill': []},
 'resulut': {'resulution': ['resulutions']},
 'resulution': ['resulutions'],
 'resulv': {'resulved': []},
 'resulzad': {'resulzade': []},
 'resum': {'resumable': [],
           'resumably': [],
           'resumant': [],
           'resumation': [],
           'resume': ['resumed', 'resumer', 'resumers', 'resumeable'],
           'resuming': [],
           'resummed': [],
           'resumming': [],
           'resums': []},
 "resum'": {"resum'e": []},
 'resumai': {'resumaient': []},
 'resumbl': {'resumbling': []},
 'resumd': {'resumds': []},
 'resume': {'resumee': ['resumees']},
 'resumebuild': {'resumebuilding': []},
 'resumee': ['resumees'],
 'resumemak': {'resumemaker': []},
 'resumen': {'resumenes': [], 'resumens': []},
 'resumenda': {'resumendae': []},
 'resumendu': {'resumendus': []},
 'resumer': {'resumere': ['resumeres']},
 'resumere': ['resumeres'],
 'resumeron': {'resumerons': []},
 'resumewrit': {'resumewriting': []},
 'resumf': {'resumfe': []},
 'resumi': {'resumis': []},
 'resumida': {'resumidas': []},
 'resumidament': {'resumidamente': []},
 'resumido': {'resumidos': []},
 'resumierons': {'resumieronse': []},
 'resumimo': {'resumimos': []},
 'resumirs': {'resumirse': []},
 'resumm': {'resummation': ['resummations']},
 'resummar': {'resummarize': ['resummarized'], 'resummarizing': []},
 'resummarize': ['resummarized'],
 'resummation': ['resummations'],
 'resummon': {'resummoned': [], 'resummoning': [], 'resummons': []},
 'resumo': {'resumos': []},
 'resumon': {'resumons': []},
 'resumpt': {'resumption': [], 'resumptive': ['resumptives', 'resumptively']},
 'resumpti': {'resumptis': []},
 'resumptionist': {'resumptionists': []},
 'resumptive': ['resumptives', 'resumptively'],
 'resun': {'resune': ['resuned'], 'resuns': []},
 'resund': {'resunded': [], 'resunding': []},
 'resune': ['resuned'],
 'resunect': {'resunection': []},
 'resuorc': {'resuorces': []},
 'resupend': {'resupended': []},
 'resuperh': {'resuperheated': [], 'resuperheating': []},
 'resuperheat': {'resuperheater': []},
 'resupin': {'resupinate': ['resupinates', 'resupinated'],
             'resupination': [],
             'resupine': []},
 'resupinate': ['resupinates', 'resupinated'],
 'resupinatu': {'resupinatus': []},
 'resupinu': {'resupinus': []},
 'resuppl': {'resupplemented': []},
 'resupplement': {'resupplementation': []},
 'resuppli': {'resupplied': [], 'resupplies': [], 'resupply': ['resupplying']},
 'resupply': ['resupplying'],
 'resupport': {'resupported': [], 'resupporting': []},
 'resuppos': {'resupposed': [], 'resupposes': []},
 'resuppress': {'resuppressed': [], 'resuppression': []},
 'resur': {'resure': [], 'resurs': []},
 'resurc': {'resurce': ['resurces']},
 'resurce': ['resurces'],
 'resurect': {'resurected': [], 'resurection': []},
 'resurfac': {'resurface': ['resurfacer',
                            'resurfaced',
                            'resurfaces',
                            'resurfacers'],
              'resurfacing': ['resurfacings']},
 'resurface': ['resurfacer', 'resurfaced', 'resurfaces', 'resurfacers'],
 'resurfacing': ['resurfacings'],
 'resurg': {'resurgance': [],
            'resurgant': [],
            'resurge': ['resurges',
                        'resurged',
                        'resurgent',
                        'resurgents',
                        'resurgency',
                        'resurgence',
                        'resurgently',
                        'resurgeance',
                        'resurgencies'],
            'resurging': []},
 'resurgamu': {'resurgamus': []},
 'resurge': ['resurges',
             'resurged',
             'resurgent',
             'resurgents',
             'resurgency',
             'resurgence',
             'resurgently',
             'resurgeance',
             'resurgencies'],
 'resurgemu': {'resurgemus': []},
 'resurgen': {'resurgens': []},
 'resurgent': {'resurgente': ['resurgentes']},
 'resurgente': ['resurgentes'],
 'resurgenti': {'resurgentis': []},
 'resurger': {'resurgere': ['resurgerent']},
 'resurgere': ['resurgerent'],
 'resurgeri': {'resurgery': []},
 'resurgimu': {'resurgimus': []},
 'resurn': {'resurned': []},
 'resurr': {'resurre': []},
 'resurrcctioni': {'resurrcctionis': []},
 'resurreccion': {'resurrecciones': []},
 'resurrect': {'resurrectable': [],
               'resurrected': [],
               'resurrecter': [],
               'resurrectible': [],
               'resurrecting': [],
               'resurrection': ['resurrectioned', 'resurrectional'],
               'resurrective': [],
               'resurrects': []},
 'resurrecte': {'resurrectee': ['resurrectees']},
 'resurrectee': ['resurrectees'],
 'resurrecti': {'resurrectiou': []},
 'resurrectin': {'resurrectine': []},
 'resurrection': {'resurrectione': [],
                  'resurrectionism': [],
                  'resurrectionized': []},
 'resurrectionari': {'resurrectionary': []},
 'resurrectionascens': {'resurrectionascension': []},
 'resurrectionbodi': {'resurrectionbody': []},
 'resurrectioni': {'resurrectionis': []},
 'resurrectionis': {'resurrectionised': []},
 'resurrectionist': {'resurrectionists': []},
 'resurrectionlif': {'resurrectionlife': []},
 'resurrector': {'resurrectors': []},
 'resurrectori': {'resurrectory': []},
 'resurrectu': {'resurrectus': []},
 'resurrecturo': {'resurrecturos': []},
 'resurrecturu': {'resurrecturus': []},
 'resurreet': {'resurreetion': []},
 'resurreft': {'resurreftion': []},
 'resurrend': {'resurrender': ['resurrendered']},
 'resurrender': ['resurrendered'],
 'resurreot': {'resurreotion': []},
 'resurres': {'resurresion': []},
 'resurrett': {'resurrettion': []},
 'resurrezion': {'resurrezione': []},
 'resurrrect': {'resurrrection': []},
 'resurs': {'resurse': ['resurser'], 'resursive': []},
 'resurse': ['resurser'],
 'resursel': {'resursele': []},
 'resursi': {'resursy': []},
 'resurt': {'resurts': []},
 'resurvci': {'resurvcy': []},
 'resurvey': ['resurveyed', 'resurveying'],
 'resus': {'resusable': [],
           'resusal': ['resusals'],
           'resuse': ['resused', 'resuses'],
           'resusing': []},
 'resusal': ['resusals'],
 'resuscept': {'resusceptibility': []},
 'resusci': {'resusciate': ['resusciated'], 'resusciation': []},
 'resusciate': ['resusciated'],
 'resuscit': {'resuscitability': [],
              'resuscitable': [],
              'resuscitant': [],
              'resuscitate': ['resuscitates', 'resuscitated'],
              'resuscitating': [],
              'resuscitation': [],
              'resuscitative': [],
              'resuscitator': [],
              'resuscite': ['resuscited', 'resuscites', 'resusciter']},
 'resuscitair': {'resuscitaire': []},
 'resuscitar': {'resuscitare': []},
 'resuscitat': {'resuscitatable': []},
 'resuscitate': ['resuscitates', 'resuscitated'],
 'resuscitation': {'resuscitatione': []},
 'resuscitatori': {'resuscitatory': []},
 'resuscitatu': {'resuscitatus': []},
 'resuscite': ['resuscited', 'resuscites', 'resusciter'],
 'resuscitolog': {'resuscitology': []},
 'resuscitori': {'resuscitory': []},
 'resuscitub': {'resuscitube': []},
 'resuse': ['resused', 'resuses'],
 'resusit': {'resusitate': ['resusitated'],
             'resusitating': [],
             'resusitation': []},
 'resusitate': ['resusitated'],
 'resusitub': {'resusitube': []},
 'resuslt': {'resuslts': []},
 'resuspcnd': {'resuspcnded': []},
 'resuspen': {'resuspened': []},
 'resuspend': {'resuspendability': [],
               'resuspendable': [],
               'resuspended': [],
               'resuspending': [],
               'resuspends': []},
 'resuspens': {'resuspensed': [], 'resuspension': []},
 'resut': {'resutation': [],
           'resute': ['resuted', 'resutes'],
           'resuting': [],
           'resuts': [],
           'resutted': [],
           'resutting': []},
 'resute': ['resuted', 'resutes'],
 'resutl': {'resutled': [], 'resutling': [], 'resutls': []},
 'resutrect': {'resutrection': []},
 'resutt': {'resutts': []},
 'resutur': {'resuture': ['resutured'], 'resuturing': []},
 'resuture': ['resutured'],
 'resuu': {'resuus': []},
 'resuurc': {'resuurces': []},
 'resv': {'resve': []},
 'resvani': {'resvanis': []},
 'resvdt': {'resvdts': []},
 'resveil': {'resveillant': [], 'resveille': ['resveiller']},
 'resveille': ['resveiller'],
 'resveri': {'resverie': ['resveries'], 'resvery': []},
 'resverie': ['resveries'],
 'resveur': {'resveurs': []},
 'resvlt': {'resvlts': []},
 'resvnthesi': {'resvnthesis': []},
 'resvol': {'resvoll': []},
 'resvrrect': {'resvrrection': []},
 'reswaddl': {'reswaddled': []},
 'reswag': {'reswaged': []},
 'reswalli': {'reswallie': []},
 'reswallow': {'reswallowed': [], 'reswallowing': [], 'reswallows': []},
 'reswap': {'reswapped': []},
 'reswear': {'reswearing': []},
 'resweat': {'resweated': [], 'resweating': []},
 'resweb': {'resweber': []},
 'resweep': {'resweeping': []},
 'reswel': {'reswell': ['reswells', 'reswelled', 'reswelling']},
 'reswell': ['reswells', 'reswelled', 'reswelling'],
 'reswitch': {'reswitched': [], 'reswitches': [], 'reswitching': []},
 'reswor': {'reswore': []},
 'resyd': {'resyde': ['resydent', 'resydence'], 'resyding': []},
 'resyde': ['resydent', 'resydence'],
 'resydew': {'resydewe': []},
 'resydu': {'resydue': []},
 'resygn': {'resygne': []},
 'resyllab': {'resyllabication': []},
 'resyllabif': {'resyllabification': []},
 'resyllabifi': {'resyllabified': [],
                 'resyllabifies': [],
                 'resyllabify': ['resyllabifying']},
 'resyllabify': ['resyllabifying'],
 'resym': {'resyme': []},
 'resymbol': {'resymbolization': ['resymbolizations'],
              'resymbolize': ['resymbolized', 'resymbolizes'],
              'resymbolizing': []},
 'resymbolis': {'resymbolisation': []},
 'resymbolization': ['resymbolizations'],
 'resymbolize': ['resymbolized', 'resymbolizes'],
 'resync': {'resynced': [], 'resyncing': []},
 'resynch': {'resynched': [], 'resynching': []},
 'resynchron': {'resynchronization': ['resynchronizations'],
                'resynchronize': ['resynchronized', 'resynchronizes'],
                'resynchronizing': []},
 'resynchronis': {'resynchronisation': [],
                  'resynchronise': ['resynchronised'],
                  'resynchronising': []},
 'resynchronise': ['resynchronised'],
 'resynchronization': ['resynchronizations'],
 'resynchronize': ['resynchronized', 'resynchronizes'],
 'resyncvalu': {'resyncvalues': []},
 'resynd': {'resyndicated': [], 'resyndication': []},
 'resynthes': {'resynthese': ['resyntheses'],
               'resynthesization': [],
               'resynthesize': ['resynthesizes', 'resynthesized'],
               'resynthesizing': []},
 'resynthese': ['resyntheses'],
 'resynthesi': {'resynthesis': []},
 'resynthesis': {'resynthesise': ['resynthesised', 'resynthesises'],
                 'resynthesising': []},
 'resynthesise': ['resynthesised', 'resynthesises'],
 'resynthesize': ['resynthesizes', 'resynthesized'],
 'resynthet': {'resynthetic': [], 'resynthetized': []},
 'resyst': {'resyste': ['resysted', 'resystence']},
 'resyste': ['resysted', 'resystence'],
 'resystem': {'resystemization': []},
 'resystemat': {'resystematization': [],
                'resystematize': ['resystematized'],
                'resystematizing': []},
 'resystematize': ['resystematized'],
 'resz': {'resze': []},
 'reszer': {'reszere': []},
 'reszk': {'reszke': ['reszkes']},
 'reszke': ['reszkes'],
 'reszlet': {'reszletes': []},
 'reszo': {'reszoe': []},
 'reszti': {'reszty': []},
 'reszvetel': {'reszvetele': []},
 'ret': {'retative': ['retatives', 'retatively'],
         'retfulness': [],
         'rets': [],
         'retted': [],
         'retting': ['rettings']},
 'reta': {'retae': [], 'retaing': [], 'retas': []},
 'retabl': {'retable': ['retabled', 'retables'],
            'retabli': ['retablis', 'retablies', 'retabling'],
            'retably': []},
 'retable': ['retabled', 'retables'],
 'retabli': {'retablie': []},
 'retablir': {'retablirent': []},
 'retabliss': {'retablissant': [],
               'retablisse': ['retablissent', 'retablissement']},
 'retablisse': ['retablissent', 'retablissement'],
 'retablisson': {'retablissons': []},
 'retablo': {'retablos': []},
 'retabul': {'retabulate': ['retabulated'],
             'retabulating': [],
             'retabulation': ['retabulations']},
 'retabulate': ['retabulated'],
 'retabulation': ['retabulations'],
 'retac': {'retace': ['retaceous']},
 'retace': ['retaceous'],
 'retack': {'retacked': [], 'retacking': []},
 'retackl': {'retackle': ['retackled']},
 'retackle': ['retackled'],
 'retag': {'retagged': [], 'retagging': []},
 'retahila': {'retahilas': []},
 'retaia': {'retaiaed': []},
 'retaid': {'retaidation': [], 'retaided': []},
 'retail': ['retaill',
            'retaile',
            'retailer',
            'retailed',
            'retaille',
            'retailing',
            'retailler',
            'retailles',
            'retailment',
            'retailable',
            'retailation',
            'retailization'],
 'retaildeal': {'retaildealer': ['retaildealers']},
 'retaildealer': ['retaildealers'],
 'retailercustom': {'retailercustomers': []},
 'retailerown': {'retailerowned': []},
 'retaili': {'retailiate': ['retailiated'], 'retailiation': []},
 'retailiate': ['retailiated'],
 'retailiatori': {'retailiatory': []},
 'retailor': {'retailored': [], 'retailoring': [], 'retailors': []},
 'retailori': {'retailoriented': []},
 'retailpric': {'retailprice': []},
 'retailsal': {'retailsales': []},
 'retailstor': {'retailstore': []},
 'retailtain': {'retailtainment': []},
 'retailtrad': {'retailtrade': ['retailtraders']},
 'retailtrade': ['retailtraders'],
 'retailwholesal': {'retailwholesale': []},
 'retain': {'retainability': [],
            'retainable': [],
            'retainance': [],
            'retaine': ['retained', 'retainer', 'retaines', 'retaineing'],
            'retaining': ['retainings'],
            'retainment': ['retainments'],
            'retains': []},
 'retainag': {'retainage': ['retainages']},
 'retainage': ['retainages'],
 'retainal': {'retainall': []},
 'retaind': {'retainder': ['retainders']},
 'retainder': ['retainders'],
 'retaine': {'retainee': ['retainees']},
 'retainedearn': {'retainedearnings': []},
 'retainedth': {'retainedthe': []},
 'retainee': ['retainees'],
 'retainership': {'retainerships': []},
 'retaining': ['retainings'],
 'retainingth': {'retainingthe': []},
 'retainingwal': {'retainingwall': ['retainingwalls']},
 'retainingwall': ['retainingwalls'],
 'retainment': ['retainments'],
 'retainsth': {'retainsthe': []},
 'retaint': {'retainted': [], 'retaintion': []},
 'retainth': {'retainthe': []},
 'retair': {'retaired': []},
 'retaiu': {'retaiued': [], 'retaiuing': [], 'retaius': []},
 'retak': {'retake': ['retaker', 'retakers'], 'retaking': []},
 'retake': ['retaker', 'retakers'],
 'retal': {'retalation': [],
           'retale': ['retaled', 'retales', 'retalers'],
           'retaling': [],
           'retall': ['retaller', 'retallic', 'retallied', 'retallers'],
           'retals': []},
 'retale': ['retaled', 'retales', 'retalers'],
 'retalho': {'retalhos': []},
 'retali': {'retaliate': ['retaliated', 'retaliates'],
            'retaliating': [],
            'retaliation': [],
            'retaliative': ['retaliatively'],
            'retaliator': [],
            'retalis': []},
 'retaliatari': {'retaliatary': []},
 'retaliate': ['retaliated', 'retaliates'],
 'retaliationist': {'retaliationists': []},
 'retaliative': ['retaliatively'],
 'retaliatori': {'retaliatory': []},
 'retaliatorili': {'retaliatorily': []},
 'retalit': {'retalitate': [], 'retalitation': [], 'retalition': []},
 'retalitori': {'retalitory': []},
 'retalk': {'retalked': [], 'retalking': [], 'retalks': []},
 'retall': ['retaller', 'retallic', 'retallied', 'retallers'],
 'retalli': {'retalliate': ['retalliated'], 'retalliation': []},
 'retalliate': ['retalliated'],
 'retalliatori': {'retalliatory': []},
 'retaln': {'retalned': [], 'retalner': []},
 'retam': {'retamal': [], 'retame': ['retamed'], 'retaming': [], 'retams': []},
 'retama': {'retama': []},
 'retamal': {'retamales': []},
 'retame': ['retamed'],
 'retamp': {'retamped': [], 'retamping': []},
 'retan': {'retaning': [], 'retanned': [], 'retanning': []},
 'retanc': {'retance': []},
 'retangl': {'retangle': ['retangled']},
 'retangle': ['retangled'],
 'retannag': {'retannage': []},
 'retant': {'retantion': []},
 'retap': {'retape': ['retapes', 'retaped'],
           'retaping': [],
           'retapped': [],
           'retapping': []},
 'retape': ['retapes', 'retaped'],
 'retar': {'retared': [], 'retarred': [], 'retarring': []},
 'retard': ['retarde',
            'retarded',
            'retarder',
            'retardes',
            'retardant',
            'retardent',
            'retarding',
            'retarders',
            'retardate',
            'retardive',
            'retardated',
            'retardates',
            'retardance',
            'retardment',
            'retardness',
            'retardable',
            'retardancy',
            'retardency',
            'retardings',
            'retardments',
            'retardation',
            'retardement',
            'retardative',
            'retardances',
            'retardements',
            'retardational'],
 'retardado': {'retardados': []},
 'retardair': {'retardaire': []},
 'retardandi': {'retardandis': []},
 'retardant': {'retardante': []},
 'retardanttr': {'retardanttreated': []},
 'retardar': {'retardare': ['retardarent']},
 'retardare': ['retardarent'],
 'retardatair': {'retardataire': ['retardataires']},
 'retardataire': ['retardataires'],
 'retardation': {'retardatione': []},
 'retardationi': {'retardationis': []},
 'retardatori': {'retardatory': []},
 'retardatric': {'retardatrice': ['retardatrices']},
 'retardatrice': ['retardatrices'],
 'retardatu': {'retardatus': []},
 'retarde': {'retardee': ['retardees']},
 'retarded': {'retardedness': []},
 'retardedli': {'retardedly': []},
 'retardee': ['retardees'],
 'retarder': {'retarderent': []},
 'retardierend': {'retardierende': []},
 'retardiert': {'retardierte': []},
 'retardingli': {'retardingly': []},
 'retarditair': {'retarditaire': []},
 'retardo': {'retardos': []},
 'retardt': {'retardtion': []},
 'retarget': {'retargetability': [],
              'retargetable': [],
              'retargeted': [],
              'retargeting': [],
              'retargets': [],
              'retargetted': [],
              'retargetting': []},
 'retari': {'retarial': [], 'retaries': [], 'retary': []},
 'retarif': {'retariffed': [], 'retariffing': []},
 'retariu': {'retarius': []},
 'retarn': {'retarned': [], 'retarning': [], 'retarns': []},
 'retarri': {'retarrier': []},
 'retart': {'retarted': []},
 'retartu': {'retartus': []},
 'retaruk': {'retaruke': []},
 'retask': {'retasked': [], 'retasking': []},
 'retast': {'retaste': ['retasted', 'retastes'], 'retasting': []},
 'retaste': ['retasted', 'retastes'],
 'retat': {'retate': ['retates', 'retated'],
           'retating': [],
           'retation': ['retations', 'retational']},
 'retate': ['retates', 'retated'],
 'retati': {'retatis': []},
 'retation': ['retations', 'retational'],
 'retationship': {'retationships': []},
 'retative': ['retatives', 'retatively'],
 'retatn': {'retatned': []},
 'retattl': {'retattled': []},
 'retatu': {'retatus': []},
 'retaur': {'retaurant': ['retaurants']},
 'retaurant': ['retaurants'],
 'retavas': {'retavase': []},
 'retayl': {'retayle': ['retayled', 'retayler', 'retaylers'], 'retayling': []},
 'retayle': ['retayled', 'retayler', 'retaylers'],
 'retayn': {'retayne': ['retayner', 'retayned', 'retaynes', 'retayners'],
            'retayning': []},
 'retayne': ['retayner', 'retayned', 'retaynes', 'retayners'],
 'retazo': {'retazos': []},
 'retbi': {'retby': []},
 'retbol': {'retboll': []},
 'retch': ['retche', 'retched', 'retching', 'retchings'],
 'retched': {'retchedness': []},
 'retchi': {'retchie': [], 'retchis': [], 'retchy': []},
 'retchingli': {'retchingly': []},
 'retchless': {'retchlesse': [], 'retchlessness': []},
 'retcliff': {'retcliffe': []},
 'retcntiv': {'retcntiveness': []},
 'retcod': {'retcode': []},
 'retcofski': {'retcofsky': []},
 'retcst': {'retcsted': []},
 'rete': ['reted', 'retee', 'reteed'],
 'reteabl': {'reteable': []},
 'reteach': {'reteaches': [], 'reteaching': []},
 'reteal': {'retealed': []},
 'reteam': {'reteamed': [], 'reteaming': []},
 'retean': {'reteane': ['reteaned'], 'reteaning': []},
 'reteane': ['reteaned'],
 'retear': {'retearing': [], 'retears': []},
 'retearch': {'retearches': []},
 'reteas': {'retease': ['reteased', 'reteases']},
 'retease': ['reteased', 'reteases'],
 'reteat': {'reteated': [], 'reteating': []},
 'retect': {'retected': [], 'retection': []},
 'retecti': {'retectis': []},
 'retegen': {'retegens': []},
 'reteger': {'retegere': []},
 'retegi': {'retegis': []},
 'reteh': {'retehing': []},
 'reteienc': {'reteience': []},
 'reteign': {'reteigne': []},
 'retein': {'reteine': ['reteined', 'reteiner'], 'reteining': []},
 'reteine': ['reteined', 'reteiner'],
 'reteir': {'reteire': ['reteired'], 'reteiring': []},
 'reteire': ['reteired'],
 'reteiv': {'reteive': ['reteived']},
 'reteive': ['reteived'],
 'retel': {'retell': ['retelle',
                      'retells',
                      'reteller',
                      'retelling',
                      'retellers',
                      'retellings',
                      'retellable']},
 'retelegraph': {'retelegraphed': []},
 'retell': ['retelle',
            'retells',
            'reteller',
            'retelling',
            'retellers',
            'retellings',
            'retellable'],
 'retembl': {'retemblance': []},
 'retemey': {'retemeyer': []},
 'retemp': {'retemper': ['retempers', 'retempered', 'retempering']},
 'retemper': ['retempers', 'retempered', 'retempering'],
 'retempor': {'retemporalization': [], 'retemporalize': ['retemporalized']},
 'retemporalize': ['retemporalized'],
 'reten': {'retenant': ['retenanted', 'retenanting'],
           'retenate': [],
           'retene': ['retened', 'retenes', 'retener']},
 'retenai': {'retenaient': [], 'retenais': []},
 'retenant': ['retenanted', 'retenanting'],
 'retenaunc': {'retenaunce': []},
 'retenc': {'retence': []},
 'retencion': {'retenciones': []},
 'retend': {'retended': [],
            'retender': ['retenders', 'retendered', 'retendering'],
            'retending': [],
            'retends': []},
 'retender': ['retenders', 'retendered', 'retendering'],
 'retene': ['retened', 'retenes', 'retener'],
 'retenensi': {'retenensis': []},
 'retener': {'retenere': []},
 'reteng': {'retenge': []},
 'retenida': {'retenidas': []},
 'retenido': {'retenidos': []},
 'retenoi': {'retenoient': []},
 'retenon': {'retenons': []},
 'retens': {'retense': [],
            'retension': ['retensions', 'retensioned', 'retensioning'],
            'retensive': []},
 'retension': ['retensions', 'retensioned', 'retensioning'],
 'retent': {'retentate': ['retentates'],
            'retentative': [],
            'retention': ['retentional', 'retentionally'],
            'retentive': ['retentives', 'retentively', 'retentiveness'],
            'retentivity': [],
            'retently': [],
            'retents': []},
 'retenta': {'retentae': [], 'retentas': []},
 'retentan': {'retentans': []},
 'retentar': {'retentare': []},
 'retentate': ['retentates'],
 'retenti': {'retentie': [], 'retentiou': ['retentious'], 'retentis': []},
 'retention': {'retentionality': [],
               'retentione': ['retentiones'],
               'retentionism': []},
 'retentioncyst': {'retentioncysts': []},
 'retentione': ['retentiones'],
 'retentioni': {'retentionis': []},
 'retentionist': {'retentionists': []},
 'retentiontim': {'retentiontime': []},
 'retentiou': ['retentious'],
 'retentir': {'retentirent': []},
 'retentiss': {'retentissant': ['retentissants'],
               'retentisse': ['retentissent',
                              'retentissement',
                              'retentissements']},
 'retentissai': {'retentissaient': []},
 'retentissant': {'retentissante': ['retentissantes']},
 'retentissante': ['retentissantes'],
 'retentisse': ['retentissent', 'retentissement', 'retentissements'],
 'retentive': ['retentives', 'retentively', 'retentiveness'],
 'retento': {'retentos': []},
 'retentu': {'retentus': []},
 'retenu': {'retenue': ['retenues'], 'retenus': []},
 'retenue': ['retenues'],
 'reteocrinu': {'reteocrinus': []},
 'reteplas': {'reteplase': []},
 'retepor': {'retepores': []},
 'reteporida': {'reteporidae': []},
 'reter': {'reteral': [],
           'retere': ['reteres', 'retered', 'reterence', 'reterences'],
           'reterred': [],
           'reterring': [],
           'reters': []},
 'reteran': {'reterans': []},
 'retere': {'reteree': []},
 'reterenc': {'reterenced': []},
 'reterm': {'retermed': [], 'reterms': []},
 'retermin': {'reterminate': ['reterminated'], 'retermination': []},
 'reterminate': ['reterminated'],
 'retern': {'reterned': []},
 'reterritori': {'reterritorialization': ['reterritorializations'],
                 'reterritorialize': ['reterritorialized', 'reterritorializes'],
                 'reterritorializing': []},
 'reterritorialis': {'reterritorialisation': ['reterritorialisations'],
                     'reterritorialise': ['reterritorialises',
                                          'reterritorialised'],
                     'reterritorialising': []},
 'reterritorialisation': ['reterritorialisations'],
 'reterritorialise': ['reterritorialises', 'reterritorialised'],
 'reterritorialization': ['reterritorializations'],
 'reterritorialize': ['reterritorialized', 'reterritorializes'],
 'reters': {'reterse': ['retersed']},
 'reterse': ['retersed'],
 'retert': {'reterted': []},
 'reterv': {'reterve': ['reterved']},
 'reterve': ['reterved'],
 'reteryk': {'reteryke': []},
 'retest': {'retestable': [],
            'retested': [],
            'retesting': ['retestings'],
            'retests': []},
 'retesting': ['retestings'],
 'retet': {'reteted': [], 'retetion': []},
 'reteth': {'retethered': [], 'retethering': []},
 'reteut': {'reteution': []},
 'retev': {'retevance': [], 'retevant': []},
 'retevis': {'retevision': []},
 'reteyn': {'reteyne': ['reteyned', 'reteyners'], 'reteyning': []},
 'reteyne': ['reteyned', 'reteyners'],
 'retfaerdigh': {'retfaerdighed': []},
 'retford': {'retfords': []},
 'retger': {'retgers': []},
 'reth': {'rethe': [], 'rething': ['rethings'], 'reths': []},
 'rethan': {'rethane': [], 'rethans': []},
 'rethar': {'rethare': []},
 'rethatch': {'rethatched': [], 'rethatching': []},
 'rethaw': {'rethawed': [], 'rethawing': []},
 'retheatric': {'retheatricalization': [],
                'retheatricalize': ['retheatricalized']},
 'retheatricalize': ['retheatricalized'],
 'rethel': {'rethell': [], 'rethels': []},
 'retheloi': {'rethelois': []},
 'rethem': {'rethemed': []},
 'rethemat': {'rethematization': [], 'rethematize': ['rethematized']},
 'rethematize': ['rethematized'],
 'rethemey': {'rethemeyer': []},
 'rethemiotaki': {'rethemiotakis': []},
 'rethemno': {'rethemnos': []},
 'retheolog': {'retheologized': [], 'retheologizing': []},
 'retheor': {'retheorization': ['retheorizations'],
             'retheorize': ['retheorized', 'retheorizes'],
             'retheorizing': []},
 'retheoret': {'retheoretization': []},
 'retheoris': {'retheorisation': [],
               'retheorise': ['retheorised'],
               'retheorising': []},
 'retheorise': ['retheorised'],
 'retheorization': ['retheorizations'],
 'retheorize': ['retheorized', 'retheorizes'],
 'rether': {'rethere': [], 'rethers': []},
 'retheri': {'retherial': []},
 'retherm': {'rethermalization': [], 'rethermalize': ['rethermalized']},
 'rethermalize': ['rethermalized'],
 'rethes': {'rethese': []},
 'rethi': {'rethis': [], 'rethy': []},
 'rethicken': {'rethickened': [], 'rethickening': []},
 'rething': ['rethings'],
 'rethinh': {'rethinhing': []},
 'rethink': ['rethinker', 'rethinkers', 'rethinking', 'rethinkings'],
 'rethinkingth': {'rethinkingthe': []},
 'rethk': {'rethke': []},
 'rethli': {'rethly': []},
 'rethlingshaf': {'rethlingshafer': []},
 'rethmet': {'rethmetic': []},
 'rethmey': {'rethmeyer': []},
 'rethmk': {'rethmking': []},
 'rethod': {'rethods': []},
 'rethond': {'rethondes': []},
 'rethor': {'rethore': [],
            'rethoric': ['rethorics', 'rethorical', 'rethorically']},
 'rethoracotomi': {'rethoracotomy': []},
 'rethori': {'rethoris': []},
 'rethoric': {'rethorice': []},
 'rethorical': {'rethoricall': []},
 'rethorici': {'rethoricis': []},
 'rethorick': {'rethoricke': []},
 'rethorik': {'rethorike': []},
 'rethoriqu': {'rethorique': []},
 'rethoryk': {'rethoryke': []},
 'rethos': {'rethose': []},
 'rethr': {'rethre': []},
 'rethre': {'rethree': []},
 'rethread': {'rethreaded': [], 'rethreading': [], 'rethreads': []},
 'rethreaten': {'rethreatened': []},
 'rethresh': {'rethreshed': [], 'rethreshing': []},
 'rethrombos': {'rethrombose': ['rethrombosed']},
 'rethrombose': ['rethrombosed'],
 'rethrombosi': {'rethrombosis': []},
 'rethron': {'rethrone': ['rethroned']},
 'rethrone': ['rethroned'],
 'rethrow': {'rethrowing': [], 'rethrows': []},
 'rethun': {'rethune': []},
 'rethymn': {'rethymne': []},
 'rethymni': {'rethymnis': []},
 'rethymno': {'rethymnos': []},
 'reti': {'retie': ['retied', 'reties', 'retieing'],
          'retis': [],
          'rety': ['retying']},
 'retiabl': {'retiable': []},
 'retianc': {'retiance': []},
 'retiari': {'retiary': []},
 'retiaric': {'retiarice': []},
 'retiariu': {'retiarius': []},
 'retibu': {'retibus': []},
 'retic': {'retical': ['retically'],
           'retice': ['retices',
                      'reticent',
                      'reticents',
                      'reticency',
                      'reticence',
                      'reticently',
                      'reticencies'],
           'retics': []},
 'retical': ['retically'],
 'retice': ['retices',
            'reticent',
            'reticents',
            'reticency',
            'reticence',
            'reticently',
            'reticencies'],
 'reticea': {'reticeas': []},
 'reticel': {'reticelle': []},
 'reticencia': {'reticencias': []},
 'reticens': {'reticense': []},
 'reticent': {'reticente': ['reticentes']},
 'reticente': ['reticentes'],
 'reticentia': {'reticentiae': []},
 'reticenz': {'reticenze': []},
 'reticer': {'reticere': []},
 'retich': {'retiche': []},
 'retici': {'reticience': [], 'reticient': [], 'reticis': []},
 'retician': {'reticians': []},
 'reticiu': {'reticius': []},
 'retick': {'reticker': [], 'reticks': []},
 'reticket': {'reticketed': [], 'reticketing': []},
 'reticl': {'reticle': []},
 'retico': {'reticos': []},
 'reticolar': {'reticolare': []},
 'reticon': {'reticons': []},
 'reticu': {'reticus': []},
 'reticul': {'reticulate': ['reticulates', 'reticulated', 'reticulately'],
             'reticulating': [],
             'reticulation': ['reticulational'],
             'reticulative': [],
             'reticulator': [],
             'reticule': ['reticuled'],
             'reticulitis': []},
 'reticula': {'reticulae': []},
 'reticulado': {'reticulados': []},
 'reticulair': {'reticulaire': ['reticulaires']},
 'reticulaire': ['reticulaires'],
 'reticulalu': {'reticulalus': []},
 'reticulan': {'reticulans': []},
 'reticular': {'reticulare': ['reticulares'],
               'reticularism': [],
               'reticularity': [],
               'reticulars': []},
 'reticularactiv': {'reticularactivating': []},
 'reticulare': ['reticulares'],
 'reticularform': {'reticularformation': []},
 'reticulari': {'reticularis': []},
 'reticularist': {'reticularists': []},
 'reticularli': {'reticularly': []},
 'reticulata': {'reticulatae': [], 'reticulatas': []},
 'reticulate': ['reticulates', 'reticulated', 'reticulately'],
 'reticulati': {'reticulatis': []},
 'reticulation': ['reticulational'],
 'reticulatisporit': {'reticulatisporites': []},
 'reticulatu': {'reticulatus': []},
 'reticule': {'reticulee': ['reticulees']},
 'reticulee': ['reticulees'],
 'reticulem': {'reticulemic': []},
 'reticulendotheli': {'reticulendothelial': []},
 'reticuli': {'reticulis': []},
 'reticulin': {'reticuline': [], 'reticulins': []},
 'reticulist': {'reticulists': []},
 'reticulit': {'reticulite': []},
 'reticuliterm': {'reticulitermes': []},
 'reticulocera': {'reticuloceras': []},
 'reticuloci': {'reticulocy': []},
 'reticulocort': {'reticulocortical': []},
 'reticulocvt': {'reticulocvte': []},
 'reticulocyt': {'reticulocyte': [], 'reticulocytic': []},
 'reticulocytopen': {'reticulocytopenic': []},
 'reticulocytosi': {'reticulocytosis': []},
 'reticuloendothcli': {'reticuloendothclial': []},
 'reticuloendotheli': {'reticuloendothelial': []},
 'reticuloendothelios': {'reticuloendothelioses': []},
 'reticuloendotheliosi': {'reticuloendotheliosis': []},
 'reticuloendothi': {'reticuloendothial': []},
 'reticuloepitheli': {'reticuloepithelial': []},
 'reticulofug': {'reticulofugal': []},
 'reticulogranular': {'reticulogranularity': []},
 'reticulohistiocyt': {'reticulohistiocytes': [], 'reticulohistiocytic': []},
 'reticulohistiocytari': {'reticulohistiocytary': []},
 'reticulohistiocytosi': {'reticulohistiocytosis': []},
 'reticulohypothalam': {'reticulohypothalamic': []},
 'reticulolimb': {'reticulolimbic': []},
 'reticuloomas': {'reticuloomasal': []},
 'reticuloperiton': {'reticuloperitonitis': []},
 'reticulopod': {'reticulopods': []},
 'reticulopodi': {'reticulopodial': []},
 'reticuloprolif': {'reticuloproliferative': []},
 'reticulorumin': {'reticuloruminal': []},
 'reticulos': {'reticulose': ['reticuloses']},
 'reticulosarcom': {'reticulosarcomes': []},
 'reticulosarcoma': {'reticulosarcomas': []},
 'reticulosarcomatosi': {'reticulosarcomatosis': []},
 'reticulose': ['reticuloses'],
 'reticulosi': {'reticulosis': []},
 'reticulospin': {'reticulospinal': []},
 'reticulospinali': {'reticulospinalis': []},
 'reticulotegment': {'reticulotegmental': []},
 'reticuloterm': {'reticulotermes': []},
 'reticulothalam': {'reticulothalamic': []},
 'reticulothalamocort': {'reticulothalamocortical': []},
 'reticulotomi': {'reticulotomy': []},
 'reticulu': {'reticulus': []},
 'reticulum': {'reticulum': []},
 'reticulumassoci': {'reticulumassociated': []},
 'reticulumcel': {'reticulumcell': []},
 'reticulumlik': {'reticulumlike': []},
 'retid': {'retide': ['retided', 'retidence'], 'retiding': []},
 'retide': ['retided', 'retidence'],
 'retido': {'retidos': []},
 'retie': ['retied', 'reties', 'retieing'],
 'retieat': {'retieated': []},
 'retief': {'retiefs': []},
 'retiembl': {'retiemble': []},
 'retien': {'retiene': ['retienes'], 'retiens': []},
 'retienc': {'retience': []},
 'retiendron': {'retiendrons': []},
 'retiene': ['retienes'],
 'retienn': {'retienne': ['retiennent']},
 'retienne': ['retiennent'],
 'retier': {'retiere': ['retiered'], 'retiering': [], 'retiers': []},
 'retiere': ['retiered'],
 'retieulatu': {'retieulatus': []},
 'retiev': {'retieval': [], 'retieve': ['retieved']},
 'retieve': ['retieved'],
 'retif': {'retifer': [], 'retification': [], 'retifism': [], 'retifs': []},
 'retifi': {'retified': []},
 'retiform': {'retiforme': []},
 'retiformi': {'retiformis': []},
 'retigabin': {'retigabine': []},
 'retighten': {'retightened': [], 'retightening': [], 'retightens': []},
 'retigi': {'retigious': []},
 'retigieus': {'retigieuse': []},
 'retigion': {'retigions': []},
 'retii': {'retiie': ['retiied'], 'retiiing': []},
 'retiie': ['retiied'],
 'retiirn': {'retiirned': [], 'retiirning': []},
 'retikulos': {'retikulose': []},
 'retikulum': {'retikulums': []},
 'retil': {'retile': ['retiled'],
           'retiling': [],
           'retill': ['retilled', 'retilling']},
 'retile': ['retiled'],
 'retill': ['retilled', 'retilling'],
 'retilt': {'retilted': []},
 'retim': {'retime': ['retimes', 'retimed'], 'retiming': ['retimings']},
 'retimb': {'retimber': ['retimbered', 'retimbering']},
 'retimber': ['retimbered', 'retimbering'],
 'retime': ['retimes', 'retimed'],
 'retiming': ['retimings'],
 'retimonocolpit': {'retimonocolpites': []},
 'retin': {'retinal': ['retinally'],
           'retine': ['retined',
                      'retines',
                      'retinent',
                      'retinence',
                      'retineant',
                      'retinement'],
           'retinic': [],
           'retining': [],
           'retinitis': [],
           'retinned': [],
           'retinning': [],
           'retins': []},
 'retina': {'retina': []},
 'retinacula': {'retinaculae': []},
 'retinaculi': {'retinaculis': []},
 'retinal': {'retinale': ['retinaler']},
 'retinaldehyd': {'retinaldehyde': []},
 'retinale': ['retinaler'],
 'retinali': {'retinalis': []},
 'retinalik': {'retinalike': []},
 'retinalimag': {'retinalimage': []},
 'retinalit': {'retinalite': []},
 'retinamid': {'retinamide': ['retinamides']},
 'retinamide': ['retinamides'],
 'retinascop': {'retinascope': []},
 'retinaspecif': {'retinaspecific': []},
 'retinc': {'retince': []},
 'retincr': {'retincre': []},
 'retine': {'retinee': []},
 'retinea': {'retineas': []},
 'retineamu': {'retineamus': []},
 'retineati': {'retineatis': []},
 'retineb': {'retinebant': []},
 'retinebi': {'retinebis': []},
 'retinebimu': {'retinebimus': []},
 'retinectomi': {'retinectomies': [], 'retinectomy': []},
 'retinemu': {'retinemus': []},
 'retinen': {'retinene': [], 'retinens': []},
 'retinenda': {'retinendae': [], 'retinendas': []},
 'retinendi': {'retinendis': []},
 'retinendo': {'retinendos': []},
 'retinendu': {'retinendus': []},
 'retinensi': {'retinensis': []},
 'retinent': {'retinente': ['retinentes']},
 'retinente': ['retinentes'],
 'retinenti': {'retinentis': []},
 'retinentibu': {'retinentibus': []},
 'retiner': {'retinere': ['retineres', 'retinerent']},
 'retinere': ['retineres', 'retinerent'],
 'retinerv': {'retinerve': []},
 'retinervi': {'retinervis': []},
 'retinet': {'retinete': []},
 'retineti': {'retinetis': []},
 'retinett': {'retinette': []},
 'retinew': {'retinewe': []},
 'reting': {'retinger': []},
 'retini': {'retinie': []},
 'retinich': {'retiniche': []},
 'retinien': {'retiniens': []},
 'retinienn': {'retinienne': ['retiniennes']},
 'retinienne': ['retiniennes'],
 'retinin': {'retinine': []},
 'retinispora': {'retinisporas': []},
 'retinit': {'retinite': ['retinites'], 'retinitic': [], 'retinits': []},
 'retinite': ['retinites'],
 'retinm': {'retinmes': []},
 'retinn': {'retinne': ['retinnes']},
 'retinne': ['retinnes'],
 'retino': {'retinoate': [], 'retinoic': []},
 'retinobla': {'retinoblas': []},
 'retinoblast': {'retinoblastic': [], 'retinoblasts': []},
 'retinoblastom': {'retinoblastome': [], 'retinoblastoms': []},
 'retinoblastoma': {'retinoblastoma': []},
 'retinoblastomat': {'retinoblastomatous': []},
 'retinocentr': {'retinocentric': ['retinocentrically']},
 'retinocentric': ['retinocentrically'],
 'retinocephal': {'retinocephalic': []},
 'retinocerebr': {'retinocerebral': []},
 'retinochorioid': {'retinochorioiditis': []},
 'retinochoroid': {'retinochoroidal': [], 'retinochoroiditis': []},
 'retinochoroidopathi': {'retinochoroidopathy': []},
 'retinochrom': {'retinochrome': []},
 'retinociliari': {'retinociliary': []},
 'retinocort': {'retinocortical': []},
 'retinocytoma': {'retinocytomas': []},
 'retinod': {'retinodes': []},
 'retinodiplosi': {'retinodiplosis': []},
 'retinofug': {'retinofugal': []},
 'retinogenesi': {'retinogenesis': []},
 'retinogenicul': {'retinogeniculate': []},
 'retinogeniculocort': {'retinogeniculocortical': []},
 'retinogeniculostri': {'retinogeniculostriate': []},
 'retinogram': {'retinograms': []},
 'retinograph': {'retinographic': []},
 'retinographi': {'retinography': []},
 'retinohypothalam': {'retinohypothalamic': []},
 'retinoid': {'retinoidal': [], 'retinoides': [], 'retinoids': []},
 'retinoidbind': {'retinoidbinding': []},
 'retinoidinduc': {'retinoidinduced': []},
 'retinol': {'retinol': []},
 'retinolbind': {'retinolbinding': []},
 'retinoma': {'retinomas': []},
 'retinopath': {'retinopathic': []},
 'retinopathi': {'retinopathie': [], 'retinopathy': []},
 'retinopet': {'retinopetal': []},
 'retinopiesi': {'retinopiesis': []},
 'retinopretect': {'retinopretectal': []},
 'retinorecipi': {'retinorecipient': []},
 'retinoschisi': {'retinoschisis': []},
 'retinoscop': {'retinoscope': ['retinoscopes'], 'retinoscopic': []},
 'retinoscope': ['retinoscopes'],
 'retinoscopi': {'retinoscopy': []},
 'retinoscopist': {'retinoscopists': []},
 'retinosi': {'retinosis': []},
 'retinospora': {'retinosporas': []},
 'retinostri': {'retinostriate': []},
 'retinotect': {'retinotectal': []},
 'retinothalam': {'retinothalamic': []},
 'retinotomi': {'retinotomies': [], 'retinotomy': []},
 'retinotop': {'retinotopic': ['retinotopical', 'retinotopically']},
 'retinotopi': {'retinotopy': []},
 'retinotopic': ['retinotopical', 'retinotopically'],
 'retinotopographi': {'retinotopography': []},
 'retinovitr': {'retinovitreal': [], 'retinovitreous': []},
 'retinr': {'retinre': ['retinrent']},
 'retinre': ['retinrent'],
 'retins': {'retinse': []},
 'retint': {'retinte': ['retintes', 'retinted'], 'retinting': []},
 'retinte': ['retintes', 'retinted'],
 'retinu': {'retinue': ['retinued']},
 'retinue': ['retinued'],
 'retinuer': {'retinuere': [], 'retinueritis': []},
 'retinueri': {'retinueris': []},
 'retinuimu': {'retinuimus': []},
 'retinuiss': {'retinuisse': ['retinuissent']},
 'retinuisse': ['retinuissent'],
 'retinul': {'retinule': []},
 'retinula': {'retinulae': [], 'retinulas': []},
 'retinuls': {'retinulse': []},
 'retinyliden': {'retinylidene': []},
 'retio': {'retios': []},
 'retiograptu': {'retiograptus': []},
 'retiolit': {'retiolites': []},
 'retiolitid': {'retiolitids': []},
 'retiolitida': {'retiolitidae': []},
 'retiolog': {'retiology': []},
 'retion': {'retional': ['retionality', 'retionalization'],
            'retionic': [],
            'retions': []},
 'retional': {'retionale': []},
 'retionalis': {'retionalisation': []},
 'retionari': {'retionary': []},
 'retip': {'retipes': [], 'retipped': [], 'retipping': []},
 'retipor': {'retipores': []},
 'retiqu': {'retiques': []},
 'retir': {'retirable': [],
           'retiral': ['retirals'],
           'retirant': ['retirants'],
           'retiration': [],
           'retire': ['retirer',
                      'retires',
                      'retired',
                      'retireds',
                      'retirers',
                      'retirent',
                      'retireing',
                      'retireable',
                      'retirement'],
           'retiring': ['retirings'],
           'retirment': [],
           'retirou': []},
 'retira': {'retiras': []},
 'retiraci': {'retiracy': []},
 'retirad': {'retirade': ['retirades']},
 'retirada': {'retiradas': []},
 'retirade': ['retirades'],
 'retirado': {'retirados': []},
 'retirai': {'retiraient': []},
 'retiral': ['retirals'],
 'retiram': {'retirames': []},
 'retiramo': {'retiramos': []},
 'retirandos': {'retirandose': []},
 'retirant': {'retirante': ['retirantes']},
 'retirante': ['retirantes'],
 'retirarm': {'retirarme': []},
 'retirars': {'retirarse': []},
 'retiras': {'retirase': []},
 'retirass': {'retirassent': []},
 'retire': {'retiree': []},
 'retirea': {'retireaent': []},
 'retired': {'retiredness': []},
 'retiredli': {'retiredly': []},
 'retiredn': {'retirednes': []},
 'retiredness': {'retirednesse': []},
 'retiree': {'retireees': []},
 'retirem': {'retiremant': [], 'retireme': []},
 'retirementag': {'retirementage': []},
 'retirementincom': {'retirementincome': []},
 'retirementplan': {'retirementplanning': []},
 'retirementrel': {'retirementrelated': []},
 'retirementsav': {'retirementsavings': []},
 'retirementtyp': {'retirementtype': []},
 'retiren': {'retirenent': []},
 'retirer': {'retirerent': []},
 'retirerai': {'retireraient': []},
 'retirev': {'retireval': []},
 'retiring': {'retiringness': []},
 'retiringallow': {'retiringallowance': []},
 'retiringli': {'retiringly': []},
 'retiringplac': {'retiringplace': []},
 'retiringroom': {'retiringrooms': []},
 'retirion': {'retirions': []},
 'retiro': {'retiros': []},
 'retiroi': {'retiroient': [], 'retirois': []},
 'retiron': {'retirons': []},
 'retiros': {'retirose': []},
 'retirugi': {'retirugis': []},
 'retis': {'retised': []},
 'retisc': {'retiscence': []},
 'retisolut': {'retisolution': []},
 'retispers': {'retispersion': []},
 'retist': {'retistance': []},
 'retit': {'retite': ['retited', 'retitered', 'retitement'],
           'retiting': [],
           'retition': []},
 'retite': ['retited', 'retitered', 'retitement'],
 'retithrip': {'retithrips': []},
 'retiti': {'retitied': []},
 'retitl': {'retitle': ['retitles', 'retitled'], 'retitling': ['retitlings']},
 'retitle': ['retitles', 'retitled'],
 'retitling': ['retitlings'],
 'retitr': {'retitrate': ['retitrated'], 'retitrating': [], 'retitration': []},
 'retitrate': ['retitrated'],
 'retitricolpit': {'retitricolpites': []},
 'retitrilet': {'retitriletes': []},
 'retitt': {'retittance': []},
 'retiu': {'retius': []},
 'retiun': {'retiuned': [], 'retiuning': []},
 'retiuu': {'retiuue': []},
 'retiv': {'retival': [], 'retive': ['retives', 'retively']},
 'retive': ['retives', 'retively'],
 'retizo': {'retizos': []},
 'retjuir': {'retjuire': ['retjuired']},
 'retjuire': ['retjuired'],
 'retl': {'retle': []},
 'retlect': {'retlected': [],
             'retlecting': [],
             'retlection': ['retlections'],
             'retlective': [],
             'retlects': []},
 'retlection': ['retlections'],
 'retli': {'retly': []},
 'retlig': {'retlige': []},
 'retlli': {'retlly': []},
 'retm': {'retme': []},
 'retmn': {'retmned': [], 'retmning': [], 'retmns': []},
 'retmu': {'retmue': []},
 'retn': {'retne': ['retnes'], 'retning': [], 'retns': []},
 'retnain': {'retnained': [], 'retnains': []},
 'retnark': {'retnarkable': [], 'retnarks': []},
 'retne': ['retnes'],
 'retnemb': {'retnember': []},
 'retnet': {'retnetion': []},
 'retnev': {'retneval': [], 'retneve': ['retneved'], 'retneving': []},
 'retneve': ['retneved'],
 'retni': {'retny': []},
 'retnin': {'retnined': []},
 'retning': {'retninger': []},
 'retningslini': {'retningslinier': []},
 'retningslinj': {'retningslinjer': []},
 'retnm': {'retnmed': [], 'retnms': []},
 'retnold': {'retnolds': []},
 'retnov': {'retnove': ['retnoved']},
 'retnove': ['retnoved'],
 'retnrn': {'retnrne': ['retnrned'], 'retnrning': [], 'retnrns': []},
 'retnrne': ['retnrned'],
 'reto': {'retos': []},
 'retoast': {'retoasted': []},
 'retocada': {'retocadas': []},
 'retogen': {'retogenes': []},
 'retograd': {'retograde': []},
 'retoh': {'retohed': []},
 'retoil': {'retoile': []},
 'retoin': {'retoined': []},
 'retoir': {'retoiric': []},
 'retolt': {'retolted': []},
 'retolut': {'retolution': []},
 'retolv': {'retolved': []},
 'retom': {'retome': ['retomed']},
 'retomado': {'retomados': []},
 'retomb': {'retombant': [], 'retombe': ['retomber', 'retombes', 'retombent']},
 'retombai': {'retombaient': []},
 'retombe': {'retombee': ['retombees']},
 'retombee': ['retombees'],
 'retombon': {'retombons': []},
 'retome': ['retomed'],
 'reton': {'retonation': [],
           'retone': ['retoned'],
           'retoning': [],
           'retons': []},
 'retone': ['retoned'],
 'retono': {'retonos': []},
 'retool': {'retooled': [], 'retooling': ['retoolings'], 'retools': []},
 'retooling': ['retoolings'],
 'retop': {'retopped': [], 'retopping': []},
 'retoqu': {'retoque': ['retoques']},
 'retoque': ['retoques'],
 'retor': {'retoration': [],
           'retore': ['retored', 'retores'],
           'retoric': ['retorical'],
           'retoring': [],
           'retors': []},
 'retorc': {'retorcer': []},
 'retorcers': {'retorcerse': []},
 'retorcida': {'retorcidas': []},
 'retorcido': {'retorcidos': []},
 'retorciendos': {'retorciendose': []},
 'retord': {'retorded': [], 'retords': []},
 'retorderi': {'retorderie': []},
 'retordr': {'retordre': []},
 'retore': ['retored', 'retores'],
 'retori': {'retory': []},
 'retoric': ['retorical'],
 'retorica': {'retoricas': []},
 'retoricament': {'retoricamente': []},
 'retorich': {'retoriche': []},
 'retorico': {'retoricos': []},
 'retorik': {'retorike': []},
 'retoriqu': {'retorique': []},
 'retorm': {'retormation': [],
            'retorme': ['retormer', 'retormes', 'retormers'],
            'retorms': []},
 'retormateur': {'retormateurs': []},
 'retorme': ['retormer', 'retormes', 'retormers'],
 'retorn': {'retornable': [],
            'retorne': ['retorner', 'retornes', 'retorned'],
            'retorning': [],
            'retorns': []},
 'retornado': {'retornados': []},
 'retornar': {'retornare': []},
 'retorne': ['retorner', 'retornes', 'retorned'],
 'retorning': {'retorninge': []},
 'retorno': {'retornos': []},
 'retornyng': {'retornynge': []},
 'retorqu': {'retorque': ['retorquer',
                          'retorqued',
                          'retorquent',
                          'retorqueant'],
             'retorquing': []},
 'retorque': ['retorquer', 'retorqued', 'retorquent', 'retorqueant'],
 'retorquen': {'retorquens': []},
 'retorquer': {'retorquere': []},
 'retors': {'retorse': [], 'retorsion': ['retorsions'], 'retorsive': []},
 'retorsion': ['retorsions'],
 'retort': ['retorte',
            'retorter',
            'retorted',
            'retortive',
            'retorters',
            'retorting',
            'retortion',
            'retortable',
            'retortings',
            'retortions'],
 'retorta': {'retortas': []},
 'retortaeformi': {'retortaeformis': []},
 'retortamona': {'retortamonas': []},
 'retortamonad': {'retortamonads': []},
 'retorthous': {'retorthouse': []},
 'retorti': {'retortis': []},
 'retortlik': {'retortlike': []},
 'retortomona': {'retortomonas': []},
 'retortshap': {'retortshaped': []},
 'retoss': {'retossed': [], 'retossing': []},
 'retot': {'retotal': ['retotaled',
                       'retotaling',
                       'retotalize',
                       'retotalizes',
                       'retotalized',
                       'retotalizing',
                       'retotalization']},
 'retotal': ['retotaled',
             'retotaling',
             'retotalize',
             'retotalizes',
             'retotalized',
             'retotalizing',
             'retotalization'],
 'retotalis': {'retotalisation': []},
 'retotheli': {'retothelial': []},
 'retouch': {'retouchable': [],
             'retouche': ['retoucher', 'retouched', 'retouches', 'retouchers'],
             'retouching': ['retouchings']},
 'retouche': {'retouchee': ['retouchees']},
 'retouchee': ['retouchees'],
 'retouching': ['retouchings'],
 'retoum': {'retoume': ['retoumer']},
 'retoume': ['retoumer'],
 'retour': {'retourable': [], 'retoured': [], 'retours': []},
 'retouraupay': {'retouraupays': []},
 'retourc': {'retource': ['retources']},
 'retource': ['retources'],
 'retourd': {'retourde': []},
 'retourn': {'retournant': [],
             'retourne': ['retourner',
                          'retourned',
                          'retournes',
                          'retournent',
                          'retournement',
                          'retournements'],
             'retourning': [],
             'retourns': []},
 'retournai': {'retournaient': [], 'retournais': []},
 'retournam': {'retournames': []},
 'retournass': {'retournassent': []},
 'retourne': {'retournee': ['retournees']},
 'retournedd': {'retournedde': []},
 'retournee': ['retournees'],
 'retournem': {'retournemer': []},
 'retourner': {'retournerent': []},
 'retournera': {'retourneras': []},
 'retournerai': {'retourneraient': []},
 'retourneron': {'retournerons': []},
 'retourning': {'retourninge': []},
 'retournion': {'retournions': []},
 'retournoi': {'retournoient': []},
 'retournon': {'retournons': []},
 'retovski': {'retovsky': []},
 'retpect': {'retpecting': [], 'retpective': ['retpectively'], 'retpects': []},
 'retpective': ['retpectively'],
 'retpiir': {'retpiired': []},
 'retpons': {'retponse': []},
 'retr': {'retre': ['retres', 'retreative']},
 'retra': {'retrae': [], 'retras': []},
 'retrac': {'retracant': [],
            'retrace': ['retracer',
                        'retraced',
                        'retraces',
                        'retracent',
                        'retracement',
                        'retraceable',
                        'retracements',
                        'retraceability'],
            'retracing': ['retracings']},
 'retraccioun': {'retracciouns': []},
 'retrace': {'retracee': []},
 'retracing': ['retracings'],
 'retrack': {'retracked': [], 'retracking': [], 'retracks': []},
 'retract': {'retractability': [],
             'retractable': ['retractables'],
             'retractably': [],
             'retractant': [],
             'retractate': [],
             'retractation': ['retractations'],
             'retracte': ['retracted', 'retracter', 'retractes'],
             'retractibility': [],
             'retractible': [],
             'retracting': [],
             'retraction': [],
             'retractive': ['retractives', 'retractively'],
             'retracts': []},
 'retractable': ['retractables'],
 'retractair': {'retractaires': []},
 'retractal': {'retractall': []},
 'retractan': {'retractans': []},
 'retractant': {'retractante': []},
 'retractar': {'retractare': ['retractarent']},
 'retractare': ['retractarent'],
 'retractation': {'retractatione': ['retractationes']},
 'retractatione': ['retractationes'],
 'retractationi': {'retractationis': []},
 'retractatu': {'retractatus': []},
 'retracte': {'retractee': []},
 'retractemu': {'retractemus': []},
 'retracti': {'retractis': []},
 'retractil': {'retractile': ['retractiles'], 'retractility': []},
 'retractile': ['retractiles'],
 'retractili': {'retractilis': []},
 'retraction': {'retractione': ['retractiones']},
 'retractione': ['retractiones'],
 'retractive': ['retractives', 'retractively'],
 'retractor': ['retractores'],
 'retractori': {'retractory': []},
 'retractoriu': {'retractorius': []},
 'retractu': {'retractus': []},
 'retrad': {'retradation': [], 'retrade': ['retraded'], 'retrading': []},
 'retrade': ['retraded'],
 'retradition': {'retraditionalization': [],
                 'retraditionalize': ['retraditionalized'],
                 'retraditionalizing': []},
 'retraditionalis': {'retraditionalisation': []},
 'retraditionalize': ['retraditionalized'],
 'retraduct': {'retraduction': []},
 'retraduir': {'retraduire': []},
 'retraet': {'retraeted': []},
 'retraffick': {'retrafficked': []},
 'retragrad': {'retragrade': []},
 'retrah': {'retrahant': [], 'retrahent': []},
 'retrahen': {'retrahens': []},
 'retrahent': {'retrahentes': []},
 'retraher': {'retrahere': []},
 'retrahuntqu': {'retrahuntque': []},
 'retrai': {'retrais': []},
 'retraict': {'retraicte': [], 'retraicts': []},
 'retraido': {'retraidos': []},
 'retrain': {'retrainability': [],
             'retrainable': [],
             'retrained': [],
             'retrainer': ['retrainers'],
             'retraining': [],
             'retrains': []},
 'retraine': {'retrainee': ['retrainees']},
 'retrainee': ['retrainees'],
 'retrainer': ['retrainers'],
 'retraint': {'retraints': []},
 'retrair': {'retraire': []},
 'retrait': {'retraitant': ['retraitants'],
             'retraite': ['retraites', 'retraiter', 'retraitement'],
             'retraiting': [],
             'retraits': []},
 'retraitant': ['retraitants'],
 'retraite': ['retraites', 'retraiter', 'retraitement'],
 'retraitt': {'retraitte': []},
 'retrakt': {'retraktion': []},
 'retral': {'retrally': []},
 'retram': {'retramed': [], 'retraming': []},
 'retran': {'retrans': []},
 'retranch': {'retranchant': [],
              'retranche': ['retrancher',
                            'retranches',
                            'retranchent',
                            'retranchement',
                            'retranchements']},
 'retranche': {'retranchee': ['retranchees']},
 'retranchee': ['retranchees'],
 'retranchemen': {'retranchemens': []},
 'retranscrib': {'retranscribe': ['retranscribes', 'retranscribed'],
                 'retranscribing': []},
 'retranscribe': ['retranscribes', 'retranscribed'],
 'retranscript': {'retranscription': ['retranscriptions']},
 'retranscription': ['retranscriptions'],
 'retranscrir': {'retranscrire': []},
 'retransect': {'retransection': []},
 'retransf': {'retransfer': ['retransfers',
                             'retransfered',
                             'retransferred',
                             'retransferring']},
 'retransfect': {'retransfected': []},
 'retransfer': {'retransference': []},
 'retransform': {'retransformable': [],
                 'retransformation': ['retransformations'],
                 'retransformed': [],
                 'retransforming': [],
                 'retransforms': []},
 'retransformation': ['retransformations'],
 'retransfus': {'retransfuse': ['retransfused'], 'retransfusion': []},
 'retransfuse': ['retransfused'],
 'retransit': {'retransition': ['retransitions', 'retransitional']},
 'retransition': ['retransitions', 'retransitional'],
 'retransl': {'retranslate': ['retranslated', 'retranslates'],
              'retranslating': [],
              'retranslation': ['retranslations'],
              'retranslator': ['retranslators']},
 'retranslat': {'retranslatable': []},
 'retranslate': ['retranslated', 'retranslates'],
 'retranslation': ['retranslations'],
 'retranslator': ['retranslators'],
 'retransliter': {'retransliteration': []},
 'retransloc': {'retranslocate': ['retranslocated'], 'retranslocation': []},
 'retranslocate': ['retranslocated'],
 'retransmettr': {'retransmettre': []},
 'retransmi': {'retransmis': []},
 'retransmiss': {'retransmission': ['retransmissions']},
 'retransmission': ['retransmissions'],
 'retransmit': {'retransmits': [], 'retransmitted': [], 'retransmitting': []},
 'retransmitt': {'retransmittal': [], 'retransmitter': ['retransmitters']},
 'retransmitter': ['retransmitters'],
 'retransmut': {'retransmuted': []},
 'retranspl': {'retransplant': ['retransplants',
                                'retransplanted',
                                'retransplanting']},
 'retransplant': {'retransplantable': [],
                  'retransplantation': ['retransplantations']},
 'retransplantation': ['retransplantations'],
 'retransport': {'retransportation': [],
                 'retransported': [],
                 'retransporting': []},
 'retranspos': {'retranspose': ['retransposed']},
 'retranspose': ['retransposed'],
 'retransposit': {'retransposition': []},
 'retraot': {'retraoted': []},
 'retrap': {'retrapped': [], 'retrapping': [], 'retraps': []},
 'retrasado': {'retrasados': []},
 'retraso': {'retrasos': []},
 'retrat': {'retrate': ['retrated'],
            'retrating': [],
            'retration': [],
            'retrats': []},
 'retratada': {'retratadas': []},
 'retratado': {'retratados': []},
 'retratars': {'retratarse': []},
 'retrate': ['retrated'],
 'retratista': {'retratistas': []},
 'retrato': {'retratos': []},
 'retraumat': {'retraumatization': [],
               'retraumatize': ['retraumatizes', 'retraumatized'],
               'retraumatizing': []},
 'retraumatis': {'retraumatisation': [],
                 'retraumatise': ['retraumatised'],
                 'retraumatising': []},
 'retraumatise': ['retraumatised'],
 'retraumatize': ['retraumatizes', 'retraumatized'],
 'retravail': {'retravaille': ['retravailler']},
 'retravaille': ['retravailler'],
 'retravel': {'retraveled': [],
              'retraveling': [],
              'retravelled': [],
              'retravels': []},
 'retravers': {'retraversal': [],
               'retraverse': ['retraversed', 'retraverses'],
               'retraversing': []},
 'retraverse': ['retraversed', 'retraverses'],
 'retravirus': {'retraviruses': []},
 'retray': {'retrayed': []},
 'retrayt': {'retrayte': []},
 'retrazion': {'retrazione': []},
 'retre': {'retree': []},
 'retread': ['retreader',
             'retreaded',
             'retreading',
             'retreaders',
             'retreadable',
             'retreadability'],
 'retrear': {'retreared': []},
 'retreat': ['retreate',
             'retreated',
             'retreater',
             'retreates',
             'retreatal',
             'retreatant',
             'retreating',
             'retreaters',
             'retreatism',
             'retreatable',
             'retreatings',
             'retreatment',
             'retreatments'],
 'retreatingli': {'retreatingly': []},
 'retreatist': {'retreatists': []},
 'retreatlik': {'retreatlike': []},
 'retreatmast': {'retreatmaster': []},
 'retreav': {'retreaved': []},
 'retrech': {'retrechment': []},
 'retreci': {'retrecie': ['retrecies'], 'retrecis': []},
 'retrecie': ['retrecies'],
 'retreciss': {'retrecissant': [],
               'retrecissement': ['retrecissements'],
               'retrecissent': []},
 'retrecissement': ['retrecissements'],
 'retreir': {'retreire': []},
 'retreit': {'retreite': []},
 'retreiv': {'retreivable': [],
             'retreival': [],
             'retreive': ['retreiver', 'retreives', 'retreived'],
             'retreiving': []},
 'retreive': ['retreiver', 'retreives', 'retreived'],
 'retremp': {'retrempe': ['retremper']},
 'retrempe': ['retremper'],
 'retrench': {'retrenched': [],
              'retrenchement': ['retrenchements'],
              'retrencher': ['retrenchers'],
              'retrenches': [],
              'retrenching': [],
              'retrenchment': []},
 'retrenche': {'retrenchee': ['retrenchees']},
 'retrenchee': ['retrenchees'],
 'retrenchement': ['retrenchements'],
 'retrencher': ['retrenchers'],
 'retret': {'retrete': ['retretes', 'retreted']},
 'retreta': {'retretas': []},
 'retrete': ['retretes', 'retreted'],
 'retrev': {'retreval': []},
 'retrevi': {'retrevial': []},
 'retri': {'retrie': ['retried', 'retries'], 'retry': ['retrys', 'retrying']},
 'retriabl': {'retriable': []},
 'retriag': {'retriaged': []},
 'retrial': {'retrial': []},
 'retriangul': {'retriangulate': ['retriangulated'],
                'retriangulating': [],
                'retriangulation': []},
 'retriangulate': ['retriangulated'],
 'retrib': {'retribalization': [],
            'retribalize': ['retribalized', 'retribalizes'],
            'retribalizing': []},
 'retribalis': {'retribalisation': [],
                'retribalise': ['retribalised'],
                'retribalising': []},
 'retribalise': ['retribalised'],
 'retribalize': ['retribalized', 'retribalizes'],
 'retribnt': {'retribntion': []},
 'retribu': {'retribue': ['retribuer', 'retribues']},
 'retribua': {'retribuas': []},
 'retribuamu': {'retribuamus': []},
 'retribubut': {'retribubution': []},
 'retribucion': {'retribuciones': []},
 'retribue': {'retribuees': []},
 'retribuer': {'retribuere': []},
 'retribut': {'retributative': [],
              'retribute': ['retributed', 'retributes'],
              'retributing': [],
              'retribution': ['retributional'],
              'retributive': ['retributively', 'retributiveness']},
 'retributari': {'retributary': []},
 'retribute': ['retributed', 'retributes'],
 'retribution': {'retributione': ['retributiones'], 'retributionism': []},
 'retributionari': {'retributionary': []},
 'retributione': ['retributiones'],
 'retributioni': {'retributionis': []},
 'retributionist': {'retributionists': []},
 'retributiv': {'retributivism': []},
 'retributive': ['retributively', 'retributiveness'],
 'retributivejustic': {'retributivejustice': []},
 'retributivist': {'retributivistic': [], 'retributivists': []},
 'retributor': {'retributors': []},
 'retributori': {'retributory': []},
 'retribuzion': {'retribuzione': []},
 'retric': {'retrices': []},
 'retrick': {'retricked': []},
 'retrict': {'retricted': [],
             'retricting': [],
             'retriction': ['retrictions'],
             'retrictive': [],
             'retricts': []},
 'retriction': ['retrictions'],
 'retricv': {'retricval': []},
 'retrie': ['retried', 'retries'],
 'retrieu': {'retrieue': []},
 'retriev': {'retrievability': [],
             'retrievable': [],
             'retrievably': [],
             'retrieval': [],
             'retrieve': ['retriever',
                          'retrieved',
                          'retrieves',
                          'retrieveable',
                          'retrievement',
                          'retrievements'],
             'retrieving': []},
 'retrievalist': {'retrievalists': []},
 'retrievalwar': {'retrievalware': []},
 'retrieve': ['retriever',
              'retrieved',
              'retrieves',
              'retrieveable',
              'retrievement',
              'retrievements'],
 'retrievedjuli': {'retrievedjuly': []},
 'retrievedjun': {'retrievedjune': []},
 'retrievednovemb': {'retrievednovember': []},
 'retrievi': {'retrievial': []},
 'retriey': {'retrieyal': []},
 'retriger': {'retrigerator': []},
 'retrigg': {'retrigger': ['retriggers', 'retriggered', 'retriggering']},
 'retrigger': {'retriggerable': []},
 'retrihut': {'retrihution': [], 'retrihutive': []},
 'retrim': {'retrimmed': [], 'retrimming': []},
 'retriu': {'retriue': []},
 'retriv': {'retrival': [],
            'retrive': ['retrives', 'retrived', 'retriveal'],
            'retriving': []},
 'retrive': ['retrives', 'retrived', 'retriveal'],
 'retrlev': {'retrleval': []},
 'retro': {'retro': []},
 'retroact': {'retroacted': [],
              'retroacting': [],
              'retroaction': ['retroactions'],
              'retroactive': ['retroactives',
                              'retroactively',
                              'retroactiveness'],
              'retroactivity': [],
              'retroacts': []},
 'retroacti': {'retroactis': []},
 'retroaction': ['retroactions'],
 'retroactiv': {'retroactivation': [], 'retroactivement': []},
 'retroactive': ['retroactives', 'retroactively', 'retroactiveness'],
 'retroactivit': {'retroactivite': []},
 'retroafr': {'retroafric': []},
 'retroaldol': {'retroaldolization': []},
 'retroambiguali': {'retroambigualis': []},
 'retroambiguu': {'retroambiguus': []},
 'retroan': {'retroanal': []},
 'retroanastomot': {'retroanastomotic': []},
 'retroantr': {'retroantral': []},
 'retroaort': {'retroaortic': []},
 'retroarticulari': {'retroarticularis': []},
 'retroaur': {'retroaural': []},
 'retroauricularli': {'retroauricularly': []},
 'retrobronchi': {'retrobronchial': []},
 'retrobulbair': {'retrobulbaire': []},
 'retrobulbari': {'retrobulbaris': []},
 'retrobulbarli': {'retrobulbarly': []},
 'retroc': {'retroces': []},
 'retrocaec': {'retrocaecal': ['retrocaecally']},
 'retrocaecal': ['retrocaecally'],
 'retrocalcan': {'retrocalcaneal': []},
 'retrocalcarin': {'retrocalcarine': []},
 'retrocallos': {'retrocallosal': []},
 'retrocardi': {'retrocardial': []},
 'retrocaus': {'retrocausal': ['retrocausality'], 'retrocausation': []},
 'retrocausal': ['retrocausality'],
 'retrocav': {'retrocaval': []},
 'retrocec': {'retrocecal': ['retrocecally']},
 'retrocecal': ['retrocecally'],
 'retroced': {'retrocede': ['retrocedes',
                            'retroceded',
                            'retroceder',
                            'retrocedent',
                            'retrocedence'],
              'retroceding': []},
 'retrocede': ['retrocedes',
               'retroceded',
               'retroceder',
               'retrocedent',
               'retrocedence'],
 'retroceden': {'retrocedens': []},
 'retroceder': {'retrocedere': []},
 'retrocel': {'retrocele': []},
 'retrocentr': {'retrocentral': []},
 'retrocerebr': {'retrocerebral': []},
 'retrocerebral': {'retrocerebrales': []},
 'retrocerv': {'retrocervical': []},
 'retroceso': {'retrocesos': []},
 'retrocess': {'retrocessed': [],
               'retrocession': ['retrocessions'],
               'retrocessive': []},
 'retrocession': {'retrocessional': [], 'retrocessione': []},
 'retrocessionair': {'retrocessionaire': ['retrocessionaires']},
 'retrocessionaire': ['retrocessionaires'],
 'retroch': {'retrochic': []},
 'retrocharriag': {'retrocharriage': []},
 'retrochiasm': {'retrochiasmal': []},
 'retrochiasmat': {'retrochiasmatic': []},
 'retrochoir': {'retrochoirs': []},
 'retrochorion': {'retrochorionic': []},
 'retrociliari': {'retrociliary': []},
 'retrocleavag': {'retrocleavage': []},
 'retroclin': {'retroclination': [],
               'retrocline': ['retroclined'],
               'retroclining': []},
 'retrocline': ['retroclined'],
 'retrocliv': {'retroclival': []},
 'retroclus': {'retroclusion': []},
 'retrocognit': {'retrocognition': ['retrocognitions'], 'retrocognitive': []},
 'retrocognition': ['retrocognitions'],
 'retrocol': {'retrocolic': ['retrocolically'], 'retrocollic': []},
 'retrocolic': ['retrocolically'],
 'retrocolli': {'retrocollis': []},
 'retrocommissur': {'retrocommissural': []},
 'retroconvers': {'retroconversion': []},
 'retroconvert': {'retroconverted': []},
 'retrocopul': {'retrocopulation': []},
 'retrocorn': {'retrocorneal': []},
 'retrocoron': {'retrocoronal': []},
 'retrocrur': {'retrocrural': []},
 'retrocurv': {'retrocurved': []},
 'retrodeform': {'retrodeformable': [], 'retrodeformation': []},
 'retrodent': {'retrodental': []},
 'retrodevi': {'retrodeviation': ['retrodeviations']},
 'retrodeviation': ['retrodeviations'],
 'retrodialysi': {'retrodialysis': []},
 'retrodiaphragmat': {'retrodiaphragmatic': []},
 'retrodict': {'retrodictability': [],
               'retrodictable': [],
               'retrodicted': [],
               'retrodicting': [],
               'retrodiction': ['retrodictions'],
               'retrodictive': ['retrodictively'],
               'retrodicts': []},
 'retrodiction': ['retrodictions'],
 'retrodictive': ['retrodictively'],
 'retrodiel': {'retrodiels': []},
 'retrodifferenti': {'retrodifferentiation': []},
 'retrodiffus': {'retrodiffused': [], 'retrodiffusion': []},
 'retrodirect': {'retrodirective': [], 'retrodirectivity': []},
 'retrodisc': {'retrodiscal': [], 'retrodiscitis': []},
 'retrodisk': {'retrodiskal': []},
 'retrodisplac': {'retrodisplace': ['retrodisplaced',
                                    'retrodisplacement',
                                    'retrodisplacements']},
 'retrodisplace': ['retrodisplaced', 'retrodisplacement', 'retrodisplacements'],
 'retrodors': {'retrodorsal': []},
 'retrodorsolater': {'retrodorsolateral': []},
 'retroduc': {'retroduce': ['retroduced']},
 'retroduce': ['retroduced'],
 'retroduct': {'retroduction': ['retroductions'],
               'retroductive': ['retroductively']},
 'retroduction': ['retroductions'],
 'retroductive': ['retroductively'],
 'retroduoden': {'retroduodenal': []},
 'retroel': {'retroelement': ['retroelements']},
 'retroelement': ['retroelements'],
 'retroendocytosi': {'retroendocytosis': []},
 'retroequatori': {'retroequatorial': []},
 'retroesophag': {'retroesophageal': []},
 'retrofaci': {'retrofacial': []},
 'retrofaciali': {'retrofacialis': []},
 'retrofasci': {'retrofascial': []},
 'retrofect': {'retrofection': []},
 'retrofemor': {'retrofemoral': []},
 'retrofenestr': {'retrofenestral': []},
 'retrofil': {'retrofile': [], 'retrofill': ['retrofilled', 'retrofilling']},
 'retrofill': ['retrofilled', 'retrofilling'],
 'retrofir': {'retrofire': ['retrofired'], 'retrofiring': []},
 'retrofire': ['retrofired'],
 'retrofit': ['retrofited',
              'retrofiting',
              'retrofitted',
              'retrofitable',
              'retrofitting',
              'retrofittings'],
 'retrofitt': {'retrofittable': [], 'retrofitter': ['retrofitters']},
 'retrofitter': ['retrofitters'],
 'retroflect': {'retroflected': [],
                'retroflecting': [],
                'retroflection': [],
                'retroflective': [],
                'retroflects': []},
 'retroflector': {'retroflectors': []},
 'retrofleet': {'retrofleeted': []},
 'retrofocu': {'retrofocus': []},
 'retrofpect': {'retrofpective': []},
 'retrofractu': {'retrofractus': []},
 'retrofront': {'retrofrontal': []},
 'retrofutur': {'retrofuture': []},
 'retrofuturist': {'retrofuturistic': []},
 'retrog': {'retrogate': [], 'retrogation': [], 'retrogative': []},
 'retrogad': {'retrogadation': [],
              'retrogade': ['retrogades', 'retrogaded'],
              'retrogading': []},
 'retrogade': ['retrogades', 'retrogaded'],
 'retrogard': {'retrogarde': []},
 'retrogastr': {'retrogastric': []},
 'retrogen': {'retrogene': ['retrogenes'], 'retrogenic': []},
 'retrogene': ['retrogenes'],
 'retrogenesi': {'retrogenesis': []},
 'retrogenet': {'retrogenetic': []},
 'retrogenicul': {'retrogeniculate': []},
 'retrogess': {'retrogession': [], 'retrogessive': []},
 'retrogloss': {'retroglossal': []},
 'retrognath': {'retrognathic': [], 'retrognathism': []},
 'retrogr': {'retrograte': [], 'retrogration': [], 'retrogres': []},
 'retrograd': {'retrogradable': [],
               'retrogradant': [],
               'retrogradation': ['retrogradations', 'retrogradational'],
               'retrograde': ['retrograded',
                              'retrogrades',
                              'retrograder',
                              'retrogradely'],
               'retrograding': [],
               'retrogradism': []},
 'retrograda': {'retrogradas': []},
 'retrogradation': ['retrogradations', 'retrogradational'],
 'retrograde': ['retrograded', 'retrogrades', 'retrograder', 'retrogradely'],
 'retrogradeinvers': {'retrogradeinversion': []},
 'retrogradist': {'retrogradists': []},
 'retrogrado': {'retrogrados': []},
 'retrogradu': {'retrogradus': []},
 'retrogress': {'retrogressed': [],
                'retrogresses': [],
                'retrogressing': [],
                'retrogression': [],
                'retrogressive': ['retrogressives',
                                  'retrogressively',
                                  'retrogressiveness']},
 'retrogression': {'retrogressional': []},
 'retrogressionist': {'retrogressionists': []},
 'retrogressive': ['retrogressives', 'retrogressively', 'retrogressiveness'],
 'retrogressor': {'retrogressors': []},
 'retrogressu': {'retrogressus': []},
 'retrohepat': {'retrohepatic': []},
 'retrohippocamp': {'retrohippocampal': []},
 'retrohom': {'retrohoming': []},
 'retroil': {'retroileal': []},
 'retroillumin': {'retroilluminated': [], 'retroillumination': []},
 'retroinclin': {'retroinclination': []},
 'retroinfect': {'retroinfection': []},
 'retroinfus': {'retroinfusion': []},
 'retroinhibit': {'retroinhibition': []},
 'retroirid': {'retroiridal': []},
 'retroisthm': {'retroisthmic': []},
 'retroject': {'retrojected': [],
               'retrojecting': [],
               'retrojection': ['retrojections'],
               'retrojective': [],
               'retrojects': []},
 'retrojection': ['retrojections'],
 'retrojet': {'retrojets': []},
 'retrolabyrinthin': {'retrolabyrinthine': []},
 'retrolaryng': {'retrolaryngeal': []},
 'retrolater': {'retrolateral': []},
 'retrolect': {'retrolective': []},
 'retrolent': {'retrolental': []},
 'retrolingu': {'retrolingual': []},
 'retrolisthesi': {'retrolisthesis': []},
 'retromamillari': {'retromamillary': []},
 'retromammari': {'retromammary': []},
 'retromammillari': {'retromammillary': []},
 'retromandibulari': {'retromandibularis': []},
 'retromaneuv': {'retromaneuver': []},
 'retromanubri': {'retromanubrial': []},
 'retromargin': {'retromarginal': []},
 'retromediastin': {'retromediastinal': []},
 'retromedullari': {'retromedullary': []},
 'retromembran': {'retromembranous': []},
 'retromesenter': {'retromesenteric': []},
 'retrometamorph': {'retrometamorphic': [], 'retrometamorphism': []},
 'retroming': {'retromingent': []},
 'retromolar': {'retromolare': []},
 'retromorph': {'retromorphic': [], 'retromorphism': []},
 'retromorphos': {'retromorphosed': []},
 'retromorphosi': {'retromorphosis': []},
 'retron': {'retrone': [], 'retrons': []},
 'retronas': {'retronasal': ['retronasally']},
 'retronasal': ['retronasally'],
 'retronecin': {'retronecine': []},
 'retronectida': {'retronectidae': []},
 'retronym': {'retronym': []},
 'retrooesophag': {'retrooesophageal': []},
 'retroolivari': {'retroolivary': []},
 'retroorbit': {'retroorbital': ['retroorbitally']},
 'retroorbital': ['retroorbitally'],
 'retrop': {'retroped': [], 'retroper': [], 'retroping': []},
 'retropackag': {'retropackage': []},
 'retropalat': {'retropalatal': []},
 'retropancreat': {'retropancreatic': []},
 'retropcriton': {'retropcritoneal': []},
 'retropect': {'retropective': []},
 'retropector': {'retropectoral': []},
 'retropel': {'retropelled': []},
 'retropelv': {'retropelvic': []},
 'retropenton': {'retropentoneal': []},
 'retroperfus': {'retroperfusion': []},
 'retroperin': {'retroperineal': []},
 'retroperistalsi': {'retroperistalsis': []},
 'retroperistalt': {'retroperistaltic': []},
 'retroperition': {'retroperitioneal': []},
 'retroperiton': {'retroperitonal': [],
                  'retroperitoneal': ['retroperitoneally',
                                      'retroperitonealized',
                                      'retroperitonealization'],
                  'retroperitonitis': []},
 'retroperitonc': {'retroperitoncal': []},
 'retroperitoneal': {'retroperitoneale': ['retroperitoneales']},
 'retroperitoneale': ['retroperitoneales'],
 'retroperitoneoscop': {'retroperitoneoscopic': []},
 'retroperitoneoscopi': {'retroperitoneoscopy': []},
 'retropharvng': {'retropharvngeal': []},
 'retropharyng': {'retropharyngeal': []},
 'retropinni': {'retropinnis': []},
 'retropinnid': {'retropinnids': []},
 'retropinnida': {'retropinnidae': []},
 'retroplac': {'retroplaced': [], 'retroplacement': []},
 'retroplacent': {'retroplacental': ['retroplacentally']},
 'retroplacental': ['retroplacentally'],
 'retropleur': {'retropleural': ['retropleurally']},
 'retropleural': ['retropleurally'],
 'retroplumida': {'retroplumidae': []},
 'retropol': {'retropolation': []},
 'retroport': {'retroportal': []},
 'retropos': {'retropose': ['retroposed']},
 'retropose': ['retroposed'],
 'retroposit': {'retroposition': ['retropositions',
                                  'retropositioned',
                                  'retropositional',
                                  'retropositioning']},
 'retroposition': ['retropositions',
                   'retropositioned',
                   'retropositional',
                   'retropositioning'],
 'retroposon': {'retroposons': []},
 'retroposterolater': {'retroposterolateral': []},
 'retroprepar': {'retropreparation': []},
 'retroprogesteron': {'retroprogesterone': []},
 'retroproject': {'retroprojected': [], 'retroprojection': []},
 'retropropuls': {'retropropulsion': []},
 'retroprospect': {'retroprospective': []},
 'retroprostat': {'retroprostatic': []},
 'retroprosthet': {'retroprosthetic': []},
 'retropsect': {'retropsective': []},
 'retropseudogen': {'retropseudogene': ['retropseudogenes']},
 'retropseudogene': ['retropseudogenes'],
 'retropso': {'retropsoal': []},
 'retropsoa': {'retropsoas': []},
 'retropub': {'retropubic': ['retropubically']},
 'retropubic': ['retropubically'],
 'retropubl': {'retropublic': []},
 'retropuls': {'retropulse': ['retropulsed'],
               'retropulsing': [],
               'retropulsion': ['retropulsions'],
               'retropulsive': []},
 'retropulse': ['retropulsed'],
 'retropulsion': ['retropulsions'],
 'retropupillari': {'retropupillary': []},
 'retropylor': {'retropyloric': []},
 'retroqu': {'retroque': []},
 'retroquir': {'retroquire': []},
 'retrorbit': {'retrorbital': []},
 'retrorect': {'retrorectal': []},
 'retroreflect': {'retroreflected': [],
                  'retroreflecting': [],
                  'retroreflection': ['retroreflections'],
                  'retroreflective': [],
                  'retroreflectivity': []},
 'retroreflection': ['retroreflections'],
 'retroreflector': {'retroreflectors': []},
 'retroregul': {'retroregulation': []},
 'retroren': {'retrorenal': []},
 'retroretin': {'retroretinal': []},
 'retrorocket': {'retrorocket': []},
 'retroroland': {'retrorolandic': []},
 'retrorolandiqu': {'retrorolandiques': []},
 'retrors': {'retrorse': ['retrorsely']},
 'retrorse': ['retrorsely'],
 'retrorsin': {'retrorsine': []},
 'retrorsu': {'retrorsus': []},
 'retrorubr': {'retrorubral': []},
 'retros': {'retrose': []},
 'retrosacr': {'retrosacral': []},
 'retroscap': {'retroscapes': []},
 'retroscop': {'retroscope': [], 'retroscopic': []},
 'retrosept': {'retroseptal': []},
 'retrosequ': {'retrosequence': ['retrosequences']},
 'retrosequence': ['retrosequences'],
 'retrosiphon': {'retrosiphonate': []},
 'retrosomat': {'retrosomatic': []},
 'retrospac': {'retrospace': []},
 'retrospec': {'retrospecive': []},
 'retrospecitv': {'retrospecitve': []},
 'retrospect': ['retrospected',
                'retrospecting',
                'retrospective',
                'retrospection',
                'retrospectant',
                'retrospectivity',
                'retrospectively',
                'retrospectiveness'],
 'retrospectif': {'retrospectifs': []},
 'retrospectiv': {'retrospectivement': [], 'retrospectivism': []},
 'retrospectiva': {'retrospectivas': []},
 'retrospectivament': {'retrospectivamente': []},
 'retrospectiveprospect': {'retrospectiveprospective': []},
 'retrospectivo': {'retrospectivos': []},
 'retrospectoscop': {'retrospectoscope': []},
 'retrospectroscop': {'retrospectroscope': []},
 'retrospectu': {'retrospectus': []},
 'retrospeet': {'retrospeetive': []},
 'retrospekt': {'retrospektive': []},
 'retrospektiv': {'retrospektiver': []},
 'retrospeni': {'retrospenial': []},
 'retrospett': {'retrospettive': []},
 'retrospettivament': {'retrospettivamente': []},
 'retrosphincter': {'retrosphincteric': []},
 'retrospin': {'retrospinal': []},
 'retrospirali': {'retrospiralis': []},
 'retrospleni': {'retrosplenial': []},
 'retrospleniali': {'retrosplenialis': []},
 'retrospondylolisthesi': {'retrospondylolisthesis': []},
 'retross': {'retrossal': []},
 'retrostant': {'retrostante': []},
 'retrostasi': {'retrostasis': []},
 'retrostem': {'retrostemal': []},
 'retrostern': {'retrosternal': ['retrosternally']},
 'retrosternal': ['retrosternally'],
 'retrosteroid': {'retrosteroids': []},
 'retrostyl': {'retrostyle': []},
 'retrosynthesi': {'retrosynthesis': []},
 'retrosynthet': {'retrosynthetic': ['retrosynthetically']},
 'retrosynthetic': ['retrosynthetically'],
 'retrotars': {'retrotarsal': []},
 'retrotendin': {'retrotendinous': []},
 'retrothalam': {'retrothalamic': []},
 'retrotors': {'retrotorsion': []},
 'retrotrach': {'retrotracheal': []},
 'retrotrag': {'retrotragal': []},
 'retrotranscrib': {'retrotranscribed': []},
 'retrotranscript': {'retrotranscription': [], 'retrotranscripts': []},
 'retrotransf': {'retrotransfer': []},
 'retrotransl': {'retrotranslation': []},
 'retrotransloc': {'retrotranslocated': [], 'retrotranslocation': []},
 'retrotranspos': {'retrotransposable': [],
                   'retrotransposal': [],
                   'retrotranspose': ['retrotransposed']},
 'retrotranspose': ['retrotransposed'],
 'retrotransposit': {'retrotransposition': ['retrotranspositions']},
 'retrotransposition': ['retrotranspositions'],
 'retrotransposon': {'retrotransposons': []},
 'retrotrigon': {'retrotrigonal': []},
 'retrotympan': {'retrotympanic': []},
 'retrourethr': {'retrourethral': []},
 'retrouse': {'retrousee': []},
 'retrouss': {'retroussant': [], 'retrousse': ['retrousses', 'retrousser']},
 'retroussag': {'retroussage': []},
 'retrousse': {'retroussee': ['retroussees']},
 'retroussee': ['retroussees'],
 'retrouterin': {'retrouterine': []},
 'retrouv': {'retrouvant': [],
             'retrouve': ['retrouver', 'retrouves', 'retrouvent']},
 'retrouvai': {'retrouvaient': [], 'retrouvais': []},
 'retrouvail': {'retrouvaille': ['retrouvailles']},
 'retrouvaille': ['retrouvailles'],
 'retrouvam': {'retrouvames': []},
 'retrouve': {'retrouvee': ['retrouvees']},
 "retrouve'": {"retrouve'e": []},
 'retrouvee': ['retrouvees'],
 'retrouver': {'retrouverent': []},
 'retrouvera': {'retrouveras': []},
 'retrouverai': {'retrouveraient': [], 'retrouverais': []},
 'retrouverion': {'retrouverions': []},
 'retrouveron': {'retrouverons': []},
 'retrouvi': {'retrouvie': []},
 'retrouvion': {'retrouvions': []},
 'retrouvon': {'retrouvons': []},
 'retrov': {'retrover': []},
 'retrovaccin': {'retrovaccination': []},
 'retrovagin': {'retrovaginal': []},
 'retrovalid': {'retrovalidated': []},
 'retrovers': {'retroverse': [], 'retroversion': [], 'retroversive': []},
 'retroversu': {'retroversus': []},
 'retrovert': {'retroverted': [], 'retroverting': [], 'retroverts': []},
 'retrovertebr': {'retrovertebral': []},
 'retroves': {'retrovesical': []},
 'retrovim': {'retrovims': []},
 'retrovir': {'retroviral': ['retrovirals', 'retrovirally']},
 'retroviral': ['retrovirals', 'retrovirally'],
 'retroviralmedi': {'retroviralmediated': []},
 'retrovirida': {'retroviridae': []},
 'retrovirolog': {'retrovirology': []},
 'retrovirologist': {'retrovirologists': []},
 'retroviru': {'retrovirus': []},
 'retrovirus': {'retrovirus': []},
 'retrovirusinduc': {'retrovirusinduced': []},
 'retrovirusinfect': {'retrovirusinfected': []},
 'retroviruslik': {'retroviruslike': []},
 'retrovirusmedi': {'retrovirusmediated': []},
 'retrovirustransduc': {'retrovirustransduced': []},
 'retrovis': {'retrovision': []},
 'retroviscer': {'retrovisceral': []},
 'retrovitr': {'retrovitreal': []},
 'retrozygomat': {'retrozygomatic': []},
 'retrtev': {'retrteval': []},
 'retru': {'retrue': ['retrued']},
 'retructur': {'retructuring': []},
 'retrud': {'retrude': ['retrudes', 'retruded'], 'retruding': []},
 'retrude': ['retrudes', 'retruded'],
 'retrudemu': {'retrudemus': []},
 'retrue': ['retrued'],
 'retrun': {'retruned': [], 'retruning': [], 'retruns': []},
 'retrus': {'retruse': [],
            'retrusion': ['retrusions'],
            'retrusive': ['retrusively']},
 'retrusion': ['retrusions'],
 'retrusive': ['retrusively'],
 'retruss': {'retrussed': []},
 'retry': ['retrys', 'retrying'],
 'retryabl': {'retryable': []},
 'rets': {'retse': []},
 'retsa': {'retsas': []},
 'retschinski': {'retschinsky': []},
 'retschitzegg': {'retschitzegger': []},
 'retselisitso': {'retselisitsoe': []},
 'retshistori': {'retshistorie': []},
 'retsi': {'retsy': []},
 'retsin': {'retsined': []},
 'retsina': {'retsina': []},
 'retsiu': {'retsius': []},
 'retski': {'retsky': []},
 'retskrivn': {'retskrivning': []},
 'retspl': {'retspls': []},
 'retstidend': {'retstidende': []},
 'rett': {'rette': ['rettes'], 'retts': []},
 'rettag': {'rettage': []},
 'rettal': {'rettale': []},
 'rettament': {'rettamente': []},
 'rettangolar': {'rettangolare': []},
 'rettatu': {'rettatus': []},
 'rette': ['rettes'],
 'retted': {'rettedal': []},
 'rettel': {'rettele': []},
 'rettels': {'rettelser': []},
 'retten': {'rettens': []},
 'rettenbach': {'rettenbacher': []},
 'rettenberg': {'rettenberger': []},
 'rettend': {'rettende': ['rettendes', 'rettender']},
 'rettende': ['rettendes', 'rettender'],
 'rettenmai': {'rettenmaier': []},
 'rettenmay': {'rettenmayer': []},
 'rettenmei': {'rettenmeier': []},
 'rettenmey': {'rettenmeyer': []},
 'rettenmi': {'rettenmier': []},
 'retter': {'rettere': ['retterer'], 'retters': []},
 'retterbuch': {'retterbuches': []},
 'rettere': ['retterer'],
 'retteri': {'retteries': [], 'rettery': []},
 'rettet': {'rettete': []},
 'rettger': {'rettgers': []},
 'retti': {'rettie': [], 'rettis': [], 'retty': []},
 'rettibut': {'rettibution': []},
 'rettiev': {'rettieval': [], 'rettieve': ['rettieved']},
 'rettieve': ['rettieved'],
 'rettificar': {'rettificare': []},
 'rettificazion': {'rettificazione': []},
 'rettifich': {'rettifiche': []},
 'rettig': {'rettigs': []},
 'rettighed': {'rettigheder': []},
 'rettighet': {'rettigheter': []},
 'rettil': {'rettile': []},
 'rettiline': {'rettilinee': []},
 'retting': {'rettinger': []},
 'rettinghau': {'rettinghaus': []},
 'rettirn': {'rettirned': [], 'rettirning': []},
 'rettitudin': {'rettitudine': []},
 'rettk': {'rettke': []},
 'rettl': {'rettle': ['rettled']},
 'rettle': ['rettled'],
 'rettledn': {'rettledning': []},
 'rettling': {'rettlinger': []},
 'retton': {'rettons': []},
 'rettor': {'rettore': ['rettored']},
 'rettoral': {'rettorale': []},
 'rettore': ['rettored'],
 'rettr': {'rettres': []},
 'rettrv': {'rettrved': []},
 'rettslig': {'rettslige': []},
 'rettsstil': {'rettsstilling': []},
 'rettstidend': {'rettstidende': []},
 'rettulimu': {'rettulimus': []},
 'rettuliss': {'rettulisse': []},
 'rettun': {'rettuned': []},
 'rettung': {'rettungs': []},
 'rettungsakt': {'rettungsaktion': []},
 'rettungsank': {'rettungsanker': []},
 'rettungshau': {'rettungshaus': []},
 'rettungskomite': {'rettungskomitees': []},
 'rettungslo': {'rettungslos': []},
 'rettungsphantasi': {'rettungsphantasie': []},
 'rettungsversuch': {'rettungsversuche': []},
 'retu': {'retue': [], 'retus': []},
 'retual': {'retuals': []},
 'retub': {'retube': ['retubed'], 'retubing': []},
 'retube': ['retubed'],
 'retubn': {'retubns': []},
 'retubular': {'retubularized': []},
 'retuck': {'retucked': [], 'retucking': [], 'retucks': []},
 'retud': {'retude': []},
 'retuen': {'retuens': []},
 'retuerc': {'retuerce': []},
 'retug': {'retuge': []},
 'retuge': {'retugee': ['retugees']},
 'retugee': ['retugees'],
 'retugi': {'retugies': []},
 'retuin': {'retuined': [], 'retuining': [], 'retuins': []},
 'retuler': {'retulerant': [], 'retulere': []},
 'retuleri': {'retuleris': []},
 'retulimu': {'retulimus': []},
 'retuliss': {'retulisse': ['retulissent']},
 'retulisse': ['retulissent'],
 'retult': {'retults': []},
 'retum': {'retumable': [],
           'retume': ['retumed', 'retumes', 'retumer'],
           'retuming': ['retumings'],
           'retums': []},
 'retumb': {'retumbe': []},
 'retumbant': {'retumbante': []},
 'retume': {'retumee': ['retumees']},
 'retumee': ['retumees'],
 'retuming': ['retumings'],
 'retun': {'retunable': [],
           'retune': ['retuned', 'retunes'],
           'retuning': ['retunings'],
           'retuns': []},
 'retund': {'retunded': []},
 'retunder': {'retundere': []},
 'retune': ['retuned', 'retunes'],
 'retuni': {'retunied': [], 'retuniing': [], 'retunis': []},
 'retuning': ['retunings'],
 'retunr': {'retunred': []},
 'retur': {'reture': ['retures', 'retured'],
           'returing': [],
           'returness': [],
           'returred': [],
           'returs': []},
 'retura': {'returae': ['returaed'], 'returas': []},
 'returae': ['returaed'],
 'reture': ['retures', 'retured'],
 'returen': {'returened': []},
 'returf': {'returfed': [], 'returfing': []},
 'returh': {'returhed': []},
 'returm': {'returmed': []},
 'return': ['returne',
            'returnes',
            'returned',
            'returnal',
            'returner',
            'returners',
            'returning',
            'returneing',
            'returnning',
            'returnable',
            'returnings',
            'returnables',
            'returnability'],
 'returncod': {'returncode': []},
 'returncurr': {'returncurrent': []},
 'returnd': {'returndate': []},
 'returne': {'returnee': ['returnees']},
 'returnedgood': {'returnedgoods': []},
 'returnedtoth': {'returnedtothe': []},
 'returnee': ['returnees'],
 'returnflu': {'returnflue': []},
 'returngener': {'returngenerating': []},
 'returnhom': {'returnhome': []},
 'returni': {'returnis': []},
 'returnin': {'returnins': []},
 'returning': {'returninge': []},
 'returninghom': {'returninghome': []},
 'returningoffic': {'returningofficer': ['returningofficers']},
 'returningofficer': ['returningofficers'],
 'returningth': {'returningthe': []},
 'returningti': {'returningties': []},
 'returnlin': {'returnline': []},
 'returnmessag': {'returnmessage': []},
 'returnmigr': {'returnmigrants': [], 'returnmigration': []},
 'returnpip': {'returnpipe': []},
 'returnsrecord': {'returnsrecords': []},
 'returnsth': {'returnsthe': []},
 'returnstr': {'returnstring': []},
 'returnstrok': {'returnstroke': []},
 'returnth': {'returnthe': []},
 'returnticket': {'returntickets': []},
 'returntoth': {'returntothe': []},
 'returntyp': {'returntype': []},
 'returnv': {'returnval': []},
 'returnvalu': {'returnvalue': []},
 'returnvoyag': {'returnvoyage': []},
 'returnyng': {'returnynge': []},
 'returo': {'returoed': [], 'returos': []},
 'returp': {'returped': []},
 'returr': {'returrs': []},
 'returrect': {'returrection': []},
 'returri': {'returried': []},
 'returu': {'returue': ['returued'], 'returuing': [], 'returus': []},
 'returue': ['returued'],
 'retus': {'retusal': [], 'retuse': ['retuses', 'retused'], 'retusing': []},
 'retusch': {'retusche': []},
 'retuse': ['retuses', 'retused'],
 'retusi': {'retusis': []},
 'retusida': {'retusidae': []},
 'retusotrilet': {'retusotriletes': []},
 'retusu': {'retusus': []},
 'retut': {'retute': ['retuted']},
 'retute': ['retuted'],
 'retutn': {'retutned': [], 'retutns': []},
 'retvalu': {'retvalue': []},
 'retvirn': {'retvirned': []},
 'retvlut': {'retvlution': []},
 'retvrn': {'retvrned': []},
 'retwin': {'retwine': ['retwined'], 'retwining': []},
 'retwine': ['retwined'],
 'retwist': {'retwisted': [], 'retwisting': [], 'retwists': []},
 'rety': ['retying'],
 'retyer': {'retyere': []},
 'retynew': {'retynewe': []},
 'retynu': {'retynue': []},
 'retyp': {'retype': ['retyped', 'retypes'], 'retyping': ['retypings']},
 'retype': ['retyped', 'retypes'],
 'retypeset': {'retypesetting': []},
 'retypif': {'retypification': []},
 'retyping': ['retypings'],
 'retyr': {'retyre': ['retyred', 'retyres', 'retyrement'], 'retyring': []},
 'retyre': ['retyred', 'retyres', 'retyrement'],
 'retz': {'retze': ['retzes']},
 'retze': ['retzes'],
 'retziacea': {'retziaceae': []},
 'retzin': {'retzins': []},
 'retzing': {'retzinger': []},
 'retziu': {'retzius': []},
 'retzk': {'retzke': []},
 'retzki': {'retzky': []},
 'retzlu': {'retzlus': []},
 'retzui': {'retzuis': []},
 'retzun': {'retzuns': []},
 'reu': {'reued': [], 'reus': []},
 'reua': {'reuas': []},
 'reuabil': {'reuability': []},
 'reuabl': {'reuable': []},
 'reuaissanc': {'reuaissance': []},
 'reuanc': {'reuance': []},
 'reub': {'reube': [], 'reubs': []},
 'reubel': {'reubell': ['reubells'], 'reubels': []},
 'reubell': ['reubells'],
 'reuben': {'reuben': []},
 'reubenesqu': {'reubenesque': []},
 'reubenit': {'reubenite': ['reubenites']},
 'reubenite': ['reubenites'],
 'reuberu': {'reuberus': []},
 'reubi': {'reubie': [], 'reuby': []},
 'reubio': {'reubios': []},
 'reubk': {'reubke': []},
 'reuc': {'reuce': ['reuced'], 'reucing': [], 'reucs': []},
 'reuce': ['reuced'],
 'reuch': {'reuched': []},
 'reuchlin': {'reuchlins': []},
 'reuchlinhau': {'reuchlinhaus': []},
 'reuchlinianu': {'reuchlinianus': []},
 'reuchlinist': {'reuchlinists': []},
 'reuchlinu': {'reuchlinus': []},
 'reud': {'reude': [], 'reuding': []},
 'reudc': {'reudced': []},
 'reudelhub': {'reudelhuber': []},
 'reuder': {'reudered': [], 'reudering': [], 'reuders': []},
 'reudi': {'reudy': []},
 'reudig': {'reudiger': []},
 'reudili': {'reudily': []},
 'reudr': {'reudre': []},
 'reudu': {'reudus': []},
 'reue': {'reues': []},
 'reueal': {'reueale': ['reuealed'], 'reuealing': []},
 'reueale': ['reuealed'],
 'reueil': {'reueiled': []},
 'reuel': {'reuele': ['reueled'], 'reueling': [], 'reuels': []},
 'reuelacion': {'reuelaciones': [], 'reuelacions': []},
 'reuelacyon': {'reuelacyons': []},
 'reuelant': {'reuelante': []},
 'reuelar': {'reuelare': []},
 'reuelat': {'reuelation': ['reuelations']},
 'reuelation': {'reuelatione': []},
 'reuele': ['reueled'],
 'reuell': {'reuelles': [], 'reuelling': [], 'reuells': []},
 'reuenew': {'reuenewes': []},
 'reueng': {'reuenge': ['reuenged', 'reuenges'], 'reuenging': []},
 'reuenge': ['reuenged', 'reuenges'],
 'reuengeful': {'reuengefull': []},
 'reuenu': {'reuenue': ['reuenues'], 'reuenus': []},
 'reuenue': ['reuenues'],
 'reuer': {'reuers': []},
 'reueranc': {'reuerance': []},
 'reuerec': {'reuerece': []},
 'reueren': {'reuerens': []},
 'reuerenc': {'reuerence': ['reuerenced'], 'reuerencing': []},
 'reuerence': ['reuerenced'],
 'reuerend': {'reuerende': []},
 'reuerendu': {'reuerendus': []},
 'reuerent': {'reuerente': ['reuerenter'], 'reuerently': []},
 'reuerente': ['reuerenter'],
 'reuers': {'reuerse': ['reuersed']},
 'reuerse': ['reuersed'],
 'reuersion': {'reuersione': [], 'reuersions': []},
 'reuersu': {'reuersus': []},
 'reuertent': {'reuertentes': []},
 'reuerter': {'reuertere': []},
 'reuest': {'reuested': []},
 'reuev': {'reueve': ['reueved']},
 'reueve': ['reueved'],
 'reuew': {'reuewed': []},
 'reuf': {'reufs': []},
 'reug': {'reuge': []},
 'reugion': {'reugions': []},
 'reugiou': {'reugious': []},
 'reugni': {'reugny': []},
 'reuh': {'reuhs': []},
 'reuhl': {'reuhle': []},
 'reuienn': {'reuienne': []},
 'reuiew': {'reuiewed': [], 'reuiewing': [], 'reuiews': []},
 'reuig': {'reuige': []},
 'reuil': {'reuile': ['reuiled'], 'reuiling': []},
 'reuile': ['reuiled'],
 'reuill': {'reuille': []},
 'reuilli': {'reuilly': []},
 'reuin': {'reuined': []},
 'reuinou': {'reuinous': []},
 'reuint': {'reuinted': []},
 'reuir': {'reuire': ['reuires', 'reuired'], 'reuiring': []},
 'reuire': ['reuires', 'reuired'],
 'reuirement': {'reuirements': []},
 'reuis': {'reuise': ['reuised']},
 'reuise': ['reuised'],
 'reuiu': {'reuiued': [], 'reuiuing': []},
 'reuiue': {'reuiues': []},
 'reuiur': {'reuiure': []},
 'reuiv': {'reuive': []},
 'reuk': {'reuke': []},
 'reul': {'reule': ['reules', 'reuled'], 'reuling': []},
 'reularli': {'reularly': []},
 'reulat': {'reulation': ['reulations']},
 'reulation': ['reulations'],
 'reulcer': {'reulcerate': [], 'reulceration': []},
 'reule': ['reules', 'reuled'],
 'reuleck': {'reulecke': []},
 'reuler': {'reulers': []},
 'reuli': {'reulis': [], 'reuly': []},
 'reuliti': {'reulity': []},
 'reulk': {'reulke': []},
 'reull': {'reulle': ['reulled']},
 'reulle': ['reulled'],
 'reulli': {'reully': []},
 'reulo': {'reulos': []},
 'reult': {'reulted': [], 'reulting': [], 'reults': []},
 'reum': {'reume': ['reumes', 'reumed'], 'reums': []},
 'reuma': {'reumas': []},
 'reumat': {'reumatic': [], 'reumatism': []},
 'reumatich': {'reumatiche': []},
 'reumatoid': {'reumatoide': []},
 'reume': ['reumes', 'reumed'],
 'reumqu': {'reumque': []},
 'reun': {'reune': ['reunes', 'reuned'], 'reuning': []},
 'reunciat': {'reunciation': []},
 'reund': {'reunde': ['reunded']},
 'reunde': ['reunded'],
 'reunderstand': {'reunderstanding': ['reunderstandings']},
 'reunderstanding': ['reunderstandings'],
 'reunderwrit': {'reunderwrite': [], 'reunderwriting': []},
 'reune': ['reunes', 'reuned'],
 'reunel': {'reunell': []},
 'reunfic': {'reunfication': []},
 'reuni': {'reunie': ['reunies'], 'reunis': []},
 'reuniamo': {'reuniamos': []},
 'reunida': {'reunidas': []},
 'reunido': {'reunidos': []},
 'reunie': ['reunies'],
 'reunien': {'reuniens': []},
 'reuniendo': {'reuniendos': []},
 'reuniendos': {'reuniendose': []},
 'reunies': {'reuniese': []},
 'reunif': {'reunification': []},
 'reunifi': {'reunified': [],
             'reunifier': ['reunifiers'],
             'reunifies': [],
             'reunify': ['reunifying']},
 'reunificationist': {'reunificationists': []},
 'reunifie': {'reunifiee': []},
 'reunifier': ['reunifiers'],
 'reuniform': {'reuniformed': []},
 'reuniftc': {'reuniftcation': []},
 'reunify': ['reunifying'],
 'reunimo': {'reunimos': []},
 'reunio': {'reunioes': []},
 'reunion': ['reunione',
             'reuniones',
             'reunioned',
             'reunioners',
             'reunionism',
             'reunioning',
             'reunionize',
             'reunionization'],
 'reunionai': {'reunionais': []},
 'reuniones': {'reunionese': []},
 'reunionist': {'reunionists': []},
 'reunionnai': {'reunionnais': []},
 'reunionnais': {'reunionnaise': []},
 'reunir': {'reunired': [], 'reunirent': []},
 'reunirai': {'reuniraient': []},
 'reuniremo': {'reuniremos': []},
 'reunirm': {'reunirme': []},
 'reunirs': {'reunirse': []},
 'reuniss': {'reunissant': [], 'reunisse': ['reunissent']},
 'reunissai': {'reunissaient': []},
 'reunisse': ['reunissent'],
 'reunisson': {'reunissons': []},
 'reunit': {'reunitable': [],
            'reunite': ['reunites', 'reuniter', 'reunited', 'reuniters'],
            'reuniting': ['reunitings'],
            'reunition': [],
            'reunitive': [],
            'reunits': []},
 'reunite': ['reunites', 'reuniter', 'reunited', 'reuniters'],
 'reuniti': {'reunity': []},
 'reuniting': ['reunitings'],
 'reunuci': {'reunuciation': []},
 'reununci': {'reununciation': []},
 'reuocar': {'reuocare': []},
 'reuocat': {'reuocation': []},
 'reuocati': {'reuocatis': []},
 'reuocation': {'reuocatione': []},
 'reuocatu': {'reuocatus': []},
 'reuok': {'reuoke': ['reuoked']},
 'reuoke': ['reuoked'],
 'reuolt': {'reuolte': ['reuolted'], 'reuolting': []},
 'reuolte': ['reuolted'],
 'reuolu': {'reuolue': ['reuolued'], 'reuoluing': []},
 'reuolue': ['reuolued'],
 'reuoluen': {'reuoluens': []},
 'reuolut': {'reuolution': ['reuolutions']},
 'reuolution': ['reuolutions'],
 'reuomin': {'reuomination': []},
 'reuon': {'reuons': []},
 'reuounc': {'reuounce': []},
 'reuov': {'reuoved': []},
 'reuown': {'reuowned': []},
 'reup': {'reuping': [], 'reupped': [], 'reupping': []},
 'reupholst': {'reupholster': ['reupholsters',
                               'reupholstered',
                               'reupholstering']},
 'reupholster': {'reupholsterer': []},
 'reupholsteri': {'reupholstery': []},
 'reupk': {'reupke': []},
 'reuplift': {'reuplifted': []},
 'reuptak': {'reuptake': []},
 'reuqir': {'reuqired': [], 'reuqirements': []},
 'reuqu': {'reuque': ['reuques']},
 'reuque': ['reuques'],
 'reur': {'reure': ['reured'], 'reurs': []},
 'reurban': {'reurbanization': [],
             'reurbanize': ['reurbanized'],
             'reurbanizing': []},
 'reurbanis': {'reurbanisation': []},
 'reurbanize': ['reurbanized'],
 'reurc': {'reurces': []},
 'reure': ['reured'],
 'reurg': {'reurge': ['reurges', 'reurged'], 'reurging': []},
 'reurge': ['reurges', 'reurged'],
 'reuri': {'reury': []},
 'reurit': {'reuriting': []},
 'reurn': {'reurned': [], 'reurning': [], 'reurns': []},
 'reurop': {'reurope': []},
 'reurv': {'reurved': []},
 'reus': {'reuse': ['reuses', 'reused'], 'reusing': []},
 'reusabl': {'reusability': [], 'reusable': ['reusables']},
 'reusable': ['reusables'],
 'reusachtig': {'reusachtige': []},
 'reusag': {'reusage': []},
 'reusahl': {'reusahle': []},
 'reusch': {'reusche': [], 'reuschs': []},
 'reuschemey': {'reuschemeyer': []},
 'reuschl': {'reuschle': [], 'reuschling': []},
 'reuschmey': {'reuschmeyer': []},
 'reuse': ['reuses', 'reused'],
 'reuseabl': {'reuseability': [], 'reuseable': []},
 'reusen': {'reusens': []},
 'reuser': {'reusers': []},
 'reuslt': {'reuslts': []},
 'reusneru': {'reusnerus': []},
 'reuson': {'reusons': []},
 'reuss': {'reusse': ['reusses']},
 'reusse': ['reusses'],
 'reussela': {'reusselaer': []},
 'reussen': {'reussens': []},
 'reussi': {'reussie': ['reussies'], 'reussis': [], 'reussy': []},
 'reussie': ['reussies'],
 'reussir': {'reussirent': []},
 'reussirai': {'reussiraient': []},
 'reussiron': {'reussirons': []},
 'reussisch': {'reussische': []},
 'reussiss': {'reussissant': [], 'reussisse': ['reussissent']},
 'reussissai': {'reussissaient': [], 'reussissais': []},
 'reussisse': ['reussissent'],
 'reussisson': {'reussissons': []},
 'reussit': {'reussite': ['reussites']},
 'reussite': ['reussites'],
 'reustl': {'reustle': []},
 'reusuabl': {'reusuable': []},
 'reut': {'reute': ['reuted', 'reutes'], 'reuting': [], 'reuts': []},
 'reute': ['reuted', 'reutes'],
 'reutel': {'reuteler': []},
 'reutelingsperg': {'reutelingsperger': []},
 'reuten': {'reutener': [], 'reutens': []},
 'reutenau': {'reutenauer': []},
 'reutenfel': {'reutenfels': []},
 'reuter': {'reuters': []},
 'reuterbi': {'reuterby': []},
 'reuterklockn': {'reuterklockner': []},
 'reuterstrass': {'reuterstrasse': []},
 'reuterwal': {'reuterwall': []},
 'reuth': {'reuthe': []},
 'reuther': {'reutherism': [], 'reuthers': []},
 'reutherit': {'reutherite': ['reutherites']},
 'reutherite': ['reutherites'],
 'reutil': {'reutilization': ['reutilizations'],
            'reutilize': ['reutilized', 'reutilizes'],
            'reutilizing': []},
 'reutilis': {'reutilisation': [],
              'reutilise': ['reutilised', 'reutiliser', 'reutilises'],
              'reutilising': []},
 'reutilise': {'reutilisee': ['reutilisees']},
 'reutilisee': ['reutilisees'],
 'reutiliz': {'reutilizable': []},
 'reutilization': ['reutilizations'],
 'reutilize': ['reutilized', 'reutilizes'],
 'reuting': {'reutinger': []},
 'reutiv': {'reutive': []},
 'reutledg': {'reutledge': []},
 'reutling': {'reutlinger': []},
 'reutrn': {'reutrned': [], 'reutrns': []},
 'reutt': {'reutte': []},
 'reutter': {'reutterance': [],
             'reuttered': [],
             'reutterer': [],
             'reuttering': [],
             'reutters': []},
 'reutting': {'reuttinger': []},
 'reuuc': {'reuuce': ['reuuced']},
 'reuuce': ['reuuced'],
 'reuuir': {'reuuired': []},
 'reuv': {'reuve': []},
 'reuven': {'reuvens': []},
 'reuveni': {'reuveny': []},
 'reuvensplaat': {'reuvensplaats': []},
 'reuver': {'reuvers': []},
 'reuvil': {'reuville': []},
 'reuvr': {'reuvre': ['reuvres']},
 'reuvre': ['reuvres'],
 'reuwe': {'reuwee': []},
 'reuyl': {'reuyle': []},
 'reuz': {'reuze': []},
 'rev': ['revved', 'revving'],
 "rev'd": {"rev'ds": []},
 'reva': {'revae': [], 'revas': []},
 'revaal': {'revaaled': []},
 'revaccin': {'revaccinate': ['revaccinated'],
              'revaccinating': [],
              'revaccination': ['revaccinations']},
 'revaccinate': ['revaccinated'],
 'revaccination': ['revaccinations'],
 'revaccine': {'revaccinees': []},
 'revacular': {'revacularization': []},
 'revacycl': {'revacycle': []},
 'revag': {'revaged': [], 'revages': [], 'revaging': []},
 'revagotomi': {'revagotomy': []},
 'revai': {'revais': []},
 'revail': {'revaile': ['revailed'], 'revailing': [], 'revails': []},
 'revaile': ['revailed'],
 'reval': {'revalation': ['revalations'],
           'revale': ['revaled', 'revaler', 'revalent', 'revalence'],
           'revaling': [],
           'revall': ['revally', 'revalles'],
           'revals': []},
 'revalation': ['revalations'],
 'revalatori': {'revalatory': []},
 'revale': ['revaled', 'revaler', 'revalent', 'revalence'],
 'revalesc': {'revalescence': []},
 'revalid': {'revalidate': ['revalidates', 'revalidated'],
             'revalidating': [],
             'revalidation': ['revalidations']},
 'revalidado': {'revalidados': []},
 'revalidate': ['revalidates', 'revalidated'],
 'revalidati': {'revalidatie': []},
 'revalidation': ['revalidations'],
 'revall': ['revally', 'revalles'],
 'revalor': {'revalorization': ['revalorizations'],
             'revalorize': ['revalorizes', 'revalorized'],
             'revalorizing': []},
 'revaloris': {'revalorisation': ['revalorisations'],
               'revalorise': ['revalorises', 'revalorised', 'revaloriser'],
               'revalorising': []},
 'revalorisation': ['revalorisations'],
 'revalorise': ['revalorises', 'revalorised', 'revaloriser'],
 'revalorization': ['revalorizations'],
 'revalorize': ['revalorizes', 'revalorized'],
 'revalri': {'revalries': [], 'revalry': []},
 'revalsch': {'revalsche': []},
 'revalu': {'revaluate': ['revaluates', 'revaluated'],
            'revaluating': [],
            'revaluation': [],
            'revaluative': [],
            'revaluator': [],
            'revalue': ['revalued', 'revalues', 'revaluer', 'revaluers'],
            'revaluing': []},
 'revaluate': ['revaluates', 'revaluated'],
 'revalue': ['revalued', 'revalues', 'revaluer', 'revaluers'],
 'revalueshanari': {'revalueshanary': []},
 'revalut': {'revalution': []},
 'revalutionari': {'revalutionary': []},
 'revalv': {'revalved': [], 'revalving': []},
 'revamp': {'revamped': [],
            'revamper': [],
            'revamping': ['revampings'],
            'revampment': [],
            'revamps': []},
 'revamping': ['revampings'],
 'revan': {'revans': []},
 'revanch': {'revanche': ['revancher', 'revanches'], 'revanchism': []},
 'revanchard': {'revanchards': []},
 'revanche': ['revancher', 'revanches'],
 'revanchism': {'revanchisme': []},
 'revanchismu': {'revanchismus': []},
 'revanchist': {'revanchiste': ['revanchistes'],
                'revanchistic': [],
                'revanchists': []},
 'revanchiste': ['revanchistes'],
 'revang': {'revange': []},
 'revanu': {'revanue': []},
 'revapor': {'revaporization': [],
             'revaporize': ['revaporizes', 'revaporized'],
             'revaporizing': []},
 'revaporis': {'revaporisation': [], 'revaporised': []},
 'revaporize': ['revaporizes', 'revaporized'],
 'revar': {'revare': []},
 'revard': {'revarded': [], 'revards': []},
 'revari': {'revaris': []},
 'revarnish': {'revarnished': [], 'revarnishing': []},
 'revarr': {'revarre': []},
 'revars': {'revarse': []},
 'revascul': {'revasculization': []},
 'revasculanz': {'revasculanzation': []},
 'revascular': {'revascularization': ['revascularizations'],
                'revascularize': ['revascularized', 'revascularizes'],
                'revascularizing': []},
 'revascularis': {'revascularisation': ['revascularisations'],
                  'revascularise': ['revascularised'],
                  'revascularising': []},
 'revascularisation': ['revascularisations'],
 'revascularise': ['revascularised'],
 'revascularization': ['revascularizations'],
 'revascularize': ['revascularized', 'revascularizes'],
 'revashank': {'revashanker': []},
 'revaskularis': {'revaskularisation': []},
 'revasseri': {'revasseries': []},
 'revasular': {'revasularization': []},
 'revathi': {'revathy': []},
 'revaug': {'revauger': []},
 'revault': {'revaulted': [], 'revaulting': []},
 'revc': {'revcs': []},
 'revcal': {'revcaled': [], 'revcaler': []},
 'revcalingli': {'revcalingly': []},
 'revcll': {'revclle': []},
 'revclut': {'revclution': []},
 'revcnu': {'revcnue': []},
 'revcount': {'revcounter': []},
 'revcr': {'revcre': [], 'revcrs': []},
 'revcrberatori': {'revcrberatory': []},
 'revcrdi': {'revcrdy': []},
 'revcri': {'revcry': []},
 'revcrsibl': {'revcrsibly': []},
 'revd': {'revde': [], 'revds': []},
 'reve': {'ref': [],
          'reved': [],
          'revee': ['revees'],
          'reveli': [],
          'revely': [],
          'reving': []},
 "revea'": {"revea'ed": []},
 'reveaf': {'reveafed': []},
 'reveai': {'reveaied': [], 'reveaiing': [], 'reveais': []},
 'reveaj': {'reveajed': [], 'reveajs': []},
 'reveal': {'revealability': [],
            'revealable': [],
            'revealation': ['revealations'],
            'reveale': ['reveales', 'revealer', 'revealed', 'revealers'],
            'revealing': [],
            'reveall': ['revealled', 'revealling'],
            'revealment': ['revealments'],
            'reveals': []},
 'revealation': ['revealations'],
 'revealatori': {'revealatory': []},
 'reveale': ['reveales', 'revealer', 'revealed', 'revealers'],
 'revealed': {'revealedness': []},
 'revealedprefer': {'revealedpreference': []},
 'revealedth': {'revealedthe': []},
 'revealing': {'revealingness': []},
 'revealingconc': {'revealingconcealing': []},
 'revealingli': {'revealingly': []},
 'revealingth': {'revealingthe': []},
 'reveall': ['revealled', 'revealling'],
 'revealment': ['revealments'],
 'revealsth': {'revealsthe': []},
 'revealt': {'revealted': [], 'revealtion': []},
 'revealth': {'revealthe': []},
 'revealtran': {'revealtrans': []},
 'revealv': {'revealved': []},
 'revear': {'reveared': []},
 'reveat': {'reveated': [], 'reveation': [], 'reveats': []},
 'reveau': {'reveaue': []},
 'reveber': {'reveberated': [],
             'reveberating': [],
             'reveberation': ['reveberations']},
 'reveberation': ['reveberations'],
 'revech': {'reveche': []},
 'revector': {'revectored': [], 'revectoring': []},
 'revectu': {'revectus': []},
 'reveder': {'revedere': []},
 'revedg': {'revedge': []},
 'revee': ['revees'],
 'reveel': {'reveeled': [], 'reveeling': [], 'reveels': []},
 'reveen': {'reveens': []},
 'reveget': {'revegetate': ['revegetated', 'revegetates'],
             'revegetating': [],
             'revegetation': [],
             'revegetative': []},
 'revegetate': ['revegetated', 'revegetates'],
 'reveh': {'revehent': []},
 'revehen': {'revehens': []},
 'revehent': {'revehentes': []},
 'revehu': {'revehue': []},
 'revei': {'reveied': [], 'reveis': []},
 'reveiat': {'reveiation': []},
 'reveienc': {'reveience': []},
 'reveiew': {'reveiewed': []},
 'reveil': {'reveile': ['reveiled'],
            'reveiling': [],
            'reveill': ['reveille',
                        'reveiller',
                        'reveilled',
                        'reveillant',
                        'reveillent'],
            'reveils': []},
 'reveile': ['reveiled'],
 'reveill': ['reveille', 'reveiller', 'reveilled', 'reveillant', 'reveillent'],
 'reveilla': {'reveillas': []},
 'reveillai': {'reveillaient': []},
 'reveille': {'reveillee': ['reveillees']},
 'reveillee': ['reveillees'],
 'reveiller': {'reveillere': ['reveillerent']},
 'reveillere': ['reveillerent'],
 'reveilli': {'reveillie': []},
 'reveillier': {'reveilliere': []},
 'reveillon': {'reveillons': []},
 'reveilu': {'reveilue': []},
 'reveir': {'reveire': [], 'reveirs': []},
 'reveis': {'reveise': ['reveised'], 'reveision': []},
 'reveise': ['reveised'],
 'reveiv': {'reveive': ['reveiver', 'reveived', 'reveives'], 'reveiving': []},
 'reveive': ['reveiver', 'reveived', 'reveives'],
 'reveiw': {'reveiwed': [],
            'reveiwer': ['reveiwers'],
            'reveiwing': [],
            'reveiws': []},
 'reveiwer': ['reveiwers'],
 'revej': {'revejation': []},
 'revekt': {'revektion': []},
 'revel': ['revell',
           'revele',
           'reveles',
           'revelou',
           'revelle',
           'reveler',
           'reveled',
           'revells',
           'revelles',
           'reveling',
           'revelent',
           'revelled',
           'revelous',
           'revelate',
           'reveller',
           'revelant',
           'revellent',
           'revelator',
           'revelancy',
           'revelance',
           'revelings',
           'revelling',
           'revelment',
           'revelated',
           'revellings',
           'revelating',
           'revelation',
           'revellents',
           'revelative',
           'revelators',
           'revellation',
           'revelational',
           'revelationally'],
 'revela': {'revelaed': [], 'revelas': []},
 'revelabi': {'revelabis': []},
 'revelabil': {'revelabile': []},
 'revelacion': {'revelacione': ['revelaciones'], 'revelacions': []},
 'revelacione': ['revelaciones'],
 'revelacioun': {'revelaciouns': []},
 'revelaco': {'revelacoes': []},
 'revelacyon': {'revelacyons': []},
 'revelada': {'reveladas': []},
 'revelado': {'revelados': []},
 'revelador': {'reveladores': []},
 'reveladora': {'reveladoras': []},
 'revelai': {'revelaient': []},
 'revelal': {'revelalation': []},
 'revelan': {'revelans': []},
 'revelant': {'revelante': ['revelantes']},
 'revelante': ['revelantes'],
 'revelanti': {'revelantis': []},
 'revelar': {'revelare': ['revelarent']},
 'revelare': ['revelarent'],
 'revelarl': {'revelarle': []},
 'revelarno': {'revelarnos': []},
 'revelars': {'revelarse': []},
 'revelas': {'revelase': []},
 'revelass': {'revelasse': []},
 'revelata': {'revelatae': [], 'revelatas': []},
 'revelateur': {'revelateurs': []},
 'revelati': {'revelatiou': ['revelatious'], 'revelatis': []},
 'revelation': {'revelatione': ['revelationes'], 'revelationism': []},
 'revelationari': {'revelationary': []},
 'revelatione': ['revelationes'],
 'revelationi': {'revelationis': []},
 'revelationibu': {'revelationibus': []},
 'revelationist': {'revelationists': []},
 'revelationlectur': {'revelationlectures': []},
 'revelatiou': ['revelatious'],
 'revelatori': {'revelatoriness': [], 'revelatory': []},
 'revelatorili': {'revelatorily': []},
 'revelatric': {'revelatrice': ['revelatrices']},
 'revelatrice': ['revelatrices'],
 'revelatu': {'revelatus': []},
 'revelazion': {'revelazione': []},
 'reveld': {'reveldes': []},
 'revele': {'revelee': ['revelees']},
 'revelee': ['revelees'],
 'reveler': {'revelerent': []},
 'revelerai': {'reveleraient': []},
 'reveleri': {'revelery': []},
 'revelett': {'revelette': []},
 'reveley': {'reveleys': []},
 'revelg': {'revelge': []},
 'revelin': {'revelins': []},
 'revelioti': {'reveliotis': []},
 'reveller': {'revellere': []},
 'revelleri': {'revellery': []},
 'revelli': {'revellie': [], 'revelly': []},
 'revellier': {'revelliere': []},
 'revellri': {'revellry': []},
 'revelo': {'revelos': []},
 'revelop': {'revelopment': []},
 'revelp': {'revelps': []},
 'revelr': {'revelrous': []},
 'revelri': {'revelrie': [], 'revelry': []},
 'revelstok': {'revelstoke': []},
 'revelston': {'revelstone': []},
 'revelstrok': {'revelstroke': []},
 'revelut': {'revelution': ['revelutions']},
 'revelution': ['revelutions'],
 'revelutionari': {'revelutionary': []},
 'revemi': {'revemie': ['revemies']},
 'revemie': ['revemies'],
 'reven': {'revenal': [],
           'revenance': [],
           'revenant': [],
           'revene': ['revenes', 'revened', 'reveneered'],
           'revening': [],
           'revenous': [],
           'revens': []},
 'revena': {'revenae': [], 'revenas': []},
 'revenai': {'revenaient': [], 'revenais': []},
 'revenan': {'revenans': []},
 'revenant': {'revenante': []},
 'revenc': {'revence': []},
 'revend': {'revendal': [],
            'revendent': [],
            'revender': [],
            'revendicate': ['revendicated'],
            'revendicating': [],
            'revendication': ['revendications'],
            'revendicative': ['revendicatives']},
 'revendedor': {'revendedores': []},
 'revendeur': {'revendeurs': []},
 'revendeus': {'revendeuse': ['revendeuses']},
 'revendeuse': ['revendeuses'],
 'revendg': {'revendge': []},
 'revendicate': ['revendicated'],
 'revendicatif': {'revendicatifs': []},
 'revendication': ['revendications'],
 'revendicative': ['revendicatives'],
 'revendicatori': {'revendicatory': []},
 'revendiqu': {'revendiquant': [],
               'revendique': ['revendiques', 'revendiquer', 'revendiquent']},
 'revendiquai': {'revendiquaient': []},
 'revendique': {'revendiquee': ['revendiquees']},
 'revendiquee': ['revendiquees'],
 'revendiquon': {'revendiquons': []},
 'revendr': {'revendre': []},
 'revendu': {'revendues': [], 'revendus': []},
 'revene': {'revenee': []},
 'revenent': {'revenentes': []},
 'revenesc': {'revenescence': []},
 'reveneu': {'reveneue': ['reveneues'], 'reveneus': []},
 'reveneue': ['reveneues'],
 'revenew': {'revenewe': ['revenewes'], 'revenews': []},
 'revenewe': ['revenewes'],
 'reveng': {'revengance': [],
            'revenge': ['revenged',
                        'revenger',
                        'revengers',
                        'revengent',
                        'revengence',
                        'revengeful',
                        'revengeance',
                        'revengement',
                        'revengefully',
                        'revengements',
                        'revengefulness'],
            'revengful': [],
            'revenging': [],
            'revengment': []},
 'revengd': {'revengde': []},
 'revenge': ['revenged',
             'revenger',
             'revengers',
             'revengent',
             'revengence',
             'revengeful',
             'revengeance',
             'revengement',
             'revengefully',
             'revengements',
             'revengefulness'],
 'revengeful': {'revengefull': []},
 'revengemind': {'revengeminded': []},
 'revengeseek': {'revengeseekers': [], 'revengeseeking': []},
 'revengingli': {'revengingly': []},
 'revengist': {'revengists': []},
 'revenion': {'revenions': []},
 'revenir': {'revenire': []},
 'revenl': {'revenled': []},
 'revenn': {'revenne': ['revennes']},
 'revenne': ['revennes'],
 'revennew': {'revennewes': []},
 'revennu': {'revennue': ['revennues']},
 'revennue': ['revennues'],
 'reveno': {'revenoe': []},
 'revenoi': {'revenoient': [], 'revenois': []},
 'revenon': {'revenons': []},
 'revenoo': {'revenooer': ['revenooers']},
 'revenooer': ['revenooers'],
 'revenoor': {'revenoors': []},
 'revenqu': {'revenque': []},
 'revent': {'revente': ['revented'],
            'reventing': [],
            'revention': [],
            'reventive': [],
            'revently': [],
            'revents': []},
 'revente': ['revented'],
 'reventi': {'revential': []},
 'reventil': {'reventilate': ['reventilated'], 'reventilation': []},
 'reventilate': ['reventilated'],
 'revention': {'reventiones': []},
 'reventionibu': {'reventionibus': []},
 'reventlow': {'reventlows': []},
 'reventlowsgad': {'reventlowsgade': []},
 'revento': {'reventos': []},
 'revenu': {'revenual': [], 'revenue': ['revenuer', 'revenued'], 'revenus': []},
 'revenuc': {'revenucs': []},
 'revenue': {'revenuee': []},
 'revenuebas': {'revenuebased': []},
 'revenuebear': {'revenuebearing': []},
 'revenuecollect': {'revenuecollecting': [], 'revenuecollection': []},
 'revenuecollector': {'revenuecollectors': []},
 'revenuecutt': {'revenuecutter': ['revenuecutters']},
 'revenuecutter': ['revenuecutters'],
 'revenueearn': {'revenueearner': [], 'revenueearning': []},
 'revenueenhanc': {'revenueenhancing': []},
 'revenuefarm': {'revenuefarmer': ['revenuefarmers'], 'revenuefarming': []},
 'revenuefarmer': ['revenuefarmers'],
 'revenuefre': {'revenuefree': []},
 'revenuegath': {'revenuegathering': []},
 'revenuegener': {'revenuegenerating': [], 'revenuegeneration': []},
 'revenuehungri': {'revenuehungry': []},
 'revenueincreas': {'revenueincreasing': []},
 'revenuelaw': {'revenuelaws': []},
 'revenuemarin': {'revenuemarine': []},
 'revenueneutr': {'revenueneutral': []},
 'revenueoffic': {'revenueofficer': ['revenueofficers']},
 'revenueofficer': ['revenueofficers'],
 'revenuepay': {'revenuepayer': ['revenuepayers'], 'revenuepaying': []},
 'revenuepayer': ['revenuepayers'],
 'revenueproduc': {'revenueproducer': [], 'revenueproducing': []},
 'revenuerais': {'revenueraising': []},
 'revenuerecognit': {'revenuerecognition': []},
 'revenuerel': {'revenuerelated': []},
 'revenuesettl': {'revenuesettlement': []},
 'revenueshar': {'revenuesharing': []},
 'revenueyield': {'revenueyielding': []},
 'revenuo': {'revenuos': []},
 'revenv': {'revenve': []},
 'reveol': {'reveoled': []},
 'reveou': {'reveoue': []},
 'rever': {'reverable': [],
           'reveral': ['reverals'],
           'reverance': [],
           'reverant': [],
           'reveration': [],
           'revere': ['reverer',
                      'revered',
                      'revereal',
                      'reverent',
                      'reverers',
                      'reverence',
                      'revereibly',
                      'reverently'],
           'revering': [],
           'reveriti': [],
           'reverred': [],
           'revers': []},
 'revera': {'reveraal': [], 'reverae': ['reveraed'], 'reveraibly': []},
 'reverae': ['reveraed'],
 'reveral': ['reverals'],
 'reverantli': {'reverantly': []},
 'reverb': {'reverbalization': [],
            'reverbalize': ['reverbalized'],
            'reverbalizing': [],
            'reverbate': ['reverbated'],
            'reverbating': [],
            'reverbation': ['reverbations'],
            'reverbe': ['reverber', 'reverbed', 'reverberative'],
            'reverbing': [],
            'reverbs': []},
 'reverbalize': ['reverbalized'],
 'reverbate': ['reverbated'],
 'reverbation': ['reverbations'],
 'reverbatori': {'reverbatory': []},
 'reverbcratori': {'reverbcratory': []},
 'reverbe': ['reverber', 'reverbed', 'reverberative'],
 'reverber': {'reverberance': [],
              'reverberant': [],
              'reverberate': ['reverberated', 'reverberates'],
              'reverberating': [],
              'reverberation': [],
              'reverberator': ['reverberators'],
              'reverbere': ['reverberes', 'reverberent']},
 'reverberacion': {'reverberaciones': []},
 'reverberant': {'reverberante': ['reverberantes']},
 'reverberante': ['reverberantes'],
 'reverberantli': {'reverberantly': []},
 'reverberate': ['reverberated', 'reverberates'],
 'reverberatingli': {'reverberatingly': []},
 'reverberation': {'reverberatione': []},
 'reverberator': ['reverberators'],
 'reverberatori': {'reverberatories': [], 'reverberatory': []},
 'reverbere': ['reverberes', 'reverberent'],
 'reverbertori': {'reverbertory': []},
 'reverbi': {'reverby': []},
 'reverboratori': {'reverboratory': []},
 'reverbr': {'reverbrate': ['reverbrated', 'reverbrates'],
             'reverbrating': [],
             'reverbration': ['reverbrations']},
 'reverbrate': ['reverbrated', 'reverbrates'],
 'reverbration': ['reverbrations'],
 'reverc': {'reverce': []},
 'revercion': {'revercions': []},
 'revercomb': {'revercombs': []},
 'revercon': {'revercons': []},
 'reverdec': {'reverdece': ['reverdecer']},
 'reverdece': ['reverdecer'],
 'reverdi': {'reverdie': ['reverdies'], 'reverdy': ['reverdys']},
 'reverdie': ['reverdies'],
 'reverdin': {'reverdins': []},
 'reverdy': ['reverdys'],
 'revere': {'reveree': ['revereed']},
 'reveree': ['revereed'],
 'reveren': {'reverened': [], 'reverens': []},
 'reverenc': {'reverenced': [],
              'reverencer': ['reverencers'],
              'reverencing': []},
 'reverencer': ['reverencers'],
 'reverenci': {'reverencial': [], 'reverencie': []},
 'reverencia': {'reverencias': []},
 'reverend': ['reverende'],
 'reverenda': {'reverendae': [], 'reverendas': []},
 'reverendi': {'reverendis': [], 'reverendy': []},
 'reverendissim': {'reverendissime': []},
 'reverendissima': {'reverendissimae': []},
 'reverendissimi': {'reverendissimis': []},
 'reverendissimo': {'reverendissimos': []},
 'reverendissimu': {'reverendissimus': []},
 'reverendli': {'reverendly': []},
 'reverendlook': {'reverendlooking': []},
 'reverendo': {'reverendos': []},
 'reverendu': {'reverendus': []},
 'reverene': {'reverenee': ['revereneed']},
 'reverenee': ['revereneed'],
 'revereno': {'reverenoe': []},
 'reverent': {'reverente': ['reverentes', 'reverenter']},
 'reverente': ['reverentes', 'reverenter'],
 'reverentement': {'reverentemente': []},
 'reverenti': {'reverential': ['reverentials',
                               'reverentially',
                               'reverentiality',
                               'reverentialness'],
               'reverentie': []},
 'reverentia': {'reverentiae': []},
 'reverential': {'reverentiall': []},
 'reverentiali': {'reverentialis': []},
 'reverentii': {'reverentiis': []},
 'reverentis': {'reverentise': []},
 'reverentissim': {'reverentissime': []},
 'reverentissimu': {'reverentissimus': []},
 'reverentiu': {'reverentius': []},
 'reverentli': {'reverentlie': []},
 'reverenzial': {'reverenziale': []},
 'reverer': {'reverere': ['revererence']},
 'reverere': ['revererence'],
 'reveres': {'reverese': ['reveresed']},
 'reverese': ['reveresed'],
 'revereuc': {'revereuce': []},
 'reverewar': {'revereware': []},
 'reverf': {'reverfal': [],
            'reverfe': ['reverfed', 'reverfes'],
            'reverfing': []},
 'reverfe': ['reverfed', 'reverfes'],
 'reverfion': {'reverfioner': [], 'reverfions': []},
 'reverher': {'reverherated': [],
              'reverherating': [],
              'reverheration': ['reverherations']},
 'reverheration': ['reverherations'],
 'reverheratori': {'reverheratory': []},
 'reveri': {'reverie': ['reveried'], 'revery': []},
 'reveridg': {'reveridge': []},
 'reverie': ['reveried'],
 'reverielik': {'reverielike': []},
 'reverif': {'reverification': ['reverifications']},
 'reverifi': {'reverified': [], 'reverifies': [], 'reverify': ['reverifying']},
 'reverification': ['reverifications'],
 'reverify': ['reverifying'],
 'reverin': {'reverine': []},
 'reveringli': {'reveringly': []},
 'reverir': {'reverire': []},
 'reverisbl': {'reverisble': []},
 'reveritu': {'reveritus': []},
 'reveriu': {'reverius': []},
 'reverl': {'reverled': []},
 'reverli': {'reverly': []},
 'reverm': {'reverme': []},
 'revern': {'reverned': []},
 'revernacular': {'revernacularization': [], 'revernacularized': []},
 'revernc': {'revernce': []},
 'reveroni': {'reverony': []},
 'reverr': {'reverrence': []},
 'reverra': {'reverras': []},
 'reverrai': {'reverrais': []},
 'reverrion': {'reverrions': []},
 'reverron': {'reverrons': []},
 'revers': ['reverse',
            'reversal',
            'reversed',
            'reverser',
            'reversely',
            'reversion',
            'reversive',
            'reversing',
            'reversers',
            'reversives',
            'reversibly',
            'reversible',
            'reversings',
            'reversable',
            'reversally',
            'reversably',
            'reversioned',
            'reversively',
            'reversative',
            'reversement',
            'reversioning',
            'reversements',
            'reversibility',
            'reversability'],
 'reversa': {'reversae': [], 'reversas': []},
 'reversad': {'reversade': []},
 'reversal': {'reversales': [], 'reversall': []},
 'reversali': {'reversalis': []},
 'reversbi': {'reversby': []},
 'reverseact': {'reverseacting': [], 'reverseaction': []},
 'reverseangl': {'reverseangle': []},
 'reverseauct': {'reverseauction': []},
 'reversebia': {'reversebias': []},
 'reversebias': {'reversebiased': [],
                 'reversebiases': [],
                 'reversebiasing': []},
 'reverseblock': {'reverseblocking': []},
 'reversecharg': {'reversecharge': []},
 'reversechronolog': {'reversechronological': []},
 'reversecod': {'reversecoded': []},
 'reversecurr': {'reversecurrent': []},
 'reversecurv': {'reversecurve': []},
 'reversedirect': {'reversedirection': []},
 'reversediscrimin': {'reversediscrimination': []},
 'reversedli': {'reversedly': []},
 'reversedphas': {'reversedphase': []},
 'reversedpolar': {'reversedpolarity': []},
 'reverseengin': {'reverseengineer': ['reverseengineered',
                                      'reverseengineering']},
 'reverseengineer': ['reverseengineered', 'reverseengineering'],
 'reverselev': {'reverselever': []},
 'reverseord': {'reverseorder': []},
 'reverseosmosi': {'reverseosmosis': []},
 'reversephas': {'reversephase': []},
 'reversepolar': {'reversepolarity': []},
 'reversepow': {'reversepower': []},
 'reversescor': {'reversescored': []},
 'reversesid': {'reverseside': []},
 'reversestr': {'reversestring': []},
 'reversetranscrib': {'reversetranscribed': []},
 'reversetranscript': {'reversetranscription': []},
 'reversetranscriptas': {'reversetranscriptase': []},
 'reversevoltag': {'reversevoltage': []},
 'reversewis': {'reversewise': []},
 'reversi': {'reversis': []},
 'reversibil': {'reversibile': []},
 'reversibili': {'reversibily': []},
 'reversibilit': {'reversibilite': []},
 'reversibilti': {'reversibilty': []},
 'reversibl': {'reversibler': [], 'reversiblity': []},
 'reversifi': {'reversified': []},
 'reversihil': {'reversihility': []},
 'reversihl': {'reversihle': []},
 'reversihli': {'reversihly': []},
 'reversingth': {'reversingthe': []},
 'reversion': {'reversional': ['reversionally'],
               'reversione': ['reversiones', 'reversioner'],
               'reversionism': []},
 'reversional': ['reversionally'],
 'reversionari': {'reversionaries': [], 'reversionary': []},
 'reversione': ['reversiones', 'reversioner'],
 'reversioni': {'reversionis': []},
 'reversionist': {'reversionist': []},
 'reverslbl': {'reverslbly': []},
 'reversli': {'reversly': []},
 'reverso': {'reversos': []},
 'reversu': {'reversus': []},
 'reversuro': {'reversuros': []},
 'reversuru': {'reversurus': []},
 'reversusqu': {'reversusque': []},
 'revert': {'revertable': [],
            'revertance': [],
            'revertant': ['revertants'],
            'reverte': ['reverter',
                        'reverted',
                        'revertent',
                        'reverters',
                        'revertence'],
            'revertibility': [],
            'revertible': [],
            'reverting': [],
            'revertion': ['revertions'],
            'revertive': [],
            'revertments': [],
            'reverts': []},
 'revertant': ['revertants'],
 'revertari': {'revertaris': []},
 'revertas': {'revertase': []},
 'revertdeni': {'revertdeny': []},
 'reverte': ['reverter', 'reverted', 'revertent', 'reverters', 'revertence'],
 'reverten': {'revertens': []},
 'revertent': {'revertente': ['revertentes']},
 'revertente': ['revertentes'],
 'revertentibu': {'revertentibus': []},
 'reverter': {'revertere': []},
 'reverteri': {'reverteris': []},
 'reverti': {'reverty': []},
 'revertion': ['revertions'],
 'revertiss': {'revertisse': []},
 'revertos': {'revertose': []},
 'revertpermitonli': {'revertpermitonly': []},
 'reveru': {'reverue': []},
 'reverv': {'reverve': ['reverved']},
 'reverve': ['reverved'],
 'reverzi': {'reverzy': []},
 'reves': {'ref': [], 'revese': [], 'revesible': []},
 'revesbi': {'revesby': []},
 'revesch': {'revesche': []},
 'revesl': {'revesled': [], 'revesls': []},
 'revest': {'reveste': ['revested'],
            'revesting': [],
            'revestment': [],
            'revests': []},
 'reveste': ['revested'],
 'revestiari': {'revestiary': []},
 'revestida': {'revestidas': []},
 'revestido': {'revestidos': []},
 'revestimiento': {'revestimientos': []},
 'revestirs': {'revestirse': []},
 'revestri': {'revestrie': [], 'revestry': []},
 'revestu': {'revestus': []},
 'revet': {'revetant': [],
           'revetation': [],
           'revete': ['reveted', 'revetent', 'revetement'],
           'reveting': [],
           'revetment': [],
           'revets': [],
           'revetted': [],
           'revetting': []},
 'revetai': {'revetaient': []},
 'revete': ['reveted', 'revetent', 'revetement'],
 'revets': {'revetse': ['revetsed']},
 'revetse': ['revetsed'],
 'revett': {'revette': [], 'revetts': []},
 'revetu': {'revetue': ['revetues'], 'revetus': []},
 'revetue': ['revetues'],
 'reveu': {'reveue': ['reveues']},
 'reveue': ['reveues'],
 'reveug': {'reveuge': []},
 'reveul': {'reveuled': []},
 'reveun': {'reveune': ['reveunes']},
 'reveune': ['reveunes'],
 'reveur': {'reveurs': []},
 'reveus': {'reveuse': ['reveuses', 'reveusement']},
 'reveuse': ['reveuses', 'reveusement'],
 'reveuu': {'reveuue': ['reveuues']},
 'reveuue': ['reveuues'],
 'revew': {'revewal': [], 'revewed': [], 'revewing': []},
 'revez': {'revezes': []},
 'revi': {'revie': ['revied', 'revies'], 'revis': [], 'revy': []},
 'revia': {'reviae': ['reviaed']},
 'reviae': ['reviaed'],
 'reviakin': {'reviakine': []},
 'reviat': {'reviations': []},
 'revibr': {'revibrate': ['revibrated'], 'revibrating': [], 'revibration': []},
 'revibrate': ['revibrated'],
 'revic': {'revice': ['revices', 'reviced'], 'revicic': []},
 'revice': ['revices', 'reviced'],
 'revickzki': {'revickzky': []},
 'revictim': {'revictimization': ['revictimizations'],
              'revictimize': ['revictimizes', 'revictimized'],
              'revictimizing': []},
 'revictimis': {'revictimisation': [], 'revictimised': []},
 'revictimization': ['revictimizations'],
 'revictimize': ['revictimizes', 'revictimized'],
 'revictu': {'revictual': ['revictuals', 'revictualed', 'revictualing']},
 'revictual': {'revictuall': ['revictualled', 'revictualling'],
               'revictualment': []},
 'revictuall': ['revictualled', 'revictualling'],
 'revicw': {'revicwed': [], 'revicws': []},
 'reviczki': {'reviczky': []},
 'revid': {'revided': [], 'revidering': []},
 'revider': {'revidere': ['revideres']},
 'revidera': {'revideras': []},
 'reviderad': {'reviderade': []},
 'reviderat': {'reviderats': []},
 'revidere': ['revideres'],
 'revidered': {'reviderede': []},
 'revidert': {'reviderte': []},
 'revidg': {'revidge': []},
 'revidiert': {'revidierte': ['revidierter', 'revidiertes']},
 'revidierte': ['revidierter', 'revidiertes'],
 'revidirt': {'revidirte': []},
 'revie': {'revieed': []},
 'reviei': {'revieie': []},
 'revieic': {'revieics': []},
 'revieio': {'revieios': []},
 'revieiu': {'revieius': []},
 'revieiv': {'revieivs': []},
 'reviel': {'revieled': [], 'revielle': []},
 'revien': {'reviens': []},
 'reviendra': {'reviendras': []},
 'reviendrai': {'reviendraient': [], 'reviendrais': []},
 'reviendroi': {'reviendrois': []},
 'reviendron': {'reviendrons': []},
 'revienn': {'revienne': ['reviennent']},
 'revienne': ['reviennent'],
 'revient': {'reviente': []},
 'revier': {'reviere': ['revieres'], 'reviers': []},
 'reviere': ['revieres'],
 'reviert': {'revierte': []},
 'reviet': {'reviete': []},
 'revietv': {'revietvs': []},
 'revieu': {'revieus': []},
 'reviev': {'revieved': [], 'revieving': [], 'revievs': []},
 'review': ['reviewe',
            'reviewer',
            'reviewal',
            'reviewes',
            'reviewed',
            'reviewing',
            'reviewals',
            'reviewable',
            'reviewings',
            'reviewability'],
 'reviewarticl': {'reviewarticle': ['reviewarticles']},
 'reviewarticle': ['reviewarticles'],
 'reviewbi': {'reviewby': []},
 'reviewe': {'reviewee': ['reviewees']},
 'reviewedbi': {'reviewedby': []},
 'reviewedth': {'reviewedthe': []},
 'reviewee': ['reviewees'],
 'revieweri': {'reviewery': []},
 'reviewessay': {'reviewessays': []},
 'reviewi': {'reviewis': [], 'reviewy': []},
 'reviewingth': {'reviewingthe': []},
 'reviewjourn': {'reviewjournal': []},
 'reviewl': {'reviewll': [], 'reviewls': []},
 'reviewofth': {'reviewofthe': []},
 'reviewth': {'reviewthe': []},
 'reviewtyp': {'reviewtype': []},
 'reviewwa': {'reviewwas': []},
 'reviezv': {'reviezvs': []},
 'revif': {'revifal': [],
           'revife': ['revifed'],
           'revification': [],
           'revifing': []},
 'revife': ['revifed'],
 'revigna': {'revignas': []},
 'revigni': {'revigny': []},
 'revigor': {'revigorate': ['revigorated'],
             'revigorating': [],
             'revigoration': [],
             'revigorer': []},
 'revigorate': ['revigorated'],
 'revii': {'reviie': ['reviied']},
 'reviie': ['reviied'],
 'revij': {'revije': []},
 'revil': {'revilalization': [],
           'revilation': [],
           'revile': ['reviler',
                      'reviles',
                      'reviled',
                      'revilers',
                      'revileing',
                      'revilement'],
           'reviling': ['revilings'],
           'revill': ['revills', 'reville', 'revilles', 'revilling']},
 'revilcr': {'revilcrs': []},
 'revile': ['reviler',
            'reviles',
            'reviled',
            'revilers',
            'revileing',
            'revilement'],
 'reviling': ['revilings'],
 'revilingli': {'revilingly': []},
 'reviliu': {'revilius': []},
 'reviliug': {'reviliugs': []},
 'revill': ['revills', 'reville', 'revilles', 'revilling'],
 'revilla': {'revillas': []},
 'revillagigedo': {'revillagigedos': []},
 'revillon': {'revillons': []},
 'revimin': {'revimine': []},
 'revin': {'revine': ['revined', 'revines'], 'revins': []},
 'revinc': {'revincent': []},
 'revincti': {'revinctis': []},
 'revinctu': {'revinctus': []},
 'revind': {'revindicate': ['revindicated', 'revindicates'],
            'revindicating': [],
            'revindication': ['revindications'],
            'revindicative': []},
 'revindicacion': {'revindicaciones': []},
 'revindicate': ['revindicated', 'revindicates'],
 'revindication': ['revindications'],
 'revindicatori': {'revindicatory': []},
 'revindr': {'revindrent': []},
 'revine': ['revined', 'revines'],
 'reving': {'revinge': []},
 'revington': {'revingtons': []},
 'revinm': {'revinmes': []},
 'revinr': {'revinrent': []},
 'revint': {'revinter': [], 'revintes': []},
 'revinu': {'revinue': []},
 'reviol': {'reviolate': []},
 'revion': {'revions': []},
 'reviou': {'revious': []},
 'revious': {'reviously': []},
 'reviow': {'reviowed': []},
 'revir': {'reviral': ['reviralization'],
           'revire': ['revired', 'revirement', 'revirements']},
 'reviral': ['reviralization'],
 'revire': ['revired', 'revirement', 'revirements'],
 'reviresc': {'revirescence': []},
 'revirescer': {'revirescere': []},
 'revirgin': {'revirginated': [],
              'revirgination': [],
              'revirginization': [],
              'revirginize': ['revirginized']},
 'revirginize': ['revirginized'],
 'revis': {'revisability': [],
           'revisable': ['revisables'],
           'revisably': [],
           'revisal': [],
           'revisant': [],
           'revise': ['revised', 'reviser', 'reviseing', 'revisement'],
           'revisibility': [],
           'revisible': [],
           'revising': [],
           'revision': ['revisioned', 'revisioning', 'revisionings'],
           'revisive': []},
 'revisa': {'revisas': []},
 'revisable': ['revisables'],
 'revisada': {'revisadas': []},
 'revisado': {'revisados': []},
 'revisal': {'revisall': []},
 'revisamo': {'revisamos': []},
 'revisars': {'revisarse': []},
 'revise': {'revisee': ['revisees']},
 'revisee': ['revisees'],
 'revisen': {'revisens': []},
 'revisentibu': {'revisentibus': []},
 'reviser': {'revisere': []},
 'reviseur': {'reviseurs': []},
 'revisi': {'revisie': [], 'revisiou': [], 'revisis': []},
 'revisingth': {'revisingthe': []},
 'revision': {'revisional': [],
              'revisione': ['revisioner', 'revisiones', 'revisioners'],
              'revisionism': []},
 'revisionar': {'revisionare': []},
 'revisionari': {'revisionaries': [], 'revisionary': []},
 'revisione': ['revisioner', 'revisiones', 'revisioners'],
 'revisioni': {'revisionis': []},
 'revisionism': {'revisionisme': []},
 'revisionismu': {'revisionismus': []},
 'revisionist': ['revisionistic', 'revisionistically'],
 'revisionista': {'revisionistas': []},
 'revisionistisch': {'revisionistische': ['revisionistischer']},
 'revisionistische': ['revisionistischer'],
 'revisionnism': {'revisionnisme': []},
 'revisionnist': {'revisionniste': ['revisionnistes']},
 'revisionniste': ['revisionnistes'],
 'revisionskommiss': {'revisionskommission': []},
 'revisionsrekur': {'revisionsrekurs': []},
 'revisir': {'revisired': []},
 'revisist': {'revisisted': []},
 'revisit': {'revisitable': [],
             'revisitant': ['revisitants'],
             'revisitation': ['revisitations'],
             'revisite': ['revisiter', 'revisites', 'revisited'],
             'revisiting': ['revisitings'],
             'revisits': []},
 'revisita': {'revisitas': []},
 'revisitant': ['revisitants'],
 'revisitation': ['revisitations'],
 'revisite': {'revisitee': []},
 'revisiting': ['revisitings'],
 'revisitor': {'revisitors': []},
 'reviso': {'revisoes': []},
 'revison': {'revisons': []},
 'revisonari': {'revisonary': []},
 'revisonist': {'revisonists': []},
 'revisor': {'revisore': ['revisorer', 'revisores', 'revisorers'],
             'revisors': []},
 'revisore': ['revisorer', 'revisores', 'revisorers'],
 'revisori': {'revisory': []},
 'revist': {'revistal': [],
            'reviste': ['revisted'],
            'revisting': [],
            'revists': []},
 'revista': {'revistas': []},
 'revistad': {'revistade': []},
 'reviste': ['revisted'],
 'revistit': {'revistited': []},
 'revisto': {'revistos': []},
 'revisu': {'revisualization': ['revisualizations'],
            'revisualize': ['revisualized', 'revisualizes'],
            'revisualizing': [],
            'revisus': []},
 'revisualis': {'revisualisation': [],
                'revisualise': ['revisualised'],
                'revisualising': []},
 'revisualise': ['revisualised'],
 'revisualization': ['revisualizations'],
 'revisualize': ['revisualized', 'revisualizes'],
 'revisw': {'reviswed': []},
 'revit': {'revital': ['revitalize',
                       'revitalism',
                       'revitalized',
                       'revitalizer',
                       'revitalizes',
                       'revitalizers',
                       'revitalizing',
                       'revitalization'],
           'revite': ['revited'],
           'revition': [],
           'revitted': []},
 'revitahz': {'revitahzation': []},
 'revitai': {'revitaiization': []},
 'revitail': {'revitaillement': []},
 'revital': ['revitalize',
             'revitalism',
             'revitalized',
             'revitalizer',
             'revitalizes',
             'revitalizers',
             'revitalizing',
             'revitalization'],
 'revitalis': {'revitalisation': [],
               'revitalise': ['revitaliser',
                              'revitalised',
                              'revitalises',
                              'revitalisering'],
               'revitalising': []},
 'revitalise': ['revitaliser', 'revitalised', 'revitalises', 'revitalisering'],
 'revitalist': {'revitalistic': []},
 'revitaliz': {'revitalizating': []},
 'revitallz': {'revitallzation': []},
 'revite': ['revited'],
 'revithiad': {'revithiadou': []},
 'reviti': {'revity': []},
 'revitil': {'revitilization': [], 'revitilize': []},
 'revitt': {'revitte': []},
 'revitzki': {'revitzky': []},
 'reviu': {'reviue': ['reviued'], 'revius': []},
 'reviue': ['reviued'],
 'reviv': {'revivabilities': [],
           'revivability': [],
           'revivable': [],
           'revival': ['revivaling', 'revivalism'],
           'revivant': [],
           'revivations': [],
           'revive': ['revives',
                      'revived',
                      'reviver',
                      'revivers',
                      'revivent',
                      'reviveing',
                      'revivement'],
           'revivication': [],
           'reviving': ['revivings']},
 'revival': {'revivall': []},
 'revivalist': ['revivalistic', 'revivalistically'],
 'revivalmeet': {'revivalmeeting': []},
 'revivalstyl': {'revivalstyle': []},
 'revivaltim': {'revivaltime': []},
 'revive': ['revives',
            'revived',
            'reviver',
            'revivers',
            'revivent',
            'reviveing',
            'revivement'],
 'reviver': {'revivere': []},
 'revivesc': {'revivescence': [], 'revivescent': []},
 'revivi': {'revivial': ['revivials'], 'revivied': []},
 'revivial': ['revivials'],
 'revivif': {'revivification': []},
 'revivifi': {'revivifie': ['revivifier',
                            'revivified',
                            'revivifies',
                            'revivifiers'],
              'revivify': ['revivifying']},
 'revivifie': ['revivifier', 'revivified', 'revivifies', 'revivifiers'],
 'revivify': ['revivifying'],
 'reviving': {'revivinge': []},
 'revivingli': {'revivingly': []},
 'revivisc': {'reviviscant': [],
              'reviviscence': ['reviviscences'],
              'reviviscency': [],
              'reviviscent': []},
 'reviviscen': {'reviviscens': []},
 'reviviscence': ['reviviscences'],
 'reviviscer': {'reviviscere': []},
 'reviviscimu': {'reviviscimus': []},
 'revivor': {'revivors': []},
 'revivr': {'revivre': []},
 'reviw': {'reviwed': [], 'reviwer': ['reviwers'], 'reviws': []},
 'reviwer': ['reviwers'],
 'reviy': {'reviyal': [], 'reviye': ['reviyed']},
 'reviye': ['reviyed'],
 'reviz': {'revize': ['revized'], 'revizing': []},
 'revize': ['revized'],
 'revkom': {'revkoms': []},
 'revl': {'revle': [], 'revls': []},
 'revla': {'revlaed': []},
 'revlat': {'revlation': []},
 'revlew': {'revlewed': [], 'revlews': []},
 'revli': {'revlis': []},
 'revlon': {'revlons': []},
 'revlout': {'revloution': []},
 'revls': {'revlsed': []},
 'revlslon': {'revlslons': []},
 'revlslt': {'revlslted': []},
 'revltal': {'revltalization': []},
 'revlut': {'revlution': []},
 'revlutionari': {'revlutionary': []},
 'revm': {'revme': ['revmed']},
 'revme': ['revmed'],
 'revmu': {'revmus': []},
 'revn': {'revne': ['revnes']},
 'revne': ['revnes'],
 'revnel': {'revnell': []},
 'revnic': {'revnice': []},
 'revnold': {'revnolds': []},
 'revnu': {'revnue': ['revnues']},
 'revnue': ['revnues'],
 'revo': {'revoe': [], 'revos': []},
 'revoak': {'revoake': ['revoaked'], 'revoaking': []},
 'revoake': ['revoaked'],
 'revoal': {'revoaled': [], 'revoals': []},
 'revoc': {'revocability': [],
           'revocable': ['revocables'],
           'revocably': [],
           'revocal': ['revocalize',
                       'revocalizes',
                       'revocalized',
                       'revocalizing',
                       'revocalization'],
           'revocant': [],
           'revocate': ['revocated'],
           'revocation': [],
           'revocative': [],
           'revocent': [],
           'revoces': []},
 'revoca': {'revocas': []},
 'revocabil': {'revocabile': []},
 'revocabimu': {'revocabimus': []},
 'revocable': ['revocables'],
 'revocada': {'revocadas': []},
 'revocal': ['revocalize',
             'revocalizes',
             'revocalized',
             'revocalizing',
             'revocalization'],
 'revocamu': {'revocamus': []},
 'revocan': {'revocans': []},
 'revocanda': {'revocandae': [], 'revocandas': []},
 'revocandi': {'revocandis': []},
 'revocando': {'revocandos': []},
 'revocandu': {'revocandus': []},
 'revocant': {'revocante': ['revocantes']},
 'revocante': ['revocantes'],
 'revocanti': {'revocantis': []},
 'revocar': {'revocare': ['revocarent']},
 'revocare': ['revocarent'],
 'revocaremu': {'revocaremus': []},
 'revocasqu': {'revocasque': []},
 'revocass': {'revocasse': []},
 'revocata': {'revocatae': [], 'revocatas': []},
 'revocate': ['revocated'],
 'revocati': {'revocatis': []},
 'revocation': {'revocatione': ['revocationes']},
 'revocatione': ['revocationes'],
 'revocationi': {'revocationis': []},
 'revocato': {'revocatos': []},
 'revocatori': {'revocatory': []},
 'revocatqu': {'revocatque': []},
 'revocatu': {'revocatus': []},
 'revocaveri': {'revocaveris': []},
 'revocavimu': {'revocavimus': []},
 'revocemu': {'revocemus': []},
 'revoceti': {'revocetis': []},
 'revock': {'revocked': []},
 'revoeat': {'revoeation': []},
 'revofut': {'revofution': []},
 'revohit': {'revohition': ['revohitions']},
 'revohition': ['revohitions'],
 'revohitionari': {'revohitionary': []},
 'revohtt': {'revohttion': []},
 'revohttionari': {'revohttionary': []},
 'revoi': {'revoie': [], 'revois': []},
 'revoic': {'revoice': ['revoiced', 'revoices'], 'revoicing': ['revoicings']},
 'revoice': ['revoiced', 'revoices'],
 'revoicing': ['revoicings'],
 'revoil': {'revoile': []},
 'revoir': {'revoire': [], 'revoirs': []},
 'revoiut': {'revoiution': ['revoiutions']},
 'revoiution': ['revoiutions'],
 'revoiutionari': {'revoiutionary': []},
 'revoiv': {'revoive': [], 'revoiving': []},
 'revojut': {'revojution': []},
 'revok': {'revokable': [],
           'revokation': [],
           'revoke': ['revoker',
                      'revoked',
                      'revokers',
                      'revokeing',
                      'revokement',
                      'revokeable'],
           'revoking': []},
 'revoke': {'revokees': []},
 'revol': {'revolant': [],
           'revolation': ['revolations'],
           'revole': [],
           'revoling': [],
           'revoll': ['revolle'],
           'revols': []},
 'revolar': {'revolare': []},
 'revolatil': {'revolatilization': [], 'revolatilize': ['revolatilized']},
 'revolatilize': ['revolatilized'],
 'revolation': ['revolations'],
 'revolcars': {'revolcarse': []},
 'revoli': {'revolyed': [], 'revolying': []},
 'revolit': {'revolition': []},
 'revoliutsion': {'revoliutsioner': []},
 'revoliutsioneri': {'revoliutsionery': []},
 'revoliutsionno': {'revoliutsionnoe': []},
 'revoliutsionny': {'revoliutsionnye': []},
 'revoll': ['revolle'],
 'revolnt': {'revolntion': ['revolntions']},
 'revolntion': ['revolntions'],
 'revolntionari': {'revolntionary': []},
 'revoloot': {'revolootion': []},
 'revolot': {'revolotion': []},
 'revolotionari': {'revolotionary': []},
 'revolout': {'revoloution': []},
 'revolt': ['revolte',
            'revolter',
            'revoltes',
            'revolted',
            'revoltion',
            'revoltant',
            'revolting',
            'revolters',
            'revoltent',
            'revoltings',
            'revoltants'],
 'revolta': {'revoltas': []},
 'revoltant': {'revoltante': ['revoltantes']},
 'revoltante': ['revoltantes'],
 'revoltcr': {'revoltcrs': []},
 'revolte': {'revoltee': ['revoltees']},
 'revoltee': ['revoltees'],
 'revolter': {'revolterent': []},
 'revolting': {'revoltingness': []},
 'revoltingli': {'revoltingly': []},
 'revoltionari': {'revoltionary': []},
 'revoltoso': {'revoltosos': []},
 'revoltuionari': {'revoltuionary': []},
 'revolu': {'revoluation': [], 'revolue': ['revolues'], 'revolus': []},
 'revolubil': {'revolubile': []},
 'revolubili': {'revolubilis': []},
 'revolubl': {'revoluble': [], 'revolubly': []},
 'revoluc': {'revoluce': []},
 'revolucij': {'revolucije': []},
 'revolucion': {'revoluciones': [], 'revolucions': []},
 'revolucionari': {'revolucionaries': [], 'revolucionary': []},
 'revolucionaria': {'revolucionarias': []},
 'revolucionario': {'revolucionarios': []},
 'revolucionarn': {'revolucionarne': []},
 'revoluco': {'revolucoes': []},
 'revoludonari': {'revoludonary': []},
 'revolue': ['revolues'],
 'revoluiionari': {'revoluiionary': []},
 'revoluion': {'revoluions': []},
 'revoluionari': {'revoluionaries': [], 'revoluionary': []},
 'revolulionari': {'revolulionary': []},
 'revolulionibu': {'revolulionibus': []},
 'revolulut': {'revolulution': ['revolulutions']},
 'revolulution': ['revolulutions'],
 'revolulutionari': {'revolulutionary': []},
 'revolunari': {'revolunary': []},
 'revolunonari': {'revolunonary': []},
 'revolunt': {'revolunteer': []},
 'revoluntari': {'revoluntary': []},
 'revoluntionari': {'revoluntionaries': [], 'revoluntionary': []},
 'revoluonari': {'revoluonary': []},
 'revolurion': {'revolurions': []},
 'revolurionari': {'revolurionary': []},
 'revolurionati': {'revolurionaty': []},
 'revolus': {'revolusion': []},
 'revolusion': {'revolusioner': []},
 'revolusjon': {'revolusjons': []},
 'revolusjonshistori': {'revolusjonshistorie': []},
 'revolut': {'revolute': ['revoluted', 'revolutes', 'revolutely'],
             'revolutic': [],
             'revoluting': [],
             'revolution': ['revolutional',
                            'revolutioned',
                            'revolutioning',
                            'revolutionally']},
 'revolutaqu': {'revolutaque': []},
 'revolute': ['revoluted', 'revolutes', 'revolutely'],
 'revoluti': {'revolutie': ['revoluties'],
              'revolutiou': ['revolutious'],
              'revolutis': []},
 'revolutia': {'revolutiae': []},
 'revolutianari': {'revolutianary': []},
 'revolutie': ['revoluties'],
 'revolutinari': {'revolutinaries': [], 'revolutinary': []},
 'revolutioanri': {'revolutioanry': []},
 'revolutioari': {'revolutioary': []},
 'revolutiombu': {'revolutiombus': []},
 'revolution': {'revolutionalism': [],
                'revolutionalization': [],
                'revolutionalize': ['revolutionalized'],
                'revolutionalizing': [],
                'revolutione': ['revolutiones',
                                'revolutioner',
                                'revolutioners'],
                'revolutionism': [],
                'revolutionization': [],
                'revolutionize': ['revolutionizes',
                                  'revolutionized',
                                  'revolutionizer',
                                  'revolutionizers'],
                'revolutionizing': []},
 'revolutionaer': {'revolutionaere': []},
 'revolutionair': {'revolutionaire': ['revolutionaires']},
 'revolutionaire': ['revolutionaires'],
 'revolutionairi': {'revolutionairies': []},
 'revolutionali': {'revolutionaly': []},
 'revolutionalis': {'revolutionalise': ['revolutionalised'],
                    'revolutionalising': []},
 'revolutionalise': ['revolutionalised'],
 'revolutionalist': {'revolutionalists': []},
 'revolutionalize': ['revolutionalized'],
 'revolutionan': {'revolutionanes': []},
 'revolutionar': {'revolutionare': ['revolutionarer', 'revolutionares'],
                  'revolutionarism': [],
                  'revolutionarize': ['revolutionarized'],
                  'revolutionars': []},
 'revolutionare': ['revolutionarer', 'revolutionares'],
 'revolutionari': {'revolutionarie': [],
                   'revolutionariness': [],
                   'revolutionary': []},
 'revolutionaria': {'revolutionarias': []},
 'revolutionarili': {'revolutionarily': []},
 'revolutionario': {'revolutionarios': []},
 'revolutionaris': {'revolutionarised': []},
 'revolutionarist': {'revolutionarists': []},
 'revolutionarize': ['revolutionarized'],
 'revolutionary': {'revolutionaryism': []},
 'revolutionarydemocrat': {'revolutionarydemocratic': []},
 'revolutionarymilitari': {'revolutionarymilitary': []},
 'revolutionarymind': {'revolutionaryminded': []},
 'revolutionarymov': {'revolutionarymovement': []},
 'revolutionarynapoleon': {'revolutionarynapoleonic': []},
 'revolutionarysound': {'revolutionarysounding': []},
 'revolutionarystruggl': {'revolutionarystruggle': []},
 'revolutionati': {'revolutionaties': [], 'revolutionaty': []},
 'revolutioncount': {'revolutioncounter': []},
 'revolutiondr': {'revolutiondre': ['revolutiondrer'], 'revolutiondrs': []},
 'revolutiondre': ['revolutiondrer'],
 'revolutione': ['revolutiones', 'revolutioner', 'revolutioners'],
 'revolutionen': {'revolutionens': []},
 'revolutionerand': {'revolutionerande': []},
 'revolutioneri': {'revolutioneries': [], 'revolutionery': []},
 'revolutioni': {'revolutionis': [], 'revolutiony': []},
 'revolutionibu': {'revolutionibus': []},
 'revolutionierend': {'revolutionierende': []},
 'revolutionierungsversuch': {'revolutionierungsversuche': []},
 'revolutionihu': {'revolutionihus': []},
 'revolutioniri': {'revolutioniry': []},
 'revolutionis': {'revolutionisation': [],
                  'revolutionise': ['revolutionised',
                                    'revolutionises',
                                    'revolutioniser',
                                    'revolutionisers'],
                  'revolutionising': []},
 'revolutionise': ['revolutionised',
                   'revolutionises',
                   'revolutioniser',
                   'revolutionisers'],
 'revolutionist': ['revolutionistic'],
 'revolutionize': ['revolutionizes',
                   'revolutionized',
                   'revolutionizer',
                   'revolutionizers'],
 'revolutionmak': {'revolutionmakers': [], 'revolutionmaking': []},
 'revolutionn': {'revolutionne': ['revolutionner']},
 'revolutionnair': {'revolutionnaire': ['revolutionnaires',
                                        'revolutionnairement']},
 'revolutionnaire': ['revolutionnaires', 'revolutionnairement'],
 'revolutionnari': {'revolutionnaries': [], 'revolutionnary': []},
 'revolutionne': ['revolutionner'],
 'revolutionori': {'revolutionory': []},
 'revolutionri': {'revolutionries': [], 'revolutionry': []},
 'revolutions': {'revolutionsed': []},
 'revolutionsbrief': {'revolutionsbriefe': []},
 'revolutionsdokument': {'revolutionsdokumente': []},
 'revolutionsgeschicht': {'revolutionsgeschichte': []},
 'revolutionsideal': {'revolutionsideale': []},
 'revolutionsjahr': {'revolutionsjahre': ['revolutionsjahres']},
 'revolutionsjahre': ['revolutionsjahres'],
 'revolutionskrieg': {'revolutionskriege': ['revolutionskrieges']},
 'revolutionskriege': ['revolutionskrieges'],
 'revolutionsp': {'revolutionsper': []},
 'revolutionsperiod': {'revolutionsperiode': []},
 'revolutionst': {'revolutionsts': []},
 'revolutionstheori': {'revolutionstheorie': []},
 'revolutionz': {'revolutionzed': []},
 'revolutiou': ['revolutious'],
 'revolutiouari': {'revolutiouary': []},
 'revolutipnari': {'revolutipnary': []},
 'revolutlon': {'revolutlons': []},
 'revolutlonari': {'revolutlonary': []},
 'revolutonari': {'revolutonary': []},
 'revolutsi': {'revolutsie': []},
 'revolutsy': {'revolutsye': []},
 'revolutu': {'revolutus': []},
 'revoluuonari': {'revoluuonary': []},
 'revoluzion': {'revoluzione': []},
 'revoluzz': {'revoluzzer': []},
 'revolv': {'revolvable': [],
            'revolvant': [],
            'revolvator': [],
            'revolve': ['revolver',
                        'revolved',
                        'revolves',
                        'revolvered',
                        'revolvency',
                        'revolvement',
                        'revolvements'],
            'revolving': ['revolvings']},
 'revolva': {'revolvas': []},
 'revolve': ['revolver',
             'revolved',
             'revolves',
             'revolvered',
             'revolvency',
             'revolvement',
             'revolvements'],
 'revolven': {'revolvens': []},
 'revolvent': {'revolventes': []},
 'revolventi': {'revolventis': []},
 'revolver': {'revolveration': [], 'revolvere': ['revolveres']},
 'revolvere': ['revolveres'],
 'revolvers': {'revolverse': []},
 'revolvershot': {'revolvershots': []},
 'revolvi': {'revolvis': []},
 'revolvimu': {'revolvimus': []},
 'revolving': ['revolvings'],
 'revolvingli': {'revolvingly': []},
 'revolvt': {'revolvtion': []},
 'revoly': {'revolye': ['revolyer', 'revolyes']},
 'revolye': ['revolyer', 'revolyes'],
 'revolyutsion': {'revolyutsioner': []},
 'revolyutsionni': {'revolyutsionny': []},
 'revolyutsionno': {'revolyutsionnoe': []},
 'revomit': {'revomited': []},
 'revon': {'revonal': [], 'revons': []},
 'revong': {'revonge': []},
 'revonu': {'revonue': ['revonues']},
 'revonue': ['revonues'],
 'revoqu': {'revoquant': [], 'revoque': ['revoques', 'revoquer']},
 'revoque': {'revoquee': ['revoquees']},
 'revoquee': ['revoquees'],
 'revor': {'revorence': []},
 'revors': {'revorse': ['revorsed']},
 'revorse': ['revorsed'],
 'revot': {'revote': ['revoted', 'revotes'],
           'revoting': [],
           'revotion': ['revotions']},
 'revote': ['revoted', 'revotes'],
 'revotion': ['revotions'],
 'revotionari': {'revotionary': []},
 'revotski': {'revotskie': []},
 'revottara': {'revottaras': []},
 'revotut': {'revotution': []},
 'revotutionari': {'revotutionary': []},
 'revoult': {'revoultion': []},
 'revoultionari': {'revoultionary': []},
 'revout': {'revoution': ['revoutions']},
 'revoution': ['revoutions'],
 'revoutionari': {'revoutionaries': [], 'revoutionary': []},
 'revov': {'revoved': [], 'revover': ['revovered']},
 'revover': ['revovered'],
 'revoveri': {'revovery': []},
 'revow': {'revowed': []},
 'revoy': {'revoyant': [], 'revoye': []},
 'revoyai': {'revoyais': []},
 'revoyon': {'revoyons': []},
 'revplut': {'revplution': []},
 'revplutionari': {'revplutionary': []},
 'revpow': {'revpower': []},
 'revrenc': {'revrence': []},
 'revrespdi': {'revrespdis': []},
 'revrespirdi': {'revrespirdis': []},
 'revsin': {'revsine': []},
 'revsn': {'revsnes': []},
 'revson': {'revsons': []},
 'revsund': {'revsunds': []},
 'revtal': {'revtaled': []},
 'revtew': {'revtews': []},
 'revti': {'revtie': []},
 'revtnu': {'revtnue': []},
 'revtribun': {'revtribunal': []},
 'revts': {'revtsed': []},
 'revtt': {'revtte': []},
 'revu': {'revue': ['revued'], 'revus': []},
 'revubu': {'revubue': []},
 'revudevil': {'revudeville': []},
 'revue': ['revued'],
 'revued': {'revuede': ['revuedes']},
 'revuede': ['revuedes'],
 'revuefilm': {'revuefilme': []},
 'revuelik': {'revuelike': []},
 'revuelta': {'revueltas': []},
 'revuelto': {'revueltos': []},
 'revueltosauru': {'revueltosaurus': []},
 'revuelv': {'revuelve': []},
 'revuer': {'revuers': []},
 'revulcan': {'revulcanization': [], 'revulcanized': []},
 'revulet': {'revulets': []},
 'revuls': {'revulsant': ['revulsants'],
            'revulse': ['revulsed', 'revulses'],
            'revulsion': [],
            'revulsive': ['revulsives', 'revulsively']},
 'revulsa': {'revulsas': []},
 'revulsant': ['revulsants'],
 'revulse': ['revulsed', 'revulses'],
 'revulsi': {'revulsis': []},
 'revulsionari': {'revulsionary': []},
 'revulsive': ['revulsives', 'revulsively'],
 'revulsu': {'revulsus': []},
 'revult': {'revultion': []},
 'revulut': {'revulution': []},
 'revus': {'revusical': []},
 'revuski': {'revusky': []},
 'revutski': {'revutsky': []},
 'revv': {'revve': []},
 'revvard': {'revvarder': []},
 'revyl': {'revyle': ['revyled'], 'revyling': []},
 'revyle': ['revyled'],
 'revyv': {'revyve': ['revyved']},
 'revyve': ['revyved'],
 'rew': {'rewe': ['rewed', 'rewes', 'reweds'],
         'rewful': ['rewfully'],
         'rewing': [],
         'rews': []},
 'rewa': {'rewas': []},
 'rewaid': {'rewaided': [], 'rewaids': []},
 'rewak': {'rewake': ['rewakes'], 'rewaking': []},
 'rewake': ['rewakes'],
 'rewaken': {'rewakened': [], 'rewakening': [], 'rewakens': []},
 'rewal': {'rewall': ['rewalled']},
 'rewalk': {'rewalked': [], 'rewalking': [], 'rewalks': []},
 'rewall': ['rewalled'],
 'rewallpap': {'rewallpapered': [], 'rewallpapering': []},
 'rewan': {'rewane': [], 'rewans': []},
 'rewar': {'reware': ['rewared']},
 'reward': ['rewarde',
            'rewarded',
            'rewardes',
            'rewarder',
            'rewarders',
            'rewarding',
            'rewardful',
            'rewardable',
            'rewardings',
            'rewardability',
            'rewardableness'],
 'rewardbas': {'rewardbased': []},
 'rewarde': {'rewardee': ['rewardees']},
 'rewardee': ['rewardees'],
 'rewardi': {'rewardis': []},
 'rewarding': {'rewardingness': []},
 'rewardingli': {'rewardingly': []},
 'rewardori': {'rewardoriented': []},
 'rewardpenalti': {'rewardpenalty': []},
 'rewardpunish': {'rewardpunishment': []},
 'rewardrel': {'rewardrelated': []},
 'rewardrelev': {'rewardrelevant': []},
 'rewardseek': {'rewardseeking': []},
 'reware': {'rewaree': []},
 'rewareh': {'rewarehoused': [], 'rewarehousing': []},
 'rewarehous': {'rewarehouse': []},
 'rewarm': {'rewarmed': [], 'rewarming': [], 'rewarms': []},
 'rewarn': {'rewarned': []},
 'rewarp': {'rewarping': []},
 'rewarre': {'rewarree': []},
 'rewash': {'rewashed': [],
            'rewashering': [],
            'rewashes': [],
            'rewashing': ['rewashings']},
 'rewashing': ['rewashings'],
 'rewat': {'rewater': ['rewatered', 'rewatering']},
 'rewatch': {'rewatched': [], 'rewatching': []},
 'rewatd': {'rewatded': [], 'rewatding': [], 'rewatds': []},
 'rewater': ['rewatered', 'rewatering'],
 'rewbel': {'rewbell': []},
 'rewbridg': {'rewbridge': []},
 'rewcastl': {'rewcastle': []},
 'rewclin': {'rewcline': []},
 'rewd': {'rewde': []},
 'rewe': ['rewed', 'rewes', 'reweds'],
 'rewear': {'rewearing': []},
 'reweav': {'reweave': ['reweaved', 'reweaver', 'reweaves', 'reweavers'],
            'reweaving': ['reweavings']},
 'reweave': ['reweaved', 'reweaver', 'reweaves', 'reweavers'],
 'reweaving': ['reweavings'],
 'reweavingth': {'reweavingthe': []},
 'reweb': {'rewebbed': [], 'rewebbing': []},
 'rewed': {'rewedded': [], 'rewedding': []},
 'rewedg': {'rewedged': []},
 'reweigh': {'reweighed': [], 'reweighing': ['reweighings'], 'reweighs': []},
 'reweighing': ['reweighings'],
 'reweight': {'reweighted': [],
              'reweighting': ['reweightings'],
              'reweights': []},
 'reweighting': ['reweightings'],
 'rewel': {'reweled': [], 'rewell': []},
 'rewelcom': {'rewelcomed': [], 'rewelcoming': []},
 'reweld': {'rewelded': [], 'rewelding': []},
 'reweliotti': {'reweliotty': []},
 'reweng': {'rewenge': []},
 'rewer': {'rewere': [], 'rewers': []},
 'rewers': {'rewerse': []},
 'rewert': {'rewerts': []},
 'rewet': {'rewets': [], 'rewetted': [], 'rewetting': []},
 'rewett': {'rewettable': []},
 'rewful': {'rewfull': []},
 'rewher': {'rewhere': []},
 'rewhip': {'rewhipped': []},
 'rewhisp': {'rewhispered': []},
 'rewhiten': {'rewhitened': [], 'rewhitening': []},
 'rewhitewash': {'rewhitewashed': []},
 'rewi': {'rewie': [], 'rewis': [], 'rewy': []},
 'rewiden': {'rewidened': [], 'rewidening': []},
 'rewiev': {'rewieved': [], 'rewievs': []},
 'rewiew': {'rewiewed': [], 'rewiews': []},
 'rewil': {'rewill': []},
 'rewild': {'rewilding': []},
 'rewin': {'rewinning': [], 'rewins': []},
 'rewind': {'rewindable': [],
            'rewinded': [],
            'rewinder': ['rewinders'],
            'rewinding': ['rewindings'],
            'rewinds': []},
 'rewinder': ['rewinders'],
 'rewinding': ['rewindings'],
 'rewindow': {'rewindowed': []},
 'rewing': {'rewinging': []},
 'rewinnow': {'rewinnowed': []},
 'rewip': {'rewipe': ['rewiped'], 'rewiping': []},
 'rewipe': ['rewiped'],
 'rewir': {'rewirable': [],
           'rewire': ['rewires', 'rewired', 'rewireable'],
           'rewiring': ['rewirings']},
 'rewire': ['rewires', 'rewired', 'rewireable'],
 'rewiring': ['rewirings'],
 'rewit': {'rewite': [], 'rewitness': ['rewitnessed', 'rewitnessing']},
 'rewitness': ['rewitnessed', 'rewitnessing'],
 'rewitz': {'rewitzer': []},
 'rewiv': {'rewive': ['rewived', 'rewives']},
 'rewive': ['rewived', 'rewives'],
 'rewl': {'rewle': ['rewled', 'rewles'], 'rewling': []},
 'rewlari': {'rewlaris': []},
 'rewle': ['rewled', 'rewles'],
 'rewler': {'rewlers': []},
 'rewli': {'rewlis': [], 'rewly': []},
 'rewlut': {'rewlution': []},
 'rewlutionari': {'rewlutionary': []},
 'rewm': {'rewme': ['rewmes']},
 'rewme': ['rewmes'],
 'rewn': {'rewne': ['rewned'], 'rewning': []},
 'rewne': ['rewned'],
 'rewnement': {'rewnements': []},
 'rewnt': {'rewnte': [], 'rewnting': []},
 'rewok': {'rewoke': []},
 'rewolucyjni': {'rewolucyjny': []},
 'rewolv': {'rewolve': []},
 'rewolw': {'rewolwer': ['rewolwers']},
 'rewolwer': ['rewolwers'],
 'rewood': {'rewooded': [], 'rewooding': []},
 'reword': {'reworded': [], 'rewording': [], 'rewords': []},
 'rework': {'reworkability': [],
            'reworkable': [],
            'reworked': [],
            'reworker': ['reworkers'],
            'reworking': ['reworkings'],
            'reworks': []},
 'reworker': ['reworkers'],
 'reworking': ['reworkings'],
 'reworld': {'reworlding': []},
 'rewound': {'rewounded': [], 'rewounding': []},
 'rewov': {'rewove': []},
 'rewrap': {'rewrapped': [], 'rewrapping': [], 'rewraps': []},
 'rewrit': {'rewritability': [],
            'rewritable': ['rewritables'],
            'rewrite': ['rewriter', 'rewrited', 'rewriteable'],
            'rewriting': [],
            'rewritting': []},
 'rewritable': ['rewritables'],
 'rewrite': ['rewriter', 'rewrited', 'rewriteable'],
 'rewritebas': {'rewritebase': []},
 'rewriteengin': {'rewriteengine': []},
 'rewriterul': {'rewriterule': []},
 'rewritingth': {'rewritingthe': []},
 'rewrot': {'rewrote': []},
 'rewrv': {'rewrved': []},
 'rews': {'rewse': []},
 'rewth': {'rewthe': []},
 'rewtit': {'rewtite': [], 'rewtiting': []},
 'rewyl': {'rewyll': []},
 'rey': {'reye': ['reyed', 'reyes'], 'reying': [], 'reys': []},
 'reya': {'reyas': []},
 'reyal': {'reyals': []},
 'reyard': {'reyarded': []},
 'reybekil': {'reybekill': []},
 'reybel': {'reybell': []},
 'reybert': {'reyberts': []},
 'reybin': {'reybine': []},
 'reybold': {'reybolds': []},
 'reyc': {'reyce': []},
 'reycend': {'reycends': []},
 'reycl': {'reycling': []},
 'reycoquai': {'reycoquais': []},
 'reyd': {'reyde': []},
 'reydam': {'reydams': []},
 'reydebov': {'reydebove': []},
 'reye': ['reyed', 'reyes'],
 "reye'": {"reye's": []},
 'reyeal': {'reyealed': [], 'reyealing': [], 'reyeals': []},
 'reyear': {'reyears': []},
 'reyel': {'reyelation': ['reyelations'], 'reyell': []},
 'reyelation': ['reyelations'],
 'reyelik': {'reyelike': []},
 'reyeng': {'reyenge': []},
 'reyenu': {'reyenue': ['reyenues']},
 'reyenue': ['reyenues'],
 'reyer': {'reyerence': [], 'reyers': []},
 'reyero': {'reyeros': []},
 'reyers': {'reyerse': ['reyersed']},
 'reyerse': ['reyersed'],
 'reyes': {'reyes': []},
 'reyezuelo': {'reyezuelos': []},
 'reygada': {'reygadas': []},
 'reygass': {'reygasse': []},
 'reygat': {'reygate': []},
 'reyger': {'reygers': []},
 'reygn': {'reygne': ['reygned']},
 'reygne': ['reygned'],
 'reyhold': {'reyholds': []},
 'reyi': {'reyis': [], 'reyy': []},
 'reyiew': {'reyiewed': [], 'reyiews': []},
 'reyim': {'reyime': []},
 'reyis': {'reyised': [], 'reyision': []},
 'reyist': {'reyister': [], 'reyists': []},
 'reyista': {'reyistas': []},
 'reyiv': {'reyival': [], 'reyive': ['reyived']},
 'reyive': ['reyived'],
 'reykia': {'reykianess': []},
 'reykian': {'reykianes': []},
 'reykiana': {'reykianas': []},
 'reykja': {'reykjaness': []},
 'reykjad': {'reykjadal': []},
 'reykjan': {'reykjanes': []},
 'reykjav': {'reykjavic': []},
 'reyl': {'reyle': ['reyles'], 'reyling': []},
 'reyland': {'reylander': []},
 'reyle': ['reyles'],
 'reyli': {'reyly': []},
 'reym': {'reyme': ['reymes']},
 'reymbout': {'reymbouts': []},
 'reyme': ['reymes'],
 'reymer': {'reymers': []},
 'reymershoff': {'reymershoffer': []},
 'reymerswael': {'reymerswaele': []},
 'reymerswal': {'reymerswale': []},
 'reymold': {'reymolds': []},
 'reymond': {'reymonds': []},
 'reymor': {'reymore': []},
 'reymundu': {'reymundus': []},
 'reyn': {'reyne': ['reyned', 'reynes'], 'reyns': []},
 'reyna': {'reynas': []},
 'reynaer': {'reynaers': []},
 'reynaerd': {'reynaerde': []},
 'reynaert': {'reynaerts': []},
 'reynafarj': {'reynafarje': []},
 'reynal': {'reynale': ['reynales'], 'reynall': [], 'reynals': []},
 'reynald': {'reynalde': [], 'reynalds': []},
 'reynaldo': {'reynaldos': []},
 'reynaldu': {'reynaldus': []},
 'reynale': ['reynales'],
 'reynant': {'reynante': []},
 'reynard': ['reynarde'],
 'reynardin': {'reynardine': []},
 'reynardson': {'reynardsons': []},
 'reynardu': {'reynardus': []},
 'reynaud': {'reynauds': []},
 'reynder': {'reynders': []},
 'reyne': ['reyned', 'reynes'],
 'reyneck': {'reynecke': []},
 'reynek': {'reyneke': []},
 'reynel': {'reynell': ['reynells'], 'reynels': []},
 'reynell': ['reynells'],
 'reyner': {'reyners': []},
 'reyneri': {'reynerie': []},
 'reyneriu': {'reynerius': []},
 'reyneru': {'reynerus': []},
 'reynett': {'reynette': []},
 'reynev': {'reyneval': []},
 'reyneyng': {'reyneynge': []},
 'reyngld': {'reynglds': []},
 'reyni': {'reynie': ['reynies'], 'reyniness': [], 'reynis': [], 'reyny': []},
 'reynie': ['reynies'],
 'reynier': {'reyniere': [], 'reyniers': []},
 'reyniers': {'reynierse': []},
 'reynin': {'reynines': []},
 'reynk': {'reynke': []},
 'reynnel': {'reynnells': []},
 'reyno': {'reynos': []},
 'reynod': {'reynods': []},
 'reynoid': {'reynoids': []},
 'reynol': {'reynolls': [], 'reynols': []},
 'reynold': {'reynolde': ['reynoldes'], 'reynolds': []},
 'reynolde': ['reynoldes'],
 'reynolds': {'reynolds': []},
 'reynoldsaverag': {'reynoldsaveraged': []},
 'reynoldsdal': {'reynoldsdale': []},
 'reynoldsnumb': {'reynoldsnumber': []},
 'reynoldsstephen': {'reynoldsstephens': []},
 'reynoldsvil': {'reynoldsville': []},
 'reynoldu': {'reynoldus': []},
 'reynolo': {'reynolos': []},
 'reynoso': {'reynosos': []},
 'reynotd': {'reynotds': []},
 'reynou': {'reynous': []},
 'reyntien': {'reyntiens': []},
 'reyntj': {'reyntjes': []},
 'reyntjen': {'reyntjens': []},
 'reynwel': {'reynwell': []},
 'reynyng': {'reynynge': []},
 'reyo': {'reyos': []},
 'reyok': {'reyoke': ['reyoked']},
 'reyoke': ['reyoked'],
 'reyold': {'reyolds': []},
 'reyolut': {'reyolution': ['reyolutions']},
 'reyolution': ['reyolutions'],
 'reyolutionari': {'reyolutionary': []},
 'reyom': {'reyome': []},
 'reyond': {'reyonds': []},
 'reyonld': {'reyonlds': []},
 'reyonold': {'reyonolds': []},
 'reypen': {'reypens': []},
 'reyr': {'reyre': []},
 'reyrol': {'reyrolle': ['reyrolles']},
 'reyrolle': ['reyrolles'],
 'reys': {'reyse': ['reysed'], 'reysing': []},
 'reyse': ['reysed'],
 'reyshe': {'reyshees': []},
 'reyson': {'reysons': []},
 'reyssi': {'reyssie': []},
 'reyssous': {'reyssouse': []},
 'reyssouz': {'reyssouze': []},
 'reyt': {'reytes': []},
 'reyu': {'reyue': []},
 'reyuno': {'reyunos': []},
 'reyuold': {'reyuolds': []},
 'reyv': {'reyve': []},
 'reyz': {'reyze': []},
 'reyzel': {'reyzele': []},
 'reza': {'rezas': []},
 'rezab': {'rezabal': []},
 'rezada': {'rezadas': []},
 'rezadeira': {'rezadeiras': []},
 'rezador': {'rezadores': []},
 'rezadora': {'rezadoras': []},
 'rezae': {'rezaee': []},
 'rezagado': {'rezagados': []},
 'rezago': {'rezagos': []},
 'rezai': {'rezaie': [], 'rezais': []},
 'rezamo': {'rezamos': []},
 'rezandero': {'rezanderos': []},
 'rezd': {'rezde': []},
 'reze': {'rezed': [], 'rezes': []},
 'rezekn': {'rezekne': ['rezeknes']},
 'rezekne': ['rezeknes'],
 'rezen': {'rezene': []},
 'rezend': {'rezende': ['rezendes']},
 'rezende': ['rezendes'],
 'rezens': {'rezensent': [], 'rezension': []},
 'rezensiert': {'rezensierte': []},
 'rezent': {'rezente': ['rezentes', 'rezenter']},
 'rezente': ['rezentes', 'rezenter'],
 'rezept': {'rezepte': [], 'rezeption': ['rezeptions'], 'rezeptive': []},
 'rezeption': ['rezeptions'],
 'rezeptionsgeschicht': {'rezeptionsgeschichte': []},
 'rezeptionsgeschichtlich': {'rezeptionsgeschichtliche': []},
 'rezeptionssitu': {'rezeptionssituation': []},
 'rezeptionstheori': {'rezeptionstheorie': []},
 'rezeptionsvorgab': {'rezeptionsvorgabe': []},
 'rezeptiv': {'rezeptiver': []},
 'rezeptor': {'rezeptors': []},
 'rezero': {'rezeroed': [], 'rezeroing': []},
 'rezerv': {'rezerve': []},
 'rezervi': {'rezervy': []},
 'rezerwi': {'rezerwy': []},
 'rezess': {'rezesse': [], 'rezession': [], 'rezessive': []},
 'rezessiv': {'rezessiver': []},
 'rezet': {'rezets': []},
 'rezett': {'rezette': []},
 'rezh': {'rezhe': []},
 'rezhim': {'rezhime': []},
 'rezhimi': {'rezhimy': []},
 'rezhiss': {'rezhisser': []},
 'rezhisserski': {'rezhisserskie': []},
 'rezi': {'rezy': []},
 'rezid': {'rezident': ['rezidents'], 'rezidive': []},
 'rezident': ['rezidents'],
 'rezidentura': {'rezidenturas': []},
 'rezidiv': {'rezidivs': []},
 'rezidivierend': {'rezidivierende': ['rezidivierender']},
 'rezidivierende': ['rezidivierender'],
 'rezillo': {'rezillos': []},
 'rezim': {'rezime': []},
 'rezin': {'rezine': []},
 'rezip': {'rezipped': [], 'rezipping': []},
 'rezipa': {'rezipas': []},
 'rezipi': {'rezipient': []},
 'rezipiert': {'rezipierte': []},
 'reziprok': {'reziproke': ['reziproker']},
 'reziproke': ['reziproker'],
 'rezist': {'rezistal': []},
 'rezit': {'rezitation': [], 'rezitative': [], 'rezits': []},
 'rezitativ': {'rezitativs': []},
 'rezitiert': {'rezitierte': []},
 'reziu': {'rezius': []},
 'rezium': {'reziume': []},
 'rezk': {'rezke': []},
 'rezki': {'rezkie': []},
 'rezko': {'rezkoe': []},
 'rezmov': {'rezmovic': []},
 'rezni': {'rezny': []},
 'reznikoff': {'reznikoffs': []},
 'reznitski': {'reznitsky': []},
 'rezo': {'rezos': []},
 'rezolucj': {'rezolucje': []},
 'rezon': {'rezone': ['rezones', 'rezoned'],
           'rezoning': ['rezonings'],
           'rezons': []},
 'rezonan': {'rezonans': []},
 'rezone': ['rezones', 'rezoned'],
 'rezoning': ['rezonings'],
 'rezonvil': {'rezonville': []},
 'rezsk': {'rezske': []},
 'rezso': {'rezsoe': []},
 'rezsohazi': {'rezsohazy': []},
 'rezu': {'rezus': []},
 'rezuk': {'rezuke': []},
 'rezult': {'rezultate': [], 'rezults': []},
 'rezultaci': {'rezultacie': []},
 'rezultatel': {'rezultatele': []},
 'rezultati': {'rezultaty': []},
 'rezz': {'rezzed': [], 'rezzing': []},
 'rezzonico': {'rezzonicos': []},
 'rezzou': {'rezzous': []}}
